//
// C++ Interface: c6invitedialog
//
// Description:
//
//
// Author: Giorgio A. <openc6@hotmail.com>, (C) 2005
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef C6INVITEDIALOG_H
#define C6INVITEDIALOG_H

class QWidget;

#include <invite.h>
#include <qstring.h>

/**
@author Giorgio A.
*/
class C6InviteDialog : public Invite
{
    Q_OBJECT
public:
    C6InviteDialog(QWidget *parent = 0);
    ~C6InviteDialog();
    
private:
    void setCustomFont();
    void fillUserList();
private slots:
    void closeInvite();
    void sendInvite();
    void aboutClicked();   
    
signals:
    void sendSelected(const QStringList &,const QString&);
    void showAbout();    
};

#endif
