//
// C++ Interface:  c6logger.h
//
// Description: 
//
//
// Author: Giorgio A. <openc6@hotmail.com>, (C) 2005
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef C6LOGGER_H
#define C6LOGGER_H

#include <c6singleton.h>
#include <qstring.h>

/**
@author Giorgio A.
*/
class C6Logger : public C6Singleton<C6Logger>
{
public:
    friend class C6Singleton<C6Logger>;       
    C6Logger();
    ~C6Logger();
    
    void debugPrint(const char *who,const char *msg,...);
    void logChatOnFile(QString const & nick,QString const & from, QString const & message);
    void logRoomOnFile(QString & room,QString & message);
    void logSystemMessage(QString const & message);
        
private:
  QString _homeDirPath;
};

#endif
