//
// C++ Interface: c6chatfontdialog
//
// Description: 
//
//
// Author: Giorgio A. <openc6@hotmail.com>, (C) 2006
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef C6CHATFONTDIALOG_H
#define C6CHATFONTDIALOG_H

#include <font.h>
#include <qstring.h>
/**
@author Giorgio A.
*/
class C6ChatFontDialog : public Font
{
Q_OBJECT
public:
    C6ChatFontDialog(int &fontNo,int &fontSizeNo);

    ~C6ChatFontDialog();
    void setPreview(QString const &font,int size);

private slots:
    void fontSelectionChanged(int sel);
    void fontSizeSelectionChanged(QListBoxItem *);
    void okButtonPressed();
    void cancelButtonPressed();
private:
    int* _pFontNo;    
    int* _pFontSize;    
           
};

#endif
