/****************************************************************************
** Form interface generated from reading ui file './login_dlg.ui'
**
** Created: Sun Dec 17 12:38:45 2006
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef LOGIN_DLG_H
#define LOGIN_DLG_H

#include <qvariant.h>
#include <qpixmap.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QFrame;
class QLabel;
class QLineEdit;
class QComboBox;
class QCheckBox;

class Login_Dlg : public QWidget
{
    Q_OBJECT

public:
    Login_Dlg( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~Login_Dlg();

    QFrame* frame5;
    QLabel* configButtonPlaceHolder;
    QLabel* pixmapLabel1;
    QLabel* textLabel1;
    QFrame* frame6_2;
    QLabel* exitButtonPlaceHolder;
    QLabel* aboutButtonPlaceHolder;
    QLabel* textLabel1_2;
    QFrame* frame20;
    QFrame* frame5_2;
    QLabel* pixmapLabel3;
    QLabel* pixmapLabel4;
    QFrame* loginFrame;
    QLabel* passwordLabel;
    QLabel* userLabel;
    QLineEdit* Password;
    QComboBox* nickName;
    QCheckBox* SavePwdChk;
    QLabel* savePasswordLabel;

protected:
    QGridLayout* Login_DlgLayout;
    QGridLayout* frame5Layout;
    QSpacerItem* spacer5;
    QVBoxLayout* layout8;
    QSpacerItem* spacer13;
    QVBoxLayout* layout9;
    QSpacerItem* spacer14;
    QGridLayout* frame6_2Layout;
    QSpacerItem* spacer5_2;
    QVBoxLayout* layout4;
    QSpacerItem* spacer7;
    QVBoxLayout* layout6;
    QSpacerItem* spacer8_2;
    QGridLayout* frame5_2Layout;
    QSpacerItem* spacer11;
    QSpacerItem* spacer39;
    QSpacerItem* spacer40;
    QSpacerItem* spacer9_2;
    QSpacerItem* spacer9;

protected slots:
    virtual void languageChange();

private:
    QPixmap image0;
    QPixmap image1;
    QPixmap image2;
    QPixmap image3;
    QPixmap image4;
    QPixmap image5;
    QPixmap image6;
    QPixmap image7;
    QPixmap image8;
    QPixmap image9;
    QPixmap image10;

};

#endif // LOGIN_DLG_H
