//
// C++ Interface: c6chatfactory
//
// Description: 
//
//
// Author: Giorgio A. <openc6@hotmail.com>, (C) 2005
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef C6CHATFACTORY_H
#define C6CHATFACTORY_H

class QWidget;

/**
@author Giorgio A.
*/
class C6ChatFactory
{
public:
    
   enum ChatType
   {
        PRIVATE,
        ROOM    
   };           
    
   static QWidget *getChat(ChatType type);
};

#endif
