
/****************************************************************************
** Form implementation generated from reading ui file './mainDlg.ui'
**
** Created: Tue Jan 9 23:19:18 2007
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#include "mainDlg.h"

#include <qvariant.h>
#include <qpushbutton.h>
#include <qframe.h>
#include <qlabel.h>
#include <qcombobox.h>
#include <qheader.h>
#include <qlistview.h>
#include <qlineedit.h>
#include <qtextedit.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qimage.h>
#include <qpixmap.h>

static const char* const img0_mainDlg[] = { 
"23 32 6 1",
"d c #00468b",
"c c #004990",
"# c #004991",
"a c #004a91",
"b c #004a92",
". c #ffffff",
".......................",
".......................",
".......................",
".......................",
".......................",
".......................",
".......................",
".......................",
"#######################",
"#######################",
"#######################",
"##############a########",
"#######################",
"#######################",
"#######################",
"#######################",
"#######################",
"#######b############a##",
"#######################",
"#######################",
"#######################",
"#######################",
"#######################",
"#######################",
"#######################",
"#######################",
"#######################",
"#######################",
"#######################",
"#######################",
"######################c",
"######################d"};

static const char* const img1_mainDlg[] = { 
"72 16 110 2",
"#j c #00080f",
".W c #000d1a",
".t c #001122",
".8 c #001223",
".o c #001224",
".n c #001325",
"#D c #001326",
".E c #001327",
".N c #001427",
".m c #001428",
".2 c #00152a",
".l c #001932",
".s c #001933",
"#i c #001f3e",
".k c #001f3f",
"#y c #002142",
".D c #002345",
".r c #00254a",
"#o c #00264a",
".M c #00264c",
".j c #00284e",
".1 c #002b56",
"#r c #003161",
".i c #003162",
".V c #003264",
".q c #003365",
".f c #00376d",
".e c #00386f",
".h c #003a72",
".L c #003a73",
".d c #003a74",
".c c #003d7a",
"#x c #003e7a",
".p c #003e7c",
".C c #00407e",
".g c #004080",
".U c #004181",
".b c #004182",
".K c #004589",
".a c #00468b",
"#h c #00478c",
".B c #00478d",
".T c #00488f",
".J c #004890",
".# c #004990",
"Qt c #004991",
"#c c #020509",
".3 c #020a11",
".9 c #070a0d",
".O c #09121a",
"#s c #0d0e11",
".F c #0e1620",
"#A c #111111",
"#e c #121212",
".6 c #131313",
"#E c #131416",
".u c #18212a",
"#R c #191919",
"#Q c #1c1c1c",
"#P c #222222",
"#I c #2e2e2e",
"#O c #383838",
"#p c #3e3f41",
".X c #404244",
"#J c #4c4c4c",
"#N c #575757",
".v c #5d6064",
"#M c #5e5e5e",
".P c #606162",
".G c #656769",
"#z c #666666",
"#k c #686868",
".4 c #6c6d6e",
"#H c #757575",
"#C c #777777",
"#w c #7a7a7a",
"#L c #7e7e7e",
"#q c #7f7f7f",
"#d c #828282",
"#. c #848484",
".w c #858687",
"#n c #868686",
"#K c #8d8d8d",
"#g c #8e8e8e",
"#b c #979797",
"#G c #9c9c9c",
"#B c #9e9e9e",
"#v c #a1a1a1",
".x c #a2a2a2",
".H c #a5a5a5",
"#t c #a6a6a6",
"#m c #aaaaaa",
"#F c #ababab",
".0 c #aeaeae",
"#f c #afafaf",
".Y c #b1b1b1",
"#u c #b3b3b3",
"#a c #b6b6b6",
"#l c #b9b9b9",
".S c #bababa",
".7 c #bbbbbb",
".Q c #bdbdbd",
"## c #bebebe",
".5 c #c0c0c0",
".Z c #c1c1c1",
".I c #c3c3c3",
".R c #c6c6c6",
".y c #c8c8c8",
".A c #c9c9c9",
".z c #cacaca",
"QtQtQtQtQtQtQtQtQtQtQtQtQt.#.a.b.c.d.e.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f",
"QtQtQtQtQtQtQtQtQtQt.#.a.g.h.i.j.k.l.m.n.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o.o",
"QtQtQtQtQtQtQtQt.#.a.p.q.r.s.t.u.v.w.x.y.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.z.A",
"QtQtQtQtQtQtQt.B.C.q.D.E.F.G.H.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.y.I",
"QtQtQtQtQt.J.K.L.M.N.O.P.Q.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.S",
"QtQtQtQt.T.U.V.k.W.X.Y.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.Z.0",
"QtQtQt.T.C.1.2.3.4.5.5.5.5.5.5.6.6.6.6.6.5.5.5.6.6.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.5.6.6.5.5.6.6.5.5.6.6.7.x",
"QtQt.J.U.1.8.9#.##############.6.6####.6.6##############################################################################.6.6####.6.6#########a#b",
"QtQt.K.V.2#c#d.7.7.7.7.7.7.7.7#e#e.7.7.7#e#e.7#e#e.7.7#e#e#e.7.7#e#e#e.7.7#e#e#e.7.7#e#e#e#e.7.7#e#e#e#e.7.7.7#e#e#e.7.7#e#e#e.7#e#e#e.7#e#e#f#g",
"Qt#h.L#i#j#k#l#l#l#l#l#l#l#l#l#e#e#l#l#l#e#e#l#e#e#l#e#e#l#l#l#e#e#l#l#l#e#e#l#e#e#l#e#e#l#e#e#l#e#e#l#e#e#l#e#e#l#e#e#l#e#e#l#l#e#e#l#l#e#e#m#n",
".J.p#o.W#p#a#a#a#a#a#a#a#a#a#a#e#e#a#a#a#e#e#a#e#e#a#a#e#e#a#a#e#e#a#a#a#e#e#a#e#e#a#e#e#a#e#e#a#e#e#a#e#e#a#e#e#e#e#e#a#e#e#a#a#e#e#a#a#e#e.H#q",
".K#r.n#s#t#u#u#u#u#u#u#u#u#u#u#e#e#u#u#e#e#u#u#e#e#u#u#u#e#e#u#e#e#u#u#u#e#e#u#e#e#u#e#e#u#e#e#u#e#e#u#e#e#u#e#e#u#u#u#u#e#e#u#u#e#e#u#u#e#e#v#w",
"#x#y#j#z.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y#A#A#A#A#A.Y.Y.Y#A#A.Y#A#A#A.Y.Y.Y#A#A#A.Y.Y#A#A#A.Y.Y#A#A.Y#A#A.Y#A#A.Y#A#A.Y.Y#A#A#A#A.Y.Y#A#A.Y.Y#A#A.Y#A#A#B#C",
".V#D#E#F#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#f#G#H",
"#d#I#J#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#L#M",
"#N#O#P#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#R.6"};

static const char* const img2_mainDlg[] = { 
"33 32 352 2",
"bB c #000305",
"bA c #00060d",
"#T c #000810",
"#I c #000a14",
"aR c #000b15",
"bz c #000c17",
"a7 c #000d1a",
"bn c #000e1c",
"#4 c #000f1f",
"#S c #001123",
"ai c #001223",
"#H c #00152a",
"az c #00152b",
"aQ c #001931",
"bm c #001c38",
"a6 c #001d3b",
"#R c #001f3d",
"#G c #002346",
"ah c #002347",
"ay c #00274d",
"bl c #002a54",
"aP c #002b55",
"#Q c #002f5d",
"#F c #003161",
"#3 c #003162",
"bk c #003366",
"ag c #003569",
"bj c #00376c",
"ax c #00386f",
"aO c #003c76",
"#E c #003d79",
"#2 c #003f7e",
"a5 c #00407f",
"af c #004282",
"aw c #004385",
"#D c #004588",
"aN c #00458a",
"#P c #00468a",
"#1 c #00478c",
"ae c #00478e",
"#C c #00488f",
"#O c #004990",
"#B c #004991",
"aj c #01070d",
"#5 c #02080e",
"dD c #030303",
"bo c #070c10",
"dC c #090909",
"dA c #101010",
"dy c #141414",
"dw c #151515",
"dr c #161616",
"dk c #1a1a1a",
"b1 c #1b1b1b",
"cH c #1c1c1c",
"a8 c #1c2022",
"cq c #1e1e1e",
"dc c #1f1f1f",
"#. c #202020",
"#J c #212121",
"#l c #222222",
"#L c #25272a",
".1 c #262626",
".0 c #272727",
".2 c #292929",
".9 c #2a2a2a",
".Z c #2b2b2b",
"#m c #2c2c2c",
".3 c #2e2e2e",
"dz c #2f2f2f",
".Y c #303030",
".4 c #343434",
"#z c #353535",
".X c #363636",
"#t c #373737",
"#k c #393939",
"cG c #3a3a3a",
"dx c #3b3b3b",
"dv c #3c3c3c",
"aS c #3c3f41",
"bt c #3c93e9",
"cT c #3d3d3d",
".W c #3e3e3e",
"dq c #3f3f3f",
".8 c #404040",
"## c #454545",
"#U c #454749",
".V c #474747",
"bT c #4799ea",
"cp c #4c4c4c",
"#n c #4d4d4d",
"db c #4e4e4e",
"bC c #4f4f4f",
"b# c #53a0eb",
"aA c #545557",
"b9 c #54a0ea",
".U c #555555",
"#6 c #565758",
"#s c #585858",
".7 c #5a5a5a",
"ak c #5d5e5e",
"cr c #5e5e5e",
".K c #636363",
".L c #646464",
"c3 c #647776",
".J c #656565",
"#K c #666666",
".M c #686868",
"c6 c #696969",
".I c #6a6a6a",
"#a c #6b6b6b",
"at c #6b9dc3",
"bc c #6caeec",
".N c #6f6f6f",
"cY c #6fa9c9",
"df c #708c8a",
".H c #727272",
"cF c #737373",
"dm c #749898",
"cm c #75aece",
"b3 c #77a7cd",
"bI c #77b4ec",
".O c #787878",
"da c #789999",
"bb c #78b4ec",
"#j c #7a7a7a",
"ap c #7aa3c5",
"c8 c #7ab0cc",
"#u c #7b7b7b",
"aC c #7bb0cb",
".G c #7c7c7c",
"d# c #7e7e7f",
"aU c #7eb3ca",
"#r c #808080",
"dg c #818280",
"b. c #81a5c8",
"as c #81a9d0",
"aY c #82baef",
"#A c #838383",
"dn c #839797",
"bF c #83b6cd",
"cD c #83bbd0",
"co c #858585",
".T c #868686",
"cd c #86bad0",
".F c #888888",
"#b c #898989",
"cR c #89a9b7",
"aJ c #89b5d9",
"ct c #89bfd5",
"cM c #89c2db",
"bp c #8a8a8a",
"by c #8ac3da",
"a# c #8bbcd0",
"bh c #8bc0d5",
"a3 c #8cbcdb",
"ao c #8dc0d3",
"bL c #8dc6dc",
"bO c #8ebed1",
"aK c #8ec2d5",
"cJ c #8ec7db",
"c2 c #8f8e8c",
"aX c #8fc2f2",
"cK c #8fc9de",
"dj c #90baba",
"cL c #90cce0",
"a. c #91bed1",
"dd c #929292",
"ar c #92b4d6",
"#y c #939393",
"bP c #93bdde",
"bq c #93c3d4",
"aq c #94b2d2",
"au c #94c5d5",
".E c #959595",
"cu c #95c6e2",
"bY c #98d1df",
"ba c #99c7ef",
"#M c #9a9a9a",
"cc c #9b9b9b",
"cS c #9bc9ca",
".6 c #9c9c9c",
"cb c #9cd5df",
"aa c #9dc9d6",
"#i c #9e9e9e",
"c9 c #9ea8aa",
"br c #9ebcda",
"ce c #9ecce9",
"di c #9f9fa0",
"#c c #a1a1a1",
"bG c #a2c7e1",
".S c #a3a3a3",
"c4 c #a3c9c9",
".D c #a4a4a4",
"#q c #a8a8a8",
"cI c #aad6df",
"#f c #ababab",
"b0 c #adadad",
"a4 c #afd7e0",
".u c #b3b3b3",
"cC c #b3def6",
".v c #b4b4b4",
".t c #b5b5b5",
"cN c #b5dbed",
"bg c #b5e2f6",
"bN c #b6b6b6",
".w c #b7b7b7",
"b2 c #b7dbe1",
"ca c #b7dcee",
".s c #b8b8b8",
"#v c #b9b9b9",
"dl c #b9dcdc",
".x c #bbbbbb",
"#V c #bbbcbc",
"c7 c #bbdde2",
"a9 c #bbdee3",
"#e c #bcbcbc",
"#9 c #bcdde2",
".r c #bdbdbd",
"dB c #bebebe",
"de c #bfe4e6",
"d. c #c0bebc",
"cj c #c0ddf1",
"cZ c #c0e7f8",
".R c #c1c1c1",
"aV c #c1cee1",
"aD c #c1cfe2",
"cX c #c1e7e8",
"aI c #c1ecfb",
".y c #c2c2c2",
"dh c #c3c4c4",
"do c #c3dcdb",
"dt c #c3e2e2",
"cv c #c3eafa",
".q c #c4c4c4",
"ab c #c4e2e5",
"cn c #c4e4e6",
"dp c #c5e6e6",
"#d c #c8c8c8",
".C c #c9c9c9",
"b4 c #c9f2fe",
"a2 c #caf4fe",
"bx c #cbeffb",
".p c #cccccc",
"#p c #cdcdcd",
"aB c #cde8e8",
"b8 c #cee4f0",
"bv c #cee4f1",
"du c #cee8e8",
"#7 c #cfcfcf",
"bX c #cfecf9",
"cU c #d0d0d0",
"cs c #d0e8e9",
"an c #d1e9e9",
"ds c #d3e8e8",
"cW c #d3e9e9",
"cl c #d3eff5",
"cf c #d3f7fe",
"cE c #d4e9e9",
".o c #d5d5d5",
"av c #d5e9e9",
"bs c #d5eafa",
"bM c #d6e9e9",
".Q c #d7d7d7",
"bQ c #d7f8fd",
".5 c #d8d8d8",
"aL c #d8e9e9",
"al c #d9d9d9",
"aT c #d9e9e9",
"bi c #dae9e9",
"bK c #daf4fc",
"aH c #dafafe",
"#8 c #dbe9e9",
"cO c #dbf8fb",
".B c #dcdcdc",
"bZ c #dce9e9",
"#h c #dddddd",
"ac c #dde9e9",
"a1 c #ddf5f7",
".n c #dedede",
"c1 c #dee2e5",
"bE c #dee9e9",
"cB c #def6f9",
"c5 c #dfe9e9",
"bf c #dff7f9",
"bD c #e0e0e0",
"#Y c #e0e9e9",
"#o c #e1e1e1",
"#X c #e1e9e9",
"cV c #e2e9e9",
"aZ c #e2f0f5",
"cw c #e2f9fd",
"#Z c #e3e9e9",
"#x c #e4e4e4",
"am c #e4e9e9",
"b5 c #e4f7f5",
"#N c #e5e5e5",
"#W c #e5e9e9",
"cy c #e5fafd",
"#w c #e6e6e6",
"#0 c #e6e9e9",
"c. c #e6f1f3",
"bH c #e6fdfe",
".m c #e7e7e7",
"ad c #e7e9e9",
"bU c #e7f1f3",
"aW c #e7f1fc",
".g c #e8e8e8",
"aM c #e8e9e9",
"cP c #e8f8fc",
".h c #e9e9e9",
".f c #eaeaea",
"cg c #eaf9f7",
"cx c #ebfcfe",
".i c #ececec",
".e c #ededed",
"aG c #edfefe",
".j c #efefef",
"cQ c #efffff",
".d c #f0f0f0",
".l c #f2f2f2",
"bw c #f2fbf7",
"cz c #f2fef8",
"bS c #f3f8f3",
".c c #f4f4f4",
"a0 c #f5fbf5",
"bJ c #f5fdf6",
".P c #f6f6f6",
"cA c #f6fcf3",
"ch c #f6fcf5",
"bW c #f6fdf9",
".A c #f7f7f7",
".b c #f8f8f8",
"bR c #f8fcf4",
".k c #f9f9f9",
"#g c #fafafa",
"aE c #fafcfe",
"ci c #fafef5",
"c# c #fafffa",
"c0 c #faffff",
".a c #fcfcfc",
"aF c #fcffff",
"be c #fdfdf3",
".z c #fdfdfd",
"b6 c #fefef3",
"bV c #fefef4",
".# c #fefefe",
"bu c #fefff4",
"ck c #fefff6",
"b7 c #fffff3",
"bd c #fffff4",
"Qt c #ffffff",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.#.a.b.c.d.e.f.g.g.g.h.i.j",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.#.k.l.m.n.o.p.q.r.s.t.u.v.w.x.y",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.z.A.e.B.C.t.D.E.F.G.H.I.J.K.L.M.N.O",
"QtQtQtQtQtQtQtQtQtQtQtQtQt.z.P.f.Q.R.S.T.M.U.V.W.X.Y.Z.0.1.1.2.3.4",
"QtQtQtQtQtQtQtQtQtQtQt.#.b.i.5.r.6.G.7.8.9#..0###a#b#c.t.q.p#d#e#f",
"QtQtQtQtQtQtQtQtQtQt#g.d#h.y#i#j.U#k#l#m#n.F.w#o.h.h.h.h.h.h.h.h.h",
"QtQtQtQtQtQtQtQt.#.b.g#p#q#r#s#k#.#t#u#v#w.h.h.h.h.h.h.h.h.h.h.h.h",
"QtQtQtQtQtQtQt.#.A#x.R#y.L.W#l#z#A.C.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h",
"#B#B#B#B#B#C#D#E#F#G#H#I#I#J#K.q.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h",
"#B#B#B#B#B#C#D#E#F#G#H#I#L#M#N.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h",
"#B#B#B#B#O#P#E#Q#R#S#T#U#V.h.h.h.h#W#X#Y#Z#0.h.h.h.h.h.h.h.h.h.h.h",
"#B#B#B#O#1#2#3#R#4#5#6#7.h.h.h#0#8#9a.a#aaabacad.h.h.h.h.h.h.h.h.h",
"#B#B#Baeafagahaiajakal.h.h.hamanaoapaqarasatauav#0.h.h.h.h.h.h.h.h",
"#B#B#Cawaxayaz#TaAal.h.h.h#0aBaCaDaEaFaGaHaIaJaKaLaM.h.h.h.h.h.h.h",
"#B#OaNaOaPaQaRaS#p.h.h.h.haTaUaVaWaXaYaZa0a1a2a3a4#Z.h.h.h.h.h.h.h",
"#Baea5#Fa6a7a8.v.h.h.h.h#0a9b.Qtb#babbbcbdbebfbgbhbi.h.h.h.h.h.h.h",
"bjbkblbmbnbobp.h.h.h.h.h#Xbqbrbsbtbubvbcbdbdbwbxbyav.h.h.h.h.h.h.h",
"ai#4bzbAbBbCbD.h.h.h.h.hbEbFbGbHbIbdbvbcbdbdbJbKbLbM.h.h.h.h.h.h.h",
"#e#M.J.Y.0bN.h.h.h.h.h.h#YbObPbQbRbdbSbTbUbVbWbXbYbZ.h.h.h.h.h.h.h",
"b0#r.Vb1.M#w.h.h.h.h.h.h#Wb2b3b4b5b6b7b8b9c.c#cacbac.h.h.h.h.h.h.h",
"cc#K.Y.1.r.h.h.h.h.h.h.h.haTcdcecfcgchcicjb7ckclcmcnam.h.h.h.h.h.h",
"cocpcqcr#o.h.h.h.h.h.h.h.h#WcsctcucvcwcxcyczcAcBcCcDcEad.h.h.h.h.h",
"cFcGcH#c.h.h.h.h.h.h.h.h.h.h#WbMcIcJcKcLcMcNcOcPcQcRcSaTad.h.h.h.h",
".J.3cTcU.h.h.h.h.h.h.h.h.h.h.haMcVaTcEcWcXcYcZc0c1c2c3c4c5.h.h.h.h",
"#s.1c6.m.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.hcVc7c8c9d.#dd#daaL.h.h.h.h",
"dbdcdd.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h#Xdedfdgdhdidjbi.h.h.h.h",
"##dk.w.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h#Ydldmdndodp#X.h.h.h.h",
"dqdrcU.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.hcVdsdtdubZad.h.h.h.h",
"dvdw#x.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.hadad.h.h.h.h.h.h",
"dxdy.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h.h",
"dzdAdBdBdBdBdBdBdBdBdBdBdBdBdBdBdBdBdBdBdBdBdBdBdBdBdBdBdBdBdBdBdB",
"dCdD#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K#K"};

static const char* const img3_mainDlg[] = { 
"28 18 47 1",
"c c #5a9de6",
"b c #5aa1e6",
"a c #62a1e6",
"d c #62a5e6",
"h c #6aa5e6",
"f c #6aaae6",
"g c #6aaaee",
"# c #737173",
"i c #73aae6",
"e c #73aaee",
"k c #73aee6",
"j c #73aeee",
"n c #7bb2e6",
"l c #7bb2ee",
"m c #83b2ee",
"o c #83b6e6",
"q c #83b6ee",
"p c #83baee",
"r c #8bb6ee",
"s c #8bbaee",
"u c #8bbeee",
"v c #94beee",
"t c #94bef6",
"y c #94c2ee",
"w c #9cc2ee",
"x c #9cc2f6",
"z c #9cc6ee",
"A c #9cc6f6",
"C c #a4caee",
"B c #a4caf6",
"D c #accaf6",
"E c #acceee",
"G c #accef6",
"F c #b4d2f6",
"I c #bdd6f6",
"J c #bddaf6",
"H c #bddaff",
"K c #cde2f6",
"M c #cde2ff",
". c #d5d2d5",
"L c #d5e2ff",
"O c #deeeff",
"N c #e6eeff",
"P c #eef6ff",
"Q c #f6f6ff",
"S c #fffaff",
"R c #ffffff",
"............................",
"############################",
"ababababacababacacacababacab",
"adadadadadadadadadadadadadad",
"efghghghghghehgfghgfghghghgh",
"ijijijikijijijijijijijijijij",
"llmllnmllnmllnmllnmlllmllnml",
"opqpqpqroqqsqpqropqqqqqrqpqp",
"tuvutuvutuvutuvutvvutvvutuvu",
"wxyzwAyzyxyzwxyzyxywwAyzwAyz",
"BCDBBCDBBCDBBCDBBCDBBCDBDCDB",
"EFGFEFGFEFGFGFGFEFGFGFGFEFGF",
"HIJIHIHIHIHIHIHIHIJIHIHIHIJI",
"KLKLKLKMKLKMKLKLKLKMKLKLKLKL",
"NNNNNNNNNNNNNONNNNNNNNNNNNNN",
"PQPQPQPQPQPQPQPQPQPQPQPQPQPQ",
"RRRRRRRRRRRRRSRRRSRSRRRRRRRR",
"RRRRRRRRRRRRRRRRRRRRRRRRRRRR"};

static const char* const img4_mainDlg[] = { 
"28 26 193 2",
".9 c #000000",
"## c #000400",
"#. c #080408",
"#H c #080808",
".W c #080c08",
"#L c #105500",
"#T c #181818",
".V c #181c18",
".J c #201c20",
"#3 c #202020",
"#K c #20c600",
"#w c #20de00",
"#s c #292429",
".F c #292829",
"#J c #29de00",
"#P c #29de08",
"#x c #29e200",
"#a c #313031",
"#0 c #31c618",
"#E c #31de10",
"#4 c #31e208",
"#W c #396d31",
"#y c #39d220",
"aG c #39de00",
"ag c #39de18",
"#V c #39e218",
".I c #413c41",
".8 c #414041",
"#A c #414441",
"#8 c #41de20",
"#F c #41e220",
"#Q c #4ae229",
"#v c #4ae629",
"#z c #528d41",
"aF c #52da08",
"#O c #52e239",
"af c #52e639",
"#S c #5a555a",
".7 c #5a595a",
"#D c #5ae639",
".D c #625962",
".Y c #625d62",
".X c #626162",
".M c #626562",
"#5 c #62e24a",
".C c #6a656a",
"#g c #6a696a",
"a# c #6aea52",
"#1 c #7be66a",
".N c #837d83",
".t c #838183",
"#m c #838583",
"ac c #83da7b",
"ar c #83ea6a",
".z c #8b858b",
".Z c #8b898b",
".6 c #8b8994",
".O c #8b8d8b",
"#j c #8bee73",
"#I c #8bee7b",
"#o c #94b64a",
"#9 c #94de8b",
"aH c #94e210",
"as c #94e252",
"#k c #94ee83",
".c c #9c999c",
"#p c #9cc273",
"#2 c #9cea8b",
"#C c #9cee8b",
".B c #a499a4",
".x c #a49da4",
".d c #a4a1a4",
"aV c #a4ce29",
"#7 c #a4f294",
"aa c #acdea4",
"#U c #acf29c",
".b c #b4aeb4",
".L c #b4b2b4",
".j c #b4b6b4",
"#6 c #b4e6ac",
"#N c #b4eeac",
"#u c #b4f6a4",
"#c c #bdaa62",
".1 c #bdaa83",
".i c #bdb6bd",
"aM c #bdb6c5",
".e c #bdbabd",
".y c #bdbebd",
".0 c #bdbec5",
"#i c #bdf6ac",
"ab c #bdf6b4",
".S c #c5ba9c",
".s c #c5bec5",
".G c #c5c2c5",
".K c #c5c2cd",
"ah c #c5ca94",
"aW c #c5da18",
"#n c #c5dacd",
".5 c #cdb27b",
"#t c #cdc6cd",
".a c #cdcacd",
"#f c #cdcad5",
".u c #cdcecd",
"aw c #cdced5",
"#l c #cdeec5",
"#R c #cdf2c5",
"#e c #d5ae31",
"ao c #d5beac",
".T c #d5c6ac",
"ai c #d5c6c5",
".v c #d5ced5",
"ad c #d5d2d5",
"ak c #d5d2de",
".m c #d5d6d5",
".H c #d5d6de",
"#b c #d5d6e6",
"aU c #d5e2a4",
"a. c #d5e2d5",
"#Y c #d5f2d5",
"av c #deaa6a",
"al c #dec6bd",
".U c #decaac",
".R c #deceac",
"aj c #ded2de",
".Q c #ded6bd",
".l c #ded6de",
".f c #dedade",
".P c #dedae6",
".o c #dedede",
"aE c #defad5",
"aN c #e6a129",
"ax c #e6aa6a",
"am c #e6c2a4",
".q c #e6dee6",
".k c #e6e2e6",
"#r c #e6e6e6",
"#X c #e6eae6",
"ae c #e6ffe6",
"aL c #eea118",
"a9 c #eeca52",
"a0 c #eece7b",
"an c #eeceb4",
"aZ c #eed229",
"a4 c #eed69c",
"a6 c #eeda31",
"b. c #eedec5",
"a1 c #eee6de",
".r c #eee6ee",
".# c #eeeaee",
".E c #eeeeee",
"#B c #eefae6",
"#q c #eefaee",
"ay c #f6aa31",
"au c #f6b24a",
"aD c #f6c273",
"#d c #f6ca00",
"a5 c #f6d252",
"a8 c #f6d631",
"at c #f6da94",
"aI c #f6de18",
"aX c #f6e229",
"a7 c #f6e231",
"ap c #f6e6de",
".2 c #f6ea73",
".A c #f6eaf6",
"a3 c #f6eeee",
".n c #f6eef6",
".p c #f6f2f6",
".w c #f6f6f6",
"a2 c #f6f6ff",
"#G c #f6faee",
"#Z c #f6ffee",
"#h c #f6fff6",
"aS c #ffba00",
"aK c #ffc600",
"aR c #ffd208",
"aC c #ffd283",
"aO c #ffd610",
"aJ c #ffda18",
"az c #ffda94",
"aQ c #ffde10",
"aP c #ffe210",
"aY c #ffe229",
"aA c #ffe29c",
"aB c #ffe6a4",
"aT c #ffeed5",
".4 c #fff2ac",
"aq c #fff2e6",
".h c #fff6ff",
".g c #fffaff",
".3 c #ffffac",
"#M c #fffff6",
"Qt c #ffffff",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQt.#.a.b.c.d.e.f.gQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQt.h.i.j.k.gQtQt.h.l.e.mQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQt.n.c.oQt.p.q.q.k.q.r.#.s.sQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQt.g.t.a.h.gQt.n.u.v.r.w.p.f.x.yQtQtQtQtQt",
"QtQtQtQtQtQtQtQt.c.z.l.r.A.k.B.C.x.#.h.p.q.s.D.EQtQtQtQt",
"QtQtQtQtQtQtQt.#.F.c.G.k.o.H.I.J.I.K.k.q.o.L.M.NQtQtQtQt",
"QtQtQtQtQtQtQt.O.J.N.x.f.P.Q.R.S.T.U.v.l.s.z.C.V.pQtQtQt",
"QtQtQtQtQtQt.g.I.W.X.Y.Z.0.1.2.3.4.5.e.6.7.C.8.9.eQtQtQt",
"QtQtQtQtQtQt.k#.###a.I.Z.##b#c#d#e#fQt.a.Y.I.J.9#gQtQtQt",
"Qt#h#i#j#k#l#m.9.9.9.ZQtQtQt#n#o#p#qQtQt#r.I.9.9#s#tQtQt",
"Qt#u#v#w#x#y#z##.9#A.gQt#B#C#D#E#F#k#G.gQt.e#H.9.J.Z.sQt",
"Qt#I#w#J#w#J#K#L#..e#M#N#O#P#w#J#w#Q#R.h.hQt#S.9.9#T#a#t",
"Qt#U#V#w#x#w#x#K#W#X#k#E#x#w#x#w#x#Q#Y.p.hQt.b.9.C.p.h.g",
"Qt#Z#C#V#w#J#w#J#0#1#P#J#w#J#w#J#E#2.E.n.E.h.l#3.eQtQtQt",
"QtQtQt#U#F#w#x#w#x#P#x#w#x#w#4#5#6#r.#.#.A.A.k.X.hQtQtQt",
"QtQtQtQt#7#4#w#J#w#J#w#J#w#8#9a..k.k.k.k.k.r.l.iQtQtQtQt",
"QtQtQtQt#Ma##x#w#x#w#x#w#8aa.q.f.q.f.q.f.q.q.s.EQtQtQtQt",
"QtQtQtQtQtab#P#J#w#J#w#Jac.P.m.l.m.l.H.lad.s.HQtQtQtQtQt",
"QtQtQtQtQtaeaf#w#x#w#xagahai#badajakalamanaoapaqQtQtQtQt",
"QtQtQtQtQtQtar#J#w#J#wasatauavakawaxayazaAaBaAaCaDQtQtQt",
"QtQtQtQtQtQtaEaF#xaGaHaIaJaKaL.LaMaNaKaOaPaPaQaRaSaTQtQt",
"QtQtQtQtQtQtQtaUaVaWaXaYaZa0a1.ha2a3a4a5a6a7a8a9b.QtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt"};

static const char* const img5_mainDlg[] = { 
"82 28 240 2",
"aq c #0030a4",
"aj c #0034a4",
"ab c #0034ac",
"az c #003cac",
"ap c #0040ac",
"av c #0040b4",
"aF c #0048b4",
"ae c #0838ac",
"#. c #0848b4",
"#0 c #084cbd",
"af c #1040ac",
"ar c #1044b4",
"#8 c #1048b4",
"ao c #104cb4",
"aQ c #104cbd",
"ak c #1050b4",
"aw c #1050bd",
"#7 c #1055bd",
"aN c #1055c5",
"aV c #1059bd",
".V c #1848ac",
"ac c #1855bd",
"ax c #1859bd",
"a4 c #1859c5",
"a2 c #185dc5",
".W c #1865cd",
"#Z c #204cac",
"#V c #2059bd",
"aP c #205dbd",
"an c #205dc5",
"aG c #2061bd",
"al c #2061c5",
"am c #2065c5",
"ai c #2950ac",
"au c #2955b4",
"#Q c #295db4",
"aE c #2961b4",
"aW c #2961c5",
"ay c #2965c5",
"#w c #2969c5",
"#K c #2969cd",
"aH c #296dc5",
"#R c #296dcd",
"#E c #2971cd",
"aM c #3165bd",
"a1 c #3169bd",
"ad c #316dcd",
"#6 c #3171cd",
"#U c #3175cd",
"#v c #3175d5",
"#2 c #3179cd",
".9 c #3179d5",
"#h c #396dbd",
"aU c #396dc5",
"#1 c #3975cd",
"aO c #3975d5",
"#J c #3979d5",
"#i c #3979de",
"#3 c #397dd5",
".8 c #3981d5",
".X c #3981de",
".Y c #3985de",
"#u c #417dd5",
"a3 c #417dde",
"#F c #4181d5",
"#j c #4185d5",
"#5 c #4185de",
"bF c #4a4c52",
"#4 c #4a85de",
"#t c #4a89de",
"#G c #4a8dde",
".7 c #4a8de6",
"#s c #4a91de",
".Z c #4a91e6",
".6 c #4a95e6",
"bG c #525052",
"bh c #5285cd",
"#k c #528de6",
"#H c #5291de",
"#T c #5291e6",
"#l c #5295e6",
".0 c #5299e6",
".q c #5a595a",
"ah c #5a5d5a",
"bi c #5a89d5",
"a9 c #5a8dd5",
"#S c #5a95e6",
"#r c #5a99e6",
"#I c #5a9de6",
".5 c #5a9dee",
".1 c #5aa5ee",
"ag c #625d62",
"bw c #62656a",
"bg c #6291d5",
"bf c #6295d5",
"#m c #62a1ee",
".2 c #62aaee",
".4 c #62b2f6",
"#q c #6aa5ee",
"#p c #6aaaee",
"#n c #6aaaf6",
"#o c #6aaef6",
".3 c #6ab2f6",
".U c #737173",
".k c #737573",
"bB c #73757b",
"a8 c #7399d5",
"b. c #739dde",
"b# c #73a1de",
"be c #73a5e6",
".l c #7b757b",
".j c #7b797b",
"aC c #7b7d7b",
"aa c #7b7d83",
"aS c #7b8183",
"ba c #7baae6",
"bd c #7baee6",
"at c #837d83",
"aK c #838183",
"aZ c #83818b",
"a6 c #83858b",
".A c #8395b4",
".N c #8395bd",
"bb c #83b2ee",
"bc c #83b6ee",
"bA c #8b858b",
".m c #8b898b",
".z c #8b8994",
"bP c #8b8d8b",
"bn c #8b8d94",
".B c #8ba1cd",
"bR c #948d94",
".w c #949194",
"a5 c #94919c",
".i c #949594",
"bC c #94959c",
".M c #94aecd",
".C c #94b2d5",
"bv c #9c959c",
"bQ c #9c999c",
"bH c #9c9d9c",
"bJ c #9c9da4",
".D c #9cb2d5",
".E c #9cb6d5",
".L c #9cbade",
"bT c #a49da4",
".p c #a4a1a4",
"#N c #a4a5a4",
"a# c #a4a5ac",
".F c #a4bade",
".G c #a4bede",
".K c #a4c2de",
".I c #a4c6de",
"#a c #aca5ac",
"#y c #acaaac",
"bl c #acaeac",
"bm c #acaeb4",
"bN c #acb2bd",
".H c #acc2e6",
".J c #acc6e6",
".P c #b4aeb4",
"bq c #b4b2b4",
".s c #b4b6b4",
".Q c #b4b6bd",
"#b c #b4b6c5",
"aY c #b4bac5",
"aI c #b4bed5",
"#9 c #b4c2de",
"bS c #bdb6bd",
".v c #bdbabd",
"aJ c #bdbac5",
".n c #bdbebd",
"br c #bdbec5",
"bK c #bdc2cd",
"aA c #bdc2de",
"bj c #bdc6d5",
"#W c #bdc6e6",
"#L c #bdcae6",
"## c #bdcee6",
"#e c #c5bec5",
"#z c #c5c2c5",
"by c #c5c6c5",
"bD c #c5c6d5",
"bL c #c5cad5",
"bz c #cdc6cd",
"bx c #cdcacd",
"bM c #cdcad5",
"bI c #cdcade",
".h c #cdcecd",
".S c #cdced5",
"bE c #cdcede",
"bO c #cdd2de",
"#x c #cdd6ee",
"bp c #d5ced5",
".c c #d5d2d5",
".b c #d5d6d5",
".T c #d5d6de",
"#C c #d5d6e6",
"#O c #d5dae6",
"bk c #ded6d5",
".d c #ded6de",
"bt c #dedad5",
".u c #dedade",
".y c #dedae6",
"bu c #dedaee",
".r c #dedede",
"#D c #dedee6",
"#g c #dedeee",
"#P c #dee2ee",
"aX c #e6dede",
".e c #e6dee6",
"aR c #e6e2de",
".a c #e6e2e6",
"bo c #e6e6e6",
"aD c #e6e6ee",
".O c #e6e6f6",
"aT c #e6eaee",
"a0 c #e6eaf6",
"a7 c #e6eef6",
"aB c #eee6e6",
"#Y c #eee6ee",
".o c #eeeaee",
"aL c #eeeaf6",
".f c #eeeeee",
".R c #eeeef6",
"bs c #eeeeff",
"#A c #eef2ff",
"as c #f6eaee",
"a. c #f6eeee",
"#f c #f6eef6",
"#X c #f6f2ee",
".# c #f6f2f6",
"#B c #f6f2ff",
".g c #f6f6f6",
".x c #f6f6ff",
"#c c #f6faff",
"#M c #fff6f6",
"#d c #fff6ff",
".t c #fffaff",
"Qt c #ffffff",
"QtQtQtQtQtQtQt.#.a.b.b.c.d.c.b.c.d.c.b.c.d.c.b.c.d.c.b.c.d.c.e.fQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQt.g.h.i.j.k.l.k.l.k.l.k.l.k.l.k.l.k.l.k.l.k.l.k.j.m.n.oQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQt.o.p.q.i.a.e.a.e.a.e.a.e.a.e.a.e.a.e.a.r.a.r.e.r.a.s.p.tQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
".u.b.c.c.c.c.v.j.qQtQt.t.tQt.tQt.tQt.tQt.tQt.tQt.tQt.tQt.t.tQtQt.w.s.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.h.u.oQt",
".t.x.t.x.t.x.y.z.lQt.o.A.B.C.D.E.F.G.H.I.J.K.K.L.F.D.D.M.B.N.OQt.P.Q.t.x.t.x.t.x.t.x.t.x.t.x.t.x.t.x.t.x.t.x.t.x.t.x.t.x.t.x.t.x.t.x.t.x.t.x.t.x.t.x.t.x.t.x.R.S.c.#",
".x.x.x.x.x.x.T.z.UQt.T.V.W.X.Y.Z.0.1.2.3.4.3.1.5.6.7.8.9.W#.##Qt#a#b.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.t#c#d#e#f",
".x.x.x.x.x.x.y.z.lQt#g#h#i#j#k#l.5#m#n#n#o#p#q.5#r#s#t#u#v#w#xQt#y.Q.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.t.t#z.o",
"#A.x#B.x#A.x#C.z.kQt#D#h#E#F#j#G#H#r#I#m#I#m#r#r#G#t#u#J#w#K#L#M#N#b#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x.x.t.n.o",
".x.x.x.x.x.x#O.z.jQt#P#Q#R#J#F#j#G#G#l#l#S#l#T#G#t#F#J#U#K#V#W#X#y#b.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.t.t#z#Y",
"#B.x#A.x#B.x.T.z.jQt#D#Z#0#1#2#3#F#4#j#G#t#t#j#5#3#J#6#6#7#8#9a.a##b#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x.x.t#e.o",
".x.x.x.x.x.x.y.zaaQt.O#Zabacad#U#3#J#F#F#F#F#u#J#J#6adacaeaf#Wa.#y.Q.x.x.x.x.x.xagah.x.x.x.xagah.x.xagahagahag.xagah.x.x.xah.x.xagah.x.xagah.x.x.x.x.x.x.x.x.t.t#z#Y",
"#A.x#B.x#A.x#C.z.jQt#Paiaj#.akal#wad#6#U#6#U#6adamanaoapaqar#9as#y#b#B.x#A.x#B.xahagah.x#Aagahag#A.xahag#A.x#B.xahagah.x#Aag#B.xahag#B.xahag#B.x#A.x#B.x#A.x.x.t.n.o",
".x.x.x.x.x.x#O.zatQt.Oauavawaxaxalay#K#wad#wayalanacaw#.azaraAaB.P#b.x.x.x.x.x.xagahagahagahagah.x.xagah.x.x.x.xagahagah.xah.x.xagah.x.xagah.x.x.x.x.x.x.x.x.t.t#z#Y",
"#B.x#A.x#B.x.T.zaCQtaDaEaFanaGay#wad#E#6#6#6aH#Kamalaxacap#8aIaB#yaJ#A.x#B.x#A.xah.xahagah.xahag#B.xahagahagah.xah.xahagahag#A.xahag#A.xahag#A.x#B.x#A.x#B.x.x.t#e.o",
".x.x.x.x.x.x.y.zaKQtaLaMaNayad#6aO#J#u#3#u#3#J#U#6#wayaPaQawaAaR.P#b.x.x.x.x.x.xag.x.xah.x.xagah.x.xagah.x.x.x.xag.x.xahagah.x.xagah.x.xagah.x.x.x.x.x.x.x.x.t.t#z#Y",
"#A.x#B.x#A.x#C.zaSQtaTaUaVad#6#J#3#5#j#t#j#t#F#F#2#6#waWakaxaIaX#yaY#B.x#A.x#B.xah.x#B.x#A.xahag#A.xahag#A.x#B.xah.x#B.xahag#B.xahag#B.xahag#B.x#A.x#B.x#A.x.x.t.n.o",
".x.x.x.x.x.x#O.zaZQta0a1a2#R#J#3#5#t.Z#s#T#G#t#ja3#U#RamaNa4#9.u.P#b.x.x.x.x.x.xag.x.x.x.x.xagah.x.xagahagahag.xag.x.x.x.xah.x.x.xahagahag.x.x.x.x.x.x.x.x.x.t.t#z#Y",
"#B.x#A.x#B.x#Oa5a6Qta7a8a9b.b#bababbbbbcbcbcbdbdbeb#bfbgbhbibjbkblaJ#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x.x.t#e.o",
".x.x.x.x.x.x.ObmbnQtQtQtQt.t.t#M.##f#f.o.f.o.o.abo.a.a.raX.ubp.dbqbr.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.t.t#z#Y",
"#A.x#B.x#A.xbs#CaK.aQtQtQtQt#M#faBaB.a.e.raXbt.d.c.bbk.ubkbk.c.u.mbu#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x.x.t.n.o",
".x.x.x.x.x.x.xbsbua5bvbna6.Ubw.w.c.c.Sbxbxbybzby#ebAbBaK.z.mbC.zbD.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.x.t.t#z#Y",
"bs.x#A.x#B.x#A.x#A#BbEa#bBbFbGbH.c.e.u.u.b.d.b.uby.p.UaabE#g#Obs#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x#A.x#B.x.x.t#e.o",
"#g.OaL.Oa0.OaL.Oa0.ObI.z.qbqQtQt.obo#d.tQt.t#d.e.eQtQt#zbJ#PaL.Oa0.OaL.Oa0.OaL.Oa0.OaL.Oa0.OaL.Oa0.OaL.Oa0.OaL.Oa0.OaL.Oa0.OaL.Oa0.OaL.Oa0.OaL.Oa0.OaL.Oa0a0.x#B.c.#",
"bKbLbDbMbDbMbDbMbDbDbNaa.mQtQtQt.#bo.a#Ybo.a.bbx.b.gQtQt.va#bDbMbDbMbDbMbDbMbDbMbDbMbDbMbDbMbDbMbDbMbDbMbDbMbDbMbDbMbDbMbDbMbDbMbDbMbDbMbDbMbDbMbDbMbDbMbLbOaDaLbo.t",
"QtQtQtQtQtQtQtQtQtQt#dbzbA.tQt.#.#.o#Y.a.a.e.abo#f.#QtQt.p.cQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.t.tQt",
"QtQtQtQtQtQtQtQtQtQtQt.g.n.jbx.#.#.#.f#f.f.#.#.g.g.#.bbP#N.tQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQt.rbQ.jbR#N.v#zbzby#e#ybvaCbR.hQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.#.bbSbTbv.w.ibQ.Pbx#f.tQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt"};

static const char* const img6_mainDlg[] = { 
"34 21 3 1",
". c #004991",
"# c #004a91",
"a c #004a92",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"......#...........................",
"..................................",
"..................................",
"..................................",
"..................................",
"....a...................#.........",
"..................................",
".....................a............"};

static const char* const img7_mainDlg[] = { 
"104 21 33 1",
"# c #004894",
"a c #004c94",
". c #004c9c",
"e c #00509c",
"x c #084c9c",
"g c #08509c",
"w c #0850a4",
"l c #0855a4",
"n c #0859a4",
"p c #1059ac",
"y c #105dac",
"b c #1061ac",
"h c #1061b4",
"C c #1065b4",
"q c #1861b4",
"k c #1865b4",
"A c #1869b4",
"j c #1869bd",
"o c #186dbd",
"E c #186dc5",
"v c #2069bd",
"z c #206dbd",
"m c #206dc5",
"d c #2071c5",
"B c #2075c5",
"t c #2075cd",
"r c #2079cd",
"s c #2979cd",
"D c #2979d5",
"f c #297dcd",
"c c #297dd5",
"i c #2981d5",
"u c #3181d5",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#",
"########################################################################################################",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#",
"########################################################################################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#",
"#######bcd######ecfg############################################################################ecfg####",
"a#.#a#.hij.#a#.#hcc#a#.#a#.#a#kja#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#kja#.#a#.#a#.lmn.#lop#hcc#a#.#",
"#######mfh###################jcq#########################################jcq##########ecr##gfs##########",
".#a#.#atuna#.#a#dcj#ldicuha#ccicv#ksucda.#a#.#ahccih.#ahscidw#anutksudg#ccicv#ksucda.hicuckcucigdcj#.#a#",
"#######scx######scy.scfcccylccfcykfcccfz######occcfcb#Acccfctx#bccfcccAlccfcykfcccfz#mfccsocccB#scy#####",
"a#.#a#pcs#.#a#.giclpitl#a#.#pcs#a#.#ayuda#.#ahusy#vcdnuck#wtih.jicq#jcv#pcs#a#.#ayuda#dch#.diy.gicl#a#.#",
"######yco######yfs#xBcccC###bcA##lCkrccj#####dck#####kct###mfk#dfk##ocb#bcA##lCkrccj##sce##Dfg#yfs######",
".#a#.#jcj#a#.#ahuda#.ktcuda#dck#ycty.tiy.#a#.sip.#a#.oik.#atuhasuna#ccp#dck#ycty.tiy.nis.#pcc#ahuda#.#a#",
"######ocya#####zcj#####bcD##scl#AcC#bcfg#####sfh#qfceqfBa#Acsxeccx#gcce#scl#AcC#bcfg#qfd##bcE##zcj######",
"a#.#a#scicucid.tihycicucio..icuhkcucicc#a#.#ahucicuhagccicuck#ycs#.nit..icuhkcucicc#akucc#jcis.tih.#a#.#",
"#####.ccfcccfjacfn#bdcccC###occbadccCcs#######bcfsb###gdfcdb##bco##qfz##occbadccCcs##lscB#gDfsacfn######",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#.#.#a#.#a#",
"########################################################################################################",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#",
"########################################################################################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#"};

static const char* const img8_mainDlg[] = { 
"72 21 20 1",
". c #004991",
"# c #004a91",
"a c #004a92",
"b c #004a94",
"m c #004c97",
"h c #004d99",
"l c #004f9c",
"q c #00509d",
"g c #00509f",
"f c #0052a2",
"p c #0053a5",
"e c #0055a8",
"j c #0056aa",
"c c #0057ad",
"i c #0059b0",
"d c #005ab3",
"o c #005cb6",
"n c #005db9",
"r c #005fbb",
"k c #0060be",
"...#...................#................................................",
"........................................................................",
"........................................................................",
"...............................................a........................",
"........................................................................",
"........................................................................",
".......................................................................a",
"..........bcddddde.dddddddf.gdddddddhddddddihbjddddddffdddddddh.........",
"..........ekkkkkkklkkkkkkkkmnkkkkkkklkkkkkkkcfkkkkkkkeokkkkkkkl.........",
"..........dkclllokekkcllpkklkkpllllllkklllckdekolllllmkkclllllb.........",
"..........dke...dkekkefdokkqkkljdddjlkk...ekdekd......kkndddil..........",
"..........dke...dkekkeekkkr.kkldkkkdlkk...ekdekd......kkkkkkkkb.........",
"..........dke...dkekkemlllb.kkl.....lkk...ekdekd......kkdeeckkl.........",
"..........jkkkkkkkfkke......rkkkkkkklkk...ekdpkkkkkkkeokkkkkkkh.........",
"..........lrkkkkknbkke......ekkkkkkklkk...ekdmnkkkkkkegkkkkkkd..........",
"........................................................................",
"........................................................................",
"........................................................................",
"........................................................................",
"........................................................................",
"........................................................................"};

static const char* const img9_mainDlg[] = { 
"85 63 29 1",
"y c #b4b2b4",
"w c #b4b6b4",
"A c #bdb6bd",
"t c #bdbabd",
"x c #bdbebd",
"r c #c5bec5",
"z c #c5c2c5",
"o c #c5c6c5",
"v c #cdc6cd",
"n c #cdcacd",
"q c #cdcecd",
"p c #d5ced5",
"m c #d5d2d5",
"j c #d5d6d5",
"k c #ded6de",
"c c #dedade",
"i c #dedede",
"b c #e6dee6",
"d c #e6e2e6",
"s c #e6e6e6",
"a c #eee6ee",
"h c #eeeaee",
"u c #eeeeee",
"e c #f6eef6",
"l c #f6f2f6",
"f c #f6f6f6",
"# c #fff6ff",
"g c #fffaff",
". c #ffffff",
".....................................................................................",
".....................................................................................",
".....................................................................................",
".....................................................................................",
"...............................##abcbdef.............................................",
"............................ghijkbddddckjdl..........................................",
"...........................hmceg........gacc#........................................",
".........................gjcl.g...g.g.g....emd.......................................",
"........................enagg#gf##ggggggggg..icg.........glhhhlg.....................",
".......................hoefg....fel#f#f#lflff.ipg......fbiqqnqqcieg..................",
"......................erel#......#el#lllgggfll.iqg...smjaegg.gglhckdg................",
".....................#tdleg.g.g...leuhl.....guu#qm.embl...........#ajag..............",
".....................vnlel.g.g.g.hahef.......fhuhrkmlggf#g.ggggg.g..gbkg.............",
"....................iwiha#fg#gfgdamnidf.gggggguahvc#fg..#llgf#fgf#f#g.hql............",
"...................gtxhshfgfgfglnnvypnmgg#g#g##svigl......le#f#lll#ffl.hnf...........",
"...................bynddsff#f#fgqwyzotmgf#f#f#enm#u.......geulheg...glhgdog..........",
"...................tAndcde#l#f#flcjcbilf#f#f#fkxlul..g.g..glehlg......eh#qp..........",
"..................swyncckhlflflleflhhluel#lflawcuhfggggggedjihl.g.g.g.fhhawd.........",
"..................pyAzcjjcel#lleg.....ghaulehztshh##gfgglmdnrjmh.gggg#guahnAg........",
".................gAwyxmmqpjahusdf.g.g.fddhikjwoadhl#f#fglzwAwvtkg#f#f#fedamwj........",
".................hAyAAqqpqnqhehidelellsa..ljzyqdbsff#f#fgdzzcppugf#f#f#hddcwtg.......",
".................cywywxqvvnhg..#dduehdd#...eywnbkbhflflflfuhbaull#lfl#udkbjtys.......",
"................etAyAyAzonl.....#daehdl....cAyvckjdl#l#ellgggf#lhu#lfudjkcmAAn.......",
"...............eizwtywwxol.......fdddug...grywxjmmmdulehh......gidsadcmmmjvAytf......",
"..............lbhvnpmqmqceg.......#heg....lwAytqmppnkshdch#l###shffcnnpqmmzyAya......",
".............ljcilg.....laihg.....ggg.....dwywyonnovcgggudslueddf...anonnnwwywm......",
"............embl.g...g.....hbl...........fvyAyAtnova.....udhladl.....lpznxAyAyru.....",
"...........aodg.g.flfgfgf#f.lke.........fbxwywywtzs.......hdsdh.......lntAywywtkl....",
"...........qaf.....fllfe#ggl#lml.......#duzyAyAyAb.........uahg........ltyAyAythdl...",
"..........jjlf..g..gueug....elsvf.g.g.fihhtwywywn..........glg..........cAywywwduif..",
".........hrhefgggg#acdl.....ghlmmg.g.fbibqtyAyAte........................oAyAyAvcic#.",
"........gzqhh#f#fgjpxvqagg#gflsdwug.unozwwywywyjg........................swwywywyxzqf",
"........hykdhf#f#gbArvzdgf#fgeddznggepvwAyAyAyrh.........................fnyAyAwttzob",
"........zAmiillfl#lsidsll#lflacbzAugggllhazwywq#g.g.g.g.....g.g.........ggiAywzefgggg",
".......eAwmkks#ffu#..g.lhe#lajkkzybgggggggbyAAa#.g.g.g.g.g.g.g.g.g.g.g.g.gezAyc......",
".......iywojqmihhdu.g..edhikqmmmwwz#fgfgfghAyzh#g.g.g.g.g.g.g.g.g.g.g.g.gglmyws......",
".......nAyrqpvph#hdhleedg.lmvnpoAythg#gfg##zAplf.g.g.g.g.g.g.g.g.g.g.g.g.g#iAAg......",
"......utywyozpu...udhuil....czotywyjl#f#f#fdycl#gggggggggggggggggggggggggglawm.......",
".....fcAAyAwnf.....esde......ctyAyAnaf#f#f#lzi##gggggggggggggggggggggggggg#hzh.......",
"....lhdAywyth.......uug.......vwywymudl#lflfjdl#fg#gfgfgfgfgfgfgfg#gfg#gfgleq........",
"...lbdpyAyAj..................etAyAzdial#l#fedlfg#gfg#gfg#gfg#gfg#gfg#gfgffhh........",
"..uzzAywywxf...................mywywyrxilflluahff#f#f#f#f#f#f#f#f#f#f#f#f#us#........",
"..#dmozwAyk....................htyArppkblhhhluae#f#f#f#f#f#f#f#f#f#f#f#f#lhh.........",
"......ftyta.g.g.g.g.g.g.g.g.g.g#nwyhl#flshf.g.shlflflflflfl#lfl#lfl#lfl#lhd..........",
".......qAvfg.g.g.g.g.g.g.g.g.g.gbwtelledau#f#l#dhl#f#l#l#l#l#l#l#l#l#f#lesg..........",
".......uykfgggggggggggggggg.g.ggstnehesshhheellldaullllflllllllllflleehhbe...........",
"........vigggggggggggggggggggg.#ercsaddaeulelleuuhleehhull#lflll#leheellllllg........",
"........idfgfg#gfg#gfgfgfg#gfg#gumhfl#fesuulhhfgg...ggfudhllllllhdh#g.g...gglhl......",
"........gs#fg#gfg#gfg#gfg#gfg#gfeh......gleahfgfg#gfg#gfhdhlllfhdslf#f#f#f#f#haf.....",
".........eu#f#f#f#f#f#f#f#f#f#flsg.........eheullllllluuhhduuehsshheullllluehuhh.....",
".........gal#f#f#f#f#f#f#f#f#f#hl..........eeullll#lllluehadasadhulell#lfllllueh.....",
"..........ualfl#lflflflflfl#llhh...........lhelll#f#lfllhhhllfffhhhllff#f#lluuhg.....",
"...........saulell#l#lfl#lluehaf............eaeull#lleehlg.......#lueuleleehhug......",
"........gllfl#fluhuflllluhuffgfgllf..........gueullluel.............gfulell#g........",
".......ghlgg.g.gguahfl#hshgggggggfhe.................................................",
".......#heelllllueashehasuulullluehhg................................................",
".......feell#lflleesaahshell#f#llleh.................................................",
"........huull#lluuugg...lehllflluuhg.................................................",
".........leelllulg.........flullf#...................................................",
".....................................................................................",
".....................................................................................",
".....................................................................................",
"....................................................................................."};

static const char* const img10_mainDlg[] = { 
"60 18 45 1",
"N c #414041",
"K c #5a9dde",
"M c #5a9de6",
"L c #5aa1e6",
"I c #62a1e6",
"H c #62a5e6",
"E c #6aa5e6",
"J c #6aa5ee",
"F c #6aaae6",
"G c #6aaaee",
"C c #73aae6",
"B c #73aee6",
"A c #73aeee",
"D c #7baeee",
"y c #7bb2e6",
"z c #7bb2ee",
"x c #83b6ee",
"u c #8bbaee",
"w c #8bbeee",
"v c #94beee",
"t c #9cc2ee",
"s c #9cc6f6",
"r c #a4c6ee",
"p c #a4caee",
"q c #a4caf6",
"n c #accef6",
"o c #acd2f6",
"m c #b4d2f6",
"l c #b4d6f6",
"Q c #bdbebd",
"k c #bdd6f6",
"O c #c5bec5",
"P c #c5c2c5",
"j c #cde2f6",
"h c #cde2ff",
"g c #d5e2ff",
"i c #d5e6ff",
"d c #deeaff",
"f c #deeeff",
"e c #e6eeff",
"b c #eef6ff",
"a c #f6f6ff",
"c c #f6faff",
"# c #fffaff",
". c #ffffff",
"............................................................",
"#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.",
"abaacbaaabaaabcaabcacbaacbaaabcaabaacbaaabcaabaaabaaabaacbca",
"dedefededefefefededefefededefedefededefededededefefedededefe",
"ghijihijihijihgjihgjghijghijghijihihihijihijghijihihihijihij",
"kklkkkkkkklkkklkkklkkkkkkklkkkkkkklkkkkkkkkkkklkkklkkkkkkkkk",
"mnmnmnmnmnmnmnmnmomnmnmnmnmnmnmnmomnmnmnmnmnmnmnmnmnmnmnmnmn",
"pqpqrqpqrqpqrqpqpqrqpqpqpqrqpqpqpqpqpqpqpqpqpqrqpqrqpqpqpqpq",
"stststststststststststststststststststststststststststststst",
"uvwvuvuvwvuvuvuvwvuvwvuvwvwvuvwvuvuvwvwvwvuvuvuvuvuvwvuvuvwv",
"uxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxux",
"yzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyz",
"ABABACABABACABABABACABABDCABDBACABABABABABABABACABABABABABAB",
"EFEFEFEFEFEFEGEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEGEFEGEFEGEF",
"HIJIHIJIHIJIHIJIHIJIHIJIHIJIEIJIEIJIHIJIHIJIEIJHEIJIHIJIEIJI",
"KLMIMIMIMLMIMLMIMLMIMLMIMLMIMIMIMIMIKIMIMLMIMIMIMLMIMLMIMLMI",
"NNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN",
"OPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQP"};


/*
 *  Constructs a MainDlg as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 */
MainDlg::MainDlg( QWidget* parent, const char* name, WFlags fl )
    : QWidget( parent, name, fl ),
      image0( (const char **) img0_mainDlg ),
      image1( (const char **) img1_mainDlg ),
      image2( (const char **) img2_mainDlg ),
      image3( (const char **) img3_mainDlg ),
      image4( (const char **) img4_mainDlg ),
      image5( (const char **) img5_mainDlg ),
      image6( (const char **) img6_mainDlg ),
      image7( (const char **) img7_mainDlg ),
      image8( (const char **) img8_mainDlg ),
      image9( (const char **) img9_mainDlg ),
      image10( (const char **) img10_mainDlg )
{
    if ( !name )
	setName( "MainDlg" );
    setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)1, 0, 0, sizePolicy().hasHeightForWidth() ) );
    setMinimumSize( QSize( 300, 398 ) );
    setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    setMouseTracking( TRUE );
    setFocusPolicy( QWidget::ClickFocus );
    MainDlgLayout = new QGridLayout( this, 1, 1, 0, 0, "MainDlgLayout"); 
    spacer36 = new QSpacerItem( 19, 16, QSizePolicy::Minimum, QSizePolicy::Fixed );
    MainDlgLayout->addItem( spacer36, 10, 0 );

    layout34 = new QHBoxLayout( 0, 0, 0, "layout34"); 

    frame15 = new QFrame( this, "frame15" );
    frame15->setMinimumSize( QSize( 100, 32 ) );
    frame15->setMaximumSize( QSize( 32767, 32 ) );
    frame15->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    frame15->setPaletteBackgroundPixmap( image0 );
    frame15->setFrameShape( QFrame::NoFrame );
    frame15->setFrameShadow( QFrame::Plain );
    frame15->setLineWidth( 0 );
    frame15Layout = new QGridLayout( frame15, 1, 1, 0, 0, "frame15Layout"); 

    layout33 = new QVBoxLayout( 0, 0, 0, "layout33"); 
    spacer37 = new QSpacerItem( 20, 16, QSizePolicy::Minimum, QSizePolicy::Fixed );
    layout33->addItem( spacer37 );

    exitButtonPlaceHolder = new QLabel( frame15, "exitButtonPlaceHolder" );
    exitButtonPlaceHolder->setMinimumSize( QSize( 72, 16 ) );
    exitButtonPlaceHolder->setMaximumSize( QSize( 72, 16 ) );
    exitButtonPlaceHolder->setPixmap( image1 );
    exitButtonPlaceHolder->setScaledContents( FALSE );
    layout33->addWidget( exitButtonPlaceHolder );

    frame15Layout->addLayout( layout33, 0, 1 );
    spacer38_2 = new QSpacerItem( 40, 18, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame15Layout->addItem( spacer38_2, 0, 0 );
    layout34->addWidget( frame15 );

    aboutButtonPlaceHolder = new QLabel( this, "aboutButtonPlaceHolder" );
    aboutButtonPlaceHolder->setMinimumSize( QSize( 33, 32 ) );
    aboutButtonPlaceHolder->setMaximumSize( QSize( 33, 32 ) );
    aboutButtonPlaceHolder->setPixmap( image2 );
    aboutButtonPlaceHolder->setScaledContents( FALSE );
    aboutButtonPlaceHolder->setIndent( 0 );
    layout34->addWidget( aboutButtonPlaceHolder );

    MainDlgLayout->addLayout( layout34, 12, 0 );

    pixmapLabel9_2 = new QLabel( this, "pixmapLabel9_2" );
    pixmapLabel9_2->setMinimumSize( QSize( 100, 22 ) );
    pixmapLabel9_2->setMaximumSize( QSize( 32767, 22 ) );
    pixmapLabel9_2->setPaletteBackgroundPixmap( image3 );
    pixmapLabel9_2->setScaledContents( FALSE );

    MainDlgLayout->addWidget( pixmapLabel9_2, 13, 0 );

    frame21 = new QFrame( this, "frame21" );
    frame21->setMinimumSize( QSize( 150, 28 ) );
    frame21->setMaximumSize( QSize( 32767, 28 ) );
    frame21->setFrameShape( QFrame::NoFrame );
    frame21->setFrameShadow( QFrame::Plain );
    frame21Layout = new QGridLayout( frame21, 1, 1, 0, 0, "frame21Layout"); 
    spacer11 = new QSpacerItem( 16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    frame21Layout->addItem( spacer11, 0, 6 );
    spacer38_3 = new QSpacerItem( 5, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    frame21Layout->addItem( spacer38_3, 0, 4 );

    statusPix = new QLabel( frame21, "statusPix" );
    statusPix->setMinimumSize( QSize( 28, 26 ) );
    statusPix->setMaximumSize( QSize( 28, 26 ) );
    statusPix->setPixmap( image4 );
    statusPix->setScaledContents( FALSE );

    frame21Layout->addWidget( statusPix, 0, 3 );
    spacer38 = new QSpacerItem( 5, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    frame21Layout->addItem( spacer38, 0, 2 );

    StatusSwitch = new QComboBox( FALSE, frame21, "StatusSwitch" );
    StatusSwitch->setMaximumSize( QSize( 32767, 24 ) );
    StatusSwitch->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    QPalette pal;
    QColorGroup cg;
    cg.setColor( QColorGroup::Foreground, black );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, white );
    cg.setColor( QColorGroup::HighlightedText, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Link, black );
    cg.setColor( QColorGroup::LinkVisited, black );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, black );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, white );
    cg.setColor( QColorGroup::HighlightedText, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Link, black );
    cg.setColor( QColorGroup::LinkVisited, black );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, white );
    cg.setColor( QColorGroup::HighlightedText, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Link, black );
    cg.setColor( QColorGroup::LinkVisited, black );
    pal.setDisabled( cg );
    StatusSwitch->setPalette( pal );
    StatusSwitch->setBackgroundOrigin( QComboBox::AncestorOrigin );
    StatusSwitch->setFocusPolicy( QComboBox::ClickFocus );

    frame21Layout->addWidget( StatusSwitch, 0, 1 );
    spacer38_4 = new QSpacerItem( 10, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    frame21Layout->addItem( spacer38_4, 0, 0 );

    Online = new QLabel( frame21, "Online" );
    Online->setMinimumSize( QSize( 145, 0 ) );
    Online->setMaximumSize( QSize( 32767, 32767 ) );
    Online->setPaletteForegroundColor( QColor( 3, 118, 231 ) );

    frame21Layout->addWidget( Online, 0, 5 );

    MainDlgLayout->addWidget( frame21, 11, 0 );
    spacer39 = new QSpacerItem( 20, 16, QSizePolicy::Minimum, QSizePolicy::Fixed );
    MainDlgLayout->addItem( spacer39, 8, 0 );

    layout6 = new QHBoxLayout( 0, 0, 0, "layout6"); 
    spacer38_4_2 = new QSpacerItem( 10, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout6->addItem( spacer38_4_2 );

    frame6 = new QFrame( this, "frame6" );
    frame6->setMinimumSize( QSize( 100, 28 ) );
    frame6->setMaximumSize( QSize( 32767, 28 ) );
    frame6->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    frame6->setFrameShape( QFrame::NoFrame );
    frame6->setFrameShadow( QFrame::Plain );

    menuButtonPlaceHolder = new QLabel( frame6, "menuButtonPlaceHolder" );
    menuButtonPlaceHolder->setGeometry( QRect( 0, 0, 82, 28 ) );
    menuButtonPlaceHolder->setMinimumSize( QSize( 82, 28 ) );
    menuButtonPlaceHolder->setMaximumSize( QSize( 82, 28 ) );
    menuButtonPlaceHolder->setPixmap( image5 );
    menuButtonPlaceHolder->setScaledContents( FALSE );
    layout6->addWidget( frame6 );

    MainDlgLayout->addLayout( layout6, 9, 0 );
    spacer12 = new QSpacerItem( 20, 16, QSizePolicy::Minimum, QSizePolicy::Fixed );
    MainDlgLayout->addItem( spacer12, 6, 0 );
    spacer21 = new QSpacerItem( 20, 16, QSizePolicy::Minimum, QSizePolicy::Fixed );
    MainDlgLayout->addItem( spacer21, 4, 0 );

    layout12 = new QHBoxLayout( 0, 0, 0, "layout12"); 
    spacer15 = new QSpacerItem( 10, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout12->addItem( spacer15 );

    FriendListView = new QListView( this, "FriendListView" );
    FriendListView->addColumn( ( "1" ) );
    FriendListView->header()->setClickEnabled( FALSE, FriendListView->header()->count() - 1 );
    FriendListView->addColumn( ( "2" ) );
    FriendListView->header()->setClickEnabled( FALSE, FriendListView->header()->count() - 1 );
    FriendListView->header()->setResizeEnabled( FALSE, FriendListView->header()->count() - 1 );
    FriendListView->setMinimumSize( QSize( 100, 50 ) );
    FriendListView->setPaletteForegroundColor( QColor( 3, 118, 231 ) );
    FriendListView->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, QColor( 218, 218, 218) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 236, 236, 236) );
    cg.setColor( QColorGroup::Dark, QColor( 109, 109, 109) );
    cg.setColor( QColorGroup::Mid, QColor( 145, 145, 145) );
    cg.setColor( QColorGroup::Text, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, white );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 230, 244, 240) );
    cg.setColor( QColorGroup::HighlightedText, QColor( 0, 0, 255) );
    cg.setColor( QColorGroup::Link, white );
    cg.setColor( QColorGroup::LinkVisited, white );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, QColor( 218, 218, 218) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 250, 250, 250) );
    cg.setColor( QColorGroup::Dark, QColor( 109, 109, 109) );
    cg.setColor( QColorGroup::Mid, QColor( 145, 145, 145) );
    cg.setColor( QColorGroup::Text, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, white );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 230, 244, 240) );
    cg.setColor( QColorGroup::HighlightedText, QColor( 0, 0, 255) );
    cg.setColor( QColorGroup::Link, white );
    cg.setColor( QColorGroup::LinkVisited, white );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, QColor( 218, 218, 218) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 250, 250, 250) );
    cg.setColor( QColorGroup::Dark, QColor( 109, 109, 109) );
    cg.setColor( QColorGroup::Mid, QColor( 145, 145, 145) );
    cg.setColor( QColorGroup::Text, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 230, 244, 240) );
    cg.setColor( QColorGroup::HighlightedText, QColor( 0, 0, 255) );
    cg.setColor( QColorGroup::Link, white );
    cg.setColor( QColorGroup::LinkVisited, white );
    pal.setDisabled( cg );
    FriendListView->setPalette( pal );
    FriendListView->setBackgroundOrigin( QListView::WidgetOrigin );
    FriendListView->setFocusPolicy( QListView::ClickFocus );
    FriendListView->setFrameShape( QListView::GroupBoxPanel );
    FriendListView->setFrameShadow( QListView::Plain );
    FriendListView->setLineWidth( 0 );
    FriendListView->setMargin( 0 );
    FriendListView->setMidLineWidth( 0 );
    FriendListView->setVScrollBarMode( QListView::AlwaysOn );
    FriendListView->setHScrollBarMode( QListView::Auto );
    FriendListView->setDragAutoScroll( TRUE );
    FriendListView->setSelectionMode( QListView::Single );
    FriendListView->setAllColumnsShowFocus( TRUE );
    FriendListView->setShowSortIndicator( FALSE );
    FriendListView->setItemMargin( 0 );
    FriendListView->setRootIsDecorated( TRUE );
    FriendListView->setShowToolTips( FALSE );
    FriendListView->setResizeMode( QListView::AllColumns );
    FriendListView->setTreeStepSize( 25 );
    layout12->addWidget( FriendListView );
    spacer13_2 = new QSpacerItem( 10, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout12->addItem( spacer13_2 );

    MainDlgLayout->addLayout( layout12, 7, 0 );

    layout64 = new QHBoxLayout( 0, 0, 0, "layout64"); 
    spacer19 = new QSpacerItem( 16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout64->addItem( spacer19 );

    messageODD = new QLineEdit( this, "messageODD" );
    cg.setColor( QColorGroup::Foreground, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Button, QColor( 202, 202, 202) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 228, 228, 228) );
    cg.setColor( QColorGroup::Dark, QColor( 101, 101, 101) );
    cg.setColor( QColorGroup::Mid, QColor( 134, 134, 134) );
    cg.setColor( QColorGroup::Text, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Button, QColor( 202, 202, 202) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 232, 232, 232) );
    cg.setColor( QColorGroup::Dark, QColor( 101, 101, 101) );
    cg.setColor( QColorGroup::Mid, QColor( 134, 134, 134) );
    cg.setColor( QColorGroup::Text, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, QColor( 202, 202, 202) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 232, 232, 232) );
    cg.setColor( QColorGroup::Dark, QColor( 101, 101, 101) );
    cg.setColor( QColorGroup::Mid, QColor( 134, 134, 134) );
    cg.setColor( QColorGroup::Text, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setDisabled( cg );
    messageODD->setPalette( pal );
    messageODD->setFocusPolicy( QLineEdit::ClickFocus );
    messageODD->setFrameShape( QLineEdit::LineEditPanel );
    messageODD->setFrameShadow( QLineEdit::Plain );
    messageODD->setLineWidth( 1 );
    messageODD->setMaxLength( 255 );
    layout64->addWidget( messageODD );
    spacer20 = new QSpacerItem( 16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout64->addItem( spacer20 );

    MainDlgLayout->addLayout( layout64, 5, 0 );
    spacer11_2 = new QSpacerItem( 20, 10, QSizePolicy::Minimum, QSizePolicy::Fixed );
    MainDlgLayout->addItem( spacer11_2, 2, 0 );

    frame4 = new QFrame( this, "frame4" );
    frame4->setMinimumSize( QSize( 100, 21 ) );
    frame4->setMaximumSize( QSize( 32767, 21 ) );
    frame4->setPaletteBackgroundPixmap( image6 );
    frame4->setFrameShape( QFrame::NoFrame );
    frame4->setFrameShadow( QFrame::Plain );
    frame4Layout = new QGridLayout( frame4, 1, 1, 0, 0, "frame4Layout"); 

    pixmapLabel1 = new QLabel( frame4, "pixmapLabel1" );
    pixmapLabel1->setMinimumSize( QSize( 104, 21 ) );
    pixmapLabel1->setMaximumSize( QSize( 104, 21 ) );
    pixmapLabel1->setPixmap( image7 );
    pixmapLabel1->setScaledContents( FALSE );

    frame4Layout->addWidget( pixmapLabel1, 0, 0 );

    pixmapLabel2_2_2 = new QLabel( frame4, "pixmapLabel2_2_2" );
    pixmapLabel2_2_2->setMinimumSize( QSize( 72, 21 ) );
    pixmapLabel2_2_2->setMaximumSize( QSize( 72, 21 ) );
    pixmapLabel2_2_2->setPixmap( image8 );
    pixmapLabel2_2_2->setScaledContents( FALSE );

    frame4Layout->addWidget( pixmapLabel2_2_2, 0, 2 );
    spacer123 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame4Layout->addItem( spacer123, 0, 1 );

    MainDlgLayout->addWidget( frame4, 1, 0 );

    layout6_2 = new QHBoxLayout( 0, 0, 0, "layout6_2"); 
    spacer14_2 = new QSpacerItem( 16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout6_2->addItem( spacer14_2 );

    pixmapLabel2_2 = new QLabel( this, "pixmapLabel2_2" );
    pixmapLabel2_2->setMinimumSize( QSize( 85, 63 ) );
    pixmapLabel2_2->setMaximumSize( QSize( 85, 63 ) );
    pixmapLabel2_2->setPixmap( image9 );
    pixmapLabel2_2->setScaledContents( FALSE );
    layout6_2->addWidget( pixmapLabel2_2 );
    spacer14_2_2 = new QSpacerItem( 16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout6_2->addItem( spacer14_2_2 );
    spacer14 = new QSpacerItem( 63, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout6_2->addItem( spacer14 );

    statistics = new QTextEdit( this, "statistics" );
    statistics->setMinimumSize( QSize( 220, 0 ) );
    statistics->setMaximumSize( QSize( 32767, 63 ) );
    statistics->setPaletteForegroundColor( QColor( 3, 118, 231 ) );
    cg.setColor( QColorGroup::Foreground, black );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, black );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setDisabled( cg );
    statistics->setPalette( pal );
    statistics->setBackgroundOrigin( QTextEdit::WindowOrigin );
    statistics->setFrameShape( QTextEdit::NoFrame );
    statistics->setFrameShadow( QTextEdit::Plain );
    statistics->setLineWidth( 2 );
    statistics->setReadOnly( TRUE );
    layout6_2->addWidget( statistics );
    spacer10 = new QSpacerItem( 62, 47, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout6_2->addItem( spacer10 );

    MainDlgLayout->addLayout( layout6_2, 3, 0 );

    layout8 = new QVBoxLayout( 0, 0, 0, "layout8"); 

    menuFrame = new QFrame( this, "menuFrame" );
    menuFrame->setMinimumSize( QSize( 0, 16 ) );
    menuFrame->setMaximumSize( QSize( 32767, 16 ) );
    menuFrame->setFrameShape( QFrame::NoFrame );
    menuFrame->setFrameShadow( QFrame::Plain );
    menuFrame->setLineWidth( 0 );
    menuFrame->setMargin( 0 );
    layout8->addWidget( menuFrame );

    frame3 = new QFrame( this, "frame3" );
    frame3->setMinimumSize( QSize( 100, 18 ) );
    frame3->setMaximumSize( QSize( 32767, 18 ) );
    frame3->setPaletteBackgroundPixmap( image10 );
    frame3->setFrameShape( QFrame::NoFrame );
    frame3->setFrameShadow( QFrame::Plain );
    layout8->addWidget( frame3 );

    MainDlgLayout->addLayout( layout8, 0, 0 );
    languageChange();
    resize( QSize(335, 500).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );
}

/*
 *  Destroys the object and frees any allocated resources
 */
MainDlg::~MainDlg()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void MainDlg::languageChange()
{
    setCaption( ( "Form1" ) );
    StatusSwitch->clear();
    StatusSwitch->insertItem( ( "Disponibile" ) );
    StatusSwitch->insertItem( ( "Solo amici" ) );
    StatusSwitch->insertItem( ( "Occupato" ) );
    StatusSwitch->insertItem( ( "Assente" ) );
    QToolTip::add( StatusSwitch, ( "Cambia il tuo stato" ) );
    Online->setText( ( "Utenti online:" ) );
    FriendListView->header()->setLabel( 0, ( "1" ) );
    FriendListView->header()->setLabel( 1, ( "2" ) );
    QToolTip::add( FriendListView, ( "Lista dei netfriend" ) );
    messageODD->setText( ( "Digita qui il tuo messaggio.." ) );
    QToolTip::add( messageODD, ( "Inserisci il tuo messaggio personale" ) );
}

#include "mainDlg.moc"
