/****************************************************************************
** Form interface generated from reading ui file './search.ui'
**
** Created: Fri Jan 12 20:07:13 2007
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef SEARCH_H
#define SEARCH_H

#include <qvariant.h>
#include <qpixmap.h>
#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QLabel;
class QFrame;
class QListView;
class QListViewItem;
class QComboBox;
class QRadioButton;
class QLineEdit;
class QCheckBox;

class search : public QDialog
{
    Q_OBJECT

public:
    search( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~search();

    QLabel* pixmapLabel1_2_3;
    QFrame* frame58_2;
    QLabel* pixmapLabel1_2_2_2;
    QLabel* textLabel1;
    QFrame* frame16;
    QLabel* pixmapLabel1;
    QLabel* pixmapLabel2_2;
    QLabel* pixmapLabel3_3;
    QLabel* pixmapLabel3_2_2_2;
    QLabel* pixmapLabel3_2_3;
    QFrame* frame15;
    QLabel* exitButtonPlaceHolder;
    QLabel* aboutButtonPlaceHolder;
    QLabel* pixmapLabel9_2;
    QFrame* frame20;
    QFrame* frame7;
    QLabel* pixmapLabel3;
    QLabel* pixmapLabel3_2_2;
    QLabel* pixmapLabel3_2;
    QLabel* pixmapLabel1_2;
    QFrame* frame58;
    QLabel* foundUsers;
    QLabel* pixmapLabel1_2_2;
    QListView* onlinePeople;
    QFrame* frame24;
    QLabel* label0;
    QComboBox* combo0;
    QLabel* label1;
    QComboBox* combo1;
    QComboBox* searchSave;
    QLabel* saveButtonPlaceHolder;
    QLabel* label2;
    QComboBox* combo2;
    QLabel* label3;
    QComboBox* combo3;
    QLabel* label4;
    QComboBox* combo4;
    QLabel* searchButtonPlaceHolder;
    QFrame* frame10;
    QRadioButton* profileSwitch;
    QRadioButton* emailSwitch;
    QLineEdit* emailEdit;
    QRadioButton* nickSwitch;
    QLineEdit* nickEdit;
    QCheckBox* notInListFilter;
    QCheckBox* onlyAvailable;
    QCheckBox* onlyPhoto;

protected:
    QGridLayout* searchLayout;
    QSpacerItem* spacer140;
    QSpacerItem* spacer43_2;
    QSpacerItem* spacer46_2_2;
    QHBoxLayout* layout59;
    QSpacerItem* spacer43;
    QSpacerItem* spacer46_2;
    QHBoxLayout* layout78_2;
    QVBoxLayout* layout119;
    QGridLayout* frame16Layout;
    QSpacerItem* spacer212;
    QHBoxLayout* layout61;
    QSpacerItem* spacer43_3;
    QSpacerItem* spacer46_2_3;
    QHBoxLayout* layout41_2;
    QHBoxLayout* layout23;
    QGridLayout* frame15Layout;
    QSpacerItem* spacer38;
    QVBoxLayout* layout22;
    QSpacerItem* spacer37;
    QGridLayout* frame20Layout;
    QVBoxLayout* layout59_2;
    QSpacerItem* spacer33;
    QSpacerItem* spacer77;
    QHBoxLayout* layout75;
    QSpacerItem* spacer78;
    QHBoxLayout* layout64;
    QHBoxLayout* layout33;
    QSpacerItem* spacer31;
    QGridLayout* frame7Layout;
    QHBoxLayout* layout41;
    QHBoxLayout* layout78;
    QVBoxLayout* layout60;
    QSpacerItem* spacer93;
    QSpacerItem* spacer41;
    QHBoxLayout* layout56;
    QSpacerItem* spacer90;
    QSpacerItem* spacer91;
    QGridLayout* frame24Layout;
    QHBoxLayout* layout53;
    QSpacerItem* spacer133;
    QSpacerItem* spacer37_2;
    QSpacerItem* spacer135;
    QHBoxLayout* layout69;
    QVBoxLayout* layout33_5;
    QVBoxLayout* layout48;
    QVBoxLayout* layout50;
    QSpacerItem* spacer38_2;
    QHBoxLayout* layout49;
    QSpacerItem* spacer43_4;
    QHBoxLayout* layout54;
    QSpacerItem* spacer134;
    QSpacerItem* spacer136;
    QSpacerItem* spacer39;
    QSpacerItem* spacer40;
    QHBoxLayout* layout71;
    QVBoxLayout* layout33_3;
    QHBoxLayout* layout72;
    QVBoxLayout* layout33_4;
    QVBoxLayout* layout33_4_2;
    QVBoxLayout* layout120;
    QSpacerItem* spacer137;
    QHBoxLayout* layout55;
    QSpacerItem* spacer75;
    QSpacerItem* spacer76;
    QGridLayout* frame10Layout;
    QHBoxLayout* layout47;
    QSpacerItem* spacer107;
    QSpacerItem* spacer42;
    QSpacerItem* spacer140_2;
    QVBoxLayout* layout45;
    QHBoxLayout* layout43;
    QHBoxLayout* layout44;
    QVBoxLayout* layout46;

protected slots:
    virtual void languageChange();

private:
    QPixmap image0;
    QPixmap image1;
    QPixmap image2;
    QPixmap image3;
    QPixmap image4;
    QPixmap image5;
    QPixmap image6;
    QPixmap image7;
    QPixmap image8;
    QPixmap image9;
    QPixmap image10;
    QPixmap image11;
    QPixmap image12;
    QPixmap image13;
    QPixmap image14;
    QPixmap image15;

};

#endif // SEARCH_H
