/****************************************************************************
** Form interface generated from reading ui file './profile.ui'
**
** Created: Sun Dec 17 12:38:45 2006
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef PROFILE_H
#define PROFILE_H

#include <qvariant.h>
#include <qpixmap.h>
#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QLabel;
class QFrame;

class profile : public QDialog
{
    Q_OBJECT

public:
    profile( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~profile();

    QLabel* textLabel1;
    QFrame* frame38;
    QFrame* frame15;
    QLabel* exitButtonPlaceHolder;
    QLabel* aboutButtonPlaceHolder;
    QFrame* frame49;
    QLabel* pixmapLabel1_2;
    QFrame* frame50;
    QLabel* nickLabel;
    QLabel* pixmapLabel2;
    QFrame* frame34;
    QLabel* pixmapLabel1_3;
    QLabel* pixmapLabel3;
    QLabel* pixmapLabel2_2;
    QLabel* pixmapLabel3_2;
    QLabel* pixmapLabel3_2_2;
    QFrame* frame35;
    QLabel* profileLabel;
    QFrame* profileInfo;
    QFrame* furtherInfo;
    QFrame* frame16;
    QLabel* pixmapLabel1;
    QLabel* pixmapLabel2_2_2;
    QLabel* pixmapLabel9_2;

protected:
    QGridLayout* profileLayout;
    QHBoxLayout* layout23;
    QGridLayout* frame15Layout;
    QSpacerItem* spacer38;
    QVBoxLayout* layout22;
    QSpacerItem* spacer37;
    QGridLayout* frame49Layout;
    QSpacerItem* spacer63;
    QSpacerItem* spacer117;
    QSpacerItem* spacer65;
    QSpacerItem* spacer64;
    QHBoxLayout* layout115;
    QSpacerItem* spacer114;
    QSpacerItem* spacer115;
    QGridLayout* frame16Layout;
    QSpacerItem* spacer141;

protected slots:
    virtual void languageChange();

private:
    QPixmap image0;
    QPixmap image1;
    QPixmap image2;
    QPixmap image3;
    QPixmap image4;
    QPixmap image5;
    QPixmap image6;
    QPixmap image7;
    QPixmap image8;
    QPixmap image9;
    QPixmap image10;
    QPixmap image11;
    QPixmap image12;
    QPixmap image13;
    QPixmap image14;
    QPixmap image15;
    QPixmap image16;
    QPixmap image17;
    QPixmap image18;

};

#endif // PROFILE_H
