/***************************************************************************
                          macroetc.h  -  description
                             -------------------
    begin                : Fri Mar 7 2003
    copyright            : (C) 2003 by Giorgio A.
    email                : openc6@hotmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MACROETC
#define MACROETC

#define C6DEBUG
#define NORESULT 255

#define BYTE unsigned char
#define WORD short int

enum USER_MENU_ACTIONS 
{
    USRLOG,  
    REMOVENICK,
    PROFILE,
    ALLPROFILE,
    INITCHAT,
    KICK,   
    ADDROOTNICK,
    SENDFILE,
    TOGGLEONLINE,
    REVOKE_AUTH,   
    ADDNICK,
    STARTCHAT,    
    SORTORDER,
    REMOVEGROUP,
    ADDGROUP,
    RENAMEGROUP,    
    SHOW_FRIENDS,
    SHOW_WHITE,       
    MOVE
};

#define C6DIR QString(".OpenC6")
#define C6VERSION "0.9.9"
 
#define NETSEARCH 0
#define IMPORTLIST 1
#define ROOMLIST 2
#define USERLOG 3
#define SYSLOG 4
#define ROOMLOG 5
#define CONFIG 6
#define CREDITS 7
#define EXITMAIN 8
#define FORCE_EXITMAIN 9
#define SINGLEUSERLOG 50
#define SINGLEROOMLOG 51
#define CHANGENICK 100

#define BLKSTR "ti ha inserito nella Lista nera.\nNon puoi comunicare con lui/lei."
#define NEWMESSAGESTR QString("Nuovi Messaggi arrivati da:")
#define RECEIVE_ABORT_TRANSFER_MSG(filename,nick) QString("Ricezione del file ")+filename+" da "+nick+" interrotta!"
#define END_OF_RECEIVE_MSG(filename,filesize) QString("Ricezione del file ")+filename+" ("+QString::number(filesize)+" bytes) "+"completata con successo!"
#define NO_USER_FOUND_MSG QString("Nessun utente trovato")
#define C6NAME QString("OpenC6")
#define C6USERSDIR QString("Users")



#endif
