/****************************************************************************
** Form interface generated from reading ui file './logview.ui'
**
** Created: Sun Dec 17 12:38:45 2006
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef LOGVIEW_H
#define LOGVIEW_H

#include <qvariant.h>
#include <qpixmap.h>
#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QFrame;
class QLabel;
class QListBox;
class QListBoxItem;
class QTextEdit;
class QLineEdit;

class logview : public QDialog
{
    Q_OBJECT

public:
    logview( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~logview();

    QFrame* frame16;
    QLabel* pixmapLabel1;
    QLabel* pixmapLabel2_2;
    QLabel* pixmapLabel4_2;
    QFrame* frame28;
    QLabel* roomName;
    QLabel* pixmapLabel4;
    QListBox* FileList;
    QLabel* pixmapLabel4_2_2;
    QFrame* frame28_2;
    QLabel* dateLog;
    QLabel* pixmapLabel4_3;
    QTextEdit* _logView;
    QLineEdit* searchEdit;
    QLabel* findButtonPlaceHolder;
    QLabel* textLabel1;
    QLabel* pixmapLabel9_2;
    QFrame* frame15;
    QLabel* exitButtonPlaceHolder;
    QLabel* aboutButtonPlaceHolder;

protected:
    QGridLayout* logviewLayout;
    QGridLayout* frame16Layout;
    QSpacerItem* spacer109;
    QVBoxLayout* layout33;
    QSpacerItem* spacer40;
    QVBoxLayout* layout25;
    QHBoxLayout* layout40;
    QSpacerItem* spacer14_2;
    QSpacerItem* spacer15_2;
    QHBoxLayout* layout22;
    QSpacerItem* spacer14;
    QSpacerItem* spacer15;
    QVBoxLayout* layout35;
    QSpacerItem* spacer41;
    QSpacerItem* spacer42;
    QHBoxLayout* layout40_2;
    QSpacerItem* spacer14_2_2;
    QSpacerItem* spacer15_2_2;
    QHBoxLayout* layout31;
    QSpacerItem* spacer14_3;
    QSpacerItem* spacer15_3;
    QHBoxLayout* layout34;
    QSpacerItem* spacer39;
    QSpacerItem* spacer38_2;
    QSpacerItem* spacer15_3_2;
    QGridLayout* frame15Layout;
    QSpacerItem* spacer38;
    QVBoxLayout* layout33_2;
    QSpacerItem* spacer37;

protected slots:
    virtual void languageChange();

private:
    QPixmap image0;
    QPixmap image1;
    QPixmap image2;
    QPixmap image3;
    QPixmap image4;
    QPixmap image5;
    QPixmap image6;
    QPixmap image7;
    QPixmap image8;
    QPixmap image9;
    QPixmap image10;
    QPixmap image11;
    QPixmap image12;

};

#endif // LOGVIEW_H
