
/****************************************************************************
** Form implementation generated from reading ui file './invite.ui'
**
** Created: Sun Dec 17 12:39:14 2006
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#include "invite.h"

#include <qvariant.h>
#include <qpushbutton.h>
#include <qframe.h>
#include <qlabel.h>
#include <qtextedit.h>
#include <qheader.h>
#include <qlistview.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qimage.h>
#include <qpixmap.h>

static const unsigned char img0_invite[] = { 
    0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
    0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x10,
    0x08, 0x06, 0x00, 0x00, 0x00, 0x1f, 0xf3, 0xff, 0x61, 0x00, 0x00, 0x00,
    0x91, 0x49, 0x44, 0x41, 0x54, 0x38, 0x8d, 0xa5, 0x93, 0xdb, 0x0d, 0xc3,
    0x30, 0x08, 0x45, 0x2f, 0xc8, 0x8b, 0x65, 0x93, 0x7a, 0x32, 0x6f, 0x12,
    0x8f, 0x46, 0x3f, 0x52, 0x23, 0x42, 0xa0, 0xc2, 0xca, 0x95, 0x2c, 0x23,
    0x04, 0x07, 0xf0, 0x83, 0x44, 0x04, 0x6f, 0xd4, 0x7e, 0xfb, 0xa2, 0x90,
    0xb1, 0xcb, 0x00, 0xa1, 0x3e, 0x2f, 0xca, 0x38, 0xd4, 0xae, 0x48, 0xc6,
    0x01, 0xde, 0x49, 0xf0, 0xa2, 0x3e, 0x75, 0x84, 0x1b, 0xb5, 0x92, 0xb8,
    0xc4, 0xd6, 0x5f, 0xad, 0x6c, 0x8b, 0x34, 0xe3, 0x14, 0x4f, 0x5f, 0xc1,
    0x91, 0xef, 0x01, 0xb0, 0xc9, 0xd1, 0x18, 0xd9, 0x68, 0x8f, 0x33, 0xc8,
    0x64, 0xbb, 0xb0, 0x30, 0x8e, 0x82, 0x33, 0x45, 0x5d, 0x70, 0x14, 0x40,
    0x7d, 0xea, 0xca, 0xba, 0x50, 0x1f, 0x3e, 0xa7, 0xbe, 0xbc, 0xca, 0x15,
    0x7a, 0x50, 0x78, 0x88, 0xff, 0xe4, 0x8b, 0x70, 0xb5, 0x6a, 0x06, 0x23,
    0xd9, 0xff, 0x8e, 0xb7, 0x0f, 0xd7, 0xb0, 0xf1, 0x02, 0x1d, 0x04, 0x00,
    0xf0, 0x05, 0x98, 0x44, 0x3e, 0x22, 0x75, 0x5a, 0x3f, 0xd7, 0x00, 0x00,
    0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};

static const char* const img1_invite[] = { 
"34 21 3 1",
". c #004991",
"# c #004a91",
"a c #004a92",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"......#...........................",
"..................................",
"..................................",
"..................................",
"..................................",
"....a...................#.........",
"..................................",
".....................a............"};

static const char* const img2_invite[] = { 
"72 21 20 1",
". c #004991",
"# c #004a91",
"a c #004a92",
"b c #004a94",
"m c #004c97",
"h c #004d99",
"l c #004f9c",
"q c #00509d",
"g c #00509f",
"f c #0052a2",
"p c #0053a5",
"e c #0055a8",
"j c #0056aa",
"c c #0057ad",
"i c #0059b0",
"d c #005ab3",
"o c #005cb6",
"n c #005db9",
"r c #005fbb",
"k c #0060be",
"...#...................#................................................",
"........................................................................",
"........................................................................",
"...............................................a........................",
"........................................................................",
"........................................................................",
".......................................................................a",
"..........bcddddde.dddddddf.gdddddddhddddddihbjddddddffdddddddh.........",
"..........ekkkkkkklkkkkkkkkmnkkkkkkklkkkkkkkcfkkkkkkkeokkkkkkkl.........",
"..........dkclllokekkcllpkklkkpllllllkklllckdekolllllmkkclllllb.........",
"..........dke...dkekkefdokkqkkljdddjlkk...ekdekd......kkndddil..........",
"..........dke...dkekkeekkkr.kkldkkkdlkk...ekdekd......kkkkkkkkb.........",
"..........dke...dkekkemlllb.kkl.....lkk...ekdekd......kkdeeckkl.........",
"..........jkkkkkkkfkke......rkkkkkkklkk...ekdpkkkkkkkeokkkkkkkh.........",
"..........lrkkkkknbkke......ekkkkkkklkk...ekdmnkkkkkkegkkkkkkd..........",
"........................................................................",
"........................................................................",
"........................................................................",
"........................................................................",
"........................................................................",
"........................................................................"};

static const char* const img3_invite[] = { 
"60 18 45 1",
"N c #414041",
"K c #5a9dde",
"M c #5a9de6",
"L c #5aa1e6",
"I c #62a1e6",
"H c #62a5e6",
"E c #6aa5e6",
"J c #6aa5ee",
"F c #6aaae6",
"G c #6aaaee",
"C c #73aae6",
"B c #73aee6",
"A c #73aeee",
"D c #7baeee",
"y c #7bb2e6",
"z c #7bb2ee",
"x c #83b6ee",
"u c #8bbaee",
"w c #8bbeee",
"v c #94beee",
"t c #9cc2ee",
"s c #9cc6f6",
"r c #a4c6ee",
"p c #a4caee",
"q c #a4caf6",
"n c #accef6",
"o c #acd2f6",
"m c #b4d2f6",
"l c #b4d6f6",
"Q c #bdbebd",
"k c #bdd6f6",
"O c #c5bec5",
"P c #c5c2c5",
"j c #cde2f6",
"h c #cde2ff",
"g c #d5e2ff",
"i c #d5e6ff",
"d c #deeaff",
"f c #deeeff",
"e c #e6eeff",
"b c #eef6ff",
"a c #f6f6ff",
"c c #f6faff",
"# c #fffaff",
". c #ffffff",
"............................................................",
"#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.",
"abaacbaaabaaabcaabcacbaacbaaabcaabaacbaaabcaabaaabaaabaacbca",
"dedefededefefefededefefededefedefededefededededefefedededefe",
"ghijihijihijihgjihgjghijghijghijihihihijihijghijihihihijihij",
"kklkkkkkkklkkklkkklkkkkkkklkkkkkkklkkkkkkkkkkklkkklkkkkkkkkk",
"mnmnmnmnmnmnmnmnmomnmnmnmnmnmnmnmomnmnmnmnmnmnmnmnmnmnmnmnmn",
"pqpqrqpqrqpqrqpqpqrqpqpqpqrqpqpqpqpqpqpqpqpqpqrqpqrqpqpqpqpq",
"stststststststststststststststststststststststststststststst",
"uvwvuvuvwvuvuvuvwvuvwvuvwvwvuvwvuvuvwvwvwvuvuvuvuvuvwvuvuvwv",
"uxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxux",
"yzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyz",
"ABABACABABACABABABACABABDCABDBACABABABABABABABACABABABABABAB",
"EFEFEFEFEFEFEGEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEGEFEGEFEGEF",
"HIJIHIJIHIJIHIJIHIJIHIJIHIJIEIJIEIJIHIJIHIJIEIJHEIJIHIJIEIJI",
"KLMIMIMIMLMIMLMIMLMIMLMIMLMIMIMIMIMIKIMIMLMIMIMIMLMIMLMIMLMI",
"NNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN",
"OPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQP"};

static const char* const img4_invite[] = { 
"28 18 47 1",
"c c #5a9de6",
"b c #5aa1e6",
"a c #62a1e6",
"d c #62a5e6",
"h c #6aa5e6",
"f c #6aaae6",
"g c #6aaaee",
"# c #737173",
"i c #73aae6",
"e c #73aaee",
"k c #73aee6",
"j c #73aeee",
"n c #7bb2e6",
"l c #7bb2ee",
"m c #83b2ee",
"o c #83b6e6",
"q c #83b6ee",
"p c #83baee",
"r c #8bb6ee",
"s c #8bbaee",
"u c #8bbeee",
"v c #94beee",
"t c #94bef6",
"y c #94c2ee",
"w c #9cc2ee",
"x c #9cc2f6",
"z c #9cc6ee",
"A c #9cc6f6",
"C c #a4caee",
"B c #a4caf6",
"D c #accaf6",
"E c #acceee",
"G c #accef6",
"F c #b4d2f6",
"I c #bdd6f6",
"J c #bddaf6",
"H c #bddaff",
"K c #cde2f6",
"M c #cde2ff",
". c #d5d2d5",
"L c #d5e2ff",
"O c #deeeff",
"N c #e6eeff",
"P c #eef6ff",
"Q c #f6f6ff",
"S c #fffaff",
"R c #ffffff",
"............................",
"############################",
"ababababacababacacacababacab",
"adadadadadadadadadadadadadad",
"efghghghghghehgfghgfghghghgh",
"ijijijikijijijijijijijijijij",
"llmllnmllnmllnmllnmlllmllnml",
"opqpqpqroqqsqpqropqqqqqrqpqp",
"tuvutuvutuvutuvutvvutvvutuvu",
"wxyzwAyzyxyzwxyzyxywwAyzwAyz",
"BCDBBCDBBCDBBCDBBCDBBCDBDCDB",
"EFGFEFGFEFGFGFGFEFGFGFGFEFGF",
"HIJIHIHIHIHIHIHIHIJIHIHIHIJI",
"KLKLKLKMKLKMKLKLKLKMKLKLKLKL",
"NNNNNNNNNNNNNONNNNNNNNNNNNNN",
"PQPQPQPQPQPQPQPQPQPQPQPQPQPQ",
"RRRRRRRRRRRRRSRRRSRSRRRRRRRR",
"RRRRRRRRRRRRRRRRRRRRRRRRRRRR"};

static const char* const img5_invite[] = { 
"34 31 4 1",
"a c #004894",
"b c #004c94",
"# c #004c9c",
". c #ffffff",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba"};

static const char* const img6_invite[] = { 
"51 16 89 2",
".R c #000000",
"#w c #000400",
"#. c #000810",
".o c #000c10",
".M c #000c18",
".n c #001020",
".m c #001429",
".l c #001831",
".p c #001c39",
".k c #002041",
".j c #00244a",
".g c #002c5a",
".i c #003062",
".f c #00346a",
".e c #00386a",
".d c #003873",
".9 c #003c73",
".c c #003c7b",
".h c #004083",
".b c #00448b",
".# c #004894",
".a c #004c94",
"Qt c #004c9c",
".5 c #080808",
".0 c #080c10",
".V c #080c18",
".G c #081018",
"#t c #101010",
"#l c #101410",
".z c #101820",
"#n c #181418",
"#h c #181818",
".U c #181c18",
".q c #182431",
".Z c #201c20",
"#c c #202020",
"#v c #202420",
".8 c #292429",
".3 c #312c31",
".L c #313031",
"#u c #313431",
".Y c #393839",
".4 c #393c39",
"#k c #413c41",
".N c #414041",
".F c #4a444a",
"#g c #4a484a",
"#b c #4a4c4a",
".T c #524c52",
".7 c #5a595a",
"#s c #625d62",
".r c #626162",
".2 c #626562",
".A c #62656a",
".K c #6a656a",
".y c #6a696a",
".W c #6a6d73",
".X c #7b757b",
"#i c #7b797b",
"#f c #837d83",
".E c #838183",
".S c #838583",
"#a c #8b858b",
".s c #8b898b",
"#r c #8b8d8b",
".6 c #948d94",
"#d c #949194",
".x c #9c999c",
"#p c #9c9d9c",
".J c #a49da4",
".t c #a4a1a4",
".B c #aca5ac",
"## c #acaaac",
".D c #acaeac",
"#o c #b4aeb4",
".O c #b4b2b4",
".1 c #b4b6b4",
"#e c #bdb6bd",
".I c #bdbabd",
".H c #bdbebd",
".w c #c5bec5",
".P c #c5c2c5",
".Q c #c5c6c5",
".C c #cdc6cd",
".u c #cdcacd",
".v c #d5ced5",
"#j c #d5d2d5",
"#m c #eee6ee",
"#q c #eeeaee",
"Qt.#.a.#Qt.#.a.#Qt.#.a.#.#.b.b.c.c.d.d.e.d.d.d.e.d.d.d.e.d.d.d.e.d.d.d.e.d.d.d.e.d.d.d.e.d.d.d.e.d.f.g",
".#.#.#.#.#.#.#.#.#.#.b.h.d.i.j.k.l.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.n.o",
".a.#Qt.#.a.#Qt.#.#.c.f.j.p.n.q.r.s.t.u.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.w.x.y",
".#.#.#.#.#.#.b.h.i.j.n.z.A.B.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.C.D.E.F",
"Qt.#.a.#.#.b.c.j.m.G.A.H.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.I.J.K.L",
".#.#.#.#.h.f.p.M.N.O.P.Q.P.C.P.Q.R.R.R.R.R.C.P.Q.P.C.P.Q.P.C.P.Q.P.C.R.R.P.C.P.Q.P.C.P.Q.P.C.P.O.S.T.U",
".a.#.#.h.g.m.V.W.P.P.P.P.P.P.P.P.R.R.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.w.t.X.Y.Z",
".#.#.h.g.n.0.S.P.H.P.H.P.H.P.H.P.R.R.H.P.H.P.H.P.R.R.R.P.H.R.R.R.H.P.R.R.H.P.H.P.H.P.H.P.H.P.1.x.2.3.4",
"Qt.b.f.m.5.E.w.H.w.H.w.H.w.H.w.H.R.R.R.R.R.H.w.R.R.H.w.H.R.R.w.H.w.H.R.R.w.H.w.H.w.H.w.H.w.H.O.6.7.8.y",
".b.9.p#..y.I.I.I.I.I.I.I.I.I.I.I.R.R.I.I.I.I.I.I.R.R.I.I.R.R.I.I.I.I.R.R.I.I.I.I.I.I.I.I.I.I###a#b#c#d",
".h.j.n.N.I#e.I#e.I#e.I#e.I#e.I#e.R.R.I#e.I#e.I#e.I.R.R#e.R.R.I#e.I#e.R.R.I#e.I#e.I#e.I#e.I#e.B#f#g#h.I",
".i.m.0##.O.1.O#e.O.1.O#e.O.1.O#e.R.R.R.R.R.1.O.R.R.R.O#e.O.R.R.R.O.1.R.R.O.1.O#e.O.1.O#e.O.1.t#i.4#h#j",
".j#..y.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.t#i#k#l#m",
".n#n##.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O#p.X.Y#n#q",
".L#b.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.E#s.L#t.P",
"#u#v.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z#h#n.5#w.2"};

static const char* const img7_invite[] = { 
"28 31 202 2",
"ao c #000008",
"#k c #000810",
"#d c #000c18",
"af c #001018",
"#j c #001020",
"#c c #001429",
"#S c #001831",
"#5 c #001c39",
"#i c #002041",
"#b c #00244a",
"#I c #002852",
"#h c #002c5a",
"#a c #003062",
"#4 c #003462",
"#y c #00346a",
"#H c #003873",
"#g c #003c7b",
"## c #004083",
"#x c #004483",
"#. c #00448b",
"#p c #00488b",
".9 c #004894",
"#o c #004c94",
".8 c #004c9c",
"#q c #080810",
"aE c #101820",
"aw c #102439",
"#6 c #182020",
".N c #202020",
".H c #202420",
"ax c #202429",
".G c #292829",
".7 c #292c29",
".V c #312c31",
".F c #313031",
".2 c #313431",
".E c #393439",
".1 c #393839",
".M c #393c39",
"#T c #393c41",
".D c #414041",
".O c #414441",
"#l c #41444a",
"aj c #4195ee",
".C c #4a444a",
".W c #4a4c4a",
"aB c #4a99ee",
"ap c #525052",
".6 c #525552",
"#J c #52555a",
"#8 c #52a1ee",
".B c #5a555a",
".0 c #5a595a",
".L c #5a5d5a",
".w c #626162",
".v c #626562",
"a7 c #62797b",
"bh c #6a656a",
".x c #6a696a",
".u c #6a6d6a",
"#F c #6a9dc5",
"al c #6aaeee",
".t c #737173",
"bc c #738d94",
"a4 c #73aed5",
"a# c #73b2f6",
".K c #7b797b",
".3 c #7b7d7b",
".Z c #7b7d83",
"b# c #7b999c",
"#B c #7ba1c5",
"aG c #7baad5",
"aQ c #7bb2d5",
"a. c #7bb6ee",
".s c #837d83",
".5 c #838183",
".r c #83858b",
"bf c #839594",
"#7 c #83a5cd",
"#E c #83aad5",
"#L c #83b2d5",
"#U c #83b6cd",
"#Y c #83bef6",
".A c #8b858b",
".P c #8b898b",
"ag c #8b8d8b",
"a1 c #8baab4",
"#Q c #8bb6de",
"ar c #8bbad5",
"ay c #8bbed5",
"#2 c #8bbede",
"ad c #8bc2d5",
"#X c #8bc2f6",
"an c #8bc6de",
"aZ c #8bc6e6",
"a6 c #949194",
".q c #94959c",
"#D c #94b6d5",
"bd c #94bec5",
"#u c #94bed5",
"az c #94bee6",
"#A c #94c2d5",
"aS c #94c2de",
"#R c #94c6de",
"aX c #94cae6",
"aY c #94cee6",
".4 c #9c959c",
".J c #9c9da4",
"b. c #9caaac",
"#C c #9cb6d5",
"#G c #9cc6de",
"aT c #9cc6e6",
"a2 c #9ccacd",
"#v c #9ccade",
"aL c #9cceee",
"aD c #9cd2e6",
"aK c #9cd6e6",
"#e c #a49da4",
".p c #a4a1a4",
"ah c #a4bede",
"as c #a4cae6",
"#9 c #a4caf6",
".Y c #acaaac",
"a8 c #accecd",
"aW c #acdae6",
".j c #b4b2b4",
".Q c #b4b6b4",
".k c #b4b6bd",
"#3 c #b4dae6",
"a0 c #b4daee",
"aU c #b4deff",
".i c #bdb6bd",
".h c #bdbabd",
".I c #bdbebd",
"be c #bddede",
"a9 c #bddee6",
"aF c #bddeee",
"aJ c #bddef6",
"ac c #bde6ff",
"#m c #c5bec5",
".g c #c5c2c5",
".f c #c5c6c5",
"#V c #c5cee6",
"#M c #c5d2e6",
"bg c #c5dede",
"aO c #c5def6",
"#t c #c5e2ee",
"aR c #c5e6e6",
"bb c #c5e6ee",
"a3 c #c5eaee",
"a5 c #c5eaff",
"#P c #c5eeff",
".R c #cdc6cd",
".o c #cdcacd",
".S c #cdcecd",
"#w c #cde6ee",
"#K c #cdeaee",
"am c #cdeeff",
"#1 c #cdf6ff",
".e c #d5ced5",
"#r c #d5d2d5",
".d c #d5d6d5",
"ak c #d5e6f6",
"#z c #d5eaee",
"ai c #d5eaff",
"aP c #d5eef6",
"aC c #d5eeff",
"aM c #d5faff",
".z c #dedade",
".U c #dedede",
".n c #dedee6",
"#s c #deeaee",
"av c #deeeee",
"#0 c #def6f6",
"#O c #defaff",
".c c #e6dee6",
"aq c #e6e2e6",
"#f c #e6e6e6",
"#n c #e6eaee",
"ba c #e6eeee",
"ae c #e6eef6",
"#Z c #e6f2f6",
"au c #e6f6ff",
"aH c #e6faf6",
"ab c #e6faff",
".X c #eee6ee",
".b c #eeeaee",
".m c #eeeeee",
"aV c #eeeef6",
"#W c #eef2ff",
"aI c #eef6ff",
"aN c #eefaff",
"at c #eeffff",
".y c #f6eef6",
".T c #f6f2f6",
".a c #f6f6ff",
"aA c #f6faf6",
"#N c #f6ffff",
".l c #fff6ff",
".# c #fffaff",
"aa c #fffff6",
"Qt c #ffffff",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.#.a.b.c.d.e.f.g.h.i.j.i.k",
"QtQtQtQtQtQtQtQtQtQtQtQt.#.l.m.n.o.i.p.q.r.s.t.u.v.v.w.x",
"QtQtQtQtQtQtQtQtQtQtQt.l.y.z.g.p.A.x.B.C.D.E.F.G.G.H.G.G",
"QtQtQtQtQtQtQtQtQt.#.b.z.I.J.K.L.M.G.N.G.O.u.P.p.Q.R.S.o",
"QtQtQtQtQtQtQt.#.T.U.f.J.s.B.M.N.V.W.P.h.X.b.m.b.y.b.m.b",
"QtQtQtQtQtQt.a.b.S.Y.Z.0.1.N.2.3.h.b.b.b.b.b.b.b.b.b.b.b",
"QtQtQtQtQt.l.X.g.4.v.D.N.E.5.e.b.m.b.y.b.m.b.y.b.m.b.y.b",
"QtQtQtQt.T.c.i.P.6.7.N.x.f.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b",
".8.9.9#.###a#b#c#d.G#e#f.y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b",
".9.9#.#g#h#i#j#k#l#m.b.b.b.b#n#n#n#n#n.b.b.b.b.b.b.b.b.b",
"#o#p###a#i#j#q.0#r.b.y.b.m#s#t#u#u#v#w#n.m.b.y.b.m.b.y.b",
"#.#x#y#b#j#k.L.z.b.b.b.b#z#A#B#C#D#E#F#G#z.b.b.b.b.b.b.b",
"#.#H#I#c#k#J.U.b.y.b.m#K#L#MQtQt#N#O#P#Q#R#s.m.b.y.b.m.b",
"#H#h#S#d#T.e.b.b.b.b#s#U#V#W#X#Y#ZQt#0#1#2#3#n.b.b.b.b.b",
"#4#5#j#6.i.b.y.b.m#n#t#7Qt#8#9a.a#aaQtabacadae.b.m.b.y.b",
"#5af#qag.b.b.b.b.b#n#AahaiajaaakalQtaa#Naman#z.b.b.b.b.b",
"#kaoapaq.y.b.m.b.y#narasata.Qtaka#aaQt#Nau#Rav.b.y.b.m.b",
"awax.Q.b.b.b.b.b.b#nayaz#OQtaaaAaB#WaaQtaCaD#s.b.b.b.b.b",
"aE.x.b.b.m.b.y.b.m#naFaG#1aHQtaaak#8aIQtaJaKae.b.m.b.y.b",
"ax#m.b.b.b.b.b.b.b.b#sayaLaMaNQtaaaOaaQtaPaQaR.b.b.b.b.b",
".waq.m.b.y.b.m.b.y.b.m#zaSaTamab#NaNQtaaabaUay#zaV.b.m.b",
".p.b.b.b.b.b.b.b.b.b.b.b#zaWanaXaYaZa0#OaN#Na1a2#s.b.b.b",
"#r.b.y.b.m.b.y.b.m.b.y.b.m#nae#zava3a4a5Qtaqa6a7a8#n.y.b",
"#f.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b#na9aQb..g.o.5b##s.b.b",
".y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.bbabbbc.5.R.pbd#s.m.b",
".b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b#nbeb#bfbgaR#n.b.b",
".m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.bba#z#w#zba.b.y.b",
".b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b",
".y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b",
".I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m",
".xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh"};

static const char* const img8_invite[] = { 
"11 18 53 1",
"g c #0075e6",
"b c #0075ee",
"R c #0079e6",
"Y c #0079ee",
". c #0879ee",
"t c #1881ee",
"x c #2989ee",
"S c #298dee",
"X c #3191ee",
"U c #3991ee",
"L c #5aa5f6",
"C c #62aaf6",
"# c #73aae6",
"d c #73aee6",
"a c #73aeee",
"e c #7baee6",
"c c #7bb2ee",
"O c #7bb6ff",
"f c #83b6ee",
"P c #83baff",
"h c #8bbaee",
"i c #8bbeee",
"Q c #8bbeff",
"l c #94beee",
"j c #94c2ee",
"N c #94c6ff",
"k c #9cc2f6",
"n c #9cc6ee",
"m c #a4c6f6",
"q c #a4caf6",
"G c #a4cef6",
"p c #accaf6",
"o c #accef6",
"W c #acd2f6",
"M c #acd2ff",
"s c #b4d2f6",
"V c #b4d6ff",
"r c #bddaf6",
"y c #bddaff",
"w c #c5daf6",
"v c #c5deff",
"u c #cde2ff",
"z c #d5e6f6",
"B c #d5e6ff",
"A c #deeaff",
"T c #deeeff",
"H c #e6f2ff",
"E c #eef2ff",
"F c #eef6ff",
"D c #f6f6ff",
"J c #f6faff",
"K c #fffaff",
"I c #ffffff",
".#a#a#a#a#a",
"bcdcecdcdcd",
".ffffffffff",
"ghhhhhhihhh",
".jklkjkjkjk",
"bmnmnmnmnmn",
".oopopoooqo",
"grsssssssss",
"tuvwvwvwvwv",
"xyzABAzABAz",
"CCDEFEDEFEF",
"G.HIJIJIJIK",
"IxLIIIIIIII",
"IMgNIIIIIII",
"IIO.PIIIIII",
"IIIQRSuIJJF",
"IIIITU.LVBI",
"IIIIIIWLXYg"};

static const char* const img9_invite[] = { 
"21 18 33 1",
"E c #0075e6",
"C c #0075ee",
"D c #0079ee",
"# c #73aae6",
"c c #73aee6",
". c #73aeee",
"a c #7baee6",
"b c #7bb2ee",
"d c #83b6ee",
"e c #8bbaee",
"f c #8bbeee",
"j c #94beee",
"h c #94c2ee",
"i c #94c2f6",
"g c #9cc2f6",
"k c #9cc6ee",
"m c #9cc6f6",
"l c #a4c6f6",
"o c #accaf6",
"n c #accef6",
"q c #acd2f6",
"p c #b4d2f6",
"s c #c5daf6",
"r c #c5deff",
"v c #d5e6f6",
"t c #d5e6ff",
"u c #deeaff",
"x c #eef2ff",
"w c #eef6ff",
"y c #f6f6ff",
"z c #f6faff",
"B c #fffaff",
"A c #ffffff",
".#.#.#.#.#.#.#.#.#.#.",
"abcbcbcbabcbabcbcbcbc",
"ddddddddddddddddddddd",
"eeeeeeefefeeeeeeeeeee",
"ghghghghghijghghgjghg",
"klklklklklklklkmklkmk",
"nonnnnnonnnonnnnnnnon",
"ppppppppppppqpppppppp",
"rsrsrsrsrsrsrsrsrsrsr",
"tuvutuvutuvutututuvut",
"wxyxwxwxwxyxwxwxwxwxw",
"zABAzBzAzAzAzBzAzAzAz",
"AAAAAAAAAAAAAAAAAAAAA",
"AAAAAAAAAAAAAAAAAAAAA",
"AAAAAAABABAAAAABAAAAA",
"wywywywywywywywywywyw",
"AAAAAAAAAAAAAAAAAAAAA",
"CDEDCDEDCDEDCDEDCDEDC"};

static const char* const img10_invite[] = { 
"11 18 51 1",
"d c #0075e6",
"g c #0075ee",
"M c #0079ee",
"a c #0879ee",
"T c #087dee",
"u c #107dee",
"K c #2085ee",
"z c #2089ee",
"R c #3191ee",
"V c #52a1f6",
"E c #5aa5f6",
"J c #62aaf6",
"D c #62aef6",
"# c #73aae6",
"b c #73aee6",
". c #73aeee",
"P c #73b6f6",
"c c #7bb2ee",
"e c #83b6ee",
"O c #83beff",
"f c #8bbaee",
"j c #94beee",
"i c #94c2ee",
"L c #94c6ff",
"h c #9cc2f6",
"k c #9cc6ee",
"m c #9cc6f6",
"l c #a4c6f6",
"I c #a4caf6",
"N c #a4ceff",
"o c #accaf6",
"n c #accef6",
"W c #acceff",
"p c #b4d2f6",
"S c #b4d6ff",
"q c #bddaf6",
"y c #bddaff",
"s c #c5daf6",
"r c #c5deff",
"t c #cde2ff",
"Q c #cde6ff",
"x c #d5e6f6",
"v c #d5e6ff",
"U c #d5eaff",
"w c #deeaff",
"B c #eef2ff",
"A c #eef6ff",
"C c #f6f6ff",
"F c #f6faff",
"H c #fffaff",
"G c #ffffff",
".#.#.#.#.#a",
"bcbcbcbcbcd",
"eeeeeeeeeea",
"ffffffffffg",
"hihihjhihja",
"klklklkmkld",
"nnnnnononna",
"pppppppppqg",
"rsrsrsrsrtu",
"vwvwvwxwvyz",
"ABABABABCDE",
"FGFHFGFGBuI",
"GGGGGGGGJKG",
"GGGGGGGLMNG",
"GGGGGGOaPGG",
"AFFGQRMOHGG",
"GvSETRUGGGG",
"gMRVWGGGGGG"};

static const char* const img11_invite[] = { 
"11 23 26 1",
"w c #0075e6",
"x c #0075ee",
"c c #0879ee",
"s c #1081ee",
"v c #2989ee",
"b c #3991ee",
"a c #62aaf6",
"l c #6ab2f6",
"o c #73b2f6",
"j c #7bb6ff",
"q c #8bbeff",
"t c #a4cef6",
"d c #a4ceff",
"e c #acceff",
"r c #acd2ff",
"# c #b4d6ff",
"m c #cddeff",
"p c #deeaff",
"k c #deeeff",
"f c #e6eeff",
"u c #eeeeff",
"h c #eef2ff",
"n c #f6f2ff",
"g c #f6f6ff",
"i c #fffaff",
". c #ffffff",
".......#abc",
".....dcefgh",
"...ijaggggg",
"..klmgnghgn",
"..opggggggg",
".qrgnghgngh",
".sggggggggg",
"t#nghgnghgn",
"auggggggggg",
"vghgnghgngh",
"sgggggggggg",
"wgnghgnghgn",
"cgggggggggg",
"xghgnghgngh",
"cgggggggggg",
"wgnghgnghgn",
"cgggggggggg",
"xghgnghgngh",
"cgggggggggg",
"wgnghgnghgn",
"cgggggggggg",
"xghgnghgngh",
"cgggggggggg"};

static const char* const img12_invite[] = { 
"24 23 5 1",
"# c #0075ee",
". c #0879ee",
"c c #eef2ff",
"a c #f6f2ff",
"b c #f6f6ff",
".#.#.#.#.#.#.#.#.#.#.#.#",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"cbabcbabcbabcbabcbabcbab",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"cbabcbabcbabcbabcbabcbab",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"cbabcbabcbabcbabcbabcbab",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"cbabcbabcbabcbabcbabcbab",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"cbabcbabcbabcbabcbabcbab",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb"};

static const char* const img13_invite[] = { 
"11 23 26 1",
"x c #0075e6",
"w c #0075ee",
". c #0879ee",
"v c #087dee",
"s c #1081ee",
"u c #2089ee",
"# c #3991ee",
"a c #62aaf6",
"m c #6ab2f6",
"p c #73b2ff",
"i c #7bb6ff",
"r c #94c6ff",
"h c #a4ceff",
"g c #acceff",
"q c #acd2ff",
"b c #b4d6ff",
"l c #cddeff",
"o c #deeaff",
"n c #deeeff",
"f c #e6eeff",
"t c #eeeeff",
"k c #eef2ff",
"d c #f6f2ff",
"e c #f6f6ff",
"j c #fffaff",
"c c #ffffff",
".#abccccccc",
"defg.hccccc",
"eeeeeaijccc",
"kedekelmncc",
"eeeeeeeopcc",
"dekedekeqrc",
"eeeeeeeeesc",
"kedekedekbh",
"eeeeeeeeeta",
"dekedekedeu",
"eeeeeeeeeev",
"kedekedekew",
"eeeeeeeeee.",
"dekedekedex",
"eeeeeeeeee.",
"kedekedekew",
"eeeeeeeeee.",
"dekedekedex",
"eeeeeeeeee.",
"kedekedekew",
"eeeeeeeeee.",
"dekedekedex",
"eeeeeeeeee."};

static const char* const img14_invite[] = { 
"80 28 341 2",
".Y c #0eb8ff",
".K c #10b8ff",
"#f c #14b5f8",
".w c #14b8fd",
"#A c #17baff",
".m c #24bdfd",
".x c #28c0ff",
".n c #2bbffd",
"#U c #2ec2ff",
".l c #30bffb",
"a# c #32bdf8",
".o c #38c2fb",
"as c #39bef7",
"#g c #39c5ff",
"aa c #3ec7ff",
".L c #40c7ff",
"#T c #42bff6",
"bf c #43434c",
"aK c #44c8ff",
"bo c #45454d",
"at c #45c9ff",
"bS c #484952",
".Z c #48c9ff",
"bF c #4b4c54",
".y c #4bcaff",
"aA c #4cc0f2",
"bT c #4d4e57",
"aP c #4f5058",
"bR c #50515a",
"bU c #51525b",
"aT c #53c9fb",
".D c #55cdff",
"aG c #58585f",
"aZ c #585961",
"dm c #585b69",
"#B c #59ceff",
"ax c #5b5e64",
".p c #5bc6f3",
"a1 c #5c5c5c",
"bE c #5c5d62",
"ak c #5d6065",
".C c #60d0ff",
"a8 c #616167",
".J c #63caf8",
".M c #63d1ff",
"bQ c #64656f",
"#4 c #65666c",
"bV c #66676f",
"#h c #67d2ff",
".z c #67d3ff",
".0 c #68d3ff",
"aU c #6ad4ff",
".E c #6cc8ef",
".k c #6cccf6",
"#V c #6dd4ff",
"a4 c #6ed4ff",
".B c #6fd5ff",
"aJ c #72bce1",
"bp c #73737e",
".A c #74d6ff",
".S c #76d6ff",
".N c #77d7ff",
"a3 c #78b8d8",
"#C c #78d7ff",
"bG c #797a85",
"au c #79d8ff",
"ae c #7ad8ff",
"#K c #7b7b83",
"#z c #7bc9ef",
"aC c #7bd8ff",
".1 c #7bd9ff",
".v c #7cd0f6",
"#Z c #7cd8ff",
"aL c #7cd9ff",
".T c #7dd4f8",
"#i c #7dd9ff",
"a9 c #7e7f86",
"af c #7fdaff",
"bb c #80c4e2",
"ad c #80daff",
"bx c #8193a3",
".X c #81cef3",
"#0 c #81daff",
"#E c #82daff",
"#F c #83daff",
"di c #848286",
"#W c #84dbff",
"aB c #85dbff",
"aV c #86dcff",
".O c #87dbff",
"#l c #88dcff",
"bg c #898a97",
".R c #89dcff",
".2 c #89ddff",
"bn c #8a8a8d",
"ab c #8addff",
"#D c #8bddff",
"dq c #8c8c90",
"bP c #8c8e98",
"#Y c #8cddff",
"#j c #8cdeff",
"bW c #8d8f96",
"bk c #8dbbd2",
"#1 c #8dddff",
"ag c #8ddeff",
".8 c #8edeff",
"cn c #8f8b89",
"be c #8f9092",
".7 c #8fdeff",
".P c #90deff",
"#X c #90dfff",
"dp c #919092",
"#q c #919195",
"ac c #91dfff",
"#m c #92deff",
".3 c #92dfff",
"db c #9394ab",
".6 c #93dfff",
".q c #94cae3",
".Q c #94dfff",
"#k c #95e0ff",
"#p c #96b6c3",
".5 c #96e0ff",
".4 c #97e0ff",
".9 c #98d8f2",
".U c #99b1c0",
"c8 c #9a979c",
"#. c #9aa1aa",
"bj c #9aa2b1",
"aS c #9bb0c2",
"#G c #9ce2ff",
"dn c #9d9fa7",
"#n c #9de2ff",
"dj c #a07130",
"dl c #a0a0b7",
"c3 c #a27545",
"bw c #a2a4ad",
"dk c #a37f59",
".F c #a4bdcd",
"dc c #a6a9b2",
"bq c #a7a9b9",
"bH c #aaaebd",
"ba c #aab0be",
"by c #aac7d6",
"cM c #aba9ae",
"#o c #abe6ff",
"#H c #abe7ff",
"cw c #acaaad",
"cX c #acaaaf",
"c9 c #ad7a30",
"cD c #aeacb0",
"cT c #b18b5e",
"#t c #b1b1b1",
"bD c #b2b2b4",
"ay c #b2b5c1",
"bX c #b2b6be",
"cK c #b38d5f",
"#u c #b3b3b3",
"dh c #b3b6bf",
"cY c #b48033",
"al c #b4b7c3",
"da c #b8936f",
"#r c #b8b8b8",
"aH c #b8bac6",
"aM c #b9eaff",
"ah c #b9ebff",
"cB c #ba9260",
"#I c #baeaff",
"cN c #bb8732",
"de c #bbbec7",
"c. c #bbbec9",
"cu c #bc935f",
"#e c #becfdc",
"#s c #bfbfbf",
"c# c #bfc2cc",
"aQ c #c0c3cd",
"b9 c #c0c3ce",
"#J c #c0e4f5",
"cE c #c18b32",
"#c c #c1c1c1",
"ck c #c29963",
"#5 c #c3c5ce",
"ao c #c4c7d1",
".j c #c4e1f2",
"cx c #c69034",
"#d c #c6c6c6",
"bO c #c6c9d3",
"ai c #c6eeff",
"aD c #c6efff",
"bI c #c7c8d6",
"ar c #c7c9d4",
"dg c #c7cad2",
"a0 c #c7cad4",
"#2 c #c7efff",
"dr c #c8c8c8",
"aY c #c8c8c9",
"ca c #cacdd7",
"bz c #cae7f3",
"co c #cb9537",
"#P c #cccccc",
".r c #ccd2d9",
"ce c #cdaf88",
"do c #cdcccb",
"az c #cdcec8",
"#w c #cdcecf",
"dd c #cdd1db",
"bJ c #cea469",
"#8 c #cfcfcf",
"b8 c #d0d4de",
"ap c #d1d1d1",
"#b c #d2d2d2",
"b. c #d2d5e0",
"b0 c #d3b287",
"a2 c #d3d5dc",
"#7 c #d3d6e1",
"#3 c #d3f2ff",
"#v c #d4d4d4",
"bY c #d4d6e0",
"cb c #d5d8e3",
"a. c #d6d8e3",
"c6 c #d7dae5",
"cV c #d8d8d8",
"c7 c #d8dbe6",
"aI c #daddd1",
".V c #dbdbde",
"bZ c #dcd7d8",
"#L c #dcdde2",
"c5 c #dde1ec",
".u c #dedde0",
"a5 c #def5ff",
"bl c #def6ff",
".I c #dfdfe1",
"br c #dfe1ed",
"b7 c #dfe3ee",
"av c #dff5ff",
"aE c #dff6ff",
"bA c #e0f5ff",
"aj c #e0f6ff",
"b4 c #e1bf90",
"an c #e1e5f0",
"bK c #e2900b",
".G c #e2e1e4",
"bh c #e2e6f1",
"bL c #e3bb81",
"cl c #e3e7f1",
"bv c #e3e7f2",
"c2 c #e4a235",
"#S c #e4e5ec",
"cU c #e4e7f2",
"cc c #e4e8f3",
"b3 c #e5920c",
"bC c #e5e8ea",
"bN c #e6e9f5",
"cJ c #e79412",
"bs c #e7d2b6",
"cv c #e7e9f3",
"cj c #e8940c",
"cA c #e89511",
"cS c #e89614",
"## c #e8e8e9",
".d c #e8eaef",
"cC c #e8eaf3",
"cL c #e8eaf4",
"cm c #e8ebf7",
"ct c #e99612",
"#a c #e9e9e9",
".e c #e9e9ee",
".c c #e9ebef",
"bi c #e9ecf7",
"c4 c #e9edf8",
"aN c #e9f8ff",
"aW c #e9f9ff",
".f c #eaeaed",
"aR c #eaeef2",
"a6 c #eaf8ff",
"aw c #eaf9ff",
"#x c #ebecef",
"b6 c #ebeffb",
"b5 c #eceef8",
"d# c #edd79c",
"b# c #edf1fc",
"cd c #edf1fd",
"bu c #eef2fe",
".g c #efeff0",
"bt c #eff1fb",
"bM c #eff2fd",
"am c #eff3ff",
"ci c #f0b13e",
".s c #f0eff1",
".b c #f0f0f3",
"#Q c #f0f2f7",
"#O c #f0f4ff",
"cz c #f1b23f",
"cs c #f1b240",
"b1 c #f1c36b",
"aq c #f1f5ff",
"bB c #f1f9fd",
"cI c #f2b340",
"b2 c #f2b441",
"cW c #f2f5ff",
"cR c #f3b340",
"df c #f3f4f7",
"#y c #f3f4f8",
"#6 c #f3f6ff",
"aF c #f3fbff",
"bc c #f3fcff",
"ds c #f4f4f4",
"#9 c #f4f7ff",
".i c #f5f4f5",
"bm c #f5f5f5",
"ch c #f6d58b",
"cQ c #f6d58c",
"aO c #f6f8fa",
"#N c #f6f8ff",
"cr c #f7d68d",
"cH c #f7d68e",
".a c #f7f7f8",
"#R c #f7f9ff",
".W c #f8f7f8",
"#M c #f8f9ff",
".t c #fafafa",
"cf c #fbd271",
"a7 c #fbfbfb",
"aX c #fbfeff",
"c1 c #fcdd92",
".H c #fcfcfc",
"bd c #fcfeff",
".h c #fdfdfd",
"cq c #fef7c9",
"cy c #fef7ca",
"cP c #fef9ca",
".# c #fefefe",
"cZ c #ffe588",
"cO c #ffe789",
"cF c #ffe988",
"cp c #ffe989",
"d. c #ffeb8d",
"cG c #fff7ca",
"c0 c #fff9ca",
"cg c #fffbcc",
"Qt c #ffffff",
"QtQtQtQtQtQtQtQt.#.a.b.c.d.e.f.gQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQt.h.i.j.k.l.m.n.o.p.q.r.s.#QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQt.t.u.v.w.x.y.z.A.B.C.D.E.F.G.HQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQt.I.J.K.L.M.N.O.P.Q.Q.R.S.T.U.V.HQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQt.W.X.Y.Z.0.1.2.3.4.5.6.3.7.8.9#.##.#QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"#a#b#c#d#e#f#g#h#i#j.6#k.6.8#l#l#m#n#o#p#q#r#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#s#t#u",
"#v#w#x#y#z#A#B#C#D.6.Q.P.O#E#F.8#G#H#I#J#K#L#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#M#N#O",
"#P#Q#R#S#T#U#V#W#X.6#Y#F#Z#0#1#G#H#I#2#3#4#5#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#6#O#7",
"#8#9#6a.a#aa#Cabac#Yadaeafag#G#oahai#3ajakalamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamanao",
"ap#6aqarasatadagag#0auad#1#G#oahai#3avawaxayamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamanao",
"ap#6aqazaAat#W#1aBaCafag#G#oahaD#3aEawaFaGaHamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamanao",
"ap#6aqaIaJaKaL.8#0#0#1#G#oaMai#3avaNaFaOaPaQamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamanao",
"ap#6aqaRaSaTaU.2aV.8#G#Hah#2#3avaWaFaXaYaZa0amamamamamamamamamamamama1a1a1a1amamama1a1a1a1a1amama1a1a1a1a1amamamama1a1a1a1amamamamama1a1a1amamamamamamamamamanao",
"ap#6aqama2a3a4#0.P#G#oahai#3a5a6aFaXa7a8a9b.amamamamamamamamamamama1a1amamama1amama1a1amamamamama1a1amama1a1amama1a1amamama1amamamama1a1a1amamamamamamamamamanao",
"ap#6aqamb#babbag#G#Hah#2#3aEaWbcbdQtbebfbgbhamamamamamamamamamamama1a1amamamamamama1a1amamamamama1a1amama1a1amama1a1amamamamamamama1a1ama1a1amamamamamamamamanao",
"ap#6aqamambibjbk#oaM#2#3blaWaFaXbmbnbobpbqbrbsbtamamamamamamamamama1a1amamamamamama1a1a1a1a1amama1a1a1a1a1amamama1a1amamamamamamama1a1ama1a1amamamamamamamamanao",
"ap#6aqamambubvbwbxbybzbAawbBbCbDbEbFbGbHbIbJbKbLbMamamamamamamamama1a1amamamamamama1a1amamamamama1a1a1a1amamamama1a1amamamamamama1a1a1a1a1a1a1amamamamamamamanao",
"ap#6aqamamambubNbObPbQbRbSbTbUbVbWbXbYbZb0b1b2b3b4b5amamamamamamama1a1amamama1amama1a1amamamamama1a1ama1a1amamama1a1amamama1amama1a1amamama1a1amamamamamamamanao",
"ap#6aqamamamamamb6b7b8b9c.c#aocacbcccdcecfcgchcicjckclamamamamamamama1a1a1a1amamama1a1a1a1a1amama1a1amama1a1amamama1a1a1a1amamama1a1amamama1a1amamamamamamamanao",
"ap#6aqamamamamamamamamamamamamamamamcmcncocpcqcrcsctcucvamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamanao",
"ap#6aqamamamamamamamamamamamamamamamamamcwcxcpcychczcAcBcCamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamanao",
"ap#6aqamamamamamamamamamamamamamamamamamamcDcEcFcGcHcIcJcKcLamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamanao",
"#b#6aqamamamamamamamamamamamamamamamamamamamcMcNcOcPcQcRcScTcUamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamanao",
"cVcW#ObuamamamamamamamamamamamamamamamamamamamcXcYcZc0c1c2c3aQamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamamanao",
"#ac4c5c6c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c8c9d.d#dadbdcc7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7c7ddde",
".Hdfdgdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdidjdkdldmdndhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdhdh",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtdodpdqdr.#QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.HdsQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt"};


/*
 *  Constructs a Invite as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
Invite::Invite( QWidget* parent, const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl ),
      image1( (const char **) img1_invite ),
      image2( (const char **) img2_invite ),
      image3( (const char **) img3_invite ),
      image4( (const char **) img4_invite ),
      image5( (const char **) img5_invite ),
      image6( (const char **) img6_invite ),
      image7( (const char **) img7_invite ),
      image8( (const char **) img8_invite ),
      image9( (const char **) img9_invite ),
      image10( (const char **) img10_invite ),
      image11( (const char **) img11_invite ),
      image12( (const char **) img12_invite ),
      image13( (const char **) img13_invite ),
      image14( (const char **) img14_invite )
{
    QImage img;
    img.loadFromData( img0_invite, sizeof( img0_invite ), "PNG" );
    image0 = img;
    if ( !name )
	setName( "Invite" );
    setMinimumSize( QSize( 430, 200 ) );
    setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    setIcon( image0 );
    InviteLayout = new QGridLayout( this, 1, 1, 0, 0, "InviteLayout"); 

    frame16 = new QFrame( this, "frame16" );
    frame16->setMinimumSize( QSize( 430, 21 ) );
    frame16->setMaximumSize( QSize( 32767, 21 ) );
    frame16->setPaletteBackgroundPixmap( image1 );
    frame16->setFrameShape( QFrame::NoFrame );
    frame16->setFrameShadow( QFrame::Plain );
    frame16Layout = new QGridLayout( frame16, 1, 1, 0, 0, "frame16Layout"); 

    pixmapLabel2_2 = new QLabel( frame16, "pixmapLabel2_2" );
    pixmapLabel2_2->setMinimumSize( QSize( 72, 21 ) );
    pixmapLabel2_2->setMaximumSize( QSize( 72, 21 ) );
    pixmapLabel2_2->setPixmap( image2 );
    pixmapLabel2_2->setScaledContents( FALSE );

    frame16Layout->addWidget( pixmapLabel2_2, 0, 1 );
    spacer132 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame16Layout->addItem( spacer132, 0, 0 );

    InviteLayout->addMultiCellWidget( frame16, 1, 1, 0, 2 );

    textLabel1 = new QLabel( this, "textLabel1" );
    textLabel1->setMinimumSize( QSize( 400, 18 ) );
    textLabel1->setMaximumSize( QSize( 32767, 18 ) );
    textLabel1->setPaletteBackgroundPixmap( image3 );

    InviteLayout->addMultiCellWidget( textLabel1, 0, 0, 0, 2 );

    pixmapLabel9_2 = new QLabel( this, "pixmapLabel9_2" );
    pixmapLabel9_2->setMinimumSize( QSize( 400, 22 ) );
    pixmapLabel9_2->setMaximumSize( QSize( 32767, 22 ) );
    pixmapLabel9_2->setPaletteBackgroundPixmap( image4 );
    pixmapLabel9_2->setScaledContents( FALSE );

    InviteLayout->addMultiCellWidget( pixmapLabel9_2, 8, 8, 0, 2 );

    layout34 = new QHBoxLayout( 0, 0, 0, "layout34"); 

    frame15 = new QFrame( this, "frame15" );
    frame15->setMinimumSize( QSize( 350, 31 ) );
    frame15->setMaximumSize( QSize( 32767, 31 ) );
    frame15->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    frame15->setPaletteBackgroundPixmap( image5 );
    frame15->setFrameShape( QFrame::NoFrame );
    frame15->setFrameShadow( QFrame::Plain );
    frame15->setLineWidth( 0 );
    frame15Layout = new QGridLayout( frame15, 1, 1, 0, 0, "frame15Layout"); 

    layout33 = new QVBoxLayout( 0, 0, 0, "layout33"); 
    spacer37 = new QSpacerItem( 20, 15, QSizePolicy::Minimum, QSizePolicy::Fixed );
    layout33->addItem( spacer37 );

    exitButtonPlaceHolder = new QLabel( frame15, "exitButtonPlaceHolder" );
    exitButtonPlaceHolder->setMinimumSize( QSize( 51, 16 ) );
    exitButtonPlaceHolder->setMaximumSize( QSize( 51, 16 ) );
    exitButtonPlaceHolder->setPixmap( image6 );
    exitButtonPlaceHolder->setScaledContents( FALSE );
    layout33->addWidget( exitButtonPlaceHolder );

    frame15Layout->addLayout( layout33, 0, 1 );
    spacer38 = new QSpacerItem( 40, 18, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame15Layout->addItem( spacer38, 0, 0 );
    layout34->addWidget( frame15 );

    aboutButtonPlaceHolder = new QLabel( this, "aboutButtonPlaceHolder" );
    aboutButtonPlaceHolder->setMinimumSize( QSize( 28, 31 ) );
    aboutButtonPlaceHolder->setMaximumSize( QSize( 28, 31 ) );
    aboutButtonPlaceHolder->setPixmap( image7 );
    aboutButtonPlaceHolder->setScaledContents( FALSE );
    layout34->addWidget( aboutButtonPlaceHolder );

    InviteLayout->addMultiCellLayout( layout34, 7, 7, 0, 2 );
    spacer100 = new QSpacerItem( 16, 30, QSizePolicy::Fixed, QSizePolicy::Minimum );
    InviteLayout->addItem( spacer100, 3, 0 );
    spacer102 = new QSpacerItem( 20, 16, QSizePolicy::Minimum, QSizePolicy::Fixed );
    InviteLayout->addItem( spacer102, 2, 1 );
    spacer101 = new QSpacerItem( 16, 25, QSizePolicy::Fixed, QSizePolicy::Minimum );
    InviteLayout->addItem( spacer101, 3, 2 );

    frame44 = new QFrame( this, "frame44" );
    frame44->setFrameShape( QFrame::NoFrame );
    frame44->setFrameShadow( QFrame::Plain );
    frame44Layout = new QGridLayout( frame44, 1, 1, 0, 0, "frame44Layout"); 

    layout61 = new QHBoxLayout( 0, 0, 0, "layout61"); 

    layout41_2 = new QHBoxLayout( 0, 0, 0, "layout41_2"); 

    pixmapLabel3_3 = new QLabel( frame44, "pixmapLabel3_3" );
    pixmapLabel3_3->setMinimumSize( QSize( 11, 18 ) );
    pixmapLabel3_3->setMaximumSize( QSize( 11, 18 ) );
    pixmapLabel3_3->setPixmap( image8 );
    pixmapLabel3_3->setScaledContents( FALSE );
    layout41_2->addWidget( pixmapLabel3_3 );

    pixmapLabel3_2_2_2 = new QLabel( frame44, "pixmapLabel3_2_2_2" );
    pixmapLabel3_2_2_2->setMinimumSize( QSize( 396, 18 ) );
    pixmapLabel3_2_2_2->setMaximumSize( QSize( 32767, 18 ) );
    pixmapLabel3_2_2_2->setPaletteBackgroundPixmap( image9 );
    pixmapLabel3_2_2_2->setLineWidth( 0 );
    pixmapLabel3_2_2_2->setScaledContents( FALSE );
    layout41_2->addWidget( pixmapLabel3_2_2_2 );

    pixmapLabel3_2_3 = new QLabel( frame44, "pixmapLabel3_2_3" );
    pixmapLabel3_2_3->setMinimumSize( QSize( 11, 18 ) );
    pixmapLabel3_2_3->setMaximumSize( QSize( 11, 18 ) );
    pixmapLabel3_2_3->setLineWidth( 0 );
    pixmapLabel3_2_3->setPixmap( image10 );
    pixmapLabel3_2_3->setScaledContents( FALSE );
    layout41_2->addWidget( pixmapLabel3_2_3 );
    layout61->addLayout( layout41_2 );

    frame44Layout->addLayout( layout61, 2, 0 );

    layout46 = new QHBoxLayout( 0, 0, 0, "layout46"); 

    pixmapLabel1_2 = new QLabel( frame44, "pixmapLabel1_2" );
    pixmapLabel1_2->setMinimumSize( QSize( 11, 23 ) );
    pixmapLabel1_2->setMaximumSize( QSize( 11, 23 ) );
    pixmapLabel1_2->setPixmap( image11 );
    pixmapLabel1_2->setScaledContents( FALSE );
    layout46->addWidget( pixmapLabel1_2 );

    frame58 = new QFrame( frame44, "frame58" );
    frame58->setMinimumSize( QSize( 130, 23 ) );
    frame58->setMaximumSize( QSize( 32767, 23 ) );
    frame58->setPaletteBackgroundPixmap( image12 );
    frame58->setFrameShape( QFrame::NoFrame );
    frame58->setFrameShadow( QFrame::Plain );
    frame58Layout = new QGridLayout( frame58, 1, 1, 0, 0, "frame58Layout"); 

    layout43 = new QHBoxLayout( 0, 0, 0, "layout43"); 

    identityCaption = new QLabel( frame58, "identityCaption" );
    identityCaption->setMinimumSize( QSize( 0, 18 ) );
    identityCaption->setMaximumSize( QSize( 32767, 18 ) );
    identityCaption->setPaletteForegroundColor( QColor( 0, 0, 0 ) );
    identityCaption->setBackgroundOrigin( QLabel::AncestorOrigin );
    QFont identityCaption_font(  identityCaption->font() );
    identityCaption_font.setBold( TRUE );
    identityCaption->setFont( identityCaption_font ); 
    layout43->addWidget( identityCaption );
    spacer40 = new QSpacerItem( 180, 16, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout43->addItem( spacer40 );

    netfriendCaption = new QLabel( frame58, "netfriendCaption" );
    netfriendCaption->setMinimumSize( QSize( 100, 18 ) );
    netfriendCaption->setMaximumSize( QSize( 100, 18 ) );
    netfriendCaption->setPaletteForegroundColor( QColor( 0, 0, 0 ) );
    netfriendCaption->setBackgroundOrigin( QLabel::AncestorOrigin );
    QFont netfriendCaption_font(  netfriendCaption->font() );
    netfriendCaption_font.setBold( TRUE );
    netfriendCaption->setFont( netfriendCaption_font ); 
    layout43->addWidget( netfriendCaption );
    spacer41 = new QSpacerItem( 75, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout43->addItem( spacer41 );

    frame58Layout->addLayout( layout43, 0, 0 );
    layout46->addWidget( frame58 );

    pixmapLabel1_2_2 = new QLabel( frame44, "pixmapLabel1_2_2" );
    pixmapLabel1_2_2->setMinimumSize( QSize( 11, 23 ) );
    pixmapLabel1_2_2->setMaximumSize( QSize( 11, 23 ) );
    pixmapLabel1_2_2->setPixmap( image13 );
    pixmapLabel1_2_2->setScaledContents( FALSE );
    layout46->addWidget( pixmapLabel1_2_2 );

    frame44Layout->addLayout( layout46, 0, 0 );

    layout8 = new QHBoxLayout( 0, 0, 0, "layout8"); 

    messageEdit = new QTextEdit( frame44, "messageEdit" );
    messageEdit->setMinimumSize( QSize( 290, 0 ) );
    QPalette pal;
    QColorGroup cg;
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 247, 247, 247) );
    cg.setColor( QColorGroup::Dark, QColor( 119, 119, 119) );
    cg.setColor( QColorGroup::Mid, QColor( 159, 159, 159) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 119, 119, 119) );
    cg.setColor( QColorGroup::Mid, QColor( 159, 159, 159) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, QColor( 239, 239, 239) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 119, 119, 119) );
    cg.setColor( QColorGroup::Mid, QColor( 159, 159, 159) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setDisabled( cg );
    messageEdit->setPalette( pal );
    messageEdit->setFrameShape( QTextEdit::Box );
    messageEdit->setFrameShadow( QTextEdit::Plain );
    messageEdit->setLineWidth( 1 );
    layout8->addWidget( messageEdit );

    netfriendList = new QListView( frame44, "netfriendList" );
    netfriendList->addColumn( ( "Column 1" ) );
    netfriendList->setMinimumSize( QSize( 190, 0 ) );
    netfriendList->setMaximumSize( QSize( 190, 32767 ) );
    netfriendList->setPaletteForegroundColor( QColor( 0, 0, 0 ) );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setDisabled( cg );
    netfriendList->setPalette( pal );
    netfriendList->setFrameShape( QListView::Box );
    netfriendList->setFrameShadow( QListView::Plain );
    netfriendList->setLineWidth( 1 );
    layout8->addWidget( netfriendList );

    frame44Layout->addLayout( layout8, 1, 0 );

    InviteLayout->addWidget( frame44, 3, 1 );
    spacer12 = new QSpacerItem( 20, 5, QSizePolicy::Minimum, QSizePolicy::Fixed );
    InviteLayout->addItem( spacer12, 4, 1 );

    layout9 = new QHBoxLayout( 0, 0, 0, "layout9"); 
    spacer10 = new QSpacerItem( 210, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout9->addItem( spacer10 );

    sendButtonPlaceHolder = new QLabel( this, "sendButtonPlaceHolder" );
    sendButtonPlaceHolder->setMinimumSize( QSize( 84, 27 ) );
    sendButtonPlaceHolder->setMaximumSize( QSize( 84, 27 ) );
    sendButtonPlaceHolder->setPixmap( image14 );
    layout9->addWidget( sendButtonPlaceHolder );
    spacer11 = new QSpacerItem( 14, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout9->addItem( spacer11 );

    InviteLayout->addMultiCellLayout( layout9, 5, 5, 0, 2 );
    languageChange();
    resize( QSize(548, 338).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );
}

/*
 *  Destroys the object and frees any allocated resources
 */
Invite::~Invite()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void Invite::languageChange()
{
    setCaption( ( "Openc6 - Invita un netfriend" ) );
    identityCaption->setText( ( "Messaggio" ) );
    netfriendCaption->setText( ( "Netfriend" ) );
    netfriendList->header()->setLabel( 0, ( "Column 1" ) );
    sendButtonPlaceHolder->setText( QString::null );
}

#include "invite.moc"
