//
// C++ Interface: c6pixmapcache
//
// Description:
//
//
// Author: Giorgio A. <openc6@hotmail.com>, (C) 2005
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef C6PIXMAPCACHE_H
#define C6PIXMAPCACHE_H

#include "c6singleton.h"
#include <qmap.h>
#include <qpixmap.h>

class QString;

/**
@author Giorgio A.
*/
class C6PixmapCache : public C6Singleton<C6PixmapCache>
{
    friend class C6Singleton<C6PixmapCache>;
    typedef QMap<QString,QPixmap*> CachePixmapMap;    
    
public:
    C6PixmapCache();
    QPixmap const& getPixmap(QString const& filename,int conversion_flag = Qt::DiffuseDither);
    ~C6PixmapCache();
    
private:
    CachePixmapMap _cacheList;
};

#endif