/***************************************************************************
                          c6users.cpp  -  description
                             -------------------
    begin                : Mon Apr 14 2003
    copyright            : (C) 2003 by Giorgio A.
    email                : openc6@hotmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "c6users.h"


bool C6Users::isStatusOnline(C6USER_STATUS status)
{
    return((status == U_AVAILABLE) || (status == U_AWAY)
            || (status == U_NETFRIENDONLY) || (status == U_BUSY));
}

C6Users C6Users::operator=(C6Users &right)
{
    _nick = right.getNick();
    _user = right.getUser();
    _status = right.getStatus();
    _isMessaged = right.isMessaged();
    _dailyMessage = right.getDailyMessage();        
}      