//
// C++ Implementation: c6abstractplugin
//
// Description:
//
//
// Author: Giorgio A. <openc6@hotmail.com>, (C) 2005
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "c6abstractplugin.h"

C6AbstractPlugin::C6AbstractPlugin():
        _kdeEntryPoint(0),
        _isForKde(false),
        _canDestroy(false)
{}

C6AbstractPlugin::~C6AbstractPlugin()
{}

C6PlugInFactory::C6PlugInFactory()
{}

C6PlugInFactory::~C6PlugInFactory()
{}

#include "c6abstractplugin.moc"

