/***************************************************************************
                          protosupport.h  -  description
                             -------------------
    begin                : Fri Mar 7 2003
    copyright            : (C) 2003 by Giorgio A.
    email                : openc6@hotmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

void encodeMD5Key(const char *,unsigned char *,unsigned char *,bool isPsw);
void xorCode(unsigned char *pSorg,unsigned char *pDest, unsigned char *pKeyOrd,int len);
void orderServerKey(unsigned char *dest,unsigned char const *source);
void blowFishEncode(int len,unsigned char *source,int len_key,unsigned char* init);
void blowFishDecode(int len,unsigned char *source,int len_key,unsigned char* init);
void encodeNewMd5Key(unsigned char *md5Key,unsigned char const *key);
