/***************************************************************************
                          c6smiley.h  -  description
                             -------------------
    begin                : Tue Sep 16 2003
    copyright            : (C) 2003 by Giorgio A.
    email                : openc6hotmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef C6SMILEY_H
#define C6SMILEY_H


class QWidget;
class QButtonGroup;
class QCloseEvent;
class QEvent;


#include <qdialog.h>
#include <qstring.h>

/**
  *@author Giorgio A.
  */


class C6Smiley : public QDialog
{
    Q_OBJECT
public:

    static const int MAXFACCINE = 18;

    C6Smiley(QWidget *parent=0, const char *name=0,bool modal=true);
    ~C6Smiley();
    static QString getSmileyText(int id);
    static void loadSmiley();

private:
    void closeEvent ( QCloseEvent * e ) ;
    void leaveEvent ( QEvent * );
    bool clicked;
private slots: // Private slots
    void whichSmiley(int id);
};


#endif
