/***************************************************************************
                          progressindicator.h  -  description
                             -------------------
    begin                : Wed Apr 2 2003
    copyright            : (C) 2003 by Giorgio A.
    email                : openc6@hotmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef PROGRESSINDICATOR_H
#define PROGRESSINDICATOR_H

#include <qwidget.h>
#include "connectDlg.h"

/**
  *@author Giorgio A.
  */

class ProgressIndicator : public ConnectDlg
{
    Q_OBJECT
public:
    ProgressIndicator(QWidget *parent=0, const char *name=0);
    ~ProgressIndicator();
    void closeEvent(QCloseEvent *e);

signals: // Signals
    void forceClose();

public slots: // Public slots
    void setProgress(int value);
private:   
    void setCustomFont();   
};

#endif
