//
// C++ Interface: c6nicklist
//
// Description: 
//
//
// Author: Giorgio A. <openc6@hotmail.com>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef C6NICKLIST_H
#define C6NICKLIST_H

#include <nickform.h>
#include "macroetc.h"

class QTimer;

/**
@author Giorgio A.
*/
class C6NickList : public nickForm
{
  Q_OBJECT
public:
    C6NickList(QWidget *parent=0, const char *name=0);
    ~C6NickList();
    void addNick(QString const &nick);
    void setDefaultIdentity(int i);
private:
    bool _isClicked;
    int _timeOut;    
    QTimer *_timer;    
    void closeEvent ( QCloseEvent * e );
    void setCustomFont();
private slots:
    virtual void show();  
    void go();
    void timerDone();
    void itemPointed(QIconViewItem* item);    
};

#endif
