
/****************************************************************************
** Form implementation generated from reading ui file './font.ui'
**
** Created: Sun Dec 17 12:39:14 2006
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#include "font.h"

#include <qvariant.h>
#include <qpushbutton.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qlistbox.h>
#include <qgroupbox.h>
#include <qtextedit.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>

/*
 *  Constructs a Font as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
Font::Font( QWidget* parent, const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl )
{
    if ( !name )
	setName( "Font" );
    FontLayout = new QGridLayout( this, 1, 1, 10, 5, "FontLayout"); 

    layout11 = new QHBoxLayout( 0, 0, 5, "layout11"); 

    layout4 = new QVBoxLayout( 0, 0, 5, "layout4"); 

    textLabel1 = new QLabel( this, "textLabel1" );
    layout4->addWidget( textLabel1 );

    selectedFont = new QLineEdit( this, "selectedFont" );
    layout4->addWidget( selectedFont );

    fontList = new QListBox( this, "fontList" );
    fontList->setMinimumSize( QSize( 0, 150 ) );
    layout4->addWidget( fontList );
    layout11->addLayout( layout4 );

    layout9 = new QVBoxLayout( 0, 0, 5, "layout9"); 

    textLabel2 = new QLabel( this, "textLabel2" );
    textLabel2->setMinimumSize( QSize( 0, 0 ) );
    textLabel2->setMaximumSize( QSize( 100, 32767 ) );
    layout9->addWidget( textLabel2 );

    selectedSize = new QLineEdit( this, "selectedSize" );
    selectedSize->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, selectedSize->sizePolicy().hasHeightForWidth() ) );
    selectedSize->setMinimumSize( QSize( 0, 0 ) );
    selectedSize->setMaximumSize( QSize( 100, 32767 ) );
    layout9->addWidget( selectedSize );

    fontSize = new QListBox( this, "fontSize" );
    fontSize->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)7, 0, 0, fontSize->sizePolicy().hasHeightForWidth() ) );
    fontSize->setMinimumSize( QSize( 0, 0 ) );
    fontSize->setMaximumSize( QSize( 100, 32767 ) );
    layout9->addWidget( fontSize );
    layout11->addLayout( layout9 );
    spacer2 = new QSpacerItem( 0, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout11->addItem( spacer2 );

    FontLayout->addLayout( layout11, 0, 0 );

    groupBox1 = new QGroupBox( this, "groupBox1" );
    groupBox1->setColumnLayout(0, Qt::Vertical );
    groupBox1->layout()->setSpacing( 5 );
    groupBox1->layout()->setMargin( 10 );
    groupBox1Layout = new QGridLayout( groupBox1->layout() );
    groupBox1Layout->setAlignment( Qt::AlignTop );

    fontPreview = new QTextEdit( groupBox1, "fontPreview" );
    fontPreview->setMinimumSize( QSize( 0, 60 ) );
    fontPreview->setMaximumSize( QSize( 32767, 32767 ) );

    groupBox1Layout->addWidget( fontPreview, 0, 0 );

    FontLayout->addWidget( groupBox1, 1, 0 );

    layout12 = new QHBoxLayout( 0, 0, 5, "layout12"); 
    spacer3 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout12->addItem( spacer3 );

    okButton = new QPushButton( this, "okButton" );
    okButton->setMinimumSize( QSize( 55, 0 ) );
    okButton->setMaximumSize( QSize( 55, 32767 ) );
    layout12->addWidget( okButton );

    cancelButton = new QPushButton( this, "cancelButton" );
    cancelButton->setMinimumSize( QSize( 85, 0 ) );
    cancelButton->setMaximumSize( QSize( 85, 32767 ) );
    layout12->addWidget( cancelButton );

    FontLayout->addLayout( layout12, 2, 0 );
    languageChange();
    resize( QSize(391, 356).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );
}

/*
 *  Destroys the object and frees any allocated resources
 */
Font::~Font()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void Font::languageChange()
{
    setCaption( ( "Select font" ) );
    textLabel1->setText( ( "Font" ) );
    textLabel2->setText( ( "Size" ) );
    groupBox1->setTitle( ( "Anteprima" ) );
    okButton->setText( ( "Ok" ) );
    cancelButton->setText( ( "Cancel" ) );
}

#include "font.moc"
