//
// C++ Implementation: c6chatfactory
//
// Description: 
//
//
// Author: Giorgio A. <openc6@hotmail.com>, (C) 2005
//
// Copyright: See COPYING file that comes with this distribution
//
//
#include "c6chatfactory.h"
#include "c6chatroom.h"
#include "chatview.h"

QWidget* C6ChatFactory::getChat(ChatType type)
{
    QWidget *ret = 0;
        
    switch(type)
    {
        case PRIVATE:
            ret =  new ChatView();       
            break;
        case ROOM:
            ret = new C6ChatRoom();    
            break;
        default:
            break;
    }      
    return(ret);   
}


