/****************************************************************************
** Form interface generated from reading ui file './chatroom.ui'
**
** Created: Tue Jan 9 23:11:08 2007
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef CHATROOM_H
#define CHATROOM_H

#include <qvariant.h>
#include <qpixmap.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QFrame;
class QLabel;
class QTextEdit;
class QListBox;
class QListBoxItem;

class ChatRoom : public QWidget
{
    Q_OBJECT

public:
    ChatRoom( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~ChatRoom();

    QFrame* frame11;
    QLabel* pixmapLabel16;
    QFrame* frame9;
    QLabel* smileyPlaceHolder;
    QLabel* logPlaceHolder;
    QLabel* downPiecePlaceHolder;
    QFrame* frame10;
    QLabel* pixmapLabel1_2_3;
    QLabel* pixmapLabel18;
    QFrame* frame10_2;
    QLabel* sendButtonPlaceHolder;
    QFrame* frame27;
    QLabel* myNick;
    QTextEdit* MyChat;
    QLabel* pixmapLabel4_4;
    QLabel* pixmapLabel5;
    QLabel* pixmapLabel6_2;
    QLabel* textLabel1;
    QFrame* frame16;
    QLabel* pixmapLabel1;
    QLabel* pixmapLabel2_2;
    QLabel* pixmapLabel9_2;
    QFrame* frame15;
    QLabel* exitButtonPlaceHolder;
    QLabel* aboutButtonPlaceHolder;
    QFrame* frame17;
    QLabel* pixmapLabel6;
    QLabel* upPiecePlaceHolder;
    QFrame* frame6;
    QLabel* kickPlaceHolder;
    QLabel* roomListPlaceHolder;
    QLabel* invitePlaceHolder;
    QLabel* pixmapLabel2;
    QFrame* frame14;
    QTextEdit* otherChatPlaceHolder;
    QLabel* pixmapLabel4_2;
    QFrame* frame28;
    QLabel* roomName;
    QLabel* pixmapLabel4;
    QFrame* frame43;
    QFrame* frame7;
    QLabel* pixmapLabel1_2;
    QFrame* frame58;
    QLabel* userCount;
    QLabel* pixmapLabel1_2_2;
    QListBox* friendList;
    QLabel* pixmapLabel3;
    QLabel* pixmapLabel3_2_2;
    QLabel* pixmapLabel3_2;

protected:
    QGridLayout* ChatRoomLayout;
    QSpacerItem* spacer36;
    QGridLayout* frame11Layout;
    QSpacerItem* spacer23_2;
    QSpacerItem* spacer22_2;
    QHBoxLayout* layout37;
    QSpacerItem* spacer20;
    QSpacerItem* spacer21;
    QGridLayout* frame9Layout;
    QSpacerItem* spacer21_2;
    QHBoxLayout* layout13_2;
    QGridLayout* frame10Layout;
    QSpacerItem* spacer22;
    QGridLayout* frame10_2Layout;
    QSpacerItem* spacer40;
    QSpacerItem* spacer41;
    QSpacerItem* spacer41_2;
    QVBoxLayout* layout20;
    QHBoxLayout* layout38;
    QSpacerItem* spacer180;
    QSpacerItem* spacer64;
    QHBoxLayout* layout76;
    QSpacerItem* spacer114_2;
    QSpacerItem* spacer114;
    QHBoxLayout* layout22;
    QGridLayout* frame16Layout;
    QSpacerItem* spacer36_2;
    QHBoxLayout* layout34;
    QGridLayout* frame15Layout;
    QSpacerItem* spacer38;
    QVBoxLayout* layout33;
    QSpacerItem* spacer37;
    QGridLayout* frame17Layout;
    QSpacerItem* spacer13;
    QHBoxLayout* layout15;
    QSpacerItem* spacer9_2;
    QSpacerItem* spacer9_2_2;
    QVBoxLayout* layout10;
    QSpacerItem* spacer11;
    QGridLayout* frame6Layout;
    QSpacerItem* spacer12;
    QHBoxLayout* layout18;
    QHBoxLayout* layout17;
    QSpacerItem* spacer14;
    QSpacerItem* spacer15;
    QGridLayout* frame14Layout;
    QHBoxLayout* layout40;
    QSpacerItem* spacer14_2;
    QSpacerItem* spacer15_2;
    QGridLayout* frame28Layout;
    QHBoxLayout* layout80;
    QGridLayout* frame43Layout;
    QSpacerItem* spacer13_2;
    QHBoxLayout* layout81;
    QSpacerItem* spacer94;
    QGridLayout* frame7Layout;
    QHBoxLayout* layout78;
    QHBoxLayout* layout41;

protected slots:
    virtual void languageChange();

private:
    QPixmap image0;
    QPixmap image1;
    QPixmap image2;
    QPixmap image3;
    QPixmap image4;
    QPixmap image5;
    QPixmap image6;
    QPixmap image7;
    QPixmap image8;
    QPixmap image9;
    QPixmap image10;
    QPixmap image11;
    QPixmap image12;
    QPixmap image13;
    QPixmap image14;
    QPixmap image15;
    QPixmap image16;
    QPixmap image17;
    QPixmap image18;
    QPixmap image19;
    QPixmap image20;
    QPixmap image21;
    QPixmap image22;
    QPixmap image23;
    QPixmap image24;
    QPixmap image25;
    QPixmap image26;
    QPixmap image27;
    QPixmap image28;
    QPixmap image29;
    QPixmap image30;
    QPixmap image31;
    QPixmap image32;
    QPixmap image33;
    QPixmap image34;

};

#endif // CHATROOM_H
