/****************************************************************************
** Form interface generated from reading ui file './rooms.ui'
**
** Created: Sat Jan 13 16:09:51 2007
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef ROOMS_H
#define ROOMS_H

#include <qvariant.h>
#include <qpixmap.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QLabel;
class QFrame;
class QComboBox;
class QLineEdit;
class QRadioButton;
class QTextEdit;
class QListView;
class QListViewItem;

class rooms : public QWidget
{
    Q_OBJECT

public:
    rooms( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~rooms();

    QLabel* pixmapLabel4_4;
    QLabel* pixmapLabel5;
    QLabel* pixmapLabel6_2_2;
    QFrame* frame15;
    QLabel* exitButtonPlaceHolder;
    QLabel* aboutButtonPlaceHolder;
    QLabel* pixmapLabel9_2;
    QLabel* pixmapLabel6_2;
    QLabel* upPiecePlaceHolder;
    QFrame* frame6;
    QLabel* pixmapLabel2;
    QFrame* frame48;
    QFrame* frame53;
    QLabel* roomlabel10_4_3_2;
    QComboBox* roomCategory;
    QLabel* createPlaceHolder;
    QLabel* roomlabel10_4_3;
    QLineEdit* roomPassword;
    QFrame* frame50_2_2;
    QRadioButton* privateSwitch;
    QRadioButton* publicSwitch;
    QLabel* searchLabel3_2;
    QFrame* frame52;
    QLabel* roomlabel10_4;
    QLineEdit* createRoomName;
    QTextEdit* roomAbout;
    QLabel* roomlabel10_4_2;
    QLabel* pixmapLabel4_2_2;
    QFrame* frame28_2;
    QLabel* roomCaption_2;
    QLabel* pixmapLabel4_3;
    QLabel* textLabel1;
    QFrame* frame16;
    QLabel* pixmapLabel1;
    QLabel* pixmapLabel2_2;
    QLabel* pixmapLabel4_2;
    QFrame* frame28;
    QLabel* roomCaption;
    QLabel* pixmapLabel4;
    QFrame* frame87;
    QLabel* roomlabel10_2;
    QFrame* frame50_2;
    QLabel* searchLabel3;
    QRadioButton* systemSwitch;
    QRadioButton* userSwitch;
    QListView* roomList;
    QLabel* roomlabel10_3;
    QLineEdit* roomName;
    QLabel* enterRoomPlaceHolder;
    QLabel* searchRoomPlaceHolder;
    QLabel* roomlabel10;
    QListView* categoryList;

protected:
    QGridLayout* roomsLayout;
    QHBoxLayout* layout76;
    QSpacerItem* spacer114_2;
    QSpacerItem* spacer114;
    QHBoxLayout* layout22_2;
    QVBoxLayout* layout103;
    QHBoxLayout* layout23;
    QGridLayout* frame15Layout;
    QSpacerItem* spacer38_2;
    QVBoxLayout* layout22;
    QSpacerItem* spacer37_2;
    QHBoxLayout* layout15;
    QSpacerItem* spacer9_2;
    QSpacerItem* spacer9_2_2;
    QVBoxLayout* layout10;
    QSpacerItem* spacer11_2;
    QGridLayout* frame6Layout;
    QSpacerItem* spacer12;
    QHBoxLayout* layout25;
    QHBoxLayout* layout79;
    QSpacerItem* spacer99;
    QSpacerItem* spacer100;
    QGridLayout* frame48Layout;
    QSpacerItem* spacer98;
    QGridLayout* frame53Layout;
    QHBoxLayout* layout111;
    QSpacerItem* spacer131;
    QVBoxLayout* layout107;
    QVBoxLayout* layout108;
    QSpacerItem* spacer130;
    QVBoxLayout* layout106;
    QHBoxLayout* layout105;
    QGridLayout* frame50_2_2Layout;
    QSpacerItem* spacer284;
    QGridLayout* frame52Layout;
    QVBoxLayout* layout80;
    QSpacerItem* spacer88;
    QHBoxLayout* layout40_2;
    QSpacerItem* spacer14_2_2;
    QSpacerItem* spacer15_2_2;
    QGridLayout* frame28_2Layout;
    QVBoxLayout* layout81;
    QSpacerItem* spacer71;
    QVBoxLayout* layout156;
    QGridLayout* frame16Layout;
    QSpacerItem* spacer184;
    QHBoxLayout* layout40;
    QSpacerItem* spacer14_2;
    QSpacerItem* spacer15_2;
    QGridLayout* frame28Layout;
    QHBoxLayout* layout192;
    QSpacerItem* spacer282;
    QSpacerItem* spacer283;
    QGridLayout* frame87Layout;
    QSpacerItem* spacer277;
    QSpacerItem* spacer279;
    QSpacerItem* spacer38;
    QVBoxLayout* layout83;
    QSpacerItem* spacer281;
    QVBoxLayout* layout33;
    QGridLayout* frame50_2Layout;
    QSpacerItem* spacer37;
    QHBoxLayout* layout81_2;
    QSpacerItem* spacer79;
    QVBoxLayout* layout75;
    QVBoxLayout* layout80_2;
    QSpacerItem* spacer133_2;
    QHBoxLayout* layout79_2;
    QSpacerItem* spacer78;
    QVBoxLayout* layout27;
    QVBoxLayout* layout26;
    QSpacerItem* spacer280;

protected slots:
    virtual void languageChange();

private:
    QPixmap image0;
    QPixmap image1;
    QPixmap image2;
    QPixmap image3;
    QPixmap image4;
    QPixmap image5;
    QPixmap image6;
    QPixmap image7;
    QPixmap image8;
    QPixmap image9;
    QPixmap image10;
    QPixmap image11;
    QPixmap image12;
    QPixmap image13;
    QPixmap image14;
    QPixmap image15;
    QPixmap image16;
    QPixmap image17;
    QPixmap image18;
    QPixmap image19;

};

#endif // ROOMS_H
