/***************************************************************************
                          c6profile.h  -  description
                             -------------------
    begin                : Fri Nov 14 2003
    copyright            : (C) 2003 by Giorgio A.
    email                : openc6@hotmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef C6PROFILE_H
#define C6PROFILE_H

class C6Button;
class QTextEdit;
class QLabel;

#include <qwidget.h>
#include <profile.h>
#include <qstring.h>
#include "c6proto.h"

#define MAXCOMBO 10
#define MAXEXTENDED 4

/**
  *@author Giorgio A.
  */



class C6Profile : public profile
{
    Q_OBJECT
public:
    C6Profile(QWidget *parent=0, const char *name=0);
    ~C6Profile();
    void updateUserProfile(unsigned char *data,int packL=0);
private:
    QLabel *profileResult[MAXCOMBO];
    QLabel *extendedInfo[MAXEXTENDED];
    QLabel *roomOwner,*roomStatus;
    QTextEdit *roomAbout;
    void closeEvent(QCloseEvent *e);
    const unsigned char* setProfileResult(const unsigned char *data,const unsigned char* maxPtr=0);
    void setCustomFont();
private slots:
    void aboutClicked();
signals:
    void showAbout();
};

#endif
