
/****************************************************************************
** Form implementation generated from reading ui file './nickform.ui'
**
** Created: Sun Dec 17 12:39:13 2006
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#include "nickform.h"

#include <qvariant.h>
#include <qpushbutton.h>
#include <qframe.h>
#include <qlabel.h>
#include <qiconview.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qimage.h>
#include <qpixmap.h>

static const unsigned char img0_nickform[] = { 
    0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
    0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x10,
    0x08, 0x06, 0x00, 0x00, 0x00, 0x1f, 0xf3, 0xff, 0x61, 0x00, 0x00, 0x00,
    0x91, 0x49, 0x44, 0x41, 0x54, 0x38, 0x8d, 0xa5, 0x93, 0xdb, 0x0d, 0xc3,
    0x30, 0x08, 0x45, 0x2f, 0xc8, 0x8b, 0x65, 0x93, 0x7a, 0x32, 0x6f, 0x12,
    0x8f, 0x46, 0x3f, 0x52, 0x23, 0x42, 0xa0, 0xc2, 0xca, 0x95, 0x2c, 0x23,
    0x04, 0x07, 0xf0, 0x83, 0x44, 0x04, 0x6f, 0xd4, 0x7e, 0xfb, 0xa2, 0x90,
    0xb1, 0xcb, 0x00, 0xa1, 0x3e, 0x2f, 0xca, 0x38, 0xd4, 0xae, 0x48, 0xc6,
    0x01, 0xde, 0x49, 0xf0, 0xa2, 0x3e, 0x75, 0x84, 0x1b, 0xb5, 0x92, 0xb8,
    0xc4, 0xd6, 0x5f, 0xad, 0x6c, 0x8b, 0x34, 0xe3, 0x14, 0x4f, 0x5f, 0xc1,
    0x91, 0xef, 0x01, 0xb0, 0xc9, 0xd1, 0x18, 0xd9, 0x68, 0x8f, 0x33, 0xc8,
    0x64, 0xbb, 0xb0, 0x30, 0x8e, 0x82, 0x33, 0x45, 0x5d, 0x70, 0x14, 0x40,
    0x7d, 0xea, 0xca, 0xba, 0x50, 0x1f, 0x3e, 0xa7, 0xbe, 0xbc, 0xca, 0x15,
    0x7a, 0x50, 0x78, 0x88, 0xff, 0xe4, 0x8b, 0x70, 0xb5, 0x6a, 0x06, 0x23,
    0xd9, 0xff, 0x8e, 0xb7, 0x0f, 0xd7, 0xb0, 0xf1, 0x02, 0x1d, 0x04, 0x00,
    0xf0, 0x05, 0x98, 0x44, 0x3e, 0x22, 0x75, 0x5a, 0x3f, 0xd7, 0x00, 0x00,
    0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};

static const char* const img1_nickform[] = { 
"34 21 3 1",
". c #004991",
"# c #004a91",
"a c #004a92",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"......#...........................",
"..................................",
"..................................",
"..................................",
"..................................",
"....a...................#.........",
"..................................",
".....................a............"};

static const char* const img2_nickform[] = { 
"72 21 20 1",
". c #004991",
"# c #004a91",
"a c #004a92",
"b c #004a94",
"m c #004c97",
"h c #004d99",
"l c #004f9c",
"q c #00509d",
"g c #00509f",
"f c #0052a2",
"p c #0053a5",
"e c #0055a8",
"j c #0056aa",
"c c #0057ad",
"i c #0059b0",
"d c #005ab3",
"o c #005cb6",
"n c #005db9",
"r c #005fbb",
"k c #0060be",
"...#...................#................................................",
"........................................................................",
"........................................................................",
"...............................................a........................",
"........................................................................",
"........................................................................",
".......................................................................a",
"..........bcddddde.dddddddf.gdddddddhddddddihbjddddddffdddddddh.........",
"..........ekkkkkkklkkkkkkkkmnkkkkkkklkkkkkkkcfkkkkkkkeokkkkkkkl.........",
"..........dkclllokekkcllpkklkkpllllllkklllckdekolllllmkkclllllb.........",
"..........dke...dkekkefdokkqkkljdddjlkk...ekdekd......kkndddil..........",
"..........dke...dkekkeekkkr.kkldkkkdlkk...ekdekd......kkkkkkkkb.........",
"..........dke...dkekkemlllb.kkl.....lkk...ekdekd......kkdeeckkl.........",
"..........jkkkkkkkfkke......rkkkkkkklkk...ekdpkkkkkkkeokkkkkkkh.........",
"..........lrkkkkknbkke......ekkkkkkklkk...ekdmnkkkkkkegkkkkkkd..........",
"........................................................................",
"........................................................................",
"........................................................................",
"........................................................................",
"........................................................................",
"........................................................................"};

static const char* const img3_nickform[] = { 
"60 18 45 1",
"N c #414041",
"K c #5a9dde",
"M c #5a9de6",
"L c #5aa1e6",
"I c #62a1e6",
"H c #62a5e6",
"E c #6aa5e6",
"J c #6aa5ee",
"F c #6aaae6",
"G c #6aaaee",
"C c #73aae6",
"B c #73aee6",
"A c #73aeee",
"D c #7baeee",
"y c #7bb2e6",
"z c #7bb2ee",
"x c #83b6ee",
"u c #8bbaee",
"w c #8bbeee",
"v c #94beee",
"t c #9cc2ee",
"s c #9cc6f6",
"r c #a4c6ee",
"p c #a4caee",
"q c #a4caf6",
"n c #accef6",
"o c #acd2f6",
"m c #b4d2f6",
"l c #b4d6f6",
"Q c #bdbebd",
"k c #bdd6f6",
"O c #c5bec5",
"P c #c5c2c5",
"j c #cde2f6",
"h c #cde2ff",
"g c #d5e2ff",
"i c #d5e6ff",
"d c #deeaff",
"f c #deeeff",
"e c #e6eeff",
"b c #eef6ff",
"a c #f6f6ff",
"c c #f6faff",
"# c #fffaff",
". c #ffffff",
"............................................................",
"#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.",
"abaacbaaabaaabcaabcacbaacbaaabcaabaacbaaabcaabaaabaaabaacbca",
"dedefededefefefededefefededefedefededefededededefefedededefe",
"ghijihijihijihgjihgjghijghijghijihihihijihijghijihihihijihij",
"kklkkkkkkklkkklkkklkkkkkkklkkkkkkklkkkkkkkkkkklkkklkkkkkkkkk",
"mnmnmnmnmnmnmnmnmomnmnmnmnmnmnmnmomnmnmnmnmnmnmnmnmnmnmnmnmn",
"pqpqrqpqrqpqrqpqpqrqpqpqpqrqpqpqpqpqpqpqpqpqpqrqpqrqpqpqpqpq",
"stststststststststststststststststststststststststststststst",
"uvwvuvuvwvuvuvuvwvuvwvuvwvwvuvwvuvuvwvwvwvuvuvuvuvuvwvuvuvwv",
"uxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxux",
"yzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyz",
"ABABACABABACABABABACABABDCABDBACABABABABABABABACABABABABABAB",
"EFEFEFEFEFEFEGEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEGEFEGEFEGEF",
"HIJIHIJIHIJIHIJIHIJIHIJIHIJIEIJIEIJIHIJIHIJIEIJHEIJIHIJIEIJI",
"KLMIMIMIMLMIMLMIMLMIMLMIMLMIMIMIMIMIKIMIMLMIMIMIMLMIMLMIMLMI",
"NNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN",
"OPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQP"};

static const char* const img4_nickform[] = { 
"34 21 3 1",
"# c #004894",
"a c #004c94",
". c #004c9c",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#",
"##################################",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#",
"##################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#",
"##################################",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#",
"##################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#",
"##################################",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#",
"##################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#",
"##################################",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#",
"##################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#",
"##################################",
"a#.#.#.#a#.#a#.#a#.#a#.#a#.#a#.#a#",
"##################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#"};

static const char* const img5_nickform[] = { 
"28 18 47 1",
"c c #5a9de6",
"b c #5aa1e6",
"a c #62a1e6",
"d c #62a5e6",
"h c #6aa5e6",
"f c #6aaae6",
"g c #6aaaee",
"# c #737173",
"i c #73aae6",
"e c #73aaee",
"k c #73aee6",
"j c #73aeee",
"n c #7bb2e6",
"l c #7bb2ee",
"m c #83b2ee",
"o c #83b6e6",
"q c #83b6ee",
"p c #83baee",
"r c #8bb6ee",
"s c #8bbaee",
"u c #8bbeee",
"v c #94beee",
"t c #94bef6",
"y c #94c2ee",
"w c #9cc2ee",
"x c #9cc2f6",
"z c #9cc6ee",
"A c #9cc6f6",
"C c #a4caee",
"B c #a4caf6",
"D c #accaf6",
"E c #acceee",
"G c #accef6",
"F c #b4d2f6",
"I c #bdd6f6",
"J c #bddaf6",
"H c #bddaff",
"K c #cde2f6",
"M c #cde2ff",
". c #d5d2d5",
"L c #d5e2ff",
"O c #deeeff",
"N c #e6eeff",
"P c #eef6ff",
"Q c #f6f6ff",
"S c #fffaff",
"R c #ffffff",
"............................",
"############################",
"ababababacababacacacababacab",
"adadadadadadadadadadadadadad",
"efghghghghghehgfghgfghghghgh",
"ijijijikijijijijijijijijijij",
"llmllnmllnmllnmllnmlllmllnml",
"opqpqpqroqqsqpqropqqqqqrqpqp",
"tuvutuvutuvutuvutvvutvvutuvu",
"wxyzwAyzyxyzwxyzyxywwAyzwAyz",
"BCDBBCDBBCDBBCDBBCDBBCDBDCDB",
"EFGFEFGFEFGFGFGFEFGFGFGFEFGF",
"HIJIHIHIHIHIHIHIHIJIHIHIHIJI",
"KLKLKLKMKLKMKLKLKLKMKLKLKLKL",
"NNNNNNNNNNNNNONNNNNNNNNNNNNN",
"PQPQPQPQPQPQPQPQPQPQPQPQPQPQ",
"RRRRRRRRRRRRRSRRRSRSRRRRRRRR",
"RRRRRRRRRRRRRRRRRRRRRRRRRRRR"};

static const char* const img6_nickform[] = { 
"11 23 26 1",
"w c #0075e6",
"x c #0075ee",
"c c #0879ee",
"s c #1081ee",
"v c #2989ee",
"b c #3991ee",
"a c #62aaf6",
"l c #6ab2f6",
"o c #73b2f6",
"j c #7bb6ff",
"q c #8bbeff",
"t c #a4cef6",
"d c #a4ceff",
"e c #acceff",
"r c #acd2ff",
"# c #b4d6ff",
"m c #cddeff",
"p c #deeaff",
"k c #deeeff",
"f c #e6eeff",
"u c #eeeeff",
"h c #eef2ff",
"n c #f6f2ff",
"g c #f6f6ff",
"i c #fffaff",
". c #ffffff",
".......#abc",
".....dcefgh",
"...ijaggggg",
"..klmgnghgn",
"..opggggggg",
".qrgnghgngh",
".sggggggggg",
"t#nghgnghgn",
"auggggggggg",
"vghgnghgngh",
"sgggggggggg",
"wgnghgnghgn",
"cgggggggggg",
"xghgnghgngh",
"cgggggggggg",
"wgnghgnghgn",
"cgggggggggg",
"xghgnghgngh",
"cgggggggggg",
"wgnghgnghgn",
"cgggggggggg",
"xghgnghgngh",
"cgggggggggg"};

static const char* const img7_nickform[] = { 
"24 23 5 1",
"# c #0075ee",
". c #0879ee",
"c c #eef2ff",
"a c #f6f2ff",
"b c #f6f6ff",
".#.#.#.#.#.#.#.#.#.#.#.#",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"cbabcbabcbabcbabcbabcbab",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"cbabcbabcbabcbabcbabcbab",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"cbabcbabcbabcbabcbabcbab",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"cbabcbabcbabcbabcbabcbab",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"cbabcbabcbabcbabcbabcbab",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb"};

static const char* const img8_nickform[] = { 
"11 23 26 1",
"x c #0075e6",
"w c #0075ee",
". c #0879ee",
"v c #087dee",
"s c #1081ee",
"u c #2089ee",
"# c #3991ee",
"a c #62aaf6",
"m c #6ab2f6",
"p c #73b2ff",
"i c #7bb6ff",
"r c #94c6ff",
"h c #a4ceff",
"g c #acceff",
"q c #acd2ff",
"b c #b4d6ff",
"l c #cddeff",
"o c #deeaff",
"n c #deeeff",
"f c #e6eeff",
"t c #eeeeff",
"k c #eef2ff",
"d c #f6f2ff",
"e c #f6f6ff",
"j c #fffaff",
"c c #ffffff",
".#abccccccc",
"defg.hccccc",
"eeeeeaijccc",
"kedekelmncc",
"eeeeeeeopcc",
"dekedekeqrc",
"eeeeeeeeesc",
"kedekedekbh",
"eeeeeeeeeta",
"dekedekedeu",
"eeeeeeeeeev",
"kedekedekew",
"eeeeeeeeee.",
"dekedekedex",
"eeeeeeeeee.",
"kedekedekew",
"eeeeeeeeee.",
"dekedekedex",
"eeeeeeeeee.",
"kedekedekew",
"eeeeeeeeee.",
"dekedekedex",
"eeeeeeeeee."};

static const char* const img9_nickform[] = { 
"84 27 361 2",
"aP c #000000",
"be c #040404",
"aV c #080808",
"aT c #090909",
"b# c #0c0c0c",
"bi c #0d0d0d",
"bt c #101010",
"bq c #121212",
"bL c #151515",
"#2 c #175b93",
"bm c #191919",
"ac c #194a72",
"bp c #1a1a1a",
"ce c #1a78ab",
"cq c #1b72a4",
"am c #1c507a",
"bs c #1d1d1d",
"au c #1f5581",
"bx c #1f5582",
"aL c #1f5681",
"bZ c #205782",
"#U c #206d97",
"cM c #215779",
"b5 c #225680",
"b. c #252525",
"aH c #262626",
"#w c #265f90",
"cc c #274d6b",
"dg c #2a567b",
"cm c #2a5b85",
"cL c #2a6588",
"#O c #2a6596",
"b8 c #2a769e",
"bK c #2e2e2e",
"#P c #316795",
"a2 c #323232",
"aQ c #333333",
"df c #335777",
"cN c #335f7c",
"cG c #33638b",
"#8 c #336a88",
"aZ c #343434",
"ab c #346892",
"dd c #365a7b",
"da c #37536f",
"d# c #375370",
"d. c #375371",
"c8 c #375372",
"c9 c #375472",
"c7 c #375473",
"c6 c #375474",
"c5 c #375575",
"c4 c #375576",
"c3 c #375677",
"c2 c #375678",
"c1 c #375779",
"db c #37577a",
"c0 c #37587a",
"cZ c #37597b",
"cY c #37597c",
"dc c #375a7c",
"cX c #375a7d",
"cW c #375b7d",
"cV c #375c7e",
"cU c #375d7f",
"cT c #375f80",
"#v c #375f84",
"cS c #376081",
"cR c #376182",
"cQ c #376283",
"cP c #376483",
"## c #376887",
"a5 c #383838",
"cO c #386482",
"#F c #387293",
"bH c #393939",
"de c #3a5c7c",
"bn c #3b3b3b",
"cb c #3c6a91",
"#. c #3c799e",
"a6 c #3e3e3e",
"br c #3f3f3f",
"ba c #414141",
".t c #434445",
".V c #47617a",
".U c #47617b",
".T c #47617c",
".S c #47617d",
".R c #47617e",
".Q c #47627e",
".P c #47627f",
".O c #476280",
".N c #476281",
".M c #476381",
".L c #476382",
".K c #476482",
".W c #476483",
".J c #476583",
".I c #476584",
".H c #476685",
".G c #476786",
".F c #476888",
".E c #476a88",
".D c #476a89",
".C c #476b89",
".B c #476c8a",
".A c #476d8c",
".z c #476f8c",
".y c #47708e",
".x c #47718e",
"aI c #484848",
".X c #486787",
"bb c #494949",
"#x c #4a7293",
"bk c #4c4c4c",
".8 c #4c5458",
".w c #4c7690",
"#7 c #4c7b93",
"cr c #4c7b96",
".Y c #4d6c8a",
"ag c #4e829f",
"#D c #4f5456",
"bD c #505050",
"cl c #506474",
"#3 c #50738f",
"#E c #51819c",
"al c #527897",
"ap c #52849f",
"cE c #535c63",
"cF c #536c82",
"ay c #53839e",
"aF c #53849e",
"cH c #546d82",
"b4 c #54758f",
".9 c #54798f",
"a7 c #555555",
"#T c #556e7b",
"bT c #5687a0",
"bl c #585858",
".Z c #58748f",
"bI c #595959",
".u c #59666e",
".i c #5a5a5a",
"bY c #5a7a94",
"at c #5a7c98",
"aD c #5a7c99",
"aK c #5a7d99",
"bR c #5a7d9a",
"cp c #5a89a4",
".h c #5b5b5b",
"b0 c #5b879e",
".g c #5c5c5c",
"cD c #5c6063",
".e c #5d5d5d",
".v c #5d7a8c",
".f c #5e5e5e",
"ah c #5e8da6",
".0 c #5f778c",
"b7 c #5f8599",
".d c #606060",
"bh c #616161",
"cs c #61727d",
".j c #626262",
"ck c #626364",
"#a c #627b8b",
"b1 c #6293ae",
".s c #646464",
"#u c #657c92",
"a4 c #676767",
"ca c #676d72",
".1 c #677682",
".c c #696969",
"bf c #6a6a6a",
"bJ c #6c6c6c",
"cn c #6e7e8b",
"aq c #6e9db8",
"bQ c #6e9fbb",
"az c #6ea0bb",
"cf c #6f94a9",
"bU c #6f9db5",
"aO c #727272",
"cC c #727476",
"ct c #72787c",
"aY c #737373",
"aW c #747474",
"cd c #758e9b",
"cK c #7590a0",
"bA c #777777",
"dh c #778490",
".k c #787878",
"bE c #7d7d7d",
"cB c #7d8082",
"cu c #7d8183",
"#t c #7d90a1",
".b c #7e7e7e",
"#q c #7e8c99",
"#p c #7e8c9a",
"#o c #7e8c9b",
"#n c #7e8c9c",
"#m c #7e8d9c",
"#l c #7e8d9d",
"#r c #7e8e9d",
"#k c #7e8e9e",
"#j c #7e8e9f",
"#s c #7e8f9f",
"#i c #7e8fa0",
"#h c #7e90a1",
"#g c #7e91a2",
"#f c #7e92a2",
"#e c #7e92a3",
"#d c #7e93a3",
"#c c #7e94a3",
"#b c #7e94a4",
"a0 c #7f7f7f",
"cA c #7f8082",
"cy c #7f8083",
"cz c #7f8182",
"cx c #7f8183",
"cw c #7f8184",
"cv c #7f8284",
"#S c #808080",
"bo c #818181",
"bS c #828282",
"by c #848484",
"#6 c #858585",
"bc c #868686",
"ao c #878787",
"b3 c #87898a",
"#y c #87949f",
"#C c #888888",
"af c #898989",
"ax c #8a8a8a",
"#N c #8a9cac",
"b6 c #8b8b8b",
".2 c #8b8d8f",
"#G c #8b9da8",
"#1 c #8ba0b1",
"bv c #8c8c8c",
".l c #919191",
"bg c #949494",
".r c #999999",
".3 c #9e9e9e",
"bX c #9e9fa0",
"cj c #9f9f9f",
"aU c #a0a0a0",
".7 c #a1a1a1",
".m c #a2a2a2",
"aR c #a3a3a3",
"aa c #a4aaaf",
"#V c #a4b0b8",
"a9 c #a5a5a5",
".4 c #a6a6a6",
"dE c #a6adb4",
"dn c #a6afb4",
"#Q c #a6afb7",
".a c #a7a7a7",
"aC c #a7a8aa",
"dD c #a7b3bf",
"dB c #a8b3be",
"dA c #a8b3bf",
"dz c #a8b3c0",
"dy c #a8b4c0",
"dx c #a8b4c1",
"dw c #a8b5c2",
"dv c #a8b5c3",
"dC c #a8b6c2",
"du c #a8b6c3",
"dt c #a8b7c3",
"ds c #a8b7c4",
"dr c #a8b8c5",
"dq c #a8b9c5",
"bd c #a9a9a9",
"as c #a9aaab",
"do c #a9b6bf",
"dp c #a9b9c3",
"bu c #acacac",
"dm c #acb1b4",
"ak c #adafb0",
"aS c #aeaeae",
"co c #aeb3b5",
"cg c #afb0b1",
"#A c #b0b0b0",
"dF c #b0b3b5",
"aG c #b1b1b1",
"di c #b1b3b5",
"bj c #b2b2b2",
".n c #b3b3b3",
"aJ c #b4b4b4",
"dI c #b5b5b5",
"#z c #b5b6b7",
"bB c #b6b6b6",
"dJ c #b7b7b7",
"cI c #b7b9bb",
".q c #b8b8b8",
".5 c #b9b9b9",
"cJ c #b9bdc0",
".# c #bababa",
"dj c #bababb",
".p c #bbbbbb",
"dG c #bbbbbc",
".o c #bcbcbc",
"bP c #bdbdbd",
"Qt c #bebebe",
"#B c #bfbfbf",
".6 c #c0c0c0",
"#R c #c1c1c1",
"dl c #c1c1c2",
"ae c #c2c2c2",
"#5 c #c3c3c3",
"aM c #c4c4c4",
"aw c #c5c5c5",
"aE c #c6c6c6",
"an c #c7c7c7",
"dM c #c8c8c8",
"#M c #c8cccf",
"aN c #c9c9c9",
"#H c #c9ccce",
"a1 c #cacaca",
"b9 c #cad2d5",
"bG c #cbcbcb",
"dH c #cccccc",
"dk c #cdcdcd",
"dK c #cecece",
"bN c #cfcfcf",
"bF c #d0d0d0",
"dL c #d1d1d1",
"av c #d2d2d2",
"#4 c #d3d3d3",
"bC c #d4d4d4",
"ad c #d5d5d5",
"a8 c #d6d6d6",
"bO c #d8d8d8",
"ch c #d9d9d9",
"ci c #dbdbdb",
"a3 c #dcdcdc",
"bw c #dddddd",
"bW c #dfdfdf",
"#9 c #dfe2e3",
"aX c #e0e0e0",
"bz c #e1e1e1",
"aB c #e2e2e2",
"#0 c #e2e3e4",
"a# c #e3e3e3",
"#L c #e3e4e5",
"aj c #e4e4e4",
"#I c #e4e5e5",
"c. c #e5e5e5",
"b2 c #e5e6e7",
"bM c #e7e7e7",
"bV c #e7e8e9",
"ai c #e7e9e9",
"aA c #e7e9ea",
"c# c #e8e8e8",
"ar c #e8e9ea",
"a. c #e9e9e9",
"#Z c #eaeaea",
"#Y c #ebebeb",
"#W c #ececec",
"#X c #eeeeee",
"#K c #efefef",
"#J c #f0f0f0",
"Qt.#.a.b.c.d.e.e.e.f.f.f.f.g.f.f.g.e.e.g.g.g.e.e.g.g.g.g.g.g.g.g.h.h.g.g.h.h.g.g.g.g.i.h.g.h.h.g.g.h.h.g.e.h.g.h.g.g.g.h.e.g.g.g.g.g.g.g.e.e.g.g.g.g.g.h.j.k.l.m.n.o.p.#",
".q.r.s.t.u.v.w.x.y.z.A.B.C.D.E.F.G.G.H.I.I.J.K.L.M.N.O.O.P.P.Q.R.S.T.T.T.U.U.U.U.V.V.V.V.V.V.V.V.V.U.U.U.U.T.T.T.T.S.R.R.P.P.O.N.M.L.L.W.I.I.H.H.G.X.Y.Z.0.1.2.3.4.5.o.6",
".7.f.8.9#.###a#b#b#c#d#e#f#g#h#h#i#i#i#j#j#j#k#k#l#l#l#l#m#m#n#o#o#o#p#p#p#p#p#p#p#q#q#q#q#q#q#p#p#p#p#p#p#p#p#o#o#o#o#n#m#m#l#l#l#r#k#j#j#s#i#i#i#h#t#u#v#w#x#y#z#A.5#B",
"#C#D#E#F#G#H#I#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#J#K#L#M#N#O#P#Q#R.#.p",
"#S#T#U#V#W#X#Y#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Z#Y#0#1#2#3#4#5#B",
"#6#7#8#9#Wa.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a#aaabacadae#5",
"afagahai#Za.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.ajakalam#4aean",
"aoapaqar#Za.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a#asatauavaeaw",
"axayazaA#Za.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.aBaCaDauav#RaE",
"#CaFazaA#Za.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.aw.7aGa.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.aHaIa.aGaJa.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.aBaCaKaLavaMaN",
"#6aFazaA#Za.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.aOaPaQa.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.aHaIa.aR.4a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.aBaCaKaLavaeaM",
"aoaFazaA#Za.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.aSaTaUaVaWa.aXaYaZaIa0a1a2aIaI#5a3a4a5a6a7a8a9b.aIb#aIa.babba.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.aBaCaKaLavaean",
"bcaFazaA#Za.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.bdaPaSbebfa.#5aPbga.a.bhbia.a.a.bjaPbkblaP.rbma7a.aHaIa.aQbna.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.aBaCaKauav#R#5",
"boayazaA#Za.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.aBbpbqbrbsbtbu#5aPbga.a.bhbia.a.a.bjaPbvawawbwbma7a.aHaIa.aQbna.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.aBaCaKbxav.6ae",
"byaFazaA#Za.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.bzaPbAa.bBaP.7bCbabDbEaRaUbpbEbEbFbGbHbIbEbEaMbJbKbEbLaIa.aQbna.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.aBaCaKaLav.6ae",
"aoaFazaA#Za.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.bM.nbNa.bw.nbOa.#4.n.naEa.bP.n.na3a.bF.n.n.na8aB.n.n.naMa.#B#Ra.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.aBaCaKauav.6aw",
"aoaFazaA#Za.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.aBaCaKaLavaeaw",
"#CaFbQaA#Za.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.aBaCbRauavaeaE",
"bSbTbUbV#Za.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.bWbXbYbZavaeaw",
"bob0b1b2a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a8b3b4b5bF.6aw",
"b6b7b8b9a#c.c#a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.bMbz.ncacbccbG.6an",
".3cdcecfcg.pbFchcia3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3a3ciadaMcjckclcmcn#5#5aN",
"aGcocpcqcrcsctcucvcvcwcwcwcwcwcxcxcxcxcxcxcxcxcxcxcxcxcxcxcxcxcxcxcxcxcycyczcAcAczcAcAcAcAcAcAcAcAczcAcAczcycycxcxcxcxcxcxcxcxcxcxcxcxcxcxcxcxcxcxcBcCcDcEcFcGcHcI#BaN#5",
".qQtcJcKcLcMcNcOcPcQcRcScTcUcVcWcXcYcZc0c0c1c2c2c3c4c5c5c6c6c7c8c9d.d.d.d#d#dadadadadadadadadadadadadad#d#d#d.d.c8c8c7c6c6c6c5c4c4c3c2c1dbc0cZcZdccWdddedfdgdhdidjdkaEae",
".n.5.6dldmdndodpdqdqdrdrdsdsdtdududvdwdwdwdxdxdxdxdydydydzdAdAdAdAdBdBdBdBdBdBdBdBdBdBdBdBdBdBdBdBdBdBdBdBdBdBdBdAdAdAdAdAdzdydydxdxdxdxdwdwdwdwdududCdDdEdFdG.6dHan.6#B",
".5.pbP#5aM#B.qdIdIdIbBbBbBbBbBdIbBdIbBbBbBbBdJbBbBbBdJbBbBdJdJbBdJdJdJdJdJdJdJdJdJ.qdJdJdJdJdJ.qdJ.qdJ.q.qdJdJdJ.q.qdJdJdJdJbBbBdJdJdJdJdJdJbBbBdJdJbBbBbB.#aNdHaM#BbPbP",
"bP.pQtQt.6anaNaNa1bGdHdHbGbGdHbGbGbGdHdHdHdkdKdHdHdkdKdkdkdKdkdKbNdkbNbFbFbFbFbFdLbNdkbFdKbNdLbNbFbFbNdLdLbFbFbFdLdLbNbFbFdKdKdKdKbFdKdKbNdkdHdkbNdKdkdKdka1dMae#Bae#R#R"};


/*
 *  Constructs a nickForm as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
nickForm::nickForm( QWidget* parent, const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl ),
      image1( (const char **) img1_nickform ),
      image2( (const char **) img2_nickform ),
      image3( (const char **) img3_nickform ),
      image4( (const char **) img4_nickform ),
      image5( (const char **) img5_nickform ),
      image6( (const char **) img6_nickform ),
      image7( (const char **) img7_nickform ),
      image8( (const char **) img8_nickform ),
      image9( (const char **) img9_nickform )
{
    QImage img;
    img.loadFromData( img0_nickform, sizeof( img0_nickform ), "PNG" );
    image0 = img;
    if ( !name )
	setName( "nickForm" );
    setMinimumSize( QSize( 430, 200 ) );
    setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    setIcon( image0 );
    nickFormLayout = new QGridLayout( this, 1, 1, 0, 0, "nickFormLayout"); 
    spacer102 = new QSpacerItem( 20, 10, QSizePolicy::Minimum, QSizePolicy::Fixed );
    nickFormLayout->addItem( spacer102, 2, 0 );
    spacer103 = new QSpacerItem( 20, 10, QSizePolicy::Minimum, QSizePolicy::Fixed );
    nickFormLayout->addItem( spacer103, 4, 0 );

    frame16 = new QFrame( this, "frame16" );
    frame16->setMinimumSize( QSize( 430, 21 ) );
    frame16->setMaximumSize( QSize( 32767, 21 ) );
    frame16->setPaletteBackgroundPixmap( image1 );
    frame16->setFrameShape( QFrame::NoFrame );
    frame16->setFrameShadow( QFrame::Plain );
    frame16Layout = new QGridLayout( frame16, 1, 1, 0, 0, "frame16Layout"); 

    pixmapLabel2_2 = new QLabel( frame16, "pixmapLabel2_2" );
    pixmapLabel2_2->setMinimumSize( QSize( 72, 21 ) );
    pixmapLabel2_2->setMaximumSize( QSize( 72, 21 ) );
    pixmapLabel2_2->setPixmap( image2 );
    pixmapLabel2_2->setScaledContents( FALSE );

    frame16Layout->addWidget( pixmapLabel2_2, 0, 1 );
    spacer132 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame16Layout->addItem( spacer132, 0, 0 );

    nickFormLayout->addWidget( frame16, 1, 0 );

    textLabel1 = new QLabel( this, "textLabel1" );
    textLabel1->setMinimumSize( QSize( 400, 18 ) );
    textLabel1->setMaximumSize( QSize( 32767, 18 ) );
    textLabel1->setPaletteBackgroundPixmap( image3 );

    nickFormLayout->addWidget( textLabel1, 0, 0 );

    frame16_2 = new QFrame( this, "frame16_2" );
    frame16_2->setMinimumSize( QSize( 400, 21 ) );
    frame16_2->setMaximumSize( QSize( 32767, 21 ) );
    frame16_2->setPaletteBackgroundPixmap( image4 );
    frame16_2->setFrameShape( QFrame::NoFrame );
    frame16_2->setFrameShadow( QFrame::Plain );

    nickFormLayout->addWidget( frame16_2, 5, 0 );

    pixmapLabel9_2 = new QLabel( this, "pixmapLabel9_2" );
    pixmapLabel9_2->setMinimumSize( QSize( 400, 22 ) );
    pixmapLabel9_2->setMaximumSize( QSize( 32767, 22 ) );
    pixmapLabel9_2->setPaletteBackgroundPixmap( image5 );
    pixmapLabel9_2->setScaledContents( FALSE );

    nickFormLayout->addWidget( pixmapLabel9_2, 6, 0 );

    layout87 = new QHBoxLayout( 0, 0, 0, "layout87"); 
    spacer100 = new QSpacerItem( 20, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout87->addItem( spacer100 );

    frame44 = new QFrame( this, "frame44" );
    frame44->setFrameShape( QFrame::NoFrame );
    frame44->setFrameShadow( QFrame::Plain );
    frame44Layout = new QGridLayout( frame44, 1, 1, 0, 0, "frame44Layout"); 

    layout78 = new QHBoxLayout( 0, 0, 0, "layout78"); 

    pixmapLabel1_2 = new QLabel( frame44, "pixmapLabel1_2" );
    pixmapLabel1_2->setMinimumSize( QSize( 11, 23 ) );
    pixmapLabel1_2->setMaximumSize( QSize( 11, 23 ) );
    pixmapLabel1_2->setPixmap( image6 );
    pixmapLabel1_2->setScaledContents( FALSE );
    layout78->addWidget( pixmapLabel1_2 );

    frame58 = new QFrame( frame44, "frame58" );
    frame58->setMinimumSize( QSize( 130, 23 ) );
    frame58->setMaximumSize( QSize( 32767, 23 ) );
    frame58->setPaletteBackgroundPixmap( image7 );
    frame58->setFrameShape( QFrame::NoFrame );
    frame58->setFrameShadow( QFrame::Plain );

    identityCaption = new QLabel( frame58, "identityCaption" );
    identityCaption->setGeometry( QRect( 0, 4, 255, 18 ) );
    identityCaption->setPaletteForegroundColor( QColor( 0, 0, 0 ) );
    identityCaption->setBackgroundOrigin( QLabel::AncestorOrigin );
    QFont identityCaption_font(  identityCaption->font() );
    identityCaption_font.setBold( TRUE );
    identityCaption->setFont( identityCaption_font ); 
    layout78->addWidget( frame58 );

    pixmapLabel1_2_2 = new QLabel( frame44, "pixmapLabel1_2_2" );
    pixmapLabel1_2_2->setMinimumSize( QSize( 11, 23 ) );
    pixmapLabel1_2_2->setMaximumSize( QSize( 11, 23 ) );
    pixmapLabel1_2_2->setPixmap( image8 );
    pixmapLabel1_2_2->setScaledContents( FALSE );
    layout78->addWidget( pixmapLabel1_2_2 );

    frame44Layout->addLayout( layout78, 0, 0 );
    spacer91 = new QSpacerItem( 20, 10, QSizePolicy::Minimum, QSizePolicy::Fixed );
    frame44Layout->addItem( spacer91, 2, 0 );

    nickList = new QIconView( frame44, "nickList" );
    nickList->setMinimumSize( QSize( 250, 85 ) );
    nickList->setPaletteForegroundColor( QColor( 3, 118, 231 ) );
    nickList->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    QPalette pal;
    QColorGroup cg;
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, QColor( 221, 223, 228) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 238, 239, 241) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 111, 114) );
    cg.setColor( QColorGroup::Mid, QColor( 147, 149, 152) );
    cg.setColor( QColorGroup::Text, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, QColor( 221, 223, 228) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 254, 254, 255) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 111, 114) );
    cg.setColor( QColorGroup::Mid, QColor( 147, 149, 152) );
    cg.setColor( QColorGroup::Text, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, QColor( 221, 223, 228) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 254, 254, 255) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 111, 114) );
    cg.setColor( QColorGroup::Mid, QColor( 147, 149, 152) );
    cg.setColor( QColorGroup::Text, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setDisabled( cg );
    nickList->setPalette( pal );
    nickList->setFocusPolicy( QIconView::TabFocus );
    nickList->setAcceptDrops( FALSE );
    nickList->setFrameShape( QIconView::Box );
    nickList->setFrameShadow( QIconView::Plain );
    nickList->setLineWidth( 1 );
    nickList->setMargin( 0 );
    nickList->setResizePolicy( QIconView::Manual );
    nickList->setVScrollBarMode( QIconView::Auto );
    nickList->setHScrollBarMode( QIconView::Auto );
    nickList->setDragAutoScroll( FALSE );
    nickList->setGridX( -1 );
    nickList->setGridY( -1 );
    nickList->setArrangement( QIconView::TopToBottom );
    nickList->setResizeMode( QIconView::Adjust );
    nickList->setMaxItemWidth( 130 );
    nickList->setMaxItemTextLength( 300 );
    nickList->setAutoArrange( TRUE );
    nickList->setItemsMovable( FALSE );
    nickList->setWordWrapIconText( FALSE );

    frame44Layout->addWidget( nickList, 1, 0 );

    layout86 = new QHBoxLayout( 0, 0, 3, "layout86"); 

    frame50_2 = new QFrame( frame44, "frame50_2" );
    frame50_2->setMinimumSize( QSize( 0, 30 ) );
    frame50_2->setMaximumSize( QSize( 32767, 30 ) );
    frame50_2->setPaletteForegroundColor( QColor( 3, 118, 231 ) );
    frame50_2->setPaletteBackgroundColor( QColor( 239, 243, 255 ) );
    frame50_2->setFrameShape( QFrame::Box );
    frame50_2->setFrameShadow( QFrame::Plain );
    frame50_2Layout = new QGridLayout( frame50_2, 1, 1, 0, 0, "frame50_2Layout"); 

    layout79 = new QHBoxLayout( 0, 0, 0, "layout79"); 
    spacer94 = new QSpacerItem( 10, 19, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout79->addItem( spacer94 );

    lastIdentity = new QLabel( frame50_2, "lastIdentity" );
    lastIdentity->setMinimumSize( QSize( 200, 20 ) );
    lastIdentity->setMaximumSize( QSize( 32767, 20 ) );
    lastIdentity->setPaletteForegroundColor( QColor( 0, 0, 0 ) );
    layout79->addWidget( lastIdentity );
    spacer92 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout79->addItem( spacer92 );

    timeOutLabel = new QLabel( frame50_2, "timeOutLabel" );
    timeOutLabel->setMinimumSize( QSize( 30, 20 ) );
    timeOutLabel->setMaximumSize( QSize( 32767, 20 ) );
    timeOutLabel->setPaletteForegroundColor( QColor( 0, 0, 0 ) );
    layout79->addWidget( timeOutLabel );
    spacer93 = new QSpacerItem( 10, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout79->addItem( spacer93 );

    frame50_2Layout->addLayout( layout79, 0, 0 );
    layout86->addWidget( frame50_2 );

    enterButtonPlaceHolder = new QLabel( frame44, "enterButtonPlaceHolder" );
    enterButtonPlaceHolder->setMinimumSize( QSize( 84, 30 ) );
    enterButtonPlaceHolder->setMaximumSize( QSize( 84, 30 ) );
    enterButtonPlaceHolder->setPixmap( image9 );
    enterButtonPlaceHolder->setScaledContents( FALSE );
    layout86->addWidget( enterButtonPlaceHolder );

    frame44Layout->addLayout( layout86, 3, 0 );
    layout87->addWidget( frame44 );
    spacer101 = new QSpacerItem( 20, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout87->addItem( spacer101 );

    nickFormLayout->addLayout( layout87, 3, 0 );
    languageChange();
    resize( QSize(430, 234).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );
}

/*
 *  Destroys the object and frees any allocated resources
 */
nickForm::~nickForm()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void nickForm::languageChange()
{
    setCaption( ( "Caption" ) );
    identityCaption->setText( ( "Identità disponibili" ) );
    lastIdentity->setText( ( "Default:" ) );
    timeOutLabel->setText( ( "3 s" ) );
}

#include "nickform.moc"
