/****************************************************************************
** Form interface generated from reading ui file './connectDlg.ui'
**
** Created: Sun Dec 17 12:38:45 2006
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef CONNECTDLG_H
#define CONNECTDLG_H

#include <qvariant.h>
#include <qpixmap.h>
#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QLabel;
class QFrame;
class QProgressBar;

class ConnectDlg : public QDialog
{
    Q_OBJECT

public:
    ConnectDlg( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~ConnectDlg();

    QLabel* textLabel1;
    QFrame* frame16;
    QLabel* pixmapLabel2_2;
    QLabel* pixmapLabel9_2;
    QFrame* frame16_2;
    QFrame* frame50;
    QLabel* pixmapLabel2;
    QFrame* frame59;
    QLabel* textLabel1_2;
    QLabel* textLabel2;
    QProgressBar* progressBar;

protected:
    QGridLayout* ConnectDlgLayout;
    QSpacerItem* spacer112;
    QSpacerItem* spacer113;
    QGridLayout* frame16Layout;
    QSpacerItem* spacer81;
    QHBoxLayout* layout82;
    QSpacerItem* spacer146;
    QSpacerItem* spacer145;
    QGridLayout* frame50Layout;
    QHBoxLayout* layout76;
    QSpacerItem* spacer124;
    QSpacerItem* spacer122;
    QSpacerItem* spacer132;
    QGridLayout* frame59Layout;
    QSpacerItem* spacer125;
    QSpacerItem* spacer131;
    QHBoxLayout* layout74;
    QSpacerItem* spacer127;
    QSpacerItem* spacer128;
    QHBoxLayout* layout75;
    QSpacerItem* spacer129;
    QSpacerItem* spacer129_2;

protected slots:
    virtual void languageChange();

private:
    QPixmap image0;
    QPixmap image1;
    QPixmap image2;
    QPixmap image3;
    QPixmap image4;
    QPixmap image5;
    QPixmap image6;

};

#endif // CONNECTDLG_H
