/****************************************************************************
** Form interface generated from reading ui file './aboutDlg.ui'
**
** Created: Sun Dec 17 12:38:45 2006
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef ABOUTDLG_H
#define ABOUTDLG_H

#include <qvariant.h>
#include <qpixmap.h>
#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QLabel;
class QFrame;
class QTextEdit;

class AboutDlg : public QDialog
{
    Q_OBJECT

public:
    AboutDlg( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~AboutDlg();

    QLabel* textLabel1;
    QFrame* frame16;
    QLabel* textLabel1_2;
    QLabel* pixmapLabel1;
    QFrame* frame15;
    QLabel* exitButtonPlaceHolder;
    QLabel* pixmapLabel8_2;
    QLabel* pixmapLabel9_2;
    QTextEdit* aboutPlaceHolder;
    QFrame* frame10;
    QLabel* pixmapLabel1_2;
    QLabel* pixmapLabel1_3;

protected:
    QGridLayout* AboutDlgLayout;
    QSpacerItem* spacer20;
    QGridLayout* frame16Layout;
    QSpacerItem* spacer8;
    QHBoxLayout* layout34;
    QGridLayout* frame15Layout;
    QSpacerItem* spacer38;
    QVBoxLayout* layout33;
    QSpacerItem* spacer37;
    QHBoxLayout* layout117;
    QSpacerItem* spacer143;
    QSpacerItem* spacer144;
    QGridLayout* frame10Layout;
    QSpacerItem* spacer21;
    QSpacerItem* spacer19;
    QSpacerItem* spacer17;
    QVBoxLayout* layout7;
    QSpacerItem* spacer19_2;

protected slots:
    virtual void languageChange();

private:
    QPixmap image0;
    QPixmap image1;
    QPixmap image2;
    QPixmap image3;
    QPixmap image4;
    QPixmap image5;
    QPixmap image6;
    QPixmap image7;
    QPixmap image8;
    QPixmap image9;

};

#endif // ABOUTDLG_H
