/***************************************************************************
                          c6about.h  -  description
                             -------------------
    begin                : Mon May 5 2003
    copyright            : (C) 2003 by Giorgio A.
    email                : openc6@hotmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef C6ABOUT_H
#define C6ABOUT_H

class QWidget;
class QString;
class C6Button;
class C6GlobalConfig;
class C6TextEdit;

#include <aboutDlg.h>

/**
  *@author Giorgio A.
  */

class C6About : public AboutDlg
{
  Q_OBJECT
public:
  C6About(QWidget *parent=0, const char *name=0);
  ~C6About();
  void setCustomFont();
private: // Private methods
  void saywhatuwant();
  C6TextEdit *Say;

private slots: // Private slots
  void execUrlProc(QString  & str);
signals:
  void execUrl(QString & );
};

#endif
