/****************************************************************************
** ui.h extension file, included from the uic-generated form implementation.
**
** If you want to add, delete, or rename functions or slots, use
** Qt Designer to update this file, preserving your code.
**
** You should not define a constructor or destructor in this file.
** Instead, write your code in functions called init() and destroy().
** These will automatically be called by the form's constructor and
** destructor.
*****************************************************************************/


void configure::Ok_clicked()
{

}


void configure::Annulla_clicked()
{

}


void configure::SelFontUp_clicked()
{

}


void configure::ForeColorUp_clicked()
{

}


void configure::Default_clicked()
{

}


void configure::beepSwitch_clicked()
{

}


void configure::soundSwitch_clicked()
{

}


void configure::inMessage_clicked()
{

}


void configure::outMessage_clicked()
{

}


void configure::netfriendOnline_clicked()
{

}


void configure::netfriendOffline_clicked()
{

}


void configure::pushButton7_3_clicked()
{

}


void configure::fileOpen1_clicked()
{

}


void configure::fileOpen2_clicked()
{

}


void configure::fileOpen3_clicked()
{

}


void configure::fileOpen4_clicked()
{

}


void configure::soundSwitch_toggled( bool )
{

}


void configure::fileOpen5_clicked()
{

}


void configure::removeSpecial_clicked()
{

}


void configure::addSpecial_clicked()
{

}


void configure::playDemo1_clicked()
{

}


void configure::playDemo2_clicked()
{

}


void configure::playDemo3_clicked()
{

}


void configure::playDemo4_clicked()
{

}


void configure::playDemo5_clicked()
{

}


void configure::ForeNetFriendUp_clicked()
{

}


void configure::ForeMessageUp_clicked()
{

}


void configure::fileDir_clicked()
{

}


void configure::globalFontButton_clicked()
{

}


void configure::selectFontButton_clicked()
{

}


void configure::defaultFontButton_clicked()
{

}


void configure::proxySwitch_toggled( bool )
{

}

void configure::groupNameForeColor_clicked()
{

}


void configure::contactSelFont_clicked()
{

}


void configure::contactForeColor_clicked()
{

}

void configure::Apply_clicked()
{

}


void configure::Cancel_clicked()
{

}


void configure::netfriendColorButton_clicked()
{

}


void configure::myselfColor_clicked()
{

}
