
/****************************************************************************
** Form implementation generated from reading ui file './connectDlg.ui'
**
** Created: Sun Dec 17 12:39:12 2006
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#include "connectDlg.h"

#include <qvariant.h>
#include <qpushbutton.h>
#include <qlabel.h>
#include <qframe.h>
#include <qprogressbar.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qimage.h>
#include <qpixmap.h>

static const unsigned char img0_connectDlg[] = { 
    0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
    0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x10,
    0x08, 0x06, 0x00, 0x00, 0x00, 0x1f, 0xf3, 0xff, 0x61, 0x00, 0x00, 0x00,
    0x91, 0x49, 0x44, 0x41, 0x54, 0x38, 0x8d, 0xa5, 0x93, 0xdb, 0x0d, 0xc3,
    0x30, 0x08, 0x45, 0x2f, 0xc8, 0x8b, 0x65, 0x93, 0x7a, 0x32, 0x6f, 0x12,
    0x8f, 0x46, 0x3f, 0x52, 0x23, 0x42, 0xa0, 0xc2, 0xca, 0x95, 0x2c, 0x23,
    0x04, 0x07, 0xf0, 0x83, 0x44, 0x04, 0x6f, 0xd4, 0x7e, 0xfb, 0xa2, 0x90,
    0xb1, 0xcb, 0x00, 0xa1, 0x3e, 0x2f, 0xca, 0x38, 0xd4, 0xae, 0x48, 0xc6,
    0x01, 0xde, 0x49, 0xf0, 0xa2, 0x3e, 0x75, 0x84, 0x1b, 0xb5, 0x92, 0xb8,
    0xc4, 0xd6, 0x5f, 0xad, 0x6c, 0x8b, 0x34, 0xe3, 0x14, 0x4f, 0x5f, 0xc1,
    0x91, 0xef, 0x01, 0xb0, 0xc9, 0xd1, 0x18, 0xd9, 0x68, 0x8f, 0x33, 0xc8,
    0x64, 0xbb, 0xb0, 0x30, 0x8e, 0x82, 0x33, 0x45, 0x5d, 0x70, 0x14, 0x40,
    0x7d, 0xea, 0xca, 0xba, 0x50, 0x1f, 0x3e, 0xa7, 0xbe, 0xbc, 0xca, 0x15,
    0x7a, 0x50, 0x78, 0x88, 0xff, 0xe4, 0x8b, 0x70, 0xb5, 0x6a, 0x06, 0x23,
    0xd9, 0xff, 0x8e, 0xb7, 0x0f, 0xd7, 0xb0, 0xf1, 0x02, 0x1d, 0x04, 0x00,
    0xf0, 0x05, 0x98, 0x44, 0x3e, 0x22, 0x75, 0x5a, 0x3f, 0xd7, 0x00, 0x00,
    0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};

static const char* const img1_connectDlg[] = { 
"60 18 45 1",
"N c #414041",
"K c #5a9dde",
"M c #5a9de6",
"L c #5aa1e6",
"I c #62a1e6",
"H c #62a5e6",
"E c #6aa5e6",
"J c #6aa5ee",
"F c #6aaae6",
"G c #6aaaee",
"C c #73aae6",
"B c #73aee6",
"A c #73aeee",
"D c #7baeee",
"y c #7bb2e6",
"z c #7bb2ee",
"x c #83b6ee",
"u c #8bbaee",
"w c #8bbeee",
"v c #94beee",
"t c #9cc2ee",
"s c #9cc6f6",
"r c #a4c6ee",
"p c #a4caee",
"q c #a4caf6",
"n c #accef6",
"o c #acd2f6",
"m c #b4d2f6",
"l c #b4d6f6",
"Q c #bdbebd",
"k c #bdd6f6",
"O c #c5bec5",
"P c #c5c2c5",
"j c #cde2f6",
"h c #cde2ff",
"g c #d5e2ff",
"i c #d5e6ff",
"d c #deeaff",
"f c #deeeff",
"e c #e6eeff",
"b c #eef6ff",
"a c #f6f6ff",
"c c #f6faff",
"# c #fffaff",
". c #ffffff",
"............................................................",
"#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.",
"abaacbaaabaaabcaabcacbaacbaaabcaabaacbaaabcaabaaabaaabaacbca",
"dedefededefefefededefefededefedefededefededededefefedededefe",
"ghijihijihijihgjihgjghijghijghijihihihijihijghijihihihijihij",
"kklkkkkkkklkkklkkklkkkkkkklkkkkkkklkkkkkkkkkkklkkklkkkkkkkkk",
"mnmnmnmnmnmnmnmnmomnmnmnmnmnmnmnmomnmnmnmnmnmnmnmnmnmnmnmnmn",
"pqpqrqpqrqpqrqpqpqrqpqpqpqrqpqpqpqpqpqpqpqpqpqrqpqrqpqpqpqpq",
"stststststststststststststststststststststststststststststst",
"uvwvuvuvwvuvuvuvwvuvwvuvwvwvuvwvuvuvwvwvwvuvuvuvuvuvwvuvuvwv",
"uxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxux",
"yzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyz",
"ABABACABABACABABABACABABDCABDBACABABABABABABABACABABABABABAB",
"EFEFEFEFEFEFEGEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEGEFEGEFEGEF",
"HIJIHIJIHIJIHIJIHIJIHIJIHIJIEIJIEIJIHIJIHIJIEIJHEIJIHIJIEIJI",
"KLMIMIMIMLMIMLMIMLMIMLMIMLMIMIMIMIMIKIMIMLMIMIMIMLMIMLMIMLMI",
"NNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN",
"OPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQP"};

static const char* const img2_connectDlg[] = { 
"34 21 3 1",
". c #004991",
"# c #004a91",
"a c #004a92",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"......#...........................",
"..................................",
"..................................",
"..................................",
"..................................",
"....a...................#.........",
"..................................",
".....................a............"};

static const char* const img3_connectDlg[] = { 
"72 21 20 1",
". c #004991",
"# c #004a91",
"a c #004a92",
"b c #004a94",
"m c #004c97",
"h c #004d99",
"l c #004f9c",
"q c #00509d",
"g c #00509f",
"f c #0052a2",
"p c #0053a5",
"e c #0055a8",
"j c #0056aa",
"c c #0057ad",
"i c #0059b0",
"d c #005ab3",
"o c #005cb6",
"n c #005db9",
"r c #005fbb",
"k c #0060be",
"...#...................#................................................",
"........................................................................",
"........................................................................",
"...............................................a........................",
"........................................................................",
"........................................................................",
".......................................................................a",
"..........bcddddde.dddddddf.gdddddddhddddddihbjddddddffdddddddh.........",
"..........ekkkkkkklkkkkkkkkmnkkkkkkklkkkkkkkcfkkkkkkkeokkkkkkkl.........",
"..........dkclllokekkcllpkklkkpllllllkklllckdekolllllmkkclllllb.........",
"..........dke...dkekkefdokkqkkljdddjlkk...ekdekd......kkndddil..........",
"..........dke...dkekkeekkkr.kkldkkkdlkk...ekdekd......kkkkkkkkb.........",
"..........dke...dkekkemlllb.kkl.....lkk...ekdekd......kkdeeckkl.........",
"..........jkkkkkkkfkke......rkkkkkkklkk...ekdpkkkkkkkeokkkkkkkh.........",
"..........lrkkkkknbkke......ekkkkkkklkk...ekdmnkkkkkkegkkkkkkd..........",
"........................................................................",
"........................................................................",
"........................................................................",
"........................................................................",
"........................................................................",
"........................................................................"};

static const char* const img4_connectDlg[] = { 
"28 18 47 1",
"c c #5a9de6",
"b c #5aa1e6",
"a c #62a1e6",
"d c #62a5e6",
"h c #6aa5e6",
"f c #6aaae6",
"g c #6aaaee",
"# c #737173",
"i c #73aae6",
"e c #73aaee",
"k c #73aee6",
"j c #73aeee",
"n c #7bb2e6",
"l c #7bb2ee",
"m c #83b2ee",
"o c #83b6e6",
"q c #83b6ee",
"p c #83baee",
"r c #8bb6ee",
"s c #8bbaee",
"u c #8bbeee",
"v c #94beee",
"t c #94bef6",
"y c #94c2ee",
"w c #9cc2ee",
"x c #9cc2f6",
"z c #9cc6ee",
"A c #9cc6f6",
"C c #a4caee",
"B c #a4caf6",
"D c #accaf6",
"E c #acceee",
"G c #accef6",
"F c #b4d2f6",
"I c #bdd6f6",
"J c #bddaf6",
"H c #bddaff",
"K c #cde2f6",
"M c #cde2ff",
". c #d5d2d5",
"L c #d5e2ff",
"O c #deeeff",
"N c #e6eeff",
"P c #eef6ff",
"Q c #f6f6ff",
"S c #fffaff",
"R c #ffffff",
"............................",
"############################",
"ababababacababacacacababacab",
"adadadadadadadadadadadadadad",
"efghghghghghehgfghgfghghghgh",
"ijijijikijijijijijijijijijij",
"llmllnmllnmllnmllnmlllmllnml",
"opqpqpqroqqsqpqropqqqqqrqpqp",
"tuvutuvutuvutuvutvvutvvutuvu",
"wxyzwAyzyxyzwxyzyxywwAyzwAyz",
"BCDBBCDBBCDBBCDBBCDBBCDBDCDB",
"EFGFEFGFEFGFGFGFEFGFGFGFEFGF",
"HIJIHIHIHIHIHIHIHIJIHIHIHIJI",
"KLKLKLKMKLKMKLKLKLKMKLKLKLKL",
"NNNNNNNNNNNNNONNNNNNNNNNNNNN",
"PQPQPQPQPQPQPQPQPQPQPQPQPQPQ",
"RRRRRRRRRRRRRSRRRSRSRRRRRRRR",
"RRRRRRRRRRRRRRRRRRRRRRRRRRRR"};

static const char* const img5_connectDlg[] = { 
"34 21 3 1",
"# c #004894",
"a c #004c94",
". c #004c9c",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#",
"##################################",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#",
"##################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#",
"##################################",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#",
"##################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#",
"##################################",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#",
"##################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#",
"##################################",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#",
"##################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#",
"##################################",
"a#.#.#.#a#.#a#.#a#.#a#.#a#.#a#.#a#",
"##################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#"};

static const char* const img6_connectDlg[] = { 
"85 63 29 1",
"y c #b4b2b4",
"w c #b4b6b4",
"A c #bdb6bd",
"t c #bdbabd",
"x c #bdbebd",
"r c #c5bec5",
"z c #c5c2c5",
"o c #c5c6c5",
"v c #cdc6cd",
"n c #cdcacd",
"q c #cdcecd",
"p c #d5ced5",
"m c #d5d2d5",
"j c #d5d6d5",
"k c #ded6de",
"c c #dedade",
"i c #dedede",
"b c #e6dee6",
"d c #e6e2e6",
"s c #e6e6e6",
"a c #eee6ee",
"h c #eeeaee",
"u c #eeeeee",
"e c #f6eef6",
"l c #f6f2f6",
"f c #f6f6f6",
"# c #fff6ff",
"g c #fffaff",
". c #ffffff",
".....................................................................................",
".....................................................................................",
".....................................................................................",
".....................................................................................",
"...............................##abcbdef.............................................",
"............................ghijkbddddckjdl..........................................",
"...........................hmceg........gacc#........................................",
".........................gjcl.g...g.g.g....emd.......................................",
"........................enagg#gf##ggggggggg..icg.........glhhhlg.....................",
".......................hoefg....fel#f#f#lflff.ipg......fbiqqnqqcieg..................",
"......................erel#......#el#lllgggfll.iqg...smjaegg.gglhckdg................",
".....................#tdleg.g.g...leuhl.....guu#qm.embl...........#ajag..............",
".....................vnlel.g.g.g.hahef.......fhuhrkmlggf#g.ggggg.g..gbkg.............",
"....................iwiha#fg#gfgdamnidf.gggggguahvc#fg..#llgf#fgf#f#g.hql............",
"...................gtxhshfgfgfglnnvypnmgg#g#g##svigl......le#f#lll#ffl.hnf...........",
"...................bynddsff#f#fgqwyzotmgf#f#f#enm#u.......geulheg...glhgdog..........",
"...................tAndcde#l#f#flcjcbilf#f#f#fkxlul..g.g..glehlg......eh#qp..........",
"..................swyncckhlflflleflhhluel#lflawcuhfggggggedjihl.g.g.g.fhhawd.........",
"..................pyAzcjjcel#lleg.....ghaulehztshh##gfgglmdnrjmh.gggg#guahnAg........",
".................gAwyxmmqpjahusdf.g.g.fddhikjwoadhl#f#fglzwAwvtkg#f#f#fedamwj........",
".................hAyAAqqpqnqhehidelellsa..ljzyqdbsff#f#fgdzzcppugf#f#f#hddcwtg.......",
".................cywywxqvvnhg..#dduehdd#...eywnbkbhflflflfuhbaull#lfl#udkbjtys.......",
"................etAyAyAzonl.....#daehdl....cAyvckjdl#l#ellgggf#lhu#lfudjkcmAAn.......",
"...............eizwtywwxol.......fdddug...grywxjmmmdulehh......gidsadcmmmjvAytf......",
"..............lbhvnpmqmqceg.......#heg....lwAytqmppnkshdch#l###shffcnnpqmmzyAya......",
".............ljcilg.....laihg.....ggg.....dwywyonnovcgggudslueddf...anonnnwwywm......",
"............embl.g...g.....hbl...........fvyAyAtnova.....udhladl.....lpznxAyAyru.....",
"...........aodg.g.flfgfgf#f.lke.........fbxwywywtzs.......hdsdh.......lntAywywtkl....",
"...........qaf.....fllfe#ggl#lml.......#duzyAyAyAb.........uahg........ltyAyAythdl...",
"..........jjlf..g..gueug....elsvf.g.g.fihhtwywywn..........glg..........cAywywwduif..",
".........hrhefgggg#acdl.....ghlmmg.g.fbibqtyAyAte........................oAyAyAvcic#.",
"........gzqhh#f#fgjpxvqagg#gflsdwug.unozwwywywyjg........................swwywywyxzqf",
"........hykdhf#f#gbArvzdgf#fgeddznggepvwAyAyAyrh.........................fnyAyAwttzob",
"........zAmiillfl#lsidsll#lflacbzAugggllhazwywq#g.g.g.g.....g.g.........ggiAywzefgggg",
".......eAwmkks#ffu#..g.lhe#lajkkzybgggggggbyAAa#.g.g.g.g.g.g.g.g.g.g.g.g.gezAyc......",
".......iywojqmihhdu.g..edhikqmmmwwz#fgfgfghAyzh#g.g.g.g.g.g.g.g.g.g.g.g.gglmyws......",
".......nAyrqpvph#hdhleedg.lmvnpoAythg#gfg##zAplf.g.g.g.g.g.g.g.g.g.g.g.g.g#iAAg......",
"......utywyozpu...udhuil....czotywyjl#f#f#fdycl#gggggggggggggggggggggggggglawm.......",
".....fcAAyAwnf.....esde......ctyAyAnaf#f#f#lzi##gggggggggggggggggggggggggg#hzh.......",
"....lhdAywyth.......uug.......vwywymudl#lflfjdl#fg#gfgfgfgfgfgfgfg#gfg#gfgleq........",
"...lbdpyAyAj..................etAyAzdial#l#fedlfg#gfg#gfg#gfg#gfg#gfg#gfgffhh........",
"..uzzAywywxf...................mywywyrxilflluahff#f#f#f#f#f#f#f#f#f#f#f#f#us#........",
"..#dmozwAyk....................htyArppkblhhhluae#f#f#f#f#f#f#f#f#f#f#f#f#lhh.........",
"......ftyta.g.g.g.g.g.g.g.g.g.g#nwyhl#flshf.g.shlflflflflfl#lfl#lfl#lfl#lhd..........",
".......qAvfg.g.g.g.g.g.g.g.g.g.gbwtelledau#f#l#dhl#f#l#l#l#l#l#l#l#l#f#lesg..........",
".......uykfgggggggggggggggg.g.ggstnehesshhheellldaullllflllllllllflleehhbe...........",
"........vigggggggggggggggggggg.#ercsaddaeulelleuuhleehhull#lflll#leheellllllg........",
"........idfgfg#gfg#gfgfgfg#gfg#gumhfl#fesuulhhfgg...ggfudhllllllhdh#g.g...gglhl......",
"........gs#fg#gfg#gfg#gfg#gfg#gfeh......gleahfgfg#gfg#gfhdhlllfhdslf#f#f#f#f#haf.....",
".........eu#f#f#f#f#f#f#f#f#f#flsg.........eheullllllluuhhduuehsshheullllluehuhh.....",
".........gal#f#f#f#f#f#f#f#f#f#hl..........eeullll#lllluehadasadhulell#lfllllueh.....",
"..........ualfl#lflflflflfl#llhh...........lhelll#f#lfllhhhllfffhhhllff#f#lluuhg.....",
"...........saulell#l#lfl#lluehaf............eaeull#lleehlg.......#lueuleleehhug......",
"........gllfl#fluhuflllluhuffgfgllf..........gueullluel.............gfulell#g........",
".......ghlgg.g.gguahfl#hshgggggggfhe.................................................",
".......#heelllllueashehasuulullluehhg................................................",
".......feell#lflleesaahshell#f#llleh.................................................",
"........huull#lluuugg...lehllflluuhg.................................................",
".........leelllulg.........flullf#...................................................",
".....................................................................................",
".....................................................................................",
".....................................................................................",
"....................................................................................."};


/*
 *  Constructs a ConnectDlg as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  TRUE to construct a modal dialog.
 */
ConnectDlg::ConnectDlg( QWidget* parent, const char* name, bool modal, WFlags fl )
    : QDialog( parent, name, modal, fl ),
      image1( (const char **) img1_connectDlg ),
      image2( (const char **) img2_connectDlg ),
      image3( (const char **) img3_connectDlg ),
      image4( (const char **) img4_connectDlg ),
      image5( (const char **) img5_connectDlg ),
      image6( (const char **) img6_connectDlg )
{
    QImage img;
    img.loadFromData( img0_connectDlg, sizeof( img0_connectDlg ), "PNG" );
    image0 = img;
    if ( !name )
	setName( "ConnectDlg" );
    setMinimumSize( QSize( 360, 195 ) );
    setMaximumSize( QSize( 32767, 32767 ) );
    setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    setIcon( image0 );
    ConnectDlgLayout = new QGridLayout( this, 1, 1, 0, 0, "ConnectDlgLayout"); 

    textLabel1 = new QLabel( this, "textLabel1" );
    textLabel1->setMinimumSize( QSize( 360, 18 ) );
    textLabel1->setMaximumSize( QSize( 32767, 18 ) );
    textLabel1->setPaletteBackgroundPixmap( image1 );
    textLabel1->setScaledContents( FALSE );

    ConnectDlgLayout->addWidget( textLabel1, 0, 0 );

    frame16 = new QFrame( this, "frame16" );
    frame16->setMinimumSize( QSize( 360, 21 ) );
    frame16->setMaximumSize( QSize( 32767, 21 ) );
    frame16->setPaletteBackgroundPixmap( image2 );
    frame16->setFrameShape( QFrame::NoFrame );
    frame16->setFrameShadow( QFrame::Plain );
    frame16Layout = new QGridLayout( frame16, 1, 1, 0, 0, "frame16Layout"); 

    pixmapLabel2_2 = new QLabel( frame16, "pixmapLabel2_2" );
    pixmapLabel2_2->setMinimumSize( QSize( 72, 21 ) );
    pixmapLabel2_2->setMaximumSize( QSize( 72, 21 ) );
    pixmapLabel2_2->setPixmap( image3 );
    pixmapLabel2_2->setScaledContents( FALSE );

    frame16Layout->addWidget( pixmapLabel2_2, 0, 1 );
    spacer81 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame16Layout->addItem( spacer81, 0, 0 );

    ConnectDlgLayout->addWidget( frame16, 1, 0 );
    spacer112 = new QSpacerItem( 20, 10, QSizePolicy::Minimum, QSizePolicy::Fixed );
    ConnectDlgLayout->addItem( spacer112, 2, 0 );

    pixmapLabel9_2 = new QLabel( this, "pixmapLabel9_2" );
    pixmapLabel9_2->setMinimumSize( QSize( 350, 22 ) );
    pixmapLabel9_2->setMaximumSize( QSize( 32767, 22 ) );
    pixmapLabel9_2->setPaletteBackgroundPixmap( image4 );
    pixmapLabel9_2->setScaledContents( FALSE );

    ConnectDlgLayout->addWidget( pixmapLabel9_2, 6, 0 );

    frame16_2 = new QFrame( this, "frame16_2" );
    frame16_2->setMinimumSize( QSize( 350, 18 ) );
    frame16_2->setMaximumSize( QSize( 32767, 18 ) );
    frame16_2->setPaletteBackgroundPixmap( image5 );
    frame16_2->setFrameShape( QFrame::NoFrame );
    frame16_2->setFrameShadow( QFrame::Plain );

    ConnectDlgLayout->addWidget( frame16_2, 5, 0 );
    spacer113 = new QSpacerItem( 20, 10, QSizePolicy::Minimum, QSizePolicy::Fixed );
    ConnectDlgLayout->addItem( spacer113, 4, 0 );

    layout82 = new QHBoxLayout( 0, 0, 0, "layout82"); 
    spacer146 = new QSpacerItem( 10, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout82->addItem( spacer146 );

    frame50 = new QFrame( this, "frame50" );
    frame50->setMinimumSize( QSize( 75, 105 ) );
    frame50->setMaximumSize( QSize( 32767, 32767 ) );
    frame50->setPaletteForegroundColor( QColor( 3, 118, 231 ) );
    frame50->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    frame50->setFrameShape( QFrame::Box );
    frame50->setFrameShadow( QFrame::Plain );
    frame50Layout = new QGridLayout( frame50, 1, 1, 0, 0, "frame50Layout"); 

    layout76 = new QHBoxLayout( 0, 0, 0, "layout76"); 
    spacer124 = new QSpacerItem( 16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout76->addItem( spacer124 );

    pixmapLabel2 = new QLabel( frame50, "pixmapLabel2" );
    pixmapLabel2->setMinimumSize( QSize( 85, 63 ) );
    pixmapLabel2->setMaximumSize( QSize( 85, 63 ) );
    pixmapLabel2->setPixmap( image6 );
    pixmapLabel2->setScaledContents( FALSE );
    layout76->addWidget( pixmapLabel2 );
    spacer122 = new QSpacerItem( 30, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout76->addItem( spacer122 );

    frame59 = new QFrame( frame50, "frame59" );
    frame59->setFrameShape( QFrame::NoFrame );
    frame59->setFrameShadow( QFrame::Plain );
    frame59Layout = new QGridLayout( frame59, 1, 1, 0, 0, "frame59Layout"); 

    layout74 = new QHBoxLayout( 0, 0, 0, "layout74"); 
    spacer127 = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout74->addItem( spacer127 );

    textLabel1_2 = new QLabel( frame59, "textLabel1_2" );
    textLabel1_2->setMinimumSize( QSize( 180, 19 ) );
    textLabel1_2->setMaximumSize( QSize( 32767, 19 ) );
    textLabel1_2->setPaletteForegroundColor( QColor( 0, 0, 0 ) );
    textLabel1_2->setBackgroundOrigin( QLabel::AncestorOrigin );
    QFont textLabel1_2_font(  textLabel1_2->font() );
    textLabel1_2->setFont( textLabel1_2_font ); 
    layout74->addWidget( textLabel1_2 );
    spacer128 = new QSpacerItem( 25, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout74->addItem( spacer128 );

    frame59Layout->addLayout( layout74, 0, 0 );
    spacer125 = new QSpacerItem( 20, 10, QSizePolicy::Minimum, QSizePolicy::Fixed );
    frame59Layout->addItem( spacer125, 1, 0 );

    layout75 = new QHBoxLayout( 0, 0, 0, "layout75"); 
    spacer129 = new QSpacerItem( 16, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout75->addItem( spacer129 );

    textLabel2 = new QLabel( frame59, "textLabel2" );
    textLabel2->setMinimumSize( QSize( 180, 19 ) );
    textLabel2->setMaximumSize( QSize( 32767, 19 ) );
    textLabel2->setPaletteForegroundColor( QColor( 0, 0, 0 ) );
    textLabel2->setBackgroundOrigin( QLabel::AncestorOrigin );
    QFont textLabel2_font(  textLabel2->font() );
    textLabel2->setFont( textLabel2_font ); 
    layout75->addWidget( textLabel2 );
    spacer129_2 = new QSpacerItem( 16, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout75->addItem( spacer129_2 );

    frame59Layout->addLayout( layout75, 2, 0 );
    spacer131 = new QSpacerItem( 20, 10, QSizePolicy::Minimum, QSizePolicy::Fixed );
    frame59Layout->addItem( spacer131, 3, 0 );

    progressBar = new QProgressBar( frame59, "progressBar" );
    progressBar->setMinimumSize( QSize( 18, 0 ) );
    progressBar->setMaximumSize( QSize( 32767, 18 ) );
    progressBar->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    QPalette pal;
    QColorGroup cg;
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, QColor( 221, 223, 228) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 238, 239, 241) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 111, 114) );
    cg.setColor( QColorGroup::Mid, QColor( 147, 149, 152) );
    cg.setColor( QColorGroup::Text, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, QColor( 221, 223, 228) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 254, 254, 255) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 111, 114) );
    cg.setColor( QColorGroup::Mid, QColor( 147, 149, 152) );
    cg.setColor( QColorGroup::Text, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, QColor( 221, 223, 228) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 254, 254, 255) );
    cg.setColor( QColorGroup::Dark, QColor( 110, 111, 114) );
    cg.setColor( QColorGroup::Mid, QColor( 147, 149, 152) );
    cg.setColor( QColorGroup::Text, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setDisabled( cg );
    progressBar->setPalette( pal );
    progressBar->setFrameShape( QProgressBar::Box );
    progressBar->setFrameShadow( QProgressBar::Plain );
    progressBar->setLineWidth( 1 );
    progressBar->setMargin( -1 );
    progressBar->setMidLineWidth( 0 );
    progressBar->setProgress( 32 );
    progressBar->setCenterIndicator( TRUE );
    progressBar->setIndicatorFollowsStyle( TRUE );
    progressBar->setPercentageVisible( TRUE );

    frame59Layout->addWidget( progressBar, 4, 0 );
    layout76->addWidget( frame59 );
    spacer132 = new QSpacerItem( 25, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout76->addItem( spacer132 );

    frame50Layout->addLayout( layout76, 0, 0 );
    layout82->addWidget( frame50 );
    spacer145 = new QSpacerItem( 10, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout82->addItem( spacer145 );

    ConnectDlgLayout->addLayout( layout82, 3, 0 );
    languageChange();
    resize( QSize(360, 195).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );
}

/*
 *  Destroys the object and frees any allocated resources
 */
ConnectDlg::~ConnectDlg()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void ConnectDlg::languageChange()
{
    setCaption( ( "OpenC6 - Connessione in corso" ) );
    textLabel1_2->setText( ( "   Connessione in corso" ) );
    textLabel2->setText( ( "       attendere prego....." ) );
}

#include "connectDlg.moc"
