/***************************************************************************
                          c6report.h  -  description
                             -------------------
    begin                : Fri Nov 21 2003
    copyright            : (C) 2003 by Giorgio A.
    email                : openc6@hotmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef C6REPORT_H
#define C6REPORT_H

#include <qwidget.h>
#include <report.h>
#include <qstring.h>
//#include "macroetc.h"

class C6TextEdit;

/**
  *@author Giorgio A.
  */

class C6Report : public report  
{
   Q_OBJECT
public: 
    C6Report(QWidget *parent=0, const char *name=0);
    ~C6Report();
    void notify(QString const &nick,QString const &text,QString const& timeString = QString::null);
    void setCustomFont();   
public slots:  
  void clearReport();
private slots: // Private slots
  void execUrlProc(QString  & str);
  void aboutClicked();
  
signals:
  void execUrl(QString &);  
  void showAbout();  
private:
  C6TextEdit* _reportEdit;
};

#endif
