/****************************************************************************
** Form interface generated from reading ui file './invite.ui'
**
** Created: Sun Dec 17 12:38:46 2006
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef INVITE_H
#define INVITE_H

#include <qvariant.h>
#include <qpixmap.h>
#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QFrame;
class QLabel;
class QTextEdit;
class QListView;
class QListViewItem;

class Invite : public QDialog
{
    Q_OBJECT

public:
    Invite( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~Invite();

    QFrame* frame16;
    QLabel* pixmapLabel2_2;
    QLabel* textLabel1;
    QLabel* pixmapLabel9_2;
    QFrame* frame15;
    QLabel* exitButtonPlaceHolder;
    QLabel* aboutButtonPlaceHolder;
    QFrame* frame44;
    QLabel* pixmapLabel3_3;
    QLabel* pixmapLabel3_2_2_2;
    QLabel* pixmapLabel3_2_3;
    QLabel* pixmapLabel1_2;
    QFrame* frame58;
    QLabel* identityCaption;
    QLabel* netfriendCaption;
    QLabel* pixmapLabel1_2_2;
    QTextEdit* messageEdit;
    QListView* netfriendList;
    QLabel* sendButtonPlaceHolder;

protected:
    QGridLayout* InviteLayout;
    QSpacerItem* spacer100;
    QSpacerItem* spacer102;
    QSpacerItem* spacer101;
    QSpacerItem* spacer12;
    QGridLayout* frame16Layout;
    QSpacerItem* spacer132;
    QHBoxLayout* layout34;
    QGridLayout* frame15Layout;
    QSpacerItem* spacer38;
    QVBoxLayout* layout33;
    QSpacerItem* spacer37;
    QGridLayout* frame44Layout;
    QHBoxLayout* layout61;
    QHBoxLayout* layout41_2;
    QHBoxLayout* layout46;
    QGridLayout* frame58Layout;
    QHBoxLayout* layout43;
    QSpacerItem* spacer40;
    QSpacerItem* spacer41;
    QHBoxLayout* layout8;
    QHBoxLayout* layout9;
    QSpacerItem* spacer10;
    QSpacerItem* spacer11;

protected slots:
    virtual void languageChange();

private:
    QPixmap image0;
    QPixmap image1;
    QPixmap image2;
    QPixmap image3;
    QPixmap image4;
    QPixmap image5;
    QPixmap image6;
    QPixmap image7;
    QPixmap image8;
    QPixmap image9;
    QPixmap image10;
    QPixmap image11;
    QPixmap image12;
    QPixmap image13;
    QPixmap image14;

};

#endif // INVITE_H
