/****************************************************************************
** Form interface generated from reading ui file './font.ui'
**
** Created: Sun Dec 17 12:38:46 2006
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef FONT_H
#define FONT_H

#include <qvariant.h>
#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QLabel;
class QLineEdit;
class QListBox;
class QListBoxItem;
class QGroupBox;
class QTextEdit;
class QPushButton;

class Font : public QDialog
{
    Q_OBJECT

public:
    Font( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~Font();

    QLabel* textLabel1;
    QLineEdit* selectedFont;
    QListBox* fontList;
    QLabel* textLabel2;
    QLineEdit* selectedSize;
    QListBox* fontSize;
    QGroupBox* groupBox1;
    QTextEdit* fontPreview;
    QPushButton* okButton;
    QPushButton* cancelButton;

protected:
    QGridLayout* FontLayout;
    QHBoxLayout* layout11;
    QSpacerItem* spacer2;
    QVBoxLayout* layout4;
    QVBoxLayout* layout9;
    QGridLayout* groupBox1Layout;
    QHBoxLayout* layout12;
    QSpacerItem* spacer3;

protected slots:
    virtual void languageChange();

};

#endif // FONT_H
