/****************************************************************************
** Form interface generated from reading ui file './nickform.ui'
**
** Created: Sun Dec 17 12:38:46 2006
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef NICKFORM_H
#define NICKFORM_H

#include <qvariant.h>
#include <qpixmap.h>
#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QFrame;
class QLabel;
class QIconView;
class QIconViewItem;

class nickForm : public QDialog
{
    Q_OBJECT

public:
    nickForm( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~nickForm();

    QFrame* frame16;
    QLabel* pixmapLabel2_2;
    QLabel* textLabel1;
    QFrame* frame16_2;
    QLabel* pixmapLabel9_2;
    QFrame* frame44;
    QLabel* pixmapLabel1_2;
    QFrame* frame58;
    QLabel* identityCaption;
    QLabel* pixmapLabel1_2_2;
    QIconView* nickList;
    QFrame* frame50_2;
    QLabel* lastIdentity;
    QLabel* timeOutLabel;
    QLabel* enterButtonPlaceHolder;

protected:
    QGridLayout* nickFormLayout;
    QSpacerItem* spacer102;
    QSpacerItem* spacer103;
    QGridLayout* frame16Layout;
    QSpacerItem* spacer132;
    QHBoxLayout* layout87;
    QSpacerItem* spacer100;
    QSpacerItem* spacer101;
    QGridLayout* frame44Layout;
    QSpacerItem* spacer91;
    QHBoxLayout* layout78;
    QHBoxLayout* layout86;
    QGridLayout* frame50_2Layout;
    QHBoxLayout* layout79;
    QSpacerItem* spacer94;
    QSpacerItem* spacer92;
    QSpacerItem* spacer93;

protected slots:
    virtual void languageChange();

private:
    QPixmap image0;
    QPixmap image1;
    QPixmap image2;
    QPixmap image3;
    QPixmap image4;
    QPixmap image5;
    QPixmap image6;
    QPixmap image7;
    QPixmap image8;
    QPixmap image9;

};

#endif // NICKFORM_H
