/****************************************************************************
** Form interface generated from reading ui file './mainDlg.ui'
**
** Created: Tue Jan 9 23:19:06 2007
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef MAINDLG_H
#define MAINDLG_H

#include <qvariant.h>
#include <qpixmap.h>
#include <qwidget.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QFrame;
class QLabel;
class QComboBox;
class QListView;
class QListViewItem;
class QLineEdit;
class QTextEdit;

class MainDlg : public QWidget
{
    Q_OBJECT

public:
    MainDlg( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
    ~MainDlg();

    QFrame* frame15;
    QLabel* exitButtonPlaceHolder;
    QLabel* aboutButtonPlaceHolder;
    QLabel* pixmapLabel9_2;
    QFrame* frame21;
    QLabel* statusPix;
    QComboBox* StatusSwitch;
    QLabel* Online;
    QFrame* frame6;
    QLabel* menuButtonPlaceHolder;
    QListView* FriendListView;
    QLineEdit* messageODD;
    QFrame* frame4;
    QLabel* pixmapLabel1;
    QLabel* pixmapLabel2_2_2;
    QLabel* pixmapLabel2_2;
    QTextEdit* statistics;
    QFrame* menuFrame;
    QFrame* frame3;

protected:
    QGridLayout* MainDlgLayout;
    QSpacerItem* spacer36;
    QSpacerItem* spacer39;
    QSpacerItem* spacer12;
    QSpacerItem* spacer21;
    QSpacerItem* spacer11_2;
    QHBoxLayout* layout34;
    QGridLayout* frame15Layout;
    QSpacerItem* spacer38_2;
    QVBoxLayout* layout33;
    QSpacerItem* spacer37;
    QGridLayout* frame21Layout;
    QSpacerItem* spacer11;
    QSpacerItem* spacer38_3;
    QSpacerItem* spacer38;
    QSpacerItem* spacer38_4;
    QHBoxLayout* layout6;
    QSpacerItem* spacer38_4_2;
    QHBoxLayout* layout12;
    QSpacerItem* spacer15;
    QSpacerItem* spacer13_2;
    QHBoxLayout* layout64;
    QSpacerItem* spacer19;
    QSpacerItem* spacer20;
    QGridLayout* frame4Layout;
    QSpacerItem* spacer123;
    QHBoxLayout* layout6_2;
    QSpacerItem* spacer14_2;
    QSpacerItem* spacer14_2_2;
    QSpacerItem* spacer14;
    QSpacerItem* spacer10;
    QVBoxLayout* layout8;

protected slots:
    virtual void languageChange();

private:
    QPixmap image0;
    QPixmap image1;
    QPixmap image2;
    QPixmap image3;
    QPixmap image4;
    QPixmap image5;
    QPixmap image6;
    QPixmap image7;
    QPixmap image8;
    QPixmap image9;
    QPixmap image10;

};

#endif // MAINDLG_H
