/****************************************************************************
** Form interface generated from reading ui file './configure.ui'
**
** Created: Sun Jan 14 16:50:49 2007
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#ifndef CONFIGURE_H
#define CONFIGURE_H

#include <qvariant.h>
#include <qpixmap.h>
#include <qdialog.h>

class QVBoxLayout;
class QHBoxLayout;
class QGridLayout;
class QSpacerItem;
class QPushButton;
class QListBox;
class QListBoxItem;
class QWidgetStack;
class QWidget;
class QLabel;
class QFrame;
class QCheckBox;
class QLineEdit;
class QButtonGroup;
class QRadioButton;
class QGroupBox;
class QComboBox;
class QSpinBox;
class QTextEdit;
class QListView;
class QListViewItem;

class configure : public QDialog
{
    Q_OBJECT

public:
    configure( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
    ~configure();

    QPushButton* Ok;
    QPushButton* Apply;
    QPushButton* Cancel;
    QListBox* optionList;
    QWidgetStack* widgetList;
    QWidget* WStackPage;
    QLabel* textLabel2_6;
    QFrame* frame4;
    QCheckBox* ShowOnline;
    QCheckBox* dockIcon;
    QLabel* textLabel1;
    QLineEdit* Browser;
    QButtonGroup* authGroup;
    QRadioButton* warnAuthButton;
    QRadioButton* askAuthButton;
    QRadioButton* noAuthButton;
    QButtonGroup* messageGroup;
    QRadioButton* reportButton;
    QRadioButton* emailButton;
    QWidget* WStackPage_2;
    QGroupBox* groupBox1;
    QLabel* textLabel1_7;
    QComboBox* startStatusSwitch;
    QLabel* textLabel1_7_2;
    QSpinBox* maxTimeOut;
    QCheckBox* AutoConnect;
    QCheckBox* Reconnect;
    QCheckBox* ipShow;
    QLabel* textLabel2_6_2;
    QGroupBox* groupBox2;
    QCheckBox* proxySwitch;
    QLineEdit* proxyName;
    QLabel* textLabel2_4;
    QSpinBox* proxyPort;
    QComboBox* proxySocksVersion;
    QLabel* textLabel1_2;
    QLineEdit* serverName;
    QLabel* textLabel2;
    QSpinBox* serverPort;
    QGroupBox* proxyAuthBox;
    QLineEdit* proxyUser;
    QLabel* textLabel3_3;
    QCheckBox* proxyAuthSwitch;
    QLineEdit* proxyPassword;
    QLabel* textLabel2_2;
    QWidget* WStackPage_3;
    QLabel* textLabel2_6_2_2;
    QGroupBox* groupBox9;
    QCheckBox* AutoRaise;
    QCheckBox* AutoPopUp;
    QCheckBox* timeStamp;
    QCheckBox* tabbedChat;
    QGroupBox* acceptFile;
    QCheckBox* autoAccept;
    QLabel* textLabel1_10;
    QLineEdit* fileReceivePath;
    QPushButton* fileDir;
    QLabel* textLabel4_3;
    QSpinBox* startPort;
    QWidget* WStackPage_4;
    QLabel* textLabel2_6_2_2_2;
    QGroupBox* groupBox10;
    QCheckBox* roomTimeStamp;
    QCheckBox* autoRoomEnter;
    QTextEdit* autoRoomList;
    QWidget* WStackPage_5;
    QLabel* textLabel2_6_2_2_2_2;
    QGroupBox* groupBox11;
    QCheckBox* AutoMsg;
    QLabel* textLabel3_5;
    QLineEdit* BlackListEdit;
    QLabel* textLabel4_5;
    QLineEdit* NetFriendsEdit;
    QLabel* textLabel5;
    QLineEdit* BusyEdit;
    QLabel* textLabel1_9;
    QLineEdit* AwayEdit;
    QCheckBox* autoAwaySwitch;
    QSpinBox* awayMinutes;
    QLabel* textLabel1_12;
    QCheckBox* backAutoAwaySwitch;
    QWidget* WStackPage_6;
    QLabel* textLabel2_6_2_2_2_2_2;
    QGroupBox* groupBox13;
    QCheckBox* selectFontButton;
    QLabel* textLabel1_11;
    QLineEdit* fontProperty;
    QPushButton* globalFontButton;
    QPushButton* defaultFontButton;
    QGroupBox* groupBox12;
    QPushButton* Default;
    QGroupBox* groupBox15;
    QLabel* textLabel1_8;
    QPushButton* SelFontUp;
    QLabel* textLabel1_4_4;
    QPushButton* netfriendColorButton;
    QLabel* textLabel3_2_5;
    QPushButton* myselfColor;
    QTextEdit* chatPreview;
    QLabel* MessageUpLabel;
    QLineEdit* serviceMessagePreview;
    QPushButton* serviceMessageColor;
    QGroupBox* groupBox11_2;
    QCheckBox* contactFontSwitch;
    QLabel* textLabel1_8_2;
    QLineEdit* contactFontProperty;
    QPushButton* contactSelFont;
    QLabel* MessageUpLabel_2;
    QLabel* groupColor;
    QPushButton* groupNameForeColor;
    QLabel* MessageUpLabel_3;
    QLabel* userColor;
    QPushButton* contactForeColor;
    QPushButton* defaultContact;
    QWidget* WStackPage_7;
    QLabel* textLabel2_6_2_2_2_2_2_2;
    QFrame* frame10;
    QCheckBox* beepSwitch;
    QCheckBox* soundOnceSwitch;
    QCheckBox* soundSwitch;
    QLabel* textLabel1_5;
    QLineEdit* playCommand;
    QGroupBox* soundGroup;
    QCheckBox* inMessageSwitch;
    QLineEdit* inMessageWav;
    QPushButton* fileOpen1;
    QPushButton* playDemo1;
    QCheckBox* outMessageSwitch;
    QLineEdit* outMessageWav;
    QPushButton* fileOpen2;
    QPushButton* playDemo2;
    QCheckBox* onlineMessageSwitch;
    QLineEdit* onlineMessageWav;
    QPushButton* fileOpen3;
    QPushButton* playDemo3;
    QCheckBox* offlineMessageSwitch;
    QLineEdit* offlineMessageWav;
    QPushButton* fileOpen4;
    QPushButton* playDemo4;
    QCheckBox* specialFriendSwitch;
    QLineEdit* specialFriendWav;
    QPushButton* fileOpen5;
    QPushButton* playDemo5;
    QWidget* WStackPage_8;
    QLabel* textLabel2_6_2_2_2_2_2_2_2;
    QFrame* frame11;
    QLabel* textLabel1_4;
    QListBox* specialList;
    QLabel* textLabel1_6;
    QLineEdit* specialEdit;
    QPushButton* removeSpecial;
    QPushButton* addSpecial;
    QCheckBox* specialNotifySwitch;
    QWidget* WStackPage_9;
    QLabel* textLabel2_6_2_2_2_2_2_2_2_2;
    QFrame* frame12;
    QCheckBox* LogProto;
    QCheckBox* Log;
    QCheckBox* LogRoom;
    QCheckBox* SysLog;
    QWidget* WStackPage_10;
    QLabel* textLabel2_6_2_2_2_2_2_2_2_2_2;
    QGroupBox* groupBox13_2;
    QListView* pluginsLoadedList;
    QPushButton* pluginUnload;
    QGroupBox* groupBox12_2;
    QListView* pluginsAvailableList;
    QPushButton* pluginLoad;
    QFrame* frame23;
    QLabel* textLabel1_3;
    QWidget* WStackPage_11;
    QLabel* textLabel2_6_2_2_2_2_2_2_2_2_2_2;
    QGroupBox* groupBox27;
    QCheckBox* activateStyle;
    QLabel* textLabel1_2_2;
    QComboBox* styleCombo;
    QWidget* WStackPage_12;
    QLabel* textLabel2_6_2_2_2_2_2_2_2_2_2_2_2;
    QFrame* frame16;
    QLabel* textLabel1_13;
    QListBox* windowsFont;
    QLabel* textLabel1_13_2;
    QListBox* visualLocalFont;
    QPushButton* mapFontSelection;
    QTextEdit* fontComment;
    QLabel* textLabel1_14;
    QLabel* textLabel2_3;
    QPushButton* defaultListButton;

public slots:
    virtual void Ok_clicked();
    virtual void Annulla_clicked();
    virtual void SelFontUp_clicked();
    virtual void ForeColorUp_clicked();
    virtual void Default_clicked();
    virtual void beepSwitch_clicked();
    virtual void soundSwitch_clicked();
    virtual void inMessage_clicked();
    virtual void outMessage_clicked();
    virtual void netfriendOnline_clicked();
    virtual void netfriendOffline_clicked();
    virtual void pushButton7_3_clicked();
    virtual void fileOpen1_clicked();
    virtual void fileOpen2_clicked();
    virtual void fileOpen3_clicked();
    virtual void fileOpen4_clicked();
    virtual void soundSwitch_toggled( bool );
    virtual void fileOpen5_clicked();
    virtual void removeSpecial_clicked();
    virtual void addSpecial_clicked();
    virtual void playDemo1_clicked();
    virtual void playDemo2_clicked();
    virtual void playDemo3_clicked();
    virtual void playDemo4_clicked();
    virtual void playDemo5_clicked();
    virtual void ForeNetFriendUp_clicked();
    virtual void ForeMessageUp_clicked();
    virtual void fileDir_clicked();
    virtual void globalFontButton_clicked();
    virtual void selectFontButton_clicked();
    virtual void defaultFontButton_clicked();
    virtual void proxySwitch_toggled( bool );
    virtual void groupNameForeColor_clicked();
    virtual void contactSelFont_clicked();
    virtual void contactForeColor_clicked();
    virtual void Apply_clicked();
    virtual void Cancel_clicked();
    virtual void netfriendColorButton_clicked();
    virtual void myselfColor_clicked();

protected:
    QGridLayout* configureLayout;
    QHBoxLayout* layout143;
    QSpacerItem* Horizontal_Spacing2;
    QGridLayout* WStackPageLayout;
    QHBoxLayout* layout5;
    QSpacerItem* spacer2;
    QSpacerItem* spacer3;
    QGridLayout* frame4Layout;
    QSpacerItem* spacer42;
    QSpacerItem* spacer43;
    QVBoxLayout* layout42;
    QHBoxLayout* layout45;
    QGridLayout* authGroupLayout;
    QGridLayout* messageGroupLayout;
    QGridLayout* WStackPageLayout_2;
    QGridLayout* groupBox1Layout;
    QSpacerItem* spacer58;
    QHBoxLayout* layout67;
    QSpacerItem* spacer56;
    QHBoxLayout* layout68;
    QSpacerItem* spacer57;
    QVBoxLayout* layout69;
    QHBoxLayout* layout5_2;
    QSpacerItem* spacer2_2;
    QSpacerItem* spacer3_2;
    QGridLayout* groupBox2Layout;
    QHBoxLayout* layout65;
    QHBoxLayout* layout63;
    QHBoxLayout* layout64;
    QHBoxLayout* layout62;
    QHBoxLayout* layout66;
    QGridLayout* WStackPageLayout_3;
    QSpacerItem* spacer63_2;
    QHBoxLayout* layout5_2_2;
    QSpacerItem* spacer2_2_2;
    QSpacerItem* spacer3_2_2;
    QGridLayout* groupBox9Layout;
    QHBoxLayout* layout50;
    QSpacerItem* spacer44;
    QVBoxLayout* layout48;
    QVBoxLayout* layout49;
    QGridLayout* acceptFileLayout;
    QHBoxLayout* layout51;
    QSpacerItem* spacer45;
    QHBoxLayout* layout52;
    QHBoxLayout* layout53;
    QSpacerItem* spacer46;
    QGridLayout* WStackPageLayout_4;
    QHBoxLayout* layout5_2_2_2;
    QSpacerItem* spacer2_2_2_2;
    QSpacerItem* spacer3_2_2_2;
    QGridLayout* groupBox10Layout;
    QVBoxLayout* layout54;
    QHBoxLayout* layout55;
    QSpacerItem* spacer48;
    QGridLayout* WStackPageLayout_5;
    QSpacerItem* spacer64;
    QHBoxLayout* layout5_2_2_2_2;
    QSpacerItem* spacer2_2_2_2_2;
    QSpacerItem* spacer3_2_2_2_2;
    QGridLayout* groupBox11Layout;
    QVBoxLayout* layout56;
    QVBoxLayout* layout57;
    QVBoxLayout* layout58;
    QVBoxLayout* layout59;
    QHBoxLayout* layout60;
    QSpacerItem* spacer50;
    QHBoxLayout* layout61;
    QSpacerItem* spacer51;
    QGridLayout* WStackPageLayout_6;
    QSpacerItem* spacer62;
    QHBoxLayout* layout5_2_2_2_2_2;
    QSpacerItem* spacer2_2_2_2_2_2;
    QSpacerItem* spacer3_2_2_2_2_2;
    QGridLayout* groupBox13Layout;
    QHBoxLayout* layout13;
    QSpacerItem* spacer23_2;
    QHBoxLayout* layout14;
    QGridLayout* groupBox12Layout;
    QHBoxLayout* layout17;
    QSpacerItem* spacer24;
    QGridLayout* groupBox15Layout;
    QHBoxLayout* layout76;
    QVBoxLayout* layout75;
    QHBoxLayout* layout72;
    QHBoxLayout* layout73_2;
    QHBoxLayout* layout74;
    QHBoxLayout* layout82;
    QGridLayout* groupBox11_2Layout;
    QHBoxLayout* layout18;
    QHBoxLayout* layout19;
    QSpacerItem* spacer25;
    QHBoxLayout* layout76_2;
    QHBoxLayout* layout20;
    QSpacerItem* spacer26;
    QGridLayout* WStackPageLayout_7;
    QSpacerItem* spacer38;
    QHBoxLayout* layout5_2_2_2_2_2_2;
    QSpacerItem* spacer2_2_2_2_2_2_2;
    QSpacerItem* spacer3_2_2_2_2_2_2;
    QGridLayout* frame10Layout;
    QVBoxLayout* layout21;
    QVBoxLayout* layout23;
    QSpacerItem* spacer27;
    QHBoxLayout* layout22;
    QGridLayout* soundGroupLayout;
    QHBoxLayout* layout24;
    QSpacerItem* spacer28;
    QHBoxLayout* layout25;
    QHBoxLayout* layout26;
    QSpacerItem* spacer29;
    QHBoxLayout* layout27;
    QHBoxLayout* layout28;
    QSpacerItem* spacer30;
    QHBoxLayout* layout29;
    QHBoxLayout* layout30;
    QSpacerItem* spacer31;
    QHBoxLayout* layout31;
    QHBoxLayout* layout32;
    QSpacerItem* spacer32;
    QHBoxLayout* layout33;
    QGridLayout* WStackPageLayout_8;
    QHBoxLayout* layout5_2_2_2_2_2_2_2;
    QSpacerItem* spacer2_2_2_2_2_2_2_2;
    QSpacerItem* spacer3_2_2_2_2_2_2_2;
    QGridLayout* frame11Layout;
    QVBoxLayout* layout34;
    QVBoxLayout* layout40;
    QSpacerItem* spacer34;
    QVBoxLayout* layout35;
    QHBoxLayout* layout39;
    QSpacerItem* spacer36;
    QGridLayout* WStackPageLayout_9;
    QHBoxLayout* layout5_2_2_2_2_2_2_2_2;
    QSpacerItem* spacer2_2_2_2_2_2_2_2_2;
    QSpacerItem* spacer3_2_2_2_2_2_2_2_2;
    QGridLayout* frame12Layout;
    QSpacerItem* spacer37;
    QVBoxLayout* layout41;
    QGridLayout* WStackPageLayout_10;
    QHBoxLayout* layout5_2_2_2_2_2_2_2_2_2;
    QSpacerItem* spacer2_2_2_2_2_2_2_2_2_2;
    QSpacerItem* spacer3_2_2_2_2_2_2_2_2_2;
    QGridLayout* groupBox13_2Layout;
    QHBoxLayout* layout13_2;
    QSpacerItem* spacer23;
    QGridLayout* groupBox12_2Layout;
    QGridLayout* frame23Layout;
    QGridLayout* WStackPageLayout_11;
    QSpacerItem* spacer66;
    QHBoxLayout* layout5_2_2_2_2_2_2_2_2_2_2;
    QSpacerItem* spacer2_2_2_2_2_2_2_2_2_2_2;
    QSpacerItem* spacer3_2_2_2_2_2_2_2_2_2_2;
    QGridLayout* groupBox27Layout;
    QVBoxLayout* layout142;
    QHBoxLayout* layout141;
    QGridLayout* WStackPageLayout_12;
    QHBoxLayout* layout5_2_2_2_2_2_2_2_2_2_2_2;
    QSpacerItem* spacer2_2_2_2_2_2_2_2_2_2_2_2;
    QSpacerItem* spacer3_2_2_2_2_2_2_2_2_2_2_2;
    QGridLayout* frame16Layout;
    QVBoxLayout* layout78;
    QVBoxLayout* layout78_2;
    QHBoxLayout* layout150;
    QSpacerItem* spacer140;
    QHBoxLayout* layout73;
    QSpacerItem* spacer61;
    QSpacerItem* spacer63;

protected slots:
    virtual void languageChange();

private:
    QPixmap image0;
    QPixmap image1;
    QPixmap image2;
    QPixmap image3;
    QPixmap image4;
    QPixmap image5;
    QPixmap image6;
    QPixmap image7;
    QPixmap image8;
    QPixmap image9;

};

#endif // CONFIGURE_H
