
/****************************************************************************
** Form implementation generated from reading ui file './chat.ui'
**
** Created: Tue Jan 9 22:55:46 2007
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#include "chat.h"

#include <qvariant.h>
#include <qpushbutton.h>
#include <qlabel.h>
#include <qframe.h>
#include <qtextedit.h>
#include <qprogressbar.h>
#include <qcheckbox.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qimage.h>
#include <qpixmap.h>

static const char* const img0_chat[] = { 
"60 18 45 1",
"N c #414041",
"K c #5a9dde",
"M c #5a9de6",
"L c #5aa1e6",
"I c #62a1e6",
"H c #62a5e6",
"E c #6aa5e6",
"J c #6aa5ee",
"F c #6aaae6",
"G c #6aaaee",
"C c #73aae6",
"B c #73aee6",
"A c #73aeee",
"D c #7baeee",
"y c #7bb2e6",
"z c #7bb2ee",
"x c #83b6ee",
"u c #8bbaee",
"w c #8bbeee",
"v c #94beee",
"t c #9cc2ee",
"s c #9cc6f6",
"r c #a4c6ee",
"p c #a4caee",
"q c #a4caf6",
"n c #accef6",
"o c #acd2f6",
"m c #b4d2f6",
"l c #b4d6f6",
"Q c #bdbebd",
"k c #bdd6f6",
"O c #c5bec5",
"P c #c5c2c5",
"j c #cde2f6",
"h c #cde2ff",
"g c #d5e2ff",
"i c #d5e6ff",
"d c #deeaff",
"f c #deeeff",
"e c #e6eeff",
"b c #eef6ff",
"a c #f6f6ff",
"c c #f6faff",
"# c #fffaff",
". c #ffffff",
"............................................................",
"#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.",
"abaacbaaabaaabcaabcacbaacbaaabcaabaacbaaabcaabaaabaaabaacbca",
"dedefededefefefededefefededefedefededefededededefefedededefe",
"ghijihijihijihgjihgjghijghijghijihihihijihijghijihihihijihij",
"kklkkkkkkklkkklkkklkkkkkkklkkkkkkklkkkkkkkkkkklkkklkkkkkkkkk",
"mnmnmnmnmnmnmnmnmomnmnmnmnmnmnmnmomnmnmnmnmnmnmnmnmnmnmnmnmn",
"pqpqrqpqrqpqrqpqpqrqpqpqpqrqpqpqpqpqpqpqpqpqpqrqpqrqpqpqpqpq",
"stststststststststststststststststststststststststststststst",
"uvwvuvuvwvuvuvuvwvuvwvuvwvwvuvwvuvuvwvwvwvuvuvuvuvuvwvuvuvwv",
"uxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxuxux",
"yzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyzyz",
"ABABACABABACABABABACABABDCABDBACABABABABABABABACABABABABABAB",
"EFEFEFEFEFEFEGEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEGEFEGEFEGEF",
"HIJIHIJIHIJIHIJIHIJIHIJIHIJIEIJIEIJIHIJIHIJIEIJHEIJIHIJIEIJI",
"KLMIMIMIMLMIMLMIMLMIMLMIMLMIMIMIMIMIKIMIMLMIMIMIMLMIMLMIMLMI",
"NNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN",
"OPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQPOPQP"};

static const char* const img1_chat[] = { 
"34 21 3 1",
". c #004991",
"# c #004a91",
"a c #004a92",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"......#...........................",
"..................................",
"..................................",
"..................................",
"..................................",
"....a...................#.........",
"..................................",
".....................a............"};

static const char* const img2_chat[] = { 
"166 21 35 1",
"# c #004894",
"a c #004c94",
". c #004c9c",
"z c #00509c",
"q c #084c9c",
"x c #08509c",
"D c #0850a4",
"t c #0855a4",
"v c #0859a4",
"y c #1059a4",
"C c #1059ac",
"g c #105dac",
"l c #1061ac",
"b c #1061b4",
"F c #1065b4",
"B c #1861b4",
"n c #1865b4",
"w c #1869b4",
"i c #1869bd",
"u c #186dbd",
"E c #186dc5",
"h c #2069bd",
"A c #206dbd",
"j c #206dc5",
"c c #2071c5",
"m c #2075c5",
"f c #2075cd",
"r c #2079cd",
"G c #2975cd",
"o c #2979cd",
"s c #2979d5",
"k c #297dcd",
"e c #297dd5",
"p c #2981d5",
"d c #3181d5",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#",
"###################################################################################################################a#############################a####################",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#",
"######################################################################################################################################################################",
".#a#.#bcdefg.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#hei#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#ieh#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#",
"#####jkeeekeg###################################################################fel###############################################mel###################li############",
"a#.#nedba#jeo#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.ipb.#a#.#a#.#a#",
"###qrel###askt#gueefv###relfkov#wel##.oex#lskeu##leilef#leeeux##gmeect#ykeeekeaykea#zAeerb###ceBueeB##aikeeB######terbeeu##xkovskbeeaoey##vem#aikeen##oekew#loeeu.####",
".#agdfa#.#a#.#bedepedvaxdepedeo#nej#.npi.upedepu.bpodenndepedfaCdepedfabdepedoabdfaxeepeden#.fpedepeD.fedepen#a#.#nedepednavdopejbpf.upb.#feB#fedepentpedebndepedua#.#",
"###nei########reE##cej#leew#vem#tem#xer.vemt#Bko#jkog##mei#########xeea###geeg#iej#cefz#Fer#zekcaqkeznkca#ueu#####weft#Aeo#beeF##ikA#Bki#Bkm######weF#tef######lef####",
"a#.npn.#a#.#aCdoq#.bpc.bpc.#nec#aoe#jen#iedepedfafdba#.bpedcg#..inGepf.#abdog#.cpbqepC.#ted.Cee.avdoafdepedei#.#a#oen#.Cpo.ipu.#acdbavdcafdta#Bniedeb#nei#.tineepi.#a#",
"###Bkc####cevbef###jkA#jkb##uel##oeBkm##ueF######oex####vieekgasrb#iki##Feot###skgxek.##leo#leE##bec#oeg#########.eet##nkc#ckl###oeg#xesFew##necxxeez#Eel#vecl#okl####",
".#avdeb#qupoqvpot#bedCafdCa#oeb#.ipedCa#hefaDfpCCeo#.#a#.#afdbbeG#todgaudfx#.#tedxaodbatoei#hei#.ipi.fpu.Cpoq#a#.vpei#godbaodxa#tepx.#oedoq#.fpC.upf.#eeC#iei#nedxa#.#",
"####Eekeeeeg##ceeekeu#aeex##oez##Bkeu###zskeeeu#geu###ceeekeetteeekeeygeeekeexgeo##ieekeefa#ceg##cel#lkeeekb#####Bkoeekec#zeo###ger###ueeB###ckeeekc#qkeeBleeekeo#####",
"a#.#andeput#a#qupeeba#Cee#.vpo.#avdox#.#atcepi.#iei#a#qipedcg#.ipejfpvnepedeo#iec#.#nedeia.#eet#aodta#Bfpon#a#.#acdbneduq#gef#.#iec#a#nef#.#atoeoidca#jepgqcpeiee#.#a#",
"#################################################################################################################oeg##################################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#Depx.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#",
"################################################################################################################gem###################################################",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#",
"######################################################################################################################################################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#"};

static const char* const img3_chat[] = { 
"72 21 20 1",
". c #004991",
"# c #004a91",
"a c #004a92",
"b c #004a94",
"m c #004c97",
"h c #004d99",
"l c #004f9c",
"q c #00509d",
"g c #00509f",
"f c #0052a2",
"p c #0053a5",
"e c #0055a8",
"j c #0056aa",
"c c #0057ad",
"i c #0059b0",
"d c #005ab3",
"o c #005cb6",
"n c #005db9",
"r c #005fbb",
"k c #0060be",
"...#...................#................................................",
"........................................................................",
"........................................................................",
"...............................................a........................",
"........................................................................",
"........................................................................",
".......................................................................a",
"..........bcddddde.dddddddf.gdddddddhddddddihbjddddddffdddddddh.........",
"..........ekkkkkkklkkkkkkkkmnkkkkkkklkkkkkkkcfkkkkkkkeokkkkkkkl.........",
"..........dkclllokekkcllpkklkkpllllllkklllckdekolllllmkkclllllb.........",
"..........dke...dkekkefdokkqkkljdddjlkk...ekdekd......kkndddil..........",
"..........dke...dkekkeekkkr.kkldkkkdlkk...ekdekd......kkkkkkkkb.........",
"..........dke...dkekkemlllb.kkl.....lkk...ekdekd......kkdeeckkl.........",
"..........jkkkkkkkfkke......rkkkkkkklkk...ekdpkkkkkkkeokkkkkkkh.........",
"..........lrkkkkknbkke......ekkkkkkklkk...ekdmnkkkkkkegkkkkkkd..........",
"........................................................................",
"........................................................................",
"........................................................................",
"........................................................................",
"........................................................................",
"........................................................................"};

static const char* const img4_chat[] = { 
"34 31 4 1",
"a c #004894",
"b c #004c94",
"# c #004c9c",
". c #ffffff",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"..................................",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"#aba#aba#aba#aba#aba#aba#aba#aba#a",
"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
"ba#aba#aba#aba#aba#aba#aba#aba#aba"};

static const char* const img5_chat[] = { 
"51 16 89 2",
".R c #000000",
"#w c #000400",
"#. c #000810",
".o c #000c10",
".M c #000c18",
".n c #001020",
".m c #001429",
".l c #001831",
".p c #001c39",
".k c #002041",
".j c #00244a",
".g c #002c5a",
".i c #003062",
".f c #00346a",
".e c #00386a",
".d c #003873",
".9 c #003c73",
".c c #003c7b",
".h c #004083",
".b c #00448b",
".# c #004894",
".a c #004c94",
"Qt c #004c9c",
".5 c #080808",
".0 c #080c10",
".V c #080c18",
".G c #081018",
"#t c #101010",
"#l c #101410",
".z c #101820",
"#n c #181418",
"#h c #181818",
".U c #181c18",
".q c #182431",
".Z c #201c20",
"#c c #202020",
"#v c #202420",
".8 c #292429",
".3 c #312c31",
".L c #313031",
"#u c #313431",
".Y c #393839",
".4 c #393c39",
"#k c #413c41",
".N c #414041",
".F c #4a444a",
"#g c #4a484a",
"#b c #4a4c4a",
".T c #524c52",
".7 c #5a595a",
"#s c #625d62",
".r c #626162",
".2 c #626562",
".A c #62656a",
".K c #6a656a",
".y c #6a696a",
".W c #6a6d73",
".X c #7b757b",
"#i c #7b797b",
"#f c #837d83",
".E c #838183",
".S c #838583",
"#a c #8b858b",
".s c #8b898b",
"#r c #8b8d8b",
".6 c #948d94",
"#d c #949194",
".x c #9c999c",
"#p c #9c9d9c",
".J c #a49da4",
".t c #a4a1a4",
".B c #aca5ac",
"## c #acaaac",
".D c #acaeac",
"#o c #b4aeb4",
".O c #b4b2b4",
".1 c #b4b6b4",
"#e c #bdb6bd",
".I c #bdbabd",
".H c #bdbebd",
".w c #c5bec5",
".P c #c5c2c5",
".Q c #c5c6c5",
".C c #cdc6cd",
".u c #cdcacd",
".v c #d5ced5",
"#j c #d5d2d5",
"#m c #eee6ee",
"#q c #eeeaee",
"Qt.#.a.#Qt.#.a.#Qt.#.a.#.#.b.b.c.c.d.d.e.d.d.d.e.d.d.d.e.d.d.d.e.d.d.d.e.d.d.d.e.d.d.d.e.d.d.d.e.d.f.g",
".#.#.#.#.#.#.#.#.#.#.b.h.d.i.j.k.l.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.n.o",
".a.#Qt.#.a.#Qt.#.#.c.f.j.p.n.q.r.s.t.u.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.w.x.y",
".#.#.#.#.#.#.b.h.i.j.n.z.A.B.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.u.C.D.E.F",
"Qt.#.a.#.#.b.c.j.m.G.A.H.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.C.u.I.J.K.L",
".#.#.#.#.h.f.p.M.N.O.P.Q.P.C.P.Q.R.R.R.R.R.C.P.Q.P.C.P.Q.P.C.P.Q.P.C.R.R.P.C.P.Q.P.C.P.Q.P.C.P.O.S.T.U",
".a.#.#.h.g.m.V.W.P.P.P.P.P.P.P.P.R.R.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.w.t.X.Y.Z",
".#.#.h.g.n.0.S.P.H.P.H.P.H.P.H.P.R.R.H.P.H.P.H.P.R.R.R.P.H.R.R.R.H.P.R.R.H.P.H.P.H.P.H.P.H.P.1.x.2.3.4",
"Qt.b.f.m.5.E.w.H.w.H.w.H.w.H.w.H.R.R.R.R.R.H.w.R.R.H.w.H.R.R.w.H.w.H.R.R.w.H.w.H.w.H.w.H.w.H.O.6.7.8.y",
".b.9.p#..y.I.I.I.I.I.I.I.I.I.I.I.R.R.I.I.I.I.I.I.R.R.I.I.R.R.I.I.I.I.R.R.I.I.I.I.I.I.I.I.I.I###a#b#c#d",
".h.j.n.N.I#e.I#e.I#e.I#e.I#e.I#e.R.R.I#e.I#e.I#e.I.R.R#e.R.R.I#e.I#e.R.R.I#e.I#e.I#e.I#e.I#e.B#f#g#h.I",
".i.m.0##.O.1.O#e.O.1.O#e.O.1.O#e.R.R.R.R.R.1.O.R.R.R.O#e.O.R.R.R.O.1.R.R.O.1.O#e.O.1.O#e.O.1.t#i.4#h#j",
".j#..y.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.1.O#e.O.t#i#k#l#m",
".n#n##.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O.D.O#o.O#p.X.Y#n#q",
".L#b.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.6#r.E#s.L#t.P",
"#u#v.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z.U.Z#h#n.5#w.2"};

static const char* const img6_chat[] = { 
"28 31 202 2",
"ao c #000008",
"#k c #000810",
"#d c #000c18",
"af c #001018",
"#j c #001020",
"#c c #001429",
"#S c #001831",
"#5 c #001c39",
"#i c #002041",
"#b c #00244a",
"#I c #002852",
"#h c #002c5a",
"#a c #003062",
"#4 c #003462",
"#y c #00346a",
"#H c #003873",
"#g c #003c7b",
"## c #004083",
"#x c #004483",
"#. c #00448b",
"#p c #00488b",
".9 c #004894",
"#o c #004c94",
".8 c #004c9c",
"#q c #080810",
"aE c #101820",
"aw c #102439",
"#6 c #182020",
".N c #202020",
".H c #202420",
"ax c #202429",
".G c #292829",
".7 c #292c29",
".V c #312c31",
".F c #313031",
".2 c #313431",
".E c #393439",
".1 c #393839",
".M c #393c39",
"#T c #393c41",
".D c #414041",
".O c #414441",
"#l c #41444a",
"aj c #4195ee",
".C c #4a444a",
".W c #4a4c4a",
"aB c #4a99ee",
"ap c #525052",
".6 c #525552",
"#J c #52555a",
"#8 c #52a1ee",
".B c #5a555a",
".0 c #5a595a",
".L c #5a5d5a",
".w c #626162",
".v c #626562",
"a7 c #62797b",
"bh c #6a656a",
".x c #6a696a",
".u c #6a6d6a",
"#F c #6a9dc5",
"al c #6aaeee",
".t c #737173",
"bc c #738d94",
"a4 c #73aed5",
"a# c #73b2f6",
".K c #7b797b",
".3 c #7b7d7b",
".Z c #7b7d83",
"b# c #7b999c",
"#B c #7ba1c5",
"aG c #7baad5",
"aQ c #7bb2d5",
"a. c #7bb6ee",
".s c #837d83",
".5 c #838183",
".r c #83858b",
"bf c #839594",
"#7 c #83a5cd",
"#E c #83aad5",
"#L c #83b2d5",
"#U c #83b6cd",
"#Y c #83bef6",
".A c #8b858b",
".P c #8b898b",
"ag c #8b8d8b",
"a1 c #8baab4",
"#Q c #8bb6de",
"ar c #8bbad5",
"ay c #8bbed5",
"#2 c #8bbede",
"ad c #8bc2d5",
"#X c #8bc2f6",
"an c #8bc6de",
"aZ c #8bc6e6",
"a6 c #949194",
".q c #94959c",
"#D c #94b6d5",
"bd c #94bec5",
"#u c #94bed5",
"az c #94bee6",
"#A c #94c2d5",
"aS c #94c2de",
"#R c #94c6de",
"aX c #94cae6",
"aY c #94cee6",
".4 c #9c959c",
".J c #9c9da4",
"b. c #9caaac",
"#C c #9cb6d5",
"#G c #9cc6de",
"aT c #9cc6e6",
"a2 c #9ccacd",
"#v c #9ccade",
"aL c #9cceee",
"aD c #9cd2e6",
"aK c #9cd6e6",
"#e c #a49da4",
".p c #a4a1a4",
"ah c #a4bede",
"as c #a4cae6",
"#9 c #a4caf6",
".Y c #acaaac",
"a8 c #accecd",
"aW c #acdae6",
".j c #b4b2b4",
".Q c #b4b6b4",
".k c #b4b6bd",
"#3 c #b4dae6",
"a0 c #b4daee",
"aU c #b4deff",
".i c #bdb6bd",
".h c #bdbabd",
".I c #bdbebd",
"be c #bddede",
"a9 c #bddee6",
"aF c #bddeee",
"aJ c #bddef6",
"ac c #bde6ff",
"#m c #c5bec5",
".g c #c5c2c5",
".f c #c5c6c5",
"#V c #c5cee6",
"#M c #c5d2e6",
"bg c #c5dede",
"aO c #c5def6",
"#t c #c5e2ee",
"aR c #c5e6e6",
"bb c #c5e6ee",
"a3 c #c5eaee",
"a5 c #c5eaff",
"#P c #c5eeff",
".R c #cdc6cd",
".o c #cdcacd",
".S c #cdcecd",
"#w c #cde6ee",
"#K c #cdeaee",
"am c #cdeeff",
"#1 c #cdf6ff",
".e c #d5ced5",
"#r c #d5d2d5",
".d c #d5d6d5",
"ak c #d5e6f6",
"#z c #d5eaee",
"ai c #d5eaff",
"aP c #d5eef6",
"aC c #d5eeff",
"aM c #d5faff",
".z c #dedade",
".U c #dedede",
".n c #dedee6",
"#s c #deeaee",
"av c #deeeee",
"#0 c #def6f6",
"#O c #defaff",
".c c #e6dee6",
"aq c #e6e2e6",
"#f c #e6e6e6",
"#n c #e6eaee",
"ba c #e6eeee",
"ae c #e6eef6",
"#Z c #e6f2f6",
"au c #e6f6ff",
"aH c #e6faf6",
"ab c #e6faff",
".X c #eee6ee",
".b c #eeeaee",
".m c #eeeeee",
"aV c #eeeef6",
"#W c #eef2ff",
"aI c #eef6ff",
"aN c #eefaff",
"at c #eeffff",
".y c #f6eef6",
".T c #f6f2f6",
".a c #f6f6ff",
"aA c #f6faf6",
"#N c #f6ffff",
".l c #fff6ff",
".# c #fffaff",
"aa c #fffff6",
"Qt c #ffffff",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.#.a.b.c.d.e.f.g.h.i.j.i.k",
"QtQtQtQtQtQtQtQtQtQtQtQt.#.l.m.n.o.i.p.q.r.s.t.u.v.v.w.x",
"QtQtQtQtQtQtQtQtQtQtQt.l.y.z.g.p.A.x.B.C.D.E.F.G.G.H.G.G",
"QtQtQtQtQtQtQtQtQt.#.b.z.I.J.K.L.M.G.N.G.O.u.P.p.Q.R.S.o",
"QtQtQtQtQtQtQt.#.T.U.f.J.s.B.M.N.V.W.P.h.X.b.m.b.y.b.m.b",
"QtQtQtQtQtQt.a.b.S.Y.Z.0.1.N.2.3.h.b.b.b.b.b.b.b.b.b.b.b",
"QtQtQtQtQt.l.X.g.4.v.D.N.E.5.e.b.m.b.y.b.m.b.y.b.m.b.y.b",
"QtQtQtQt.T.c.i.P.6.7.N.x.f.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b",
".8.9.9#.###a#b#c#d.G#e#f.y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b",
".9.9#.#g#h#i#j#k#l#m.b.b.b.b#n#n#n#n#n.b.b.b.b.b.b.b.b.b",
"#o#p###a#i#j#q.0#r.b.y.b.m#s#t#u#u#v#w#n.m.b.y.b.m.b.y.b",
"#.#x#y#b#j#k.L.z.b.b.b.b#z#A#B#C#D#E#F#G#z.b.b.b.b.b.b.b",
"#.#H#I#c#k#J.U.b.y.b.m#K#L#MQtQt#N#O#P#Q#R#s.m.b.y.b.m.b",
"#H#h#S#d#T.e.b.b.b.b#s#U#V#W#X#Y#ZQt#0#1#2#3#n.b.b.b.b.b",
"#4#5#j#6.i.b.y.b.m#n#t#7Qt#8#9a.a#aaQtabacadae.b.m.b.y.b",
"#5af#qag.b.b.b.b.b#n#AahaiajaaakalQtaa#Naman#z.b.b.b.b.b",
"#kaoapaq.y.b.m.b.y#narasata.Qtaka#aaQt#Nau#Rav.b.y.b.m.b",
"awax.Q.b.b.b.b.b.b#nayaz#OQtaaaAaB#WaaQtaCaD#s.b.b.b.b.b",
"aE.x.b.b.m.b.y.b.m#naFaG#1aHQtaaak#8aIQtaJaKae.b.m.b.y.b",
"ax#m.b.b.b.b.b.b.b.b#sayaLaMaNQtaaaOaaQtaPaQaR.b.b.b.b.b",
".waq.m.b.y.b.m.b.y.b.m#zaSaTamab#NaNQtaaabaUay#zaV.b.m.b",
".p.b.b.b.b.b.b.b.b.b.b.b#zaWanaXaYaZa0#OaN#Na1a2#s.b.b.b",
"#r.b.y.b.m.b.y.b.m.b.y.b.m#nae#zava3a4a5Qtaqa6a7a8#n.y.b",
"#f.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b#na9aQb..g.o.5b##s.b.b",
".y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.bbabbbc.5.R.pbd#s.m.b",
".b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b#nbeb#bfbgaR#n.b.b",
".m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.bba#z#w#zba.b.y.b",
".b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b",
".y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b.y.b.m.b",
".I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m.I#m",
".xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh.xbh"};

static const char* const img7_chat[] = { 
"8 2000 18 1",
"# c #cde6ff",
"b c #cdeaff",
"a c #d5e6ff",
". c #d5eaff",
"d c #d5eeff",
"c c #deeaff",
"e c #deeeff",
"h c #def2ff",
"f c #e6eeff",
"g c #e6f2ff",
"j c #e6f6ff",
"i c #eef2ff",
"k c #eef6ff",
"l c #f6f6ff",
"m c #f6faff",
"p c #f6ffff",
"n c #fffaff",
"o c #ffffff",
".#.#.#.#",
"#.#.#.#.",
".#.#.#.#",
"#.#.#a#.",
".a.#.a.#",
"#.#.#.#a",
".#.a.#.#",
"#.#.#.#.",
"...#.a.#",
"#.#.#.#.",
".a.a.a..",
"#.#.#.#.",
".a.a.a.#",
"#.#.#.#.",
".#...b..",
"#.#.#.#.",
".a...a.a",
"#.#.#.#.",
"........",
"#.#.#.#.",
"........",
"a.#.a.#.",
"........",
"#.a.#...",
"........",
"a.a.a.#.",
"........",
"b...b.a.",
"........",
"........",
"........",
"a.....a.",
"c.......",
"..a.....",
"........",
"........",
"c...c.d.",
"........",
"d.e.e.c.",
"........",
"c.c.e.e.",
"........",
"e.e.e.e.",
"........",
"e.e.e.e.",
".....c..",
"e.e.e.e.",
"...c...e",
"e.e.e.e.",
".c.d.e.e",
"e.e.e.e.",
".c.e.e.e",
"e.e.e.e.",
".c.e.e.c",
"e.e.e.e.",
".e.e.e.e",
"ece.ece.",
".e.e.e.e",
"e.ececec",
".e.e.e.e",
"eee.eeee",
".e.e.e.e",
"eeeeedec",
".e.e.e.e",
"eeeeeeee",
".e.e.e.e",
"eeeeeeec",
".ece.e.e",
"eeeeeeee",
"cedecece",
"eeeeeeee",
"deeecece",
"eeeeeeee",
"eeceeece",
"eeeeeeee",
"eeeeceee",
"feeeeeee",
"eeeeeeee",
"gefeeefe",
"eeeeeeee",
"gegefefe",
"eeeeeeee",
"gefegege",
"eeeeeeee",
"fegegege",
"efeeeeee",
"gegegege",
"eeefeeef",
"gegegege",
"efegefee",
"gegegege",
"egefegeg",
"gegegege",
"egegefeg",
"gegfgegf",
"egegegeg",
"gfgegfgh",
"egegegeg",
"ghgggfgf",
"egegegeg",
"gggggggg",
"egegegeg",
"gggggfgg",
"egfgegeg",
"gggggggg",
"fgegggfg",
"gggggggg",
"fgfgggfg",
"gggggggg",
"ggfgggfg",
"gggggggg",
"gggggggg",
"igggiggg",
"gggggggg",
"jgkgggig",
"gggggggg",
"kgkgkggg",
"gggggggg",
"kgigkgkg",
"gggggggg",
"kgkgkgkg",
"gigggigg",
"kgkgkgkg",
"gggigggi",
"kgkgkgkg",
"gkgkgkgi",
"kgkgkgkg",
"gigigkgk",
"kgkgkgkg",
"gkgkgkgk",
"kgkikgki",
"gkgkgkgk",
"kikgkikg",
"gkgkgkgk",
"kkkikiki",
"gkgkgkgk",
"kkkkkkki",
"gkgkikgk",
"kkkkkkkk",
"gkgkgkik",
"kkkkkkkk",
"ikgkikgk",
"kkkkkkkk",
"ikikkkkk",
"kkkkkkkk",
"ikkkikkk",
"kklkkkkk",
"kkkkkkkk",
"lkkklkkk",
"kkkkkkkk",
"lkmkmklk",
"kkkkkkkk",
"mkmklkmk",
"kkkkkkkk",
"mkmkmkmk",
"kkklkkkk",
"mkmkmkmk",
"klkkklkk",
"mkmkmkmk",
"klklkmkl",
"mkmkmkmk",
"klkmkmkm",
"mkmkmkmk",
"kmkmklkm",
"mlmkmlmk",
"kmkmkmkm",
"mkmlmkml",
"kmkmkmkm",
"mlmmmmml",
"kmkmkmkm",
"mlmmmlmm",
"kmlmkmkm",
"mmmlmmmm",
"lmkmlmkm",
"mmmmmmmm",
"mmlmkmlm",
"mmmmmmmm",
"lmmmlmlm",
"mmmmmmmm",
"mmmmlmlm",
"nmmmnmmm",
"mmmmmmmm",
"mmnmmmom",
"mmmmmmmm",
"ommmompm",
"mmmmmmmm",
"nmnmomom",
"mmmnmmmm",
"nmomomom",
"mnmmmnmm",
"omomomom",
"mmmnmmmn",
"omomomom",
"mnmnmomm",
"omomomom",
"mmmnmnmo",
"omomomom",
"momomomn",
"omomomon",
"momomnmo",
"onomonom",
"momomomo",
"omonomon",
"momomomo",
"onomooon",
"momomomo",
"ooononon",
"momomomo",
"ooooooon",
"nomomomo",
"oooooooo",
"monomono",
"oooooooo",
"nomonono",
"oooooooo",
"oonomono",
"oooooooo",
"oonooono",
"oooooooo",
"nooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo",
"oooooooo"};

static const char* const img8_chat[] = { 
"311 12 33 1",
"k c #0075e6",
"c c #0075ee",
"E c #0079ee",
". c #0879ee",
"q c #1881ee",
"o c #3995f6",
"r c #4a9df6",
"i c #73aee6",
"j c #7bb2ee",
"g c #83b6e6",
"l c #83b6ee",
"n c #83bae6",
"f c #83baee",
"m c #8bbae6",
"h c #8bbaee",
"e c #8bbeee",
"d c #94beee",
"D c #9ccaff",
"B c #a4caee",
"C c #a4caf6",
"A c #accef6",
"p c #acd2ff",
"z c #b4d2f6",
"s c #b4d6f6",
"u c #bdd6f6",
"t c #bdd6ff",
"w c #bddaf6",
"v c #c5daff",
"b c #c5deff",
"y c #cddeff",
"x c #cde2ff",
"a c #cde6ff",
"# c #d5e6ff",
".##a#bbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbbb",
"cdefghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghgfghg",
".ijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijijij",
"klglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglg",
".lfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlfghlf",
"clglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglglg",
".fhhhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhhhfhfhlhlhlhfhfhfhfhfhfhfhfhfhfhfhlhlhlhfhfhfhfhlhlhlhfhhhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhfhlhlhlhfhfhfhfhfhfhfhfhfhfhfhfhfhlhlhlhlhlhfhfhfhhhfhhhfhfhfh",
"khmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhhhnhhhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhhhnhhhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhmhnhm",
".hdedededededededededededededededededededededededededededededededededededededededhehdhehdhdhdhdedededededededededededededededededededededhdhdhdededededededededededededededededededededededededededededededededhdhdhdhdededededededededededededededededededededededededededededededededededededededededededhdhdhdhdeded",
"coddddedededddedddedddedddedddedededededededededddedddedddddddddddedededededddedddedddedddedddedddedddedededededededededededddedddedddedddedddedddedddedddedddedededededededededddedddedddedededddedddedededededededededddedddedededededededddedddedddedddedddedededededededddedededededddedddedddededededddddddddedede",
"pqrststststststststststststststststststststststststuvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwbbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxbxx#x#x#x#x#x#x#x#x#x#x#x#x#x#x#x#x#x#x#bxbxbxbxbxbxbxbxbxbxbxbyvvwvwvwvwvwvwvwvwvwvwvwvuuststststststststststststststststststststststststststszAABC",
"aDcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEcEkEc"};

static const unsigned char img9_chat[] = { 
    0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
    0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x2d, 0x00, 0x00, 0x00, 0x1f,
    0x08, 0x06, 0x00, 0x00, 0x00, 0x73, 0xa8, 0x44, 0x3c, 0x00, 0x00, 0x02,
    0xab, 0x49, 0x44, 0x41, 0x54, 0x58, 0x85, 0xd5, 0x97, 0x3f, 0x48, 0xdc,
    0x60, 0x18, 0xc6, 0x9f, 0x1c, 0x37, 0xdc, 0x81, 0x85, 0x4b, 0x41, 0x68,
    0x86, 0xc2, 0x59, 0x74, 0x50, 0xb2, 0xf4, 0x36, 0xe9, 0xa4, 0xd0, 0xc5,
    0xa3, 0x53, 0xe9, 0xa2, 0x9b, 0x9d, 0xc4, 0xa9, 0x43, 0x0a, 0x22, 0x4e,
    0x67, 0x29, 0x25, 0x85, 0x2e, 0xed, 0x20, 0xd8, 0x82, 0xe0, 0xb9, 0x54,
    0xda, 0xc5, 0xde, 0x60, 0xa9, 0x15, 0x41, 0x0b, 0xfd, 0x73, 0x83, 0x1c,
    0x37, 0x38, 0x9c, 0x42, 0x4b, 0x02, 0x0a, 0x5f, 0x0e, 0x85, 0x04, 0x5c,
    0x9e, 0x0e, 0x5f, 0xc4, 0x78, 0xed, 0xa5, 0xf7, 0xa7, 0x77, 0xc6, 0x17,
    0xc2, 0x8f, 0x27, 0x84, 0x2f, 0x6f, 0x7e, 0x79, 0x13, 0x12, 0x90, 0x24,
    0xf7, 0x48, 0x92, 0xfc, 0xe4, 0x33, 0xea, 0x59, 0xc9, 0x15, 0x2c, 0x4e,
    0xe8, 0x1a, 0xf2, 0x25, 0x1b, 0xd0, 0x35, 0xa0, 0x64, 0x23, 0xea, 0x39,
    0x36, 0xd6, 0xaf, 0xe1, 0xd5, 0x77, 0x60, 0xac, 0x5f, 0x43, 0xd5, 0x67,
    0xd4, 0xb3, 0x92, 0x2b, 0x58, 0x8c, 0x8a, 0xc1, 0x46, 0x73, 0x6c, 0x42,
    0xd7, 0x80, 0x12, 0xfc, 0x1d, 0x92, 0x51, 0xcf, 0x57, 0x73, 0xa6, 0xa3,
    0x64, 0xb0, 0xd1, 0xac, 0xe4, 0xd6, 0xaf, 0xde, 0x4c, 0xc3, 0xb2, 0x48,
    0x73, 0x9d, 0xbc, 0x4a, 0x54, 0xcc, 0x0d, 0xc1, 0x09, 0x5d, 0x45, 0xbe,
    0xe4, 0x00, 0xba, 0x0a, 0x94, 0x1c, 0xb4, 0x9b, 0x1f, 0xea, 0x2a, 0x56,
    0x4a, 0x0e, 0xc6, 0xff, 0x41, 0xaf, 0xc5, 0xf5, 0x21, 0x04, 0x99, 0x3b,
    0xbb, 0x92, 0x0d, 0x52, 0x1c, 0x92, 0x2f, 0xb7, 0x48, 0x21, 0xa2, 0x4b,
    0xc0, 0xb0, 0x08, 0x83, 0xc4, 0x8c, 0xc5, 0xc4, 0x0c, 0x99, 0x9a, 0xb3,
    0x38, 0xb2, 0x40, 0xe6, 0xd6, 0x85, 0x7f, 0x60, 0xf4, 0x08, 0xc0, 0x04,
    0x70, 0xfb, 0x7c, 0x5b, 0xa2, 0xbc, 0x88, 0x25, 0x32, 0xfd, 0x84, 0xdc,
    0xde, 0x23, 0x17, 0xb7, 0x48, 0xf7, 0x98, 0x5c, 0xdc, 0x89, 0x06, 0x2f,
    0x36, 0x5c, 0xbb, 0x19, 0x24, 0x0c, 0x79, 0x07, 0xc6, 0x16, 0x04, 0xc5,
    0x21, 0xb9, 0xfc, 0x55, 0x90, 0x2e, 0xb9, 0xbc, 0x23, 0xc8, 0xe3, 0x16,
    0xe9, 0x06, 0xd6, 0x69, 0x81, 0x81, 0x26, 0x6b, 0x8c, 0x07, 0xb3, 0x6f,
    0x1e, 0x06, 0x39, 0x58, 0x20, 0x67, 0x0b, 0xf4, 0x17, 0x08, 0xe7, 0x6a,
    0x1d, 0x2e, 0x17, 0x49, 0x9e, 0x92, 0xab, 0x2d, 0x32, 0xdc, 0xf4, 0x5f,
    0xed, 0xcb, 0x67, 0x20, 0x35, 0x27, 0x38, 0x59, 0xf6, 0x0d, 0x9c, 0x92,
    0xab, 0xc5, 0xee, 0x31, 0xdc, 0x70, 0x58, 0xf6, 0xcd, 0x27, 0xf2, 0xe4,
    0xc8, 0x82, 0x34, 0xb8, 0xb6, 0x2b, 0xbf, 0x77, 0x3b, 0xcd, 0xe6, 0x4d,
    0xd7, 0x31, 0x9f, 0x98, 0xb1, 0x38, 0x59, 0x26, 0xd7, 0x76, 0x5d, 0xf9,
    0xc1, 0x5e, 0xee, 0x1c, 0x9b, 0x37, 0x5c, 0x2f, 0xfb, 0xe6, 0x53, 0xef,
    0xe4, 0x7b, 0xbf, 0x91, 0x3f, 0x90, 0x56, 0x73, 0xfb, 0xa6, 0xeb, 0x98,
    0x1f, 0x7c, 0x26, 0xe8, 0xba, 0xe4, 0x76, 0x45, 0x1a, 0xfa, 0x83, 0x7b,
    0x2d, 0xb2, 0xe2, 0xb6, 0x31, 0xd3, 0x0d, 0xce, 0xfc, 0xe2, 0x0e, 0xb9,
    0x56, 0x96, 0x86, 0x7e, 0x54, 0x7c, 0x63, 0x95, 0xf6, 0xb2, 0x22, 0x4f,
    0xd4, 0xa1, 0x32, 0x8a, 0x04, 0x6c, 0x24, 0xe2, 0x1a, 0xa6, 0x87, 0x1d,
    0x3c, 0xbf, 0xa7, 0xa2, 0xf8, 0xd3, 0x43, 0xe6, 0x66, 0xb2, 0x2d, 0x06,
    0x9a, 0x1e, 0x07, 0xb0, 0x12, 0x38, 0xe3, 0x7f, 0xcc, 0x46, 0x91, 0xd0,
    0x81, 0x1b, 0xbf, 0x00, 0xfb, 0x11, 0x50, 0xae, 0x02, 0x43, 0x1a, 0x00,
    0x1b, 0x80, 0x06, 0x94, 0xed, 0xe6, 0x72, 0x67, 0x4d, 0xd7, 0x96, 0x6f,
    0x7e, 0x38, 0xad, 0x61, 0xfe, 0xae, 0x87, 0xd1, 0x81, 0x24, 0xf6, 0x8f,
    0x3c, 0xf4, 0xf5, 0x36, 0xc7, 0x98, 0x34, 0x12, 0xac, 0x0e, 0x66, 0x33,
    0xa3, 0xc0, 0xcc, 0x2b, 0x5f, 0x0e, 0x80, 0xec, 0xb7, 0x24, 0xa6, 0xdf,
    0x03, 0x7d, 0xbd, 0x49, 0xe0, 0xa8, 0x39, 0x76, 0xd7, 0x74, 0xb0, 0x8c,
    0x0f, 0x04, 0x34, 0xa4, 0x12, 0x0e, 0x8a, 0x53, 0x2a, 0xbc, 0x38, 0x30,
    0xd4, 0x0b, 0xec, 0x3b, 0x40, 0x9f, 0x1a, 0xce, 0xd8, 0xf9, 0x2a, 0x5d,
    0x34, 0x0e, 0x00, 0x66, 0x5e, 0x81, 0x99, 0x51, 0xaa, 0xfd, 0x2a, 0x6e,
    0xbd, 0x00, 0xee, 0x6c, 0x02, 0xf3, 0x9f, 0x65, 0x63, 0x70, 0xc2, 0x79,
    0x79, 0xa6, 0x6b, 0xeb, 0xcc, 0x7c, 0x8f, 0x83, 0xd9, 0x29, 0x15, 0xf7,
    0xe3, 0xb2, 0x41, 0xfb, 0x04, 0xd0, 0xae, 0x5d, 0x64, 0x77, 0x67, 0x3a,
    0x2c, 0x9b, 0x59, 0x69, 0x3e, 0xad, 0xc2, 0x30, 0x81, 0xcc, 0x26, 0x30,
    0xff, 0x51, 0x36, 0x8a, 0x93, 0x8b, 0x8c, 0x8e, 0xe9, 0xda, 0xf2, 0xcd,
    0x23, 0x6e, 0x23, 0xdd, 0xa3, 0x61, 0x74, 0xc0, 0xc3, 0xeb, 0x07, 0x49,
    0x38, 0xde, 0x65, 0xce, 0x74, 0x83, 0x33, 0x8f, 0xa7, 0x59, 0xe5, 0xa0,
    0x0a, 0xbc, 0xf1, 0x92, 0x50, 0x1e, 0x03, 0xd7, 0xdf, 0x02, 0xbf, 0x01,
    0x13, 0x9d, 0xe8, 0x5c, 0x59, 0xeb, 0xa8, 0x66, 0x00, 0x00, 0x00, 0x00,
    0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82
};

static const char* const img10_chat[] = { 
"23 31 45 1",
"Q c #0075ee",
"P c #0879ee",
"d c #73aee6",
"c c #7bb2ee",
"# c #83b6e6",
"e c #83b6ee",
"f c #83bae6",
"b c #83baee",
"g c #8bbae6",
"a c #8bbaee",
"i c #8bbeee",
"h c #94beee",
"k c #94c2ee",
"j c #9cc2ee",
"l c #9cc2f6",
"m c #9cc6ee",
"q c #a4c6ee",
"o c #a4c6f6",
"p c #a4caee",
"n c #a4caf6",
"s c #acceee",
"r c #accef6",
"t c #b4d2f6",
"w c #b4d6f6",
"u c #bdd6f6",
"v c #bddaf6",
"x c #c5daf6",
"y c #c5daff",
"z c #c5def6",
". c #c5deff",
"A c #cddef6",
"B c #cddeff",
"D c #cde2f6",
"E c #cde2ff",
"C c #d5e2ff",
"F c #d5e6ff",
"H c #deeaf6",
"G c #deeaff",
"J c #deeeff",
"I c #e6eeff",
"K c #e6f2ff",
"L c #eef2ff",
"N c #eef6ff",
"M c #f6f6ff",
"O c #ffffff",
".......................",
"#a#b#a#b#a#b#a#b#a#b#a#",
"cdcdcdcdcdcdcdcdcdcdcdc",
"#e#e#e#e#e#e#e#e#e#e#e#",
"aeb#aeb#aeb#aeb#aeb#aeb",
"#e#e#e#e#e#e#e#e#e#e#e#",
"aeaeabababababababaeaea",
"fagafafafafafagafagafag",
"hihihihihihihihihihihih",
"ihihhhhhhhhhhhhhhhhhihi",
"jklkjklkjklkjklkjklkjkl",
"kjjmjmjmjmjmjmjmjmjmkmj",
"nmnmomomomomomomomomomo",
"pnpnpnqnqnqnqnqnqnqnpnp",
"rsrrrsrrrsrrrsrrrsrrrsr",
"stststststststststststs",
"utututututututututututu",
"uuuuuuuuuuuvuvuvuvuuuuw",
"xvyxxvyxxvyxxvyxxvyxxvy",
"zAzBzzxBxzxBxzxBxzxBxzx",
"CDEDEDEDEDEDEDEDEDEDCDE",
"DFDFDFDFDFDFDFDFDFDFDFD",
"GFGFGFGFGFGFGFGFGFGFGFG",
"HGGGHGGGHGGGHGGGHGGGHGG",
"IGIGIGIGIGIGIGIGIGIGIGI",
"JIJIJIJIJIJIJIJIJIJIJIJ",
"KILIKILIKILIKILIKILIKIL",
"KLKLKLKLKLKLKLKLKLKLKLK",
"MNMNMNMNMNMNMNMNMNMNMNM",
"OOOOOOOOOOOOOOOOOOOOOOO",
"PQPQPQPQPQPQPQPQPQPQPQP"};

static const char* const img11_chat[] = { 
"25 31 263 2",
"ce c #0075ff",
"cd c #08aeff",
".D c #3969cd",
"#O c #415dff",
"#4 c #4161cd",
"#A c #4161ff",
".6 c #4165ff",
".5 c #4169bd",
".R c #4169c5",
"aq c #4169ee",
".P c #4169ff",
".4 c #416dbd",
"#j c #4195ff",
".Q c #419dff",
"ar c #4a5dff",
"ae c #4a61bd",
"#3 c #4a61ff",
"#2 c #4a65cd",
"#z c #4a65de",
".7 c #4a69bd",
"aM c #4a6dff",
".E c #4a71ff",
"a6 c #4a75ff",
"#h c #4a79d5",
"bg c #4a7dff",
"#5 c #526dff",
"aN c #5275ff",
"#k c #5279b4",
"aD c #5279ff",
".C c #5281ff",
".N c #5285cd",
"as c #5a71de",
"aF c #5a79ff",
"#y c #5a7dff",
".B c #5a85cd",
"aL c #5a85f6",
".t c #5a85ff",
".r c #5a89ff",
"au c #6279ff",
"ac c #6281ff",
"#B c #6289bd",
".A c #6289ff",
".2 c #628dc5",
"#x c #628dee",
".3 c #6291ff",
"aY c #6a75bd",
"a8 c #6a79bd",
"bl c #6a79ff",
".X c #6a8db4",
"aW c #6a95ff",
".k c #6a99c5",
"bv c #6a99ff",
"#f c #6a9dff",
"bW c #737dff",
"bh c #7381c5",
".J c #7391b4",
"#1 c #7391ff",
"#Q c #7395c5",
".H c #7395ff",
"ap c #7399f6",
".L c #7399ff",
"a5 c #739dff",
"#w c #73a1ff",
".x c #73a5d5",
"ao c #73a5f6",
"#Y c #73a5ff",
"#v c #73aaf6",
".f c #73aeff",
"bG c #7b85ff",
"b5 c #7b8db4",
"#U c #7b91b4",
"bR c #7b91bd",
"#M c #7b9dff",
"#0 c #7ba1f6",
"#a c #7ba1ff",
".p c #7ba5ff",
".i c #7baad5",
"#K c #7baaff",
".z c #7baede",
".T c #7baeff",
".v c #7bb2e6",
".l c #7bdeff",
".w c #7be2ff",
"br c #838dcd",
"bs c #8391ff",
"aj c #8395ff",
"b6 c #8399ff",
"#9 c #83a1c5",
"#6 c #83a5cd",
"aB c #83a5ff",
"a4 c #83aeff",
".9 c #83b2de",
".m c #83b2e6",
"an c #83b2f6",
".b c #83b6e6",
".n c #83b6ff",
".U c #83bae6",
".G c #83baff",
"aK c #83deff",
".F c #83e6ff",
".g c #83eaff",
".d c #83eeff",
"aH c #8b99ac",
"a9 c #8b9dff",
"#H c #8ba1bd",
"aR c #8ba1ff",
"aQ c #8baac5",
"ag c #8baacd",
"bL c #8baaff",
"bo c #8baeff",
"#X c #8bb6f6",
".W c #8bbae6",
"#l c #8bbaff",
"#D c #8bbee6",
"#n c #8bbeee",
"## c #8bbeff",
".V c #8beeff",
"bx c #949dd5",
"bk c #94aabd",
"at c #94aade",
"bC c #94aecd",
"ai c #94b2d5",
"bK c #94b2ff",
"bE c #94b6f6",
"bd c #94b6ff",
"av c #94bade",
"aU c #94baff",
"#m c #94beee",
"#t c #94bef6",
"#F c #94beff",
"#7 c #94c2ee",
"#E c #94c2ff",
"bF c #9caade",
"bI c #9caeff",
".0 c #9cb2cd",
"b7 c #9cbaf6",
"bu c #9cbeff",
"#R c #9cc2ee",
"#J c #9cc2ff",
"#W c #9cc6f6",
"#8 c #9cc6ff",
"bY c #a4aec5",
"bb c #a4aeff",
"b# c #a4b2c5",
"b8 c #a4b2ee",
"bt c #a4baff",
"#e c #a4c2ff",
"ah c #a4c6ee",
"a3 c #a4c6f6",
"aw c #a4c6ff",
"#r c #a4caf6",
"aA c #a4caff",
"bZ c #a4ceff",
"bN c #acbaff",
"bU c #acbef6",
"aZ c #acc2de",
"bS c #accaf6",
"aS c #accaff",
"aG c #acceee",
"bT c #acd2ff",
"ad c #b495ff",
"aE c #b4a1ff",
"#i c #b4a5ff",
"c# c #b4baff",
"b9 c #b4becd",
"bV c #b4bee6",
"ay c #b4c2ff",
"bX c #b4c6d5",
"#p c #b4c6de",
"b. c #b4cae6",
"bi c #b4caff",
"bm c #b4ceff",
"aJ c #b4d2f6",
"bc c #b4d2ff",
"af c #bd95ff",
"#P c #bd9dff",
"aX c #bdaeff",
".s c #bdb2ff",
"#g c #bdbaff",
"bH c #bdcade",
"bQ c #bdcede",
"bn c #bdd2f6",
"a2 c #bdd2ff",
"bj c #bdd6ee",
"#I c #bdd6ff",
"#N c #c5aaff",
".O c #c5beff",
"b4 c #c5d2de",
"am c #c5daf6",
".a c #c5deff",
".S c #cdbaff",
".q c #cdbeff",
"b1 c #cdd2ff",
"cc c #cdd6de",
"cb c #cdd6e6",
"ak c #cddaee",
"aI c #cddaf6",
"bM c #cddaff",
".Z c #cddef6",
"#c c #cddeff",
"bB c #cde2f6",
"bA c #cde2ff",
".M c #d5c2ff",
"aC c #d5c6ff",
"bf c #d5caff",
"a1 c #d5def6",
"al c #d5e2f6",
"az c #d5e2ff",
"#q c #d5e6f6",
"#V c #d5e6ff",
"bP c #d5eaf6",
"#o c #de91ff",
".8 c #de95ff",
".j c #de9dff",
".K c #decaff",
"bp c #dee6f6",
"aO c #deeaf6",
"aP c #deeaff",
"bD c #deeeff",
".1 c #e68dff",
"#Z c #e6a5ff",
"b2 c #e6b2ff",
"bO c #e6b6ff",
"bJ c #e6caff",
"aa c #e6daff",
".y c #e6deff",
".e c #e6e6ff",
"a0 c #e6eaf6",
"a7 c #e6eeff",
"ca c #e6f2ff",
"c. c #eebeff",
"by c #eec2ff",
".I c #eeceff",
"#G c #eed6ff",
"ab c #eedaff",
"#L c #eedeff",
".u c #eee2ff",
"#u c #eee6ff",
".h c #eeeaff",
".o c #eeeeff",
"bq c #eef2ff",
"#b c #f6ceff",
"ax c #f6d6ff",
"bw c #f6deff",
"be c #f6e2ff",
"aV c #f6e6ff",
"#C c #f6eaff",
".c c #f6eeff",
"b3 c #ffc2ff",
"bz c #ffcaff",
"b0 c #ffceff",
"ba c #ffd2ff",
"a# c #ffd6ff",
"aT c #ffdaff",
".# c #ffdeff",
"a. c #ffe2ff",
"#d c #ffe6ff",
"#T c #ffeaff",
".Y c #ffeeff",
"#. c #fff2ff",
"#s c #fff6ff",
"#S c #fffaff",
"Qt c #ffffff",
"Qt.#Qt.aQt.#Qt.aQt.#Qt.aQt.#Qt.aQt.#Qt.aQt.#Qt.aQt",
".b.c.b.d.b.c.b.d.b.c.b.d.b.c.b.d.b.c.b.d.b.c.b.d.b",
".e.f.e.f.e.f.e.f.e.f.e.f.e.f.e.f.e.f.e.f.e.f.e.f.e",
".b.g.b.h.b.g.b.h.b.g.b.h.b.g.i.j.k.l.m.h.b.g.b.h.b",
".c.n.o.n.c.n.o.n.h.n.o.n.h.p.q.r.s.t.u.n.c.n.o.n.c",
".b.h.b.g.b.h.v.w.x.y.z.g.i.A.B.C.D.E.k.F.b.h.b.g.b",
".c.G.c.G.c.n.y.H.I.J.K.L.M.N.O.P.Q.R.S.T.c.G.c.G.c",
".U.V.W.c.U.F.X.Y.ZQt.0.1.2.3.4.P.5.6.7.8.9.V.W.c.U",
"#.###.###.#a#b#cQt#dQt#e.Y#f#g#h#i.6#j#k.u#l#.###.",
"#m#.#n#..9#o#pQt#qQt#r#s#t#u#v#w#x#y#z#A#B#C#D#.#n",
"#s#E#s#F#G#HQt#dQt#I#s#J#..T.y#K#L#M#N#O#P#Q#.#E#s",
"#R#S#R#T#UQt#VQt#qQt#W#S#X.w#Y#Z#0#1#2#3#4#5#6#.#7",
"#S#8#s#9a.#TQt#VQta##S#J.c#Kaa#Yabacadaeaf#5#Nag#S",
"ahQtaiajakQtalQtam#S#W#san.uao.pap#yaqaras#satauav",
"QtawaxayQtazQt.##SaAQt#F#C#K#LaBaCaDaEaF#s.YQtaja.",
"aG.YaHQt#qQtaIQtaJQt#r#.anaK#K#ZaLaMaN#.aOQtaP#TaQ",
"QtaRQt#TQta.QtaSQtaTQtaUaV.paaaWaXaN.Y#TQt.YQtaY.Y",
"aZ#da0QtaOQta1Qta2Qta3.Ya4#Za5.ta6#daOQta7Qta8a9b.",
"Qtb#babbQt#TQta.QtbcQtbdbe#Kbfbga.#TQt#.Qtbh#bbiQt",
"bjQtbkblbmQtaIQtbn#SaS.Ybo.p.r#LbpQtbqQtbrbsb.Qtam",
"QtaTa.agQt#dQt#IQtbt#SbuaVbvbwa.Qt#.QtbxbybzQtbAQt",
"bBQtbC#..ZQtbDQtbm#sbE#Ta5bwaIQt.oQtbFbGbHQtbBQtal",
"QtazQtbIbJbKQt#TQtbc#.bL#TbMQt#TQtbNbObzQt#VQt#dQt",
"bPQt#qQtbQa.bR.#bSQtbTbebUQta0QtbVbWbXQtaOQtaPQtaO",
"Qt#TQt#TQta.QtbYbyaRQtbZ#Tb0Qtb1b2b3Qt#TQt#TQt#TQt",
"a7QtbDQta7QtaOQtb4a.b5b6b7#.b8bGb9QtbDQtbDQtbDQtbD",
"Qt.YQt.YQt.YQt.YQt#dQtbbc.ajbOc#Qt.YQt.YQt.YQt.YQt",
"caQtcaQtcaQtcaQtcaQta7QtcbQtccQta7QtcaQtcaQtcaQtca",
"Qt#sQt#sQt#sQt#sQt#sQt#sQt#sQt#sQt#sQt#sQt#sQt#sQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"cdcecdcecdcecdcecdcecdcecdcecdcecdcecdcecdcecdcecd"};

static const char* const img12_chat[] = { 
"25 31 286 2",
"cB c #0075ff",
"cA c #08aeff",
"#M c #394c5a",
"#Z c #414c62",
"aa c #41505a",
"#L c #415062",
"#0 c #4150cd",
"#y c #415562",
"#U c #41556a",
"#H c #4189d5",
"ab c #4a5562",
"ag c #4a596a",
"#7 c #4a5d6a",
"#c c #4a5d73",
"#j c #4a6173",
"#i c #4a65e6",
"#t c #4a6983",
"aN c #52596a",
"aw c #525d6a",
"aH c #52616a",
"#s c #526173",
"aD c #5261de",
".0 c #52657b",
".T c #5265e6",
".v c #52697b",
".A c #526983",
".B c #527594",
".u c #5275ff",
"a1 c #5a61de",
"aP c #5a6573",
"#T c #5a6d83",
"#V c #5a718b",
"bb c #626d7b",
"ax c #627183",
"aC c #6271ee",
".S c #6285ac",
".F c #6289b4",
"a0 c #6a7583",
"aF c #6a7d8b",
"#n c #6a7d94",
".z c #6a8194",
".w c #6a81ff",
"#I c #6a8dac",
".1 c #6a8dff",
".o c #6a91ff",
".m c #6a95bd",
".5 c #6a95ff",
".t c #6a99c5",
"ah c #738dac",
".q c #73a1cd",
".f c #73aeff",
"bz c #7b7d8b",
"bH c #7b8183",
"bk c #7b818b",
"cd c #7b858b",
"aS c #7b89ff",
"bd c #7b8d9c",
".x c #7b8da4",
"av c #7b8dff",
".H c #7b91ac",
"aE c #7b95ac",
"at c #7b99b4",
".k c #7baaff",
".D c #7bb2de",
"cf c #838583",
"co c #83897b",
"cr c #838d83",
"ac c #838d9c",
"am c #8391a4",
"bl c #8391ff",
"a2 c #8395ac",
"#E c #8399ac",
"#Y c #83a5c5",
"#h c #83aacd",
".O c #83aeff",
".2 c #83b2de",
".b c #83b6e6",
".i c #83b6ff",
".P c #83bae6",
".E c #83baff",
".s c #83e6ff",
".g c #83eaff",
".d c #83eeff",
"cm c #8b897b",
"ct c #8b8983",
"bn c #8b91a4",
"a7 c #8b95a4",
"aR c #8b9db4",
"#W c #8bb6de",
"#d c #8bb6ff",
".R c #8bbae6",
"#e c #8bbaff",
"#u c #8bbee6",
"#g c #8bbeee",
".4 c #8bbeff",
".Q c #8beeff",
"b8 c #949183",
"b0 c #9499ac",
"aL c #949dac",
"bA c #94a1ac",
"#r c #94a1b4",
"#C c #94a1ff",
".7 c #94a5b4",
"a# c #94bade",
"#w c #94baff",
"#f c #94beee",
"#v c #94c2ff",
"by c #9ca1ac",
"ck c #9ca5a4",
"#A c #9caeff",
".X c #9cb2c5",
".L c #9cb2ff",
"aj c #9cbaff",
"#J c #9cc2ee",
"#X c #9cc6ff",
"bJ c #a4a5a4",
"bq c #a4aab4",
"bF c #a4aaff",
"bx c #a4aebd",
"bj c #a4b2bd",
"bC c #a4b6c5",
"## c #a4b6ff",
".U c #a4bacd",
"a3 c #a4bad5",
"au c #a4c6e6",
"ai c #a4c6ee",
"a. c #a4caee",
"#8 c #ac50cd",
"bG c #acb2bd",
"b# c #acb2ff",
"cu c #acb6c5",
"cq c #acb6ff",
"aZ c #acbac5",
"bs c #acbaff",
"#S c #acbed5",
"a5 c #acbeff",
".K c #acc2d5",
".J c #acc2ff",
"al c #b489cd",
"ak c #b48dd5",
".6 c #b491de",
"bO c #b4aea4",
"bN c #b4b6bd",
"bp c #b4bac5",
"cp c #b4baff",
"bw c #b4bec5",
"aB c #b4becd",
"aY c #b4c2cd",
"aK c #b4c2ff",
"#P c #b4c6cd",
".Z c #b4c6d5",
"#2 c #b4c6ff",
"#F c #b4caff",
"aQ c #b4ceee",
"aG c #bd91d5",
"#z c #bd91de",
"as c #bd95de",
".G c #bd99ee",
"bK c #bdbaac",
"bT c #bdc2c5",
"bi c #bdc2cd",
"bv c #bdc6cd",
"aA c #bdc6d5",
"aJ c #bdcad5",
"#Q c #bdce83",
"#O c #bdcede",
"bI c #bdceff",
"bm c #bdd2ee",
"a4 c #bdd6ff",
"aM c #c595de",
"aO c #c599de",
"bR c #c5baa4",
"bE c #c5cad5",
"bh c #c5ced5",
"a9 c #c5ceff",
"bu c #c5d2de",
"aq c #c5d2ff",
"az c #c5d6e6",
"#p c #c5d6ee",
"bc c #c5daf6",
".a c #c5deff",
"a6 c #cda5ee",
"cy c #cdd6de",
"aX c #cdd6e6",
"#6 c #cdd6ff",
"aU c #cddae6",
"#q c #cddaee",
"b6 c #cddaff",
".9 c #cddeff",
"#l c #cde2f6",
"bt c #cde2ff",
"br c #d5aaee",
"#1 c #d5aef6",
"#x c #d5beff",
"bM c #d5cab4",
".n c #d5caff",
"cb c #d5ce62",
"#R c #d5d2b4",
"bg c #d5dae6",
"cx c #d5dee6",
"ao c #d5deff",
"#3 c #d5e28b",
"aW c #d5e2ee",
".V c #d5e2f6",
"#B c #d5e2ff",
"#k c #d5e6f6",
"bB c #d5e6ff",
"aT c #de7df6",
"#N c #de7dff",
".C c #dea1ff",
"#D c #deb6ff",
".N c #decaff",
".p c #deceff",
"bP c #ded2bd",
"ch c #ded662",
"bQ c #ded6c5",
".l c #ded6ff",
"ae c #deda8b",
"cz c #dee2ee",
"bf c #dee6ee",
"ad c #deeaf6",
"ay c #deeaff",
"b7 c #deeeff",
".y c #e691ff",
"ba c #e6baff",
".M c #e6c2ff",
".e c #e6e6ff",
"cw c #e6eef6",
"aV c #e6eeff",
"cv c #e6f2ff",
"af c #ee8dff",
"ar c #eebeff",
"#b c #eecaff",
"bL c #eee2cd",
".r c #eee2ff",
"c. c #eee662",
"ci c #eeea62",
".h c #eeeaff",
".j c #eeeeff",
"be c #eef2ff",
"ce c #f695ff",
"cn c #f6c2e6",
"cs c #f6c2ee",
"cl c #f6c2f6",
"bD c #f6c2ff",
"#G c #f6ceff",
"#9 c #f6e2ff",
"#K c #f6e6ff",
"ca c #f6ee62",
".c c #f6eeff",
"cc c #ff9573",
"cj c #ff99de",
"bS c #ff9d8b",
"#o c #ffa1ff",
"cg c #ffa573",
".W c #ffa5ff",
"b. c #ffc2ff",
"bo c #ffc6ff",
"#5 c #ffca62",
"#a c #ffcaff",
"b5 c #ffceff",
"bZ c #ffd273",
"ap c #ffd2ff",
"aI c #ffd6ff",
"a8 c #ffdaff",
".# c #ffdeff",
"b4 c #ffe273",
"#m c #ffe2ff",
"bW c #ffe68b",
"bU c #ffe6e6",
".8 c #ffe6ff",
"b2 c #ffea73",
"b3 c #ffea8b",
"an c #ffeaff",
"b1 c #ffeee6",
"#. c #ffeeff",
"bV c #fff28b",
".3 c #fff2ff",
".I c #fff6ff",
"b9 c #fffa6a",
".Y c #fffaff",
"c# c #ffff6a",
"#4 c #ffffcd",
"bY c #ffffee",
"bX c #fffff6",
"Qt c #ffffff",
"Qt.#Qt.aQt.#Qt.aQt.#Qt.aQt.#Qt.aQt.#Qt.aQt.#Qt.aQt",
".b.c.b.d.b.c.b.d.b.c.b.d.b.c.b.d.b.c.b.d.b.c.b.d.b",
".e.f.e.f.e.f.e.f.e.f.e.f.e.f.e.f.e.f.e.f.e.f.e.f.e",
".b.g.b.h.b.g.b.h.b.g.b.h.b.g.b.h.b.g.b.h.b.g.b.h.b",
".c.i.j.i.c.i.j.i.h.k.l.m.n.o.p.q.r.i.j.i.c.i.j.i.c",
".b.h.b.g.b.h.b.s.t.u.v.w.x.y.z.A.B.C.D.g.b.h.b.g.b",
".c.E.c.E.c.i.r.F.G.H.I.J.I.K.I.L.M.A.N.O.c.i.c.i.c",
".P.Q.R.c.b.s.S.T.UQt.VQt.U.W.X.Y.Z.W.0.1.2.Q.R.c.P",
".3.4.3.4.c.5.6.7Qt.8Qt.9#.##Qt.9Qt#a#b#c.p#d.3#e.3",
"#f.3#g.3#h#i#j#.#kQt#l#m#n#o#pQt#qQt#r#s#t.r#u.3#f",
".I#v.I#w#x#y#z#AQt#BQt#C#D#EQt.#Qt#F#G#c#H#I.3#v.I",
"#J.Y#J#K.v#L#M#N#OQt#PQt#QQt#RQt#S#o#T#U#M#V#W.Y#J",
".Y#X.Y#Y.6#Z#0#Z#1#2Qt#3#4#5Qt#6.##7#0#L#8#c#9#X.Y",
"a.Qta#.w#y#LaaabacQtadQtaeQt#qQt#Oaf#y#L#Lagah.Iai",
"Qtaj.M#7ak#yalamQt#.QtanQtaoQtapQtaqar#Lalabasat.I",
"auav#7awawabaxQtayQtayQt.VQtazQtaAQtaBaCaaagagaDaE",
".YaFaGaHaGawan#.Qt#.Qt#BQtaIQtaJQtaK.YaLaMaNaOaP.M",
"aQ.8aRaSawaTaUQtaVQtaWQtaXQtaJ.YaY.3aZ.8a0a1a2.8a3",
"Qta4Qta5a6a7Qt.3Qt.8Qta8Qta9Qtb..3aZanb#babb.YaIQt",
"bcQtbcQtbd#obeQtbfQtbgQtbhQtbi.3aZanbj.8bkblbmQtbc",
"Qt#mQt.9.3bnQtanQt.#QtaqQtbo.Ibp#.b#anbqbrbsQtbtQt",
".VQt#lQt#p.WbpQtbgQtbuQtbv.Ibw#.bx.#bybzbAQt#lQt#l",
"QtbBQt#mQtbCbDboQtbE.YaK.IbpanbF#mbGaIbH.#bIQt.8Qt",
"adQt#kQtbJ#mbKQtbLQtbM#.bN#.bO.3bPQtbQ.YbRbSaZQtad",
"QtanQtbTbUbVQtbWbXbWbYbZ#mb0b1b2bXb3bXbVQtb4b5b6Qt",
"b7QtadQtb8b9c.c#cac#cbcccdcecfcgchc#cic#cbcjbyQtaV",
"Qt#.Qt.8Qtckclcmcnco#acpQt#BQtcqb5crcsct#acuQt#.Qt",
"cvQtcvQtcwQtcxQtcyQtczQtaVQtaVQtczQtbgQtczQtaVQtcv",
"Qt.IQt.IQt.IQt.IQt.IQt.IQt.IQt.IQt.IQt.IQt.IQt.IQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"cAcBcAcBcAcBcAcBcAcBcAcBcAcBcAcBcAcBcAcBcAcBcAcBcA"};

static const char* const img13_chat[] = { 
"25 31 192 2",
"a9 c #0075ee",
"a8 c #0879ee",
".n c #3971a4",
".7 c #416d8b",
".C c #416d94",
".l c #41719c",
".I c #41759c",
".m c #4175a4",
".0 c #41799c",
".y c #4a6d94",
".U c #4a7194",
"#i c #4a719c",
"#m c #4a7594",
"#h c #4a759c",
"#I c #4a7da4",
"#y c #5275a4",
".s c #52799c",
"ab c #527d9c",
"#V c #527da4",
"#Y c #5281a4",
".t c #5281ac",
".x c #528db4",
"## c #5a7594",
"#n c #5a799c",
"ad c #5a7d9c",
"#8 c #5a7da4",
"ac c #5a819c",
"ae c #5a81a4",
"#r c #5a81ac",
"aA c #5a85a4",
"#2 c #5a85ac",
"aN c #5a89ac",
"#x c #5a89b4",
"#U c #5a8db4",
".w c #5a91bd",
"aq c #627d9c",
"af c #62819c",
".O c #6289ac",
".i c #628db4",
"aT c #6291b4",
"#7 c #6291bd",
"#R c #6295bd",
".v c #6295c5",
".u c #6299c5",
".6 c #6a81a4",
"aR c #6a89a4",
"#g c #6a8dac",
".1 c #6a8db4",
"aS c #6a91b4",
".h c #6a91bd",
".j c #6a99c5",
"#H c #6a99cd",
"az c #6aa1c5",
"as c #73859c",
"aL c #739dbd",
".B c #739dc5",
"#6 c #73a1c5",
".g c #73a1cd",
"#5 c #73a5cd",
"#N c #73aad5",
".d c #73aee6",
"ap c #7b8da4",
".5 c #7b99bd",
"#a c #7b9dbd",
".T c #7b9dc5",
".4 c #7ba1c5",
".k c #7ba1cd",
"#4 c #7ba5cd",
"aM c #7ba5d5",
"#3 c #7baacd",
"#v c #7baad5",
".D c #7baecd",
"#O c #7baed5",
".f c #7baede",
".V c #7bb2cd",
"#l c #7bb2d5",
"#Q c #7bb2de",
".c c #7bb2ee",
"#k c #7bbade",
"#b c #83a1c5",
"ar c #83aad5",
"#c c #83aed5",
".r c #83aede",
"#M c #83b2d5",
"#P c #83b2de",
".o c #83b2e6",
".Z c #83b6de",
".# c #83b6e6",
".e c #83b6ee",
".p c #83bae6",
".b c #83baee",
"aa c #8b9db4",
"#K c #8ba1bd",
"#C c #8ba5c5",
"#q c #8baacd",
"#z c #8baecd",
"aG c #8baed5",
".8 c #8bb2de",
"#w c #8bb6d5",
".J c #8bb6de",
"#G c #8bb6e6",
"#u c #8bbade",
".q c #8bbae6",
".a c #8bbaee",
".X c #8bbee6",
".A c #8bbeee",
".H c #8bc2e6",
"#. c #8bc2ee",
".Y c #8bc6ee",
"at c #94a1b4",
"an c #94a5b4",
"ao c #94a5bd",
"#T c #94a5c5",
"#W c #94aabd",
"#Z c #94aac5",
".3 c #94bae6",
".P c #94baee",
".2 c #94bee6",
".z c #94beee",
"#t c #94c2e6",
".R c #94c2ee",
".M c #94c6ee",
".L c #94c6f6",
"aH c #9caabd",
"ag c #9caac5",
"aO c #9caebd",
"am c #9caec5",
"#f c #9cbee6",
"#s c #9cc2e6",
".Q c #9cc2ee",
".S c #9cc2f6",
"#e c #9cc6ee",
".N c #9ccaee",
"#F c #9cceee",
"#E c #9ccef6",
"#j c #9cd2f6",
"#o c #a4c6ee",
"#d c #a4c6f6",
"#X c #a4caee",
"#p c #a4caf6",
".9 c #a4ceee",
".F c #a4cef6",
"#L c #a4d2ee",
".G c #a4d2f6",
"a0 c #acbac5",
"ay c #acbacd",
"#1 c #acbad5",
"aF c #acbecd",
"#9 c #acbed5",
"#B c #acceee",
"#A c #accef6",
".K c #acd6f6",
".W c #acd6ff",
"aZ c #b4bac5",
"a1 c #b4c2cd",
"aK c #b4c2d5",
"au c #b4c2de",
"#J c #b4d2f6",
".E c #b4def6",
"a# c #bdcee6",
"ah c #bdd2ee",
"#S c #bdd6f6",
"aY c #c5cade",
"aU c #c5cede",
"av c #c5d6ee",
"ax c #c5daee",
"#0 c #c5daf6",
"Qt c #c5deff",
"#D c #c5e6ff",
"aQ c #cddae6",
"aB c #cddaee",
"a. c #cddef6",
"ai c #cddeff",
"ak c #cde2f6",
"al c #cde2ff",
"aX c #d5deee",
"aC c #d5e2f6",
"aj c #d5e2ff",
"aJ c #d5e6f6",
"aw c #d5e6ff",
"a2 c #dee6f6",
"aE c #dee6ff",
"aI c #deeaf6",
"aD c #deeaff",
"aV c #deeeff",
"aW c #e6eaff",
"aP c #e6eeff",
"a3 c #e6f2ff",
"a4 c #eef2ff",
"a6 c #eef6ff",
"a5 c #f6f6ff",
"a7 c #ffffff",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
".#.a.#.b.#.a.#.b.#.a.#.b.#.a.#.b.#.a.#.b.#.a.#.b.#",
".c.d.c.d.c.d.c.d.c.d.c.d.c.d.c.d.c.d.c.d.c.d.c.d.c",
".#.e.#.e.#.e.#.e.#.e.#.e.#.e.#.e.#.e.#.e.#.e.#.e.#",
".a.e.b.#.a.e.b.#.a.e.b.#.a.e.b.#.a.e.b.#.a.e.b.#.a",
".#.e.#.e.#.e.#.e.f.g.h.h.i.h.j.f.#.e.#.e.#.e.#.e.#",
".a.e.a.e.a.e.a.#.k.l.m.n.m.n.m.i.o.#.a.b.a.b.a.b.a",
".p.a.q.a.p.a.#.r.s.t.u.v.w.v.x.y.g.a.q.a.p.a.p.a.p",
".z.A.z.A.z.a.a.B.C.D.E.F.F.G.H.I.h.q.z.A.z.A.z.A.z",
".z.z.A.z.A.z.q.B.C.J.K.L.M.N.p.m.O.P.A.z.z.z.z.z.z",
".Q.R.S.R.Q.R.Q.T.U.V.W.X.X.Y.Z.0.1.2.Q.R.Q.R.S.R.Q",
".R.Q.R.3.4.T.5.6.7.8.9.X.X#..Z.m###a#a#b#c.2.R.Q.R",
"#d#e#f#g#h.U#h.y#i.D#j#k.q.R#l.I#i.U#m.U#n#a#f#e#d",
"#o#p#q#r.2#s.2#t#u#e#t.p.Z#u.Z#v#w#u#w#v#x#y#z#p#o",
"#A#B#C.i#D.9#p#E#F.2#G.Z.Z#l.q.A#e#e#e.R#H#I#C#A#A",
"#B#J#K.i#L#M#N#O#O#P#l#P#Q#P#M#P#O.f#O.Z#R#I#K#J#B",
"#S#J#T#U#A.Z#M#M.o#P#P#M#P#P#P#l.8#Q.Z#M.j#V#T#J#S",
"#S#S#W.i#X.J#l.Z#M#M#O#M#O#c#O.Z#M.Z#M.Z#R#Y#Z#S#S",
"#0#0#1#2#3#4#5.g#6#3#P#c#c#O#c#6#4#6#4#5#7#8#9#0#0",
"#0a.a#aaabacacadab.B#M#v#3#c#5aeabacadacafagahai#0",
"ajakala#amanaoapaq#6.J#3ar#v#5#Vasatao#Wauavalakal",
"akawakaja.a.axayaf.B#v#5#5#vazaAanaBaxa.akajakawaC",
"aDawaDawaDawaEaFaf.BaG#5#5#4#4aAaHaCaDawaDawaDawaD",
"aIaDaDaDaIaDaJaKafaL#4#5#6aM.BaNaOaJaDaDaIaDaDaDaI",
"aPaDaPaDaPaDaPaQanaR.h.iaSaTaSapaUaDaPaDaPaDaPaDaP",
"aVaPaVaPaVaPaVaWaXaYaZaZa0aZa1aQa2aPaVaPaVaPaVaPaP",
"a3aPa4aPa3aPa4aPa4aPa4aPa3aPa4aPa4aPa4aPa3aPa4aPa4",
"a3a4a3a4a3a4a3a4a3a4a3a4a3a4a3a4a3a4a3a4a3a4a3a4a3",
"a5a6a5a6a5a6a5a6a5a6a5a6a5a6a5a6a5a6a5a6a5a6a5a6a5",
"a7a7a7a7a7a7a7a7a7a7a7a7a7a7a7a7a7a7a7a7a7a7a7a7a7",
"a8a9a8a9a8a9a8a9a8a9a8a9a8a9a8a9a8a9a8a9a8a9a8a9a8"};

static const char* const img14_chat[] = { 
"25 31 283 2",
"cy c #0075ff",
"cx c #08aeff",
"ay c #41505a",
"#2 c #415062",
"be c #4a5562",
".E c #4a5973",
".Z c #4a5d73",
"bo c #525562",
"bD c #525962",
"cf c #525d62",
"#w c #525d73",
"#3 c #52697b",
"ah c #5a5062",
"bY c #5a5d62",
"cp c #5a616a",
".Y c #624c62",
"ax c #625062",
"aX c #625562",
"bg c #625962",
"bT c #625d62",
"cc c #625d6a",
"bE c #62717b",
".0 c #6275f6",
".o c #628db4",
".C c #6a5062",
"bd c #6a5962",
"cl c #6a5d62",
".N c #6a758b",
".v c #6a7d9c",
".p c #6a8dff",
".q c #6a91b4",
".n c #6a95ff",
"#1 c #73505a",
"bM c #735962",
"cd c #735d62",
".3 c #73758b",
"#k c #737594",
"cq c #73797b",
"#g c #7391b4",
"#x c #7399bd",
".G c #7399ff",
".M c #739dff",
".m c #73a1cd",
".f c #73aeff",
"b7 c #7b5d62",
"bS c #7b818b",
"b3 c #7b858b",
"bG c #7b8994",
"aj c #7b9dbd",
".s c #7baad5",
".k c #7bb2e6",
".l c #7be2ff",
"cb c #83858b",
"ch c #838d94",
"b9 c #838d9c",
"az c #839dff",
"#Q c #83aed5",
".b c #83b6e6",
".i c #83b6ff",
".J c #83bae6",
".I c #83baff",
"#j c #83deff",
".t c #83e6ff",
".g c #83eaff",
".d c #83eeff",
"#m c #8b616a",
"#r c #8b6573",
"cm c #8b919c",
"b0 c #8b99ac",
"aN c #8ba1bd",
"a5 c #8ba5bd",
"#O c #8bb6ff",
".L c #8bbae6",
".2 c #8bbaff",
"#i c #8bbeee",
".K c #8beeff",
"## c #944c5a",
".z c #94556a",
"bU c #945d62",
".X c #945d6a",
".A c #945d73",
"aE c #94616a",
"a1 c #94656a",
"bj c #946573",
"#9 c #94697b",
"aK c #946d73",
"bl c #94717b",
"#I c #947d8b",
"av c #948594",
"#o c #94899c",
"a7 c #94a5bd",
"bq c #94aaff",
"#y c #94beee",
"#5 c #94c2ee",
"#A c #94c2ff",
"ae c #9c4c62",
"bc c #9c5d62",
"a0 c #9c616a",
"bI c #9c656a",
".x c #9c6d83",
"ac c #9c8d9c",
"aW c #9c919c",
"#H c #9c99b4",
".9 c #9ca5bd",
"#P c #9cc2ee",
"#7 c #9cc6ff",
".7 c #a4505a",
"aw c #a4555a",
"#L c #a45962",
".P c #a4616a",
"bV c #a46973",
".T c #a46d7b",
"bK c #a4818b",
"bB c #a4858b",
"#W c #a4a5b4",
"cr c #a4aebd",
"bs c #a4b6cd",
"ak c #a4c6ee",
"a4 c #ac5562",
"#v c #ac5d62",
"#d c #ac6573",
"aq c #aca5b4",
"ab c #acaaff",
"#F c #acbacd",
"aM c #acceee",
"aA c #acceff",
"#T c #b4595a",
"aP c #b45962",
"an c #b45d5a",
"bm c #b45d62",
"bv c #b46162",
"aL c #b489cd",
"bX c #b4aeb4",
"aG c #b4aeff",
"aI c #b4b2c5",
"aR c #b4b6c5",
"cv c #b4bac5",
"cu c #b4baff",
"#V c #b4c2d5",
"bP c #b4c6ff",
"aZ c #b4d2ff",
"#M c #bd50cd",
"#t c #bd5d5a",
"af c #bd5d62",
"aD c #bd6162",
".5 c #bd656a",
".R c #bd6d73",
"bp c #bd8dcd",
"ai c #bd91de",
"ap c #bdbed5",
"ct c #bdc6cd",
"#X c #bdc6d5",
"#p c #bdc6de",
"a6 c #bdd6f6",
"bf c #bddaff",
"#J c #c5615a",
"#b c #c5656a",
"#C c #c56d7b",
"bN c #c591d5",
".D c #c591de",
"cj c #c595d5",
".F c #c5aaff",
"aS c #c5c2cd",
"b. c #c5c2d5",
"aT c #c5c6cd",
"aU c #c5c6d5",
"bx c #c5cad5",
"ar c #c5cede",
"c# c #c5d2de",
"bF c #c5daf6",
"br c #c5def6",
".a c #c5deff",
"#e c #cd4ccd",
".V c #cd757b",
"bi c #cd797b",
"a8 c #cd7d83",
"bH c #cd91d5",
"#f c #cdaeff",
"cw c #cdd6ff",
"aV c #cddae6",
"bR c #cddef6",
"b1 c #cde2f6",
"am c #d57d83",
"aO c #d58183",
"b4 c #d591d5",
"ck c #d595d5",
".w c #d595e6",
"#N c #d5b6ff",
"bJ c #d5ceff",
"by c #d5d6e6",
"ba c #d5e2ee",
"bQ c #d5e2f6",
"#Y c #d5e6ff",
"#q c #de61de",
"#R c #de71f6",
"bZ c #de7df6",
".r c #de9dff",
"bO c #deb2f6",
"cs c #dee6f6",
"at c #deeaf6",
"c. c #deeaff",
"cn c #deeeff",
"bt c #e675ee",
"co c #e67dee",
"cg c #e67df6",
"b8 c #e6b2f6",
".u c #e6d6ff",
".e c #e6e6ff",
"b# c #e6eeff",
"bz c #e6f2ff",
"ce c #ee5d6a",
"#n c #ee65de",
"bn c #ee8dcd",
"#8 c #eed6ff",
".H c #eee6ff",
".h c #eeeaff",
".j c #eeeeff",
"bA c #eef2ff",
"#U c #f661de",
".8 c #f699de",
"aY c #f6a1ff",
"aB c #f6d6ff",
"#4 c #f6deff",
"#h c #f6e6ff",
".c c #f6eeff",
"ad c #ff50cd",
"al c #ff596a",
"#0 c #ff5d62",
"bC c #ff5d6a",
"#s c #ff6162",
"#l c #ff616a",
"ao c #ff6173",
"a9 c #ff6573",
"aQ c #ff65de",
"#u c #ff696a",
"bw c #ff69de",
".Q c #ff6d7b",
".W c #ff6de6",
".S c #ff6dee",
".U c #ff717b",
"#S c #ff757b",
".O c #ff75f6",
"bu c #ff7983",
"#a c #ff89cd",
"au c #ff89ff",
"ag c #ff8dcd",
".y c #ff8dde",
"#Z c #ff8dff",
"a# c #ff91cd",
"bL c #ff91d5",
"bb c #ff91ff",
"b5 c #ff95d5",
".B c #ff95de",
"#K c #ff99cd",
"#D c #ff99d5",
"b6 c #ff99de",
"ca c #ff99ff",
".6 c #ff9dde",
"a3 c #ffa1e6",
"bW c #ffa1ff",
"bh c #ffa5e6",
"#B c #ffa5ee",
"#c c #ffaae6",
".4 c #ffaaf6",
"a. c #ffb2ee",
"bk c #ffb2ff",
"aC c #ffb6f6",
"aJ c #ffbaff",
"#. c #ffc2ff",
"aF c #ffcaff",
"b2 c #ffceff",
"aH c #ffd2ff",
"ci c #ffd6ff",
"#E c #ffdaff",
".# c #ffdeff",
"as c #ffe2ff",
"#G c #ffe6ff",
"aa c #ffeaff",
"a2 c #ffeeff",
".1 c #fff2ff",
"#z c #fff6ff",
"#6 c #fffaff",
"Qt c #ffffff",
"Qt.#Qt.aQt.#Qt.aQt.#Qt.aQt.#Qt.aQt.#Qt.aQt.#Qt.aQt",
".b.c.b.d.b.c.b.d.b.c.b.d.b.c.b.d.b.c.b.d.b.c.b.d.b",
".e.f.e.f.e.f.e.f.e.f.e.f.e.f.e.f.e.f.e.f.e.f.e.f.e",
".b.g.b.h.b.g.b.h.b.g.b.h.b.g.b.h.b.g.b.h.b.g.b.h.b",
".c.i.j.i.c.i.j.i.c.i.j.i.c.i.j.i.c.i.j.i.c.i.j.i.c",
".b.h.b.g.b.h.k.l.m.n.o.p.o.p.o.p.q.r.s.t.b.h.b.g.b",
".c.i.c.i.c.i.u.v.w.x.y.z.y.A.B.C.D.E.F.G.H.i.c.I.c",
".J.K.L.c.b.M.N.O.P.Q.R.S.T.U.V.W.X.Y.Z.0.q.t.b.c.J",
".1.2.1.2.u.3.4.5.6.7.8.9#.###a#b#c#d#e.Z#f#g#h.2.1",
"#i.1#i#j#k.O.5#l#m#n#oQt#p#q#r#s#t#u#v.Y#w.0#x.K#y",
"#z#A.1#g#B#C#D.X#E#F#E#GQt#H#z#I#a#J#K#L#M.Z#N#O#z",
"#P#z#Q#R.P#S#T#U#VQt#WQt#X#G#Y#Z###s#J#0#1#2#3#4#5",
"#6#7#8#9a.#sa##m#z#E.#aaQtabQtacadaeadafagahaiaj#6",
"akQtajalam#sanaoapQtaqQtarasatau#1auav#lawaxayazak",
"QtaAaB.XaCaDa#aE#6asaFaGaHaIQt#oaJ#YQtaK#aaxaLazQt",
"aMQtaN#laO#saPaQaR#6aS#zaT.1aUQtaVQtaW#lawaX#2aYaM",
"QtaZ#Ea0aC#0a#a1.1#EQta2QtasQta2QtaFa3a4a#aXaLa5Qt",
"a6Qta7#la8#s#va9b.Qtb#QtaSQtb#Qtbabbbc#0#Lbdbe.#a6",
"Qtbf.#bgbhbia#bj#6.1QtbkQt.1Qt.1QtblagbmbnbobpbqQt",
"brQtbsbta0bubvbwbxQtby.#bzQtbAQtbBbCbm#0bdbDbE#GbF",
"QtasQtbGbHbI.6a0.#.1QtbJQt.1QtbKbLbma#bMbNbDbObPQt",
"bQQtbRaabSbTbU#0bVbWbX.#bXasbB#0#v#0bMbYbDbZb0Qtb1",
"Qt#YQtaHb2b3b4bUb5a0b6bI#DbIb5#vb5b7bNbYb8b9#6asQt",
"atQtc.Qtc#cacbcccd#0bcbCbc#0bccebTbTcfcgch#6bQQtat",
"QtaaQtaaQtciaHb3cjbTckbTckclckbYcjbYb8cmQt#GQtaaQt",
"cnQtcnQtb#QtaVa2cbcobYcpbYcpbYcpcqcocrQtcsQtcnQtcn",
"Qta2Qta2Qta2QtaaQtct.1cu.1cv.1cu#zcwQta2Qta2Qta2Qt",
"bzQtbzQtbzQtbzQtbzQtbzQtbzQtbzQtbzQtbzQtbzQtbzQtbz",
"Qt#zQt#zQt#zQt#zQt#zQt#zQt#zQt#zQt#zQt#zQt#zQt#zQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"cxcycxcycxcycxcycxcycxcycxcycxcycxcycxcycxcycxcycx"};

static const char* const img15_chat[] = { 
"24 31 423 2",
"eK c #0276e7",
"el c #486279",
"dy c #4a6277",
"ee c #4b6780",
"er c #4c6379",
"es c #4e6e8a",
"dH c #506579",
"dZ c #52708c",
"db c #53687b",
"cC c #54677b",
"cx c #54687a",
"d7 c #546a7f",
"dq c #547089",
"c6 c #566e86",
"dP c #586e82",
"dp c #596d80",
"cW c #5a6e81",
"em c #5a7185",
"d6 c #5a7c9c",
"dI c #5c7d9a",
"bT c #5d6f80",
"cQ c #617385",
"ek c #6187ab",
"cd c #637b94",
"c5 c #66798a",
"c# c #677686",
"da c #6789a8",
"dO c #678db1",
"eA c #6790b6",
"eB c #6790b7",
"ez c #6891b8",
"cR c #6a88a5",
"eC c #6a94bb",
"dF c #6b7e8f",
"ey c #6b97bf",
"af c #6d7985",
"dz c #6e8193",
"dc c #6f8394",
"dS c #6f8395",
"dA c #708495",
"dR c #708496",
"cV c #7091b1",
"dx c #7097bb",
"eD c #709cc6",
"aj c #717e89",
"dT c #718597",
"eq c #71879b",
"et c #719ec8",
"dE c #728597",
"en c #72879b",
"#F c #737d87",
"ef c #739fc8",
"ex c #73a1cc",
"eI c #73ade3",
"d8 c #74889b",
"bA c #758492",
"dQ c #75899b",
"dB c #76899b",
"dD c #778a9c",
"ej c #78a8d5",
".X c #798087",
"#X c #798896",
"ce c #798a9a",
"do c #798b9c",
"dY c #798da0",
"dC c #7a8c9e",
"d0 c #7ba8d2",
"dU c #7c90a2",
"d5 c #7caad7",
"ew c #7caedd",
"az c #7d8993",
"ed c #7d92a6",
"dr c #7da6cc",
"dJ c #7eaad1",
"eu c #7eb1e0",
".L c #7f888f",
"bP c #7f8e9c",
"dG c #7f92a4",
"eE c #7fb2e1",
"#z c #808c98",
"dd c #8092a4",
"ei c #80b3e3",
"ev c #80b4e4",
"eF c #80b4e5",
"eG c #80b5e5",
"dn c #8194a5",
"eH c #81b4e5",
"eh c #81b5e5",
"cB c #82a5c8",
"eg c #82b4e2",
"#m c #838d94",
"cX c #8395a5",
"dw c #83b1dc",
"dN c #83b3df",
"d4 c #83b5e5",
"eJ c #83b6e6",
".4 c #848b93",
"cD c #8494a4",
"dV c #8498aa",
"d3 c #84b6e6",
"d2 c #84b7e6",
".D c #858e96",
"eo c #859bae",
"bQ c #85a2bc",
"#S c #868f98",
"aD c #86929d",
"ca c #86a5c4",
"c7 c #86add2",
"d1 c #86b6e4",
"d9 c #879bae",
"bx c #87a1ba",
"d# c #87b2da",
"dM c #87b8e6",
"dL c #87b9e6",
"c4 c #899bab",
"ep c #899fb3",
"dK c #89b8e3",
".w c #8a9197",
"#f c #8a95a0",
"bf c #8a98a5",
"be c #8aa5be",
"bz c #8aa7c3",
"cy c #8aafd1",
"dv c #8abae5",
"#e c #8b939a",
"b4 c #8b99a8",
"cw c #8b9cab",
"dt c #8bbae7",
"du c #8bbbe7",
"#. c #8c949b",
"b1 c #8c9ba9",
"bc c #8ca4bb",
"ds c #8cb9e4",
"## c #8d949b",
".9 c #8e959c",
"b2 c #8e9dac",
"bS c #8eaecf",
"d. c #8ebce7",
"#a c #8f969d",
"b3 c #8f9eac",
"cn c #8f9fae",
"cP c #8fa0af",
"de c #8fa1b3",
"aW c #8fa7be",
"cU c #8fb9e0",
"c9 c #8fbde8",
".C c #90969c",
"cS c #90bae0",
".v c #919aa2",
"aX c #919eaa",
"b5 c #92a1af",
"co c #92a2b1",
"#q c #939ba3",
"cm c #93a3b2",
"cY c #93a5b5",
"dm c #93a5b6",
"cc c #93b9dc",
"c8 c #93bfe7",
"#b c #949ba2",
"#T c #94a4b4",
"aU c #94aac1",
"#r c #959da5",
"bw c #95a3b0",
"cA c #95bfe6",
"cT c #95c0e9",
"#v c #969ea5",
"#u c #969ea6",
"#P c #969fa7",
"aT c #96a1ad",
"#y c #979fa7",
"cz c #97c2ea",
".8 c #989fa6",
"#s c #98a0a8",
"aC c #98afc6",
"#t c #99a1a8",
"#p c #9aa2aa",
"#M c #9aa3ab",
"#l c #9aa9b7",
"c3 c #9aacbc",
"e. c #9aaec1",
"#I c #9ba4ac",
"#L c #9ba4ad",
".3 c #9ba7b3",
"bK c #9baab7",
"bU c #9baab9",
"#O c #9ca5ad",
"dW c #9cb0c2",
"cb c #9cc4ea",
"#N c #9da6ae",
"b0 c #9dabba",
"cp c #9dadbc",
"cE c #9daebe",
"#K c #9ea7af",
"#J c #9ea7b0",
"bG c #9eacba",
"aA c #9eb5ca",
"bb c #9fabb7",
"#1 c #a0a9b3",
"#4 c #a0aab4",
".Y c #a0acb7",
"bJ c #a0afbc",
"cl c #a0b1c0",
"ac c #a1abb4",
"a. c #a1abb5",
"bI c #a1afbd",
"bR c #a2c7ec",
".M c #a3aab0",
"ab c #a3acb5",
"a# c #a3acb6",
"#3 c #a3adb6",
"bH c #a3b1be",
"df c #a3b5c6",
"#2 c #a4adb7",
"aa c #a4aeb7",
"am c #a4afb9",
"cf c #a4b4c3",
"cO c #a4b5c5",
"ai c #a4bcd2",
"aw c #a5b0ba",
"bL c #a5b4c1",
"#0 c #a6afb9",
"ao c #a7b2bc",
"dl c #a7b9cb",
"by c #a7cbed",
"an c #a8b3bd",
"c. c #a8b7c6",
".W c #a9b0b6",
"av c #a9b4be",
"#E c #a9bccd",
"#5 c #aab4be",
"cv c #aabaca",
"#c c #abb3b9",
"#Y c #abb5bf",
"aG c #abb6c1",
".x c #acb3b9",
"aR c #adb8c3",
"bd c #adcfee",
".R c #aeb5bb",
"#9 c #aeb8c2",
"aI c #aeb9c4",
"bp c #aebbc8",
"bq c #aebcc8",
"aH c #afbac5",
"bo c #afbdc9",
".k c #b0bbc5",
".l c #b0bbc6",
".K c #b0bcc8",
"bF c #b0becc",
"ag c #b0c5db",
".S c #b1b7bd",
".Q c #b2b9bf",
".j c #b2bdc7",
"a0 c #b2bfca",
"bl c #b2c0cc",
"bB c #b2c0cd",
"dg c #b2c5d6",
".E c #b3bfca",
"bk c #b3c1cd",
"e# c #b3c7db",
"aV c #b3d2ef",
".B c #b4b9bf",
".7 c #b4bbc2",
"a2 c #b4c0cc",
"bn c #b4c2cf",
"dk c #b4c7d8",
".m c #b5c0cb",
"aJ c #b5c1cc",
"b. c #b5c1cd",
"a1 c #b5c2cd",
"bm c #b5c2cf",
"cZ c #b5c7d7",
"dX c #b5c9db",
"#W c #b5cde3",
"#w c #b6bec6",
".i c #b6c2cd",
"a9 c #b6c2ce",
"b6 c #b6c6d4",
"ax c #b8c2cc",
"b# c #b8c5d0",
"br c #b8c5d2",
"bt c #b8c6d2",
"ap c #b9c4ce",
"bi c #b9c7d3",
"aB c #b9d5f1",
"bj c #bac7d4",
"cq c #bacbda",
"c2 c #bacbdb",
"dh c #bacdde",
".T c #bbc2c8",
"#6 c #bbc4ce",
"aQ c #bbc7d2",
"bs c #bbc8d5",
"dj c #bbcedf",
"a8 c #bcc8d4",
"di c #bccfe0",
".P c #bdc3c9",
"#8 c #bdc7d0",
"aF c #bdc8d3",
"a3 c #bdc9d5",
"bV c #bdccdb",
"#g c #bdcfdd",
"#A c #bdcfe2",
"ah c #bdd8f1",
"#Q c #bec7cf",
".n c #becad5",
"aZ c #becbd6",
"bu c #beccd8",
"bM c #becdda",
"ec c #bed2e5",
"au c #bfcad4",
"bE c #bfcedb",
"cF c #bfd0e0",
"Qt c #bfdbf6",
"bN c #c0cedc",
"ck c #c0d0df",
".y c #c1c8cd",
"al c #c1cbd5",
".h c #c1cdd9",
"bg c #c1cfdb",
"bZ c #c1cfde",
"bD c #c1d0dd",
"#7 c #c2cbd5",
"#U c #c2d7ec",
"#V c #c2dbf3",
".A c #c3c9cf",
".5 c #c3cad0",
"cg c #c3d3e2",
".z c #c4cacf",
"bh c #c4d1de",
"b9 c #c4d3e2",
"ea c #c4d9eb",
"bC c #c5d4e1",
"bX c #c5d5e3",
"cu c #c5d5e5",
"#k c #c5d8eb",
"#D c #c5dbf0",
"bO c #c6d5e2",
"#o c #c7cfd6",
"ae c #c7d1da",
"bY c #c7d6e4",
".2 c #c7d8e6",
"a7 c #c8d4e0",
"a6 c #c8d5e0",
".Z c #c8d7e5",
"b7 c #c8d8e6",
"cN c #c8d9e8",
"eb c #c8ddf0",
"a4 c #c9d5e1",
"aY c #c9d6e1",
"b8 c #c9d8e7",
"cK c #c9d9e9",
"#C c #c9dff4",
".N c #cad0d6",
"a5 c #cad6e1",
".U c #cbd1d7",
"bW c #cbdbe9",
"ci c #cbdbeb",
".O c #ccd2d8",
"#H c #ccd5dd",
".o c #ccd9e5",
"bv c #ccdae7",
"cs c #ccdcec",
"ak c #cdd8e2",
".J c #cddcea",
"cj c #cddeec",
"cr c #cddeed",
"cJ c #cddeee",
"c0 c #cddfef",
"#B c #cde1f4",
"ct c #cedeee",
"#d c #cfd7dd",
"aE c #cfdae5",
".g c #cfdce8",
"#j c #cfe2f6",
"ba c #d0dde8",
"ch c #d0e0ef",
"c1 c #d0e2f2",
"#h c #d0e3f2",
".V c #d1d7dd",
".6 c #d1d8df",
"ad c #d1dae4",
"aP c #d1dce7",
".F c #d1e0ec",
"#G c #d2dbe3",
"cL c #d2e2f2",
"cI c #d2e3f3",
"aK c #d3dfea",
".1 c #d3e5f5",
"#i c #d3e5f6",
"#Z c #d4dee8",
"cH c #d4e5f5",
".0 c #d4e6f6",
"aS c #d5e0ec",
"cG c #d5e6f6",
"cM c #d5e7f7",
"at c #d6e1eb",
"aO c #d6e2ec",
".u c #d6e4f1",
".I c #d6e6f5",
".p c #d8e6f2",
".H c #d8e8f7",
"ay c #d9e3ed",
"aq c #d9e4ee",
"aN c #d9e5ef",
"#x c #dae2ea",
"aM c #dae5f0",
".f c #dae8f4",
".G c #dae9f6",
"#n c #dbe4eb",
".r c #dbeaf7",
".t c #dbeaf8",
".s c #dceaf8",
".q c #ddebf8",
"#R c #dee7ef",
".e c #deecf9",
"as c #dfe9f3",
"aL c #dfeaf5",
".d c #dfecf9",
".c c #e1eef9",
".b c #e2eef9",
"ar c #e3eef8",
".a c #e6f0fa",
".# c #eaf3fb",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
".#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#",
".#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#",
".a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a",
".b.b.b.b.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c",
".d.d.d.d.e.e.f.g.h.i.j.k.k.k.l.m.n.o.p.q.e.e.e.e",
".r.r.s.s.t.u.n.v.w.x.y.z.z.A.y.B.C.D.E.F.G.r.r.r",
".H.H.H.I.J.K.L.M.N.O.P.Q.R.S.T.U.V.W.X.Y.Z.I.H.H",
".0.0.1.2.3.4.5.6.7.8.9#.#.###a#b#c#d.6#e#f#g#h#i",
"#j#j#k#l#m#n#o#p#q#r#s#t#t#t#t#u#q#v#w#x#y#z#A#B",
"#C#D#E#F#G#H#I#I#J#K#L#M#I#M#I#N#K#O#P#Q#R#S#T#U",
"#V#W#X#Y#Z#0#1#2#3#4#5#6#7#8#9a.a#aaabacadaeafag",
"ahaiajakalamananaoapaqararasatauavaoavawaxayazaA",
"aBaCaDaEaFaGaHaIaJaKaLaMaNaOaPaEaQaRaHaR.maSaTaU",
"aVaWaXaYaZa0a1a2a3a4a5a6a6a7aZa8a8a9b.a2b#babbbc",
"bdbebfbgbhbibjbibkblbmbnbnbkbobpbqbrbsbtbubvbwbx",
"bybzbAbBbCbDbEbDbFbGbHbHbHbIbJbKbLbMbDbNbObNbPbQ",
"bRbSbTbUbVbWbXbYbZb0b1b2b3b2b4b5b6b7bXb8b9c.c#ca",
"cbcccdcecfcgchcicjckclcmcncocpcqcrcsctcucvcwcxcy",
"czcAcBcCcDcEcFcGcHcGcIcJcKcscLcMcHcGcNcOcPcQcRcS",
"cTcTcUcVcWcXcYcZc0.1.0.0.0.0.0#ic1c2c3c4c5c6c7c8",
"c9c9d.d#dadbdcdddedfdgdhdidjdkdldmdndodpdqdrdsc9",
"dtdtdudvdwdxdydzdAdAdBdCdCdDdEdFdDdGdHdIdJdKdudu",
"dLdLdMdMdMdNdOdPdQdRdSdTdQdUdVdWdXdYdZd0d1dMdMdM",
"d2d2d2d2d3d4d5d6d7d8d9e.e#eaebecedeeefegd2d2d2d2",
"eheheheheheheiejekelemeneoepeqereseteueheheheheh",
"ehehehehehehehevewexeyezeAeBeCeDejeEeheheheheheh",
"eFeFeheheGeGeFeFeHeheheheheheheFeFeFeFeFeFeheheh",
"eIeIeIeIeIeIeIeIeIeIeIeIeIeIeIeIeIeIeIeIeIeIeIeI",
"eJeJeJeJeJeJeJeJeJeJeJeJeJeJeJeJeJeJeJeJeJeJeJeJ",
"eKeKeKeKeKeKeKeKeKeKeKeKeKeKeKeKeKeKeKeKeKeKeKeK"};

static const char* const img16_chat[] = { 
"25 31 229 2",
".# c #0075ee",
"Qt c #0879ee",
"bx c #416583",
"bD c #416983",
"bb c #4a6583",
"aQ c #4a6983",
"aG c #4a6d83",
"a8 c #4a6d8b",
"aW c #4a718b",
"bh c #4a7194",
"bC c #4a7594",
"bB c #4a7da4",
"a1 c #526d8b",
"ah c #527594",
"aL c #52819c",
"ac c #5a7d9c",
"#V c #5a89a4",
"av c #5a89ac",
"a0 c #5a8dac",
"aq c #627994",
"a7 c #62819c",
"#q c #62859c",
"bc c #6289a4",
"bj c #6289ac",
"bv c #628db4",
"#u c #6295b4",
"#1 c #629dc5",
"#T c #6a7d94",
"#N c #6a8194",
"#5 c #6a819c",
".6 c #6a859c",
"aK c #6a89ac",
"#. c #6a8dac",
"bA c #6a91bd",
"bu c #6a95bd",
"#Q c #6aa5cd",
"#G c #6aaede",
"#h c #73899c",
".Z c #7389a4",
"#2 c #738da4",
".F c #7391a4",
"bg c #7391bd",
"aV c #7395bd",
"bp c #7399c5",
".w c #739dbd",
"bF c #739dcd",
".3 c #73a1cd",
"#D c #73aad5",
"#6 c #73aede",
"bI c #73aee6",
"ap c #73b2de",
".Q c #7b95ac",
"au c #7b95b4",
"aR c #7b9dbd",
".E c #7ba1c5",
"bf c #7ba5d5",
".T c #7baacd",
"bo c #7baad5",
"bG c #7baade",
"aX c #7baecd",
"bE c #7baede",
"bw c #7bb2d5",
"#i c #7bb2de",
"bz c #7bb2e6",
"bH c #7bb2ee",
"aP c #7bb6de",
"#d c #7bb6e6",
"#M c #7bbaee",
"#e c #8391a4",
"#E c #8395ac",
"a2 c #83a1c5",
".P c #83a5c5",
"a6 c #83a5cd",
"bd c #83aed5",
"a9 c #83b2d5",
"bn c #83b2e6",
"bm c #83b6e6",
"by c #83b6ee",
"ba c #83bad5",
"bl c #83bae6",
"bs c #83baee",
"br c #83c2e6",
"aF c #83c2ee",
".S c #8ba1b4",
"ad c #8ba5c5",
"aH c #8ba5cd",
"ag c #8baacd",
"aJ c #8bb6de",
"a5 c #8bb6e6",
"bt c #8bb6ee",
".x c #8bbade",
"be c #8bbae6",
"bk c #8bbaee",
"a3 c #8bbeee",
"#W c #8bc6f6",
".2 c #94a1b4",
".v c #94a5bd",
"#U c #94b2cd",
"aS c #94bae6",
"at c #94bee6",
"a4 c #94beee",
".L c #94c2e6",
"aT c #94c2ee",
"bi c #94c6e6",
"#H c #94c6f6",
"#v c #94c6ff",
"aZ c #94caee",
".5 c #94caf6",
"#0 c #94caff",
"#p c #94ceff",
".K c #9caebd",
"#F c #9caec5",
"#P c #9cb2cd",
"ar c #9cbede",
".D c #9cc2de",
"aI c #9cc2ee",
"aU c #9cc2f6",
".Y c #9ccaee",
"#C c #9ccaff",
"#w c #9cceff",
"## c #9cd2ff",
"ao c #9cd6f6",
"ab c #9cd6ff",
"ai c #9cdaff",
".9 c #a4bacd",
"#4 c #a4c2e6",
"#3 c #a4c6e6",
"af c #a4c6ee",
"as c #a4c6f6",
"aD c #a4caee",
"an c #a4caf6",
"a# c #a4ceee",
"#S c #a4cef6",
"#B c #a4ceff",
"bq c #a4d2ee",
"#j c #a4d2ff",
"#R c #a4d6ff",
"ak c #a4daf6",
"#X c #a4daff",
".o c #acb6c5",
".m c #acbac5",
"#r c #acbacd",
"#t c #acbed5",
"#O c #accae6",
"ae c #accaf6",
".y c #acceee",
"aa c #acd2ff",
"#I c #acd6ff",
"#8 c #acdaf6",
"#J c #acdaff",
"#7 c #acdeff",
"aw c #ace2ff",
".n c #b4bac5",
".l c #b4becd",
".p c #b4c2cd",
".7 c #b4c2d5",
"aC c #b4c2e6",
"#g c #b4cade",
"aN c #b4caee",
"aM c #b4ceee",
"b. c #b4d2e6",
"#A c #b4d2f6",
"#o c #b4d2ff",
"#x c #b4d6ff",
"az c #b4daf6",
".U c #b4daff",
"aj c #b4deff",
"aO c #b4e6f6",
".k c #bdc2cd",
".R c #bdc6d5",
".q c #bdcad5",
"#n c #bdcae6",
"#Z c #bdcee6",
"am c #bdceee",
"#f c #bdd2e6",
"al c #bdd2ee",
"#Y c #bdd6ee",
".C c #bdd6f6",
"#k c #bddaff",
".O c #bddef6",
"#l c #bddeff",
"ay c #bde2ff",
"aE c #bde6ff",
".j c #c5d2de",
"#b c #c5d2ee",
"#K c #c5d6ee",
"#9 c #c5d6f6",
"#s c #c5daf6",
"#c c #c5deff",
"b# c #c5e2f6",
".z c #c5e2ff",
"ax c #c5e6ff",
"#z c #cdd2ee",
".G c #cdd6e6",
".J c #cdd6ee",
"aB c #cdd6f6",
".1 c #cddaee",
"aA c #cddaf6",
".8 c #cddef6",
"aY c #cde2f6",
".A c #cde2ff",
".B c #cde6ff",
"#m c #d5d6ee",
".r c #d5daee",
".i c #d5deee",
".X c #d5def6",
".u c #d5e2f6",
"a. c #d5e2ff",
".I c #d5e6f6",
".0 c #d5e6ff",
".4 c #d5eaff",
"#a c #dee2f6",
".s c #dee6f6",
"#L c #dee6ff",
".H c #deeaf6",
".t c #deeaff",
".g c #deeeff",
".N c #def2ff",
".W c #e6e6f6",
".V c #e6eaf6",
".h c #e6eaff",
".f c #e6eeff",
".d c #e6f2ff",
"#y c #eeeeff",
".e c #eef2ff",
".c c #eef6ff",
".b c #f6f6ff",
".M c #f6faff",
".a c #ffffff",
"Qt.#Qt.#Qt.#Qt.#Qt.#Qt.#Qt.#Qt.#Qt.#Qt.#Qt.#Qt.#Qt",
".a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a",
".b.c.b.c.b.c.b.c.b.c.b.c.b.c.b.c.b.c.b.c.b.c.b.c.b",
".d.e.d.e.d.e.d.e.d.e.d.e.d.e.d.e.d.e.d.e.d.e.d.e.d",
".e.f.e.f.e.f.d.f.e.f.e.f.e.f.d.f.e.f.e.f.e.f.d.f.e",
".f.f.g.f.g.h.i.j.k.l.m.n.o.n.m.p.q.r.s.f.f.f.g.f.g",
".f.t.f.t.u.q.v.w.x.y.z.A.B.z.C.D.E.F.o.G.t.t.f.t.f",
".H.t.I.J.K.w.L.B.f.b.e.b.e.b.b.M.N.O.P.Q.R.u.t.t.H",
".t.I.J.S.T.U.d.d.h.V.V.V.W.i.X.g.e.e.d.Y.Z.p.u.0.t",
".u.1.2.3.U.t.0.0.s.b.e.c.e.W.i.X.B.4.4.t.5.6.7.u.u",
".8.9#.##.A.A.B.A#a.e.b.e.e#a.W.r#b.z.A.A#c#d#e#f.A",
"#g#h#i#j#k#c#l#c.8.e.e.e.f.s.J#m#n.C#l#c#o#p#q#r#s",
"#t#u#v#w#x#k#l#k.8#y.e.d#y.h#a.X#z#A#l#x#B#C#D#E.C",
"#F#G#H#w#w#I#J.U#K#y.f.f.H#L.u#a#b#A#I#j#v#C#M#N#O",
"#P#Q#C#w#j#R#J#J#s.V.f.s#L.u#a#a#b#S#R#w#C#C#M#T#O",
"#U#V#W#j###R#X#J#Y.h.H#L.u.s.u.s#Z#S#R#j#0###1#2#3",
"#4#5#6#J#I#R#7#8#9.H.t.I#L.ua..u#ba##X#waaabacadae",
"afagahaiaj#Jak#8al.t.H.t.t.t.I.tamanao#I#7apaqaraf",
"asatauavawaxayazam.JaA.1aA#KaB#KaCaDayaEaFaGaHaIan",
"aIaIaJaKaLaoax.B#Y#Y#Y#9alalaMaMaN.zaOaPaQaRaSaIaT",
"aUaTaIaJaVaWaX#8.B.0.t.0.t.0.BaYaxaZa0a1a2aSaIaTaU",
"a3a4a4a4a5a6a7a8ava9.D#Ob..zb#axbabbbcbdbea4a3a4a4",
"a4a3a4a3a4bea5bfbgacaha8bhbi.0aEbjbja5bka4a3a4a3a4",
"blbkblbkblbkbebkbmbnbobpaQbq.ubraQbfbmbkblbkbebkbl",
"bkbsbkbsbkbsbkbsbkbsbtbubvawbwbxaVbnbkbybkbybkbybk",
"bmbybmbybmbybmbybmbybzbAbBbCbDbubEbybmbybmbybmbybm",
"bsbmbkbybsbmbkbybsbmbybE.3bFbGbnbybmbkbybsbmbkbybs",
"bmbybmbybmbybmbybmbybmbybmbybmbybmbybmbybmbybmbybm",
"bHbIbHbIbHbIbHbIbHbIbHbIbHbIbHbIbHbIbHbIbHbIbHbIbH",
"bmbkbmbsbmbkbmbsbmbkbmbsbmbkbmbsbmbkbmbsbmbkbmbsbm",
".0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0"};

static const char* const img17_chat[] = { 
"11 31 48 1",
"d c #0075e6",
"h c #0075ee",
"T c #0079ee",
"# c #0879ee",
"f c #73aee6",
"e c #7bb2ee",
"a c #83b6e6",
"g c #83b6ee",
"i c #83bae6",
"c c #83baee",
"j c #8bbae6",
"b c #8bbaee",
"l c #8bbeee",
"k c #94beee",
"n c #94c2ee",
"m c #9cc2ee",
"o c #9cc2f6",
"p c #9cc6ee",
"s c #a4c6ee",
"q c #a4c6f6",
"t c #a4caee",
"r c #a4caf6",
"v c #acceee",
"u c #accef6",
"w c #b4d2f6",
"y c #b4d6f6",
"x c #bdd6f6",
"z c #bddaf6",
"A c #c5daf6",
"B c #c5daff",
"C c #c5def6",
". c #c5deff",
"G c #cddef6",
"E c #cde2f6",
"D c #cde2ff",
"H c #d5e2f6",
"F c #d5e2ff",
"I c #d5e6ff",
"L c #d5eaf6",
"K c #deeaf6",
"J c #deeaff",
"N c #deeeff",
"M c #e6eeff",
"O c #e6f2ff",
"P c #eef2ff",
"R c #eef6ff",
"Q c #f6f6ff",
"S c #ffffff",
"..........#",
"abacabacabd",
"efefefefef#",
"agagagagagh",
"bgcabgcabg#",
"agagagagagd",
"bcbcbcbcbc#",
"ibjbibjbibh",
"klklklklkl#",
"lklklklkkkd",
"mnonmnonmn#",
"npmmnpmpnph",
"qprprpqpqp#",
"srsrsrtrtrd",
"uvuuuvuuuv#",
"vwvwvwvwvwh",
"xwxwxwxwxy#",
"xxxxxzxxxxd",
"AzBAAzBAAz#",
"ACA.ACA.ACh",
"DEDEFEDEDG#",
"HIEIEIEIHId",
"JIJIJIJIJI#",
"KJJJKJJJLJh",
"MJMJMJMJMJ#",
"NMNMNMNMMMd",
"OMPMOMPMPM#",
"OPOPOPOPOPh",
"QRQRQRQRQh#",
"SSSSSSSShTO",
"#h#h#h#h#OR"};

static const char* const img18_chat[] = { 
"127 19 32 1",
"B c #000000",
"l c #7b7d7b",
"v c #8b898b",
"s c #949194",
"y c #acaeb4",
"z c #acb2b4",
"A c #acb2bd",
"D c #b4b2bd",
"w c #b4b6bd",
"n c #c5c6c5",
"k c #cdcecd",
"f c #cdd2d5",
"t c #cdd2de",
"g c #d5d2d5",
"j c #d5d6d5",
"d c #d5deee",
"i c #ded6de",
"h c #dedade",
"c c #dee2f6",
"b c #dee6ee",
"a c #dee6f6",
"# c #e6e6f6",
"m c #e6f2ff",
"o c #eeeaee",
"e c #eef2ff",
". c #eef6ff",
"p c #f6f2f6",
"r c #f6f6f6",
"C c #f6f6ff",
"x c #fff6ff",
"u c #fffaff",
"q c #ffffff",
"....#a#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#bcd.",
".efghihjhihjhihjhihjhihjhihjhihjhihjhihjhihjhihjhihjhihjhihjhihjhihjhihjhihjhihjhihjhihjhihjhihjhihjhihjhihjhihjhihjhihjhihjklm",
".nopqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqrqs.",
"tgupqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqppve",
"wiqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpxv.",
"yhqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqppv.",
"ziqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpxv.",
"yiqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqppv.",
"AiqpqpBBBBBBqBBBBBqpqpBBBBqpqBBBBBqpqBBBBBBBBpqBBpqBBBBBqpqBBBBBqBBpqpBBBBqpBBqpBBqpBBBBBpqpqpqBBBBBqpBBqBBpqpqpqBBBBBqpqpqpxv.",
"yiqpqpqpBBqpqBBpqBBpqBBpqBBpBBqpqpqpBBqpBBqpBBqBBpBBqpqpqpBBqpqpqBBpqBBpqBBpBBBpBBqBBpqpqpqpqpBBqpqpqpBBqBBpqpqpBBqpqpqpqpqppv.",
"zjqpqpqpBBqpqBBBBBqpqBBBBBBpqBBBBpqpBBqpBBqpBBqBBpqBBBBpqpqBBBBpqBBpqBBpqBBpBBBBBBqBBBBBBpqpqpBBBBBBqpBBqBBpqpqpBBBBBBqpqpqpxvC",
"yiqpqpqpBBqpqBBpqBBpqBBpqBBpqpqpBBqpBBqpBBqpBBqBBpqpqpBBqpqpqpBBqBBpqBBpqBBpBBqBBBqBBpqpqpqpqpBBqpqpqpBBqBBpqpqpBBqpqpqpqpqppv.",
"DiqpqpqpBBqpqBBpqBBpqBBpqBBpBBBBBpqpBBqpBBqpBBqBBpBBBBBpqpBBBBBpqBBpqpBBBBqpBBqpBBqpBBBBBpqpqpBBqpqpqpBBqpBBBBBpqBBBBBqpqpqpxvC",
"yiqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqppv.",
"zjqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpxvC",
"yiqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqppv.",
"DiqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpxvC",
"yiqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqppv.",
"zjqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpqpxvC"};

static const char* const img19_chat[] = { 
"12 29 11 1",
"# c #a4aab4",
"a c #a4aeb4",
"h c #acaaac",
". c #acaebd",
"i c #b4b2b4",
"f c #d5d6d5",
"g c #e6e2e6",
"e c #f6f2f6",
"d c #fff6ff",
"b c #fffaff",
"c c #ffffff",
".#.a.a.a.a.a",
"bcbcbcbcbcbc",
"dcdcdcdcdcdc",
"ecececececec",
"ecececececec",
"ecececececec",
"ecececececec",
"ecececececec",
"ecececececec",
"ecececececec",
"ecececececec",
"ecececececec",
"ecececececec",
"ecececececec",
"ecececececec",
"ecececececec",
"ecececececec",
"ecececececec",
"ecececececec",
"ecececececec",
"ecececececec",
"ecececececec",
"ecececececec",
"ecececececec",
"ecececececec",
"ecececececec",
"ecececececec",
"fgfgfgfgfgfg",
"hihihihihihi"};

static const char* const img20_chat[] = { 
"4 29 27 1",
"c c #62656a",
". c #83858b",
"# c #949194",
"b c #9c999c",
"a c #acaaac",
"g c #bdbecd",
"h c #bdc2cd",
"k c #bdc6cd",
"j c #c5c2cd",
"l c #c5c6cd",
"m c #cdcede",
"y c #d5dade",
"o c #d5dae6",
"v c #dee2e6",
"w c #e6e2e6",
"r c #e6eaf6",
"s c #eeeaee",
"q c #eeeeff",
"u c #eef2ff",
"t c #eef6ff",
"i c #f6f2f6",
"n c #f6f6f6",
"p c #f6f6ff",
"x c #f6faff",
"d c #fff6ff",
"e c #fffaff",
"f c #ffffff",
".#ab",
"cdef",
"gfef",
"hfif",
"hfdf",
"hfif",
"hfdf",
"hfif",
"jfdf",
"hfif",
"kfdf",
"hfif",
"lfdf",
"hfif",
"kfdf",
"hfif",
"lfdf",
"hfif",
"lfdf",
"hfif",
"lfdf",
"hfif",
"lfdf",
"kfif",
"mfnf",
"opif",
"qrsn",
"tuvw",
"xxpy"};

static const char* const img21_chat[] = { 
"26 24 297 2",
".g c #007500",
".r c #007d00",
".J c #008900",
".1 c #009500",
"#h c #009d00",
"#g c #00a100",
"#z c #00aa00",
"#A c #00ae00",
"#U c #00b200",
"#T c #00b600",
"a# c #00be00",
"aa c #00c200",
"at c #00c600",
"as c #00ca00",
"au c #00ce00",
".f c #087d08",
".0 c #089d08",
"aK c #08d208",
".q c #108d10",
"#f c #10a510",
"av c #10be10",
"aL c #10d610",
"#y c #18b218",
"#S c #18ba18",
"aM c #18c218",
"ar c #18ce18",
".b c #207920",
"a. c #20c620",
"#q c #295d29",
"a3 c #29c629",
"aJ c #29d629",
".I c #31a531",
"a1 c #31d631",
"a0 c #31da31",
"a2 c #31de31",
".9 c #397541",
".Z c #39b239",
"#m c #414041",
"ci c #414052",
"#n c #414441",
"#e c #41ba41",
"#x c #41c241",
"#R c #41ca41",
"#9 c #41ce41",
"aq c #41d641",
"aZ c #41da41",
".G c #4a8d52",
".p c #4aa541",
"#B c #4aae4a",
".H c #4ab24a",
"#V c #4aba52",
"bh c #4aca4a",
"aI c #4ade4a",
"#o c #525052",
".s c #52a15a",
".S c #52ae52",
"#i c #52b65a",
"bf c #52e252",
"aS c #5a996a",
".K c #5aaa5a",
".2 c #5aae5a",
".X c #5abe5a",
"#d c #5ac25a",
"#Q c #5ace5a",
"ap c #5ada5a",
"#p c #62505a",
"cj c #626173",
".C c #628573",
"#J c #629d6a",
"aj c #62a573",
".h c #62ae62",
".Y c #62be62",
"#w c #62ca62",
"bx c #62ce62",
"#8 c #62d662",
"be c #62e262",
"bg c #62e662",
"cn c #6a6d7b",
".D c #6a8973",
".F c #6a897b",
".E c #6a8d7b",
"#2 c #6aa57b",
".c c #6aaa6a",
"bs c #6ab673",
"bt c #6abe6a",
".W c #6ac26a",
"ab c #6ac66a",
"aH c #6ae26a",
"co c #736d7b",
"ck c #737183",
"c. c #737583",
"ca c #737983",
".B c #738983",
"br c #73b273",
"bp c #73b673",
"bq c #73b67b",
"#7 c #73de73",
"cp c #7b7983",
"c# c #7b798b",
"cw c #7b7d83",
"cb c #7b818b",
"cq c #7b9d83",
"a8 c #7bae8b",
"bo c #7bb683",
".V c #7bc67b",
"cD c #7bce7b",
"#v c #7bd27b",
"#P c #7bda7b",
"ao c #7be27b",
"aG c #7be67b",
"cl c #838194",
"cc c #838594",
".5 c #838994",
"bX c #83a594",
"#c c #83d283",
"bd c #83ea83",
"bw c #83f283",
"ct c #8b8994",
"cm c #8b899c",
"cg c #8b8d94",
".6 c #8b8d9c",
".7 c #8b919c",
"b8 c #8b95a4",
"bP c #8bca8b",
".U c #8bce83",
".T c #8bce8b",
"an c #8be68b",
".M c #9491a4",
"b7 c #94959c",
"#l c #9499a4",
"b9 c #949dac",
"cr c #94aaa4",
".o c #94ba94",
"bD c #94be94",
"bN c #94be9c",
"a9 c #94d694",
"#O c #94de94",
"#6 c #94e694",
"aY c #94ee94",
".3 c #9c99ac",
"bH c #9c9da4",
".x c #9c9dac",
"ch c #9c9db4",
"bY c #9ca1ac",
".w c #9ca1b4",
"cd c #9ca5b4",
"bQ c #9cae9c",
"bU c #9cbea4",
"#b c #9cde9c",
"aF c #9cee9c",
".8 c #a499b4",
"cx c #a49dac",
"bR c #a4a1ac",
"cu c #a4a1b4",
"b6 c #a4a5b4",
"#Y c #a4a5bd",
".A c #a4aab4",
".y c #a4aabd",
"ce c #a4aac5",
"cf c #a4aebd",
"b4 c #a4c6ac",
".e c #a4caa4",
".R c #a4cab4",
"#. c #a4d6a4",
"#K c #a4daa4",
"ak c #a4dea4",
"bu c #a4eaa4",
"bv c #a4f2a4",
"bj c #acaab4",
".z c #acaabd",
"cG c #acaebd",
"cI c #acb2bd",
"ad c #acb2c5",
"ag c #acb6c5",
"ay c #acb6cd",
"#r c #acd6ac",
"#u c #ace6ac",
"#5 c #aceaac",
"aX c #aceea4",
"bc c #acf2ac",
"bF c #acf6ac",
"cF c #b4aeb4",
"cJ c #b4b2b4",
".v c #b4b2bd",
"cy c #b4b2c5",
"cH c #b4b6c5",
"aB c #b4b6cd",
"af c #b4bacd",
"aA c #b4becd",
"bT c #b4c2d5",
"bV c #b4d6b4",
"aw c #b4dabd",
"bW c #b4debd",
"aT c #b4e2b4",
"cE c #b4e2c5",
"#N c #b4e6b4",
"am c #b4eeb4",
"aE c #b4f2b4",
"aP c #bdbabd",
"aR c #bdbade",
"cM c #bdbebd",
"cK c #bdbec5",
"cs c #bdbede",
"aQ c #bdc2d5",
"ah c #bdc6d5",
"a5 c #bdc6de",
"bI c #bdcade",
"a4 c #bdd6bd",
"b5 c #bdd6cd",
"bG c #bddec5",
"#a c #bdeabd",
"bb c #bdf2bd",
"#F c #c5c2c5",
"cL c #c5c6c5",
".O c #c5c6d5",
"a6 c #c5cade",
"ae c #c5cede",
".4 c #c5cee6",
"bS c #c5d2e6",
"bi c #c5e2c5",
"aN c #c5e6c5",
"#M c #c5eec5",
"al c #c5f2c5",
"aW c #c5f6c5",
"bE c #c5fac5",
"cz c #cdc6de",
"#G c #cdcacd",
"ax c #cdcad5",
"cA c #cdcade",
"#H c #cdced5",
"cv c #cdcede",
"az c #cdcee6",
"a7 c #cdceee",
"bZ c #cdd2de",
"#Z c #cdd2e6",
"bn c #cdd6de",
"#D c #cdd6e6",
"#k c #cdd6ee",
".a c #cddacd",
"cC c #cddade",
"bl c #cddae6",
"#W c #cde2cd",
"#t c #cdeecd",
"#4 c #cdf2cd",
"ba c #cdf6cd",
"aD c #cdfacd",
"ac c #d5d2d5",
"cB c #d5d2e6",
"aC c #d5d6e6",
"bB c #d5d6ee",
"#E c #d5dae6",
".P c #d5daee",
"by c #d5deee",
".N c #d5def6",
"b3 c #d5e2e6",
"b1 c #d5e2ee",
"## c #d5f2d5",
"aV c #d5fad5",
"#I c #ded2de",
"#1 c #ded6ee",
"ai c #ded6f6",
"bC c #dedaee",
".l c #dedee6",
"bk c #dedeee",
"bA c #dedef6",
"#j c #dee2de",
"bL c #dee2ee",
"b2 c #dee2f6",
".L c #dee6de",
".i c #dee6e6",
"bK c #dee6ee",
"b0 c #dee6f6",
"b# c #defade",
".k c #e6dee6",
"#X c #e6e2e6",
"#0 c #e6e2f6",
"#C c #e6e6ee",
"bz c #e6e6f6",
"bm c #e6eaf6",
"#s c #e6f6ee",
"#3 c #e6fae6",
"bO c #e6ffe6",
".n c #eeeaee",
".m c #eeeaf6",
"aO c #eeeeee",
"bJ c #eeeef6",
".t c #eef2ee",
".Q c #eef2ff",
"b. c #eefae6",
"#L c #eefaee",
".j c #f6eef6",
".d c #f6f2f6",
"bM c #f6f2ff",
".# c #f6f6f6",
"aU c #f6fff6",
".u c #fffaff",
"Qt c #ffffff",
"Qt.#Qt.#Qt.#Qt.#Qt.#Qt.#Qt.#Qt.a.b.c.#.#Qt.#Qt.#Qt.#",
"Qt.dQt.dQt.dQt.dQt.dQt.dQt.dQt.e.f.g.h.iQt.dQt.dQt.d",
"Qt.j.j.k.j.l.j.k.j.k.m.l.m.l.n.o.p.q.r.s.t.dQt.dQt.d",
".u.v.w.x.w.y.y.z.A.B.C.D.D.E.F.G.H.I.J.J.K.LQt.dQt.d",
".u.M.N.O.P.Q.Q.u.R.S.T.U.V.W.X.H.Y.Z.0.1.1.2.t.dQt.d",
".#.3.4.y.5.6.7.8.9#.QtQt###a#b#c#d#e#f#g#g#h#i#jQt.d",
".d.x#k#l#m#n#o#p#q#rQt#s#t#u#b#v#w#x#y#z#A#z#z#B.t.d",
"#C.w#D#E#F#G#H#I#J#KQt#L#M#N#O#P#Q#R#S#T#U#T#U#T#V#W",
"#X#Y#Z#D#0.P#Z#1#2#KQt#3#4#5#6#7#8#9a.a#aaa#aaa#aaab",
"acadaeaeafagahaiajakQt#Lalamanaoapaqarasatasatauavaw",
"axayazaAaBaeaCaiajakQt#LaDaEaFaGaHaIaJaKaKaKaLaMaNaO",
"aPaQahaAae#DahaRaSaTQtaUaVaWaXaYaGaHaZa0a1a2a3a4Qt.d",
".va5a6a6#D#Daha7a8a9b.b#babbbcaFaFbdbebfbgbhbi.dQt.d",
"bja6a6bk#D#Dblbmbnbobpbqbrbqbsbtbubvbdbwbxa4Qt.dQt.d",
"bj.4aebybm#E.P#EbzbzbAbBbCbkbzbD#5bEbF#vbG.dQt.dQt.d",
"bH#kbIaebkbJbKbLbLbKbKbmbmbM#CbN#4bObPbQQt.dQt.dQt.d",
"bRbSadbT.4#Dbz#Cbmbm.mbmbmbL#EbUbVbWbXbRQt.dQt.dQt.d",
"bYbyaAbZ.PblblbybLbzbKb0b1b2bKb3b4b5.4bHQt.dQt.dQt.d",
"b6byby#EaCbnaCbZaC#DaC#E#E#EaCaC#EbCaCb7Qt.dQt.dQt.d",
"b8b9c.c#cacbcbcccacacac#c.cbcd.y#Ycecfcg.u.dQt.dQt.d",
"ch.6cicjckc#clcmckcnckcncocpafcfcqcrcsct.u.dQt.dQt.d",
"cucvcwcxcyczcAaCaxcAcvcAaxcB#0cCcDcEaib7Qt.dQt.dQt.d",
"cFcGcycGcy.vcy.vcHcycHcycHcycycGcIcH.McJQt.dQt.dQt.d",
".u#F#FcKcLcMcLcMcLcMcLcMcLcMcLcMcLaPacaOQt.dQt.dQt.d"};

static const char* const img22_chat[] = { 
"67 5 3 1",
"# c #000000",
"a c #f6f2f6",
". c #ffffff",
".####a.#####.a.a###a.a#####a.a.###.a.a.a#a.a#a.a#a.#.a.#.a.#.a.###.",
"#a.a.a.a.#.a.a.#.a.#.a.a#a.a.a#a.a#a.a.a#a.a##.a#a.#.a.#.a.#.a#a.a#",
".###.a.a.#.a.a.#####.a.a#a.a.a#a.a#a.a.a#a.a#a#a#a.#.a.#.a.#.a#a.a#",
".a.a#a.a.#.a.a.#.a.#.a.a#a.a.a#a.a#a.a.a#a.a#a.##a.a#a#a.a.#.a#a.a#",
"####.a.a.#.a.a.#.a.#.a.a#a.a.a.###.a.a.a#a.a#a.a#a.a.#.a.a.#.a.###."};

static const char* const img23_chat[] = { 
"5 29 26 1",
"# c #a4aeb4",
". c #acaebd",
"a c #acb2bd",
"v c #b4b2b4",
"w c #bdbebd",
"s c #c5c2c5",
"x c #c5c6c5",
"b c #c5cad5",
"q c #cdc6cd",
"m c #cdcacd",
"r c #ded6de",
"p c #dedade",
"i c #dedede",
"l c #e6dee6",
"o c #e6e2e6",
"c c #e6eaf6",
"g c #e6eeff",
"u c #eee6ee",
"t c #eeeeee",
"k c #f6f2f6",
"f c #f6f6f6",
"n c #f6f6ff",
"j c #f6faff",
"h c #fff6ff",
"d c #fffaff",
"e c #ffffff",
".#abc",
"defeg",
"hehij",
"kelmn",
"keomj",
"keimn",
"keomj",
"kelmn",
"keomd",
"keimj",
"keomj",
"kelmj",
"keomd",
"keimn",
"keomj",
"kelmj",
"keomd",
"keimj",
"keomd",
"kelmj",
"keomd",
"keimj",
"keomd",
"kepqj",
"kdrse",
"tksmj",
"upvoe",
"swxdj",
"vmnjj"};

static const char* const img24_chat[] = { 
"19 24 246 2",
"#w c #007500",
"#M c #008100",
"#2 c #008d00",
"#L c #009100",
"#1 c #009900",
"ae c #009d00",
"#0 c #00aa00",
"#Z c #00b200",
"ad c #00b600",
"aQ c #00ba00",
"#Y c #00c200",
"#X c #00ca00",
"ap c #00ce00",
"ac c #08ce08",
"aD c #189d20",
"#K c #18a518",
"#J c #18b218",
"#3 c #209129",
"af c #209929",
"aq c #209d20",
"aR c #20aa29",
"#I c #20be20",
"#H c #20ca20",
"ao c #20d618",
"#W c #20d620",
"#N c #299131",
"#v c #299929",
"#G c #29d629",
"ab c #29da29",
"#j c #319139",
"aC c #31a539",
"#x c #399141",
"aP c #39ae39",
"#F c #39da39",
"#h c #41a541",
".L c #4a9152",
"#u c #4ab24a",
"an c #4ab252",
"#t c #4aba4a",
"#r c #4aca4a",
"#q c #4ad64a",
"#p c #4ada4a",
"br c #525062",
"bF c #525562",
".y c #528152",
".r c #528952",
"a# c #52aa5a",
"#s c #52c652",
"aa c #52de52",
"#V c #52e252",
"bs c #5a5d6a",
".o c #5a895a",
"#i c #5aa55a",
"bx c #625d6a",
"bA c #62616a",
"by c #626173",
"bz c #626573",
".1 c #62ae62",
"bM c #62ba62",
"bt c #6a697b",
"bu c #6a6d83",
"#g c #6aca6a",
"#f c #6ace6a",
"#d c #6ade6a",
"#o c #6ae26a",
"#E c #6ae66a",
"bv c #73758b",
".D c #73a17b",
"#k c #73aa83",
"#T c #73ba73",
"#e c #73d673",
"#c c #73e673",
"bw c #7b798b",
"bg c #7b818b",
".0 c #7bce7b",
"#U c #7be67b",
"bT c #83818b",
"bB c #838194",
"b. c #83858b",
".5 c #838594",
"#l c #83859c",
"bL c #83be8b",
"#B c #83c28b",
"## c #83d28b",
"#b c #83ea83",
"bC c #8b8d9c",
"bp c #8b919c",
".p c #8ba58b",
".f c #8bb28b",
".c c #8bb68b",
".Y c #8bde8b",
".W c #8bea8b",
".P c #948d9c",
"bW c #949194",
"a5 c #94919c",
".B c #9491a4",
"#y c #9491ac",
"bY c #94959c",
".7 c #9495a4",
"a. c #9499ac",
"#P c #9499b4",
"#7 c #949dac",
"bq c #949db4",
".s c #94a594",
".e c #94ba94",
".d c #94be94",
"#n c #94bea4",
".T c #94ca9c",
".Z c #94da94",
".X c #94e694",
"#D c #94ee94",
"bX c #9c959c",
"bV c #9c999c",
".N c #9c99ac",
"aV c #9c9da4",
"#Q c #9c9dac",
".A c #9c9db4",
"#6 c #9ca1b4",
"bc c #9ca5b4",
".i c #9caa9c",
"a0 c #9cc69c",
".U c #9cea9c",
"#a c #9cee9c",
".C c #a499b4",
"bJ c #a49dac",
".M c #a49db4",
"bD c #a4a1ac",
"bU c #a4a5a4",
"aB c #a4a5b4",
"ay c #a4a5bd",
"ag c #a4aab4",
"am c #a4aabd",
"bn c #a4aeb4",
"be c #a4aebd",
"aj c #a4aec5",
".b c #a4c6a4",
".9 c #a4ceac",
"#. c #a4d6ac",
".V c #a4eea4",
"bG c #aca5bd",
"bb c #acaaac",
"bh c #acaab4",
"bH c #acaabd",
"aJ c #acaeb4",
"as c #acaebd",
"bm c #acb2bd",
"#9 c #acb2c5",
"aK c #acb2cd",
"ar c #acb6b4",
"aE c #acb6bd",
".R c #acb6c5",
".8 c #acc6c5",
".K c #ace2ac",
".j c #aceaac",
"#C c #aceeac",
"a6 c #b4b2b4",
"b# c #b4b2bd",
"aw c #b4b6b4",
"bo c #b4bac5",
"av c #b4bacd",
"bd c #b4becd",
"aI c #b4bed5",
".n c #b4e2b4",
".J c #b4e6b4",
".I c #b4eab4",
".H c #b4eeb4",
".G c #b4f2b4",
".E c #b4f6b4",
".O c #bdb6bd",
"bI c #bdb6cd",
"aW c #bdbac5",
"aO c #bdbacd",
".3 c #bdbecd",
"aA c #bdbed5",
"bl c #bdc2cd",
".S c #bdc2d5",
"#S c #bdc6d5",
"aU c #bdc6de",
"aL c #bdcade",
".F c #bdf6bd",
"ah c #c5becd",
"ak c #c5c2c5",
"at c #c5c2cd",
"bE c #c5c2d5",
"#8 c #c5c6de",
"ai c #c5cad5",
"al c #c5cade",
"aX c #c5cae6",
"#O c #c5ced5",
"#A c #c5cede",
"#R c #c5cee6",
"aN c #c5d2e6",
"bS c #c5dad5",
"aF c #cdc6de",
".z c #cdcacd",
"az c #cdcede",
"bK c #cdcee6",
"aM c #cdd2e6",
"a1 c #cdd6d5",
"bR c #cdd6de",
"au c #cdd6e6",
".Q c #cdd6ee",
"#4 c #cddade",
".x c #cdf2cd",
".v c #cdf6cd",
".t c #cdffcd",
"ax c #d5d2d5",
".2 c #d5d2de",
"bN c #d5d2e6",
"aG c #d5d6e6",
"aT c #d5dae6",
"bf c #d5daee",
"a9 c #d5dee6",
"aY c #d5deee",
".4 c #d5def6",
".l c #d5eed5",
".m c #d5f2d5",
".w c #d5f6d5",
"bZ c #ded6de",
".g c #dedade",
"bO c #dedae6",
"#5 c #dedaee",
"bQ c #dedaf6",
"aH c #dedeee",
"aS c #dee2ee",
"bi c #dee2f6",
"a2 c #dee6ee",
"bj c #dee6f6",
".k c #def2de",
".u c #defade",
"#z c #e6e2e6",
"bP c #e6e2ee",
"aZ c #e6e2f6",
"a4 c #e6e6f6",
"a7 c #e6eaf6",
"bk c #e6eef6",
".a c #eeeaee",
"a3 c #eeeaf6",
"a8 c #eeeef6",
".q c #eeffee",
"#m c #f6eef6",
".h c #f6f2f6",
"ba c #f6f2ff",
".# c #f6f6f6",
".6 c #fffaff",
"Qt c #ffffff",
"Qt.#Qt.#Qt.a.b.c.d.c.e.f.e.gQt.#Qt.#Qt",
"Qt.hQt.hQt.i.j.k.l.m.l.l.n.oQt.hQt.hQt",
"Qt.hQt.hQt.p.qQtQtQtQtQtQt.rQt.hQt.hQt",
"Qt.hQt.hQt.s.t.u.v.w.x.m.x.yQt.hQt.hQt",
"Qt.z.A.B.C.D.E.F.G.H.I.J.K.L.M.N.N.OQt",
"Qt.P.Q.R.S.T.U.V.W.X.Y.Z.0.1.2.3.4.5.6",
"Qt.7.8.9#.###a#b#c#d#e#f#g#h#i#j#k#l#m",
"Qt.N#n.w.t.E.W#o#p#q#r#s#t#u#v#w#x#y#z",
"Qt.N#A#B#C#D#E#F#G#H#I#J#K#L#M#N#O#P.g",
".6#Q#R#S#T#U#V#W#X#Y#Z#0#1#2#3#4#5#6.z",
".h#7#8#9a.a#aaabac#Yad#0aeafagahaiajak",
"#z#6alam#Qamanaoap#Y#Z#0aqarasatauavaw",
"axay#R.SazaAaBaCap#YadaDaEaFaGaGaHaIaJ",
"akaKaLaMaNaualaOaPaQaRaEaMaSaSaHaTaUaV",
"aWaIaXaSaYauaYaZaTa0a1aZa2aSa3a4aHala5",
"a6alaLaua7aSaTaYaYa4aSaSaSa8a8aHa9aMb.",
"b#aNalaLaua4a8a7a7a7a3a8baa7aHaTaT.Q.5",
"bbaubcbd#A#AauaHaHaSaSaSaTaTa9.Sbebfbg",
"bha7biaSbja2a4aSa4a2a7a7a7a7a8a7a3bk.B",
"aVblbeasbeasbeasbeasasbmbn.Rbobdbo#Sbp",
".7bqbrbsbtbubvbwbxbybybzbAbB#9#6#6#9bC",
"bDbEbFbw.BbGbHbIbJbHaBasaBaObKbLbMbNbC",
".OazaG.2bOaHaZbPaZbPaZaZaZaHbQbRbS#5bT",
".6bUbVa5bVbWbXbWbYbWbXbWbYbWbXa5bXbWbZ"};

static const char* const img25_chat[] = { 
"97 5 3 1",
"# c #000000",
". c #f6f2f6",
"a c #ffffff",
".####a.#####.a.a###a.a#####a.a.###.a.a.a####.a.a#a.a###a.a.a####.a####.a.#.a.a###a.a#a.a#a.a.####",
"#a.a.a.a.#.a.a.#.a.#.a.a#a.a.a#a.a#a.a.a#a.a#a.a#a.#.a.#.a.#.a.a.a.a.a#a.#.a.#.a.#.a##.a#a.a#a.a.",
".###.a.a.#.a.a.#####.a.a#a.a.a#a.a#a.a.a####.a.a#a.#.a.a.a.#####.a.####a.#.a.#.a.#.a#a#a#a.a#####",
".a.a#a.a.#.a.a.#.a.#.a.a#a.a.a#a.a#a.a.a#a.a#a.a#a.#.a.#.a.#.a.a.a#a.a.a.#.a.#.a.#.a#a.##a.a#a.a.",
"####.a.a.#.a.a.#.a.#.a.a#a.a.a.###.a.a.a#a.a#a.a#a.a###a.a.a####.a#####a.#.a.a###a.a#a.a#a.a.####"};

static const char* const img26_chat[] = { 
"13 12 108 2",
"#E c #73484a",
".F c #734c52",
".H c #735052",
".s c #7b555a",
".R c #7b6562",
"#v c #7b656a",
"#t c #834c52",
"#K c #837573",
".m c #83797b",
"#M c #8b484a",
"#D c #94484a",
"#i c #944c4a",
"#l c #944c52",
".2 c #94504a",
"#a c #945052",
"#O c #9c484a",
"#N c #9c4c4a",
"#J c #9c4c52",
".n c #9c595a",
".w c #9c8d94",
".3 c #9c9d9c",
".r c #a4595a",
".e c #a49da4",
".c c #a4a1a4",
"#H c #ac484a",
".Q c #ac4c4a",
"#F c #ac4c52",
".d c #aca5ac",
".f c #acaaac",
".t c #acaeac",
"#G c #b4484a",
"#b c #b45052",
".4 c #b4595a",
".x c #b46162",
".g c #b4aeb4",
"#j c #b4b2b4",
"#k c #b4b6b4",
"#m c #bd484a",
"#z c #bd4c4a",
"#I c #bd4c52",
".G c #bdb6bd",
"#L c #bdbabd",
"## c #c5504a",
"#h c #c5554a",
"#C c #c5615a",
".T c #c56562",
"#A c #c56962",
".b c #c5c2c5",
"#P c #c5c6c5",
"#c c #cd554a",
"#s c #cd615a",
"#w c #cd6d6a",
"#y c #cd716a",
".S c #cdcecd",
"#g c #d5554a",
".1 c #d5594a",
".7 c #d5695a",
"#f c #d56d62",
".o c #d56d6a",
"#p c #d57d7b",
"#n c #d58583",
"#d c #d59194",
".h c #d5d2d5",
".M c #de554a",
".6 c #de5952",
"#. c #de6152",
".I c #de6d62",
".9 c #de7162",
"#B c #dea1a4",
"#u c #ded6de",
".a c #dedade",
".5 c #e66152",
".E c #e6695a",
".V c #e67162",
".q c #e6756a",
"#x c #e6a5ac",
".l c #e6dee6",
".v c #e6e2e6",
".U c #ee695a",
".0 c #ee7162",
".J c #ee958b",
".N c #eea19c",
".Y c #eea5ac",
".i c #eeeaee",
".k c #eeeeee",
".C c #f6654a",
".z c #f66952",
".P c #f6715a",
".D c #f67162",
".L c #f67562",
".p c #f67d73",
"#o c #f6cacd",
".O c #f6d2d5",
".K c #f6d6de",
"#r c #f6dee6",
".u c #f6eef6",
"Qt c #f6f2f6",
".A c #ff654a",
".B c #ff694a",
".y c #ff7d73",
".Z c #ffd2d5",
".X c #ffdede",
".W c #ffe2e6",
"#q c #ffe6ee",
".8 c #ffeef6",
"#e c #fff6ff",
".# c #fffaff",
".j c #ffffff",
"Qt.#.a.b.c.d.e.f.g.h.i.jQt",
".k.l.m.n.o.p.q.p.r.s.tQt.u",
".v.w.x.y.z.A.B.C.D.E.F.G.i",
".b.H.I.J.K.L.M.N.O.P.Q.R.S",
".f.T.U.V.W.X.Y.#.Z.0.1.2.G",
".3.4.5.6.7.8.#.O.9#.###a.f",
".d#b.6#c#d#e#e.W#f#g#h#i#j",
"#k#l#m#n.##o#p#q#r#s.Q#t.b",
"#u#v.Q#w#x#y#z#A#B#C#D.w.v",
".i.b#E#F#G#b#H#I#H#J#K.l.k",
"QtQt#L.R#M#N#O#N#E.w.h.#Qt",
"Qt.j.i.v#k.g.e.G#P.u.k.jQt"};

static const char* const img27_chat[] = { 
"11 23 29 1",
"z c #0075e6",
"A c #0075ee",
"d c #0879ee",
"u c #1081ee",
"y c #2085ee",
"c c #298dee",
"b c #52a1f6",
"o c #5aa5f6",
"m c #62aaf6",
"l c #62aaff",
"s c #73b2ff",
"v c #83bef6",
"f c #83beff",
"a c #8bc2ff",
"g c #acceff",
"t c #acd2ff",
"w c #b4d6ff",
"n c #b4daff",
"k c #c5e2ff",
"p c #cddeff",
"# c #cde6ff",
"e c #d5e6ff",
". c #d5eaff",
"r c #deeaff",
"h c #e6eeff",
"x c #eeeeff",
"j c #eef2ff",
"q c #f6f2ff",
"i c #f6f6ff",
".#.#.#.abcd",
"#e#.#fdghij",
".#.klmiiiii",
"#enopiqijiq",
".#oriiiiiii",
"#stiqijiqij",
"#uiiiiiiiii",
"vwqijiqijiq",
"bxiiiiiiiii",
"yijiqijiqij",
"uiiiiiiiiii",
"ziqijiqijiq",
"diiiiiiiiii",
"Aijiqijiqij",
"diiiiiiiiii",
"ziqijiqijiq",
"diiiiiiiiii",
"Aijiqijiqij",
"diiiiiiiiii",
"ziqijiqijiq",
"diiiiiiiiii",
"Aijiqijiqij",
"diiiiiiiiii"};

static const char* const img28_chat[] = { 
"24 23 5 1",
"# c #0075ee",
". c #0879ee",
"c c #eef2ff",
"a c #f6f2ff",
"b c #f6f6ff",
".#.#.#.#.#.#.#.#.#.#.#.#",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"cbabcbabcbabcbabcbabcbab",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"cbabcbabcbabcbabcbabcbab",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"cbabcbabcbabcbabcbabcbab",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"cbabcbabcbabcbabcbabcbab",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"cbabcbabcbabcbabcbabcbab",
"bbbbbbbbbbbbbbbbbbbbbbbb",
"abcbabcbabcbabcbabcbabcb",
"bbbbbbbbbbbbbbbbbbbbbbbb"};

static const char* const img29_chat[] = { 
"11 23 31 1",
"C c #0075e6",
"B c #0075ee",
". c #0879ee",
"A c #087dee",
"v c #1081ee",
"z c #1885ee",
"# c #298dee",
"a c #4aa1f6",
"y c #52a1f6",
"p c #5aa5f6",
"s c #5aa5ff",
"k c #62aaf6",
"l c #62aaff",
"u c #73b6ff",
"j c #83beff",
"b c #8bc2ff",
"i c #acceff",
"t c #acd2ff",
"w c #b4d6ff",
"q c #b4daff",
"o c #cddeff",
"m c #cde2ff",
"d c #cde6ff",
"c c #d5e6ff",
"e c #d5eaff",
"r c #deeaff",
"h c #e6eeff",
"x c #eeeeff",
"n c #eef2ff",
"f c #f6f2ff",
"g c #f6f6ff",
".#abcdedede",
"fghi.jdcdcd",
"gggggklmede",
"ngfgngopqed",
"gggggggrsde",
"fgngfgngtud",
"gggggggggvd",
"ngfgngfgnwj",
"gggggggggxy",
"fgngfgngfgz",
"ggggggggggA",
"ngfgngfgngB",
"gggggggggg.",
"fgngfgngfgC",
"gggggggggg.",
"ngfgngfgngB",
"gggggggggg.",
"fgngfgngfgC",
"gggggggggg.",
"ngfgngfgngB",
"gggggggggg.",
"fgngfgngfgC",
"gggggggggg."};

static const char* const img30_chat[] = { 
"28 18 47 1",
"c c #5a9de6",
"b c #5aa1e6",
"a c #62a1e6",
"d c #62a5e6",
"h c #6aa5e6",
"f c #6aaae6",
"g c #6aaaee",
"# c #737173",
"i c #73aae6",
"e c #73aaee",
"k c #73aee6",
"j c #73aeee",
"n c #7bb2e6",
"l c #7bb2ee",
"m c #83b2ee",
"o c #83b6e6",
"q c #83b6ee",
"p c #83baee",
"r c #8bb6ee",
"s c #8bbaee",
"u c #8bbeee",
"v c #94beee",
"t c #94bef6",
"y c #94c2ee",
"w c #9cc2ee",
"x c #9cc2f6",
"z c #9cc6ee",
"A c #9cc6f6",
"C c #a4caee",
"B c #a4caf6",
"D c #accaf6",
"E c #acceee",
"G c #accef6",
"F c #b4d2f6",
"I c #bdd6f6",
"J c #bddaf6",
"H c #bddaff",
"K c #cde2f6",
"M c #cde2ff",
". c #d5d2d5",
"L c #d5e2ff",
"O c #deeeff",
"N c #e6eeff",
"P c #eef6ff",
"Q c #f6f6ff",
"S c #fffaff",
"R c #ffffff",
"............................",
"############################",
"ababababacababacacacababacab",
"adadadadadadadadadadadadadad",
"efghghghghghehgfghgfghghghgh",
"ijijijikijijijijijijijijijij",
"llmllnmllnmllnmllnmlllmllnml",
"opqpqpqroqqsqpqropqqqqqrqpqp",
"tuvutuvutuvutuvutvvutvvutuvu",
"wxyzwAyzyxyzwxyzyxywwAyzwAyz",
"BCDBBCDBBCDBBCDBBCDBBCDBDCDB",
"EFGFEFGFEFGFGFGFEFGFGFGFEFGF",
"HIJIHIHIHIHIHIHIHIJIHIHIHIJI",
"KLKLKLKMKLKMKLKLKLKMKLKLKLKL",
"NNNNNNNNNNNNNONNNNNNNNNNNNNN",
"PQPQPQPQPQPQPQPQPQPQPQPQPQPQ",
"RRRRRRRRRRRRRSRRRSRSRRRRRRRR",
"RRRRRRRRRRRRRRRRRRRRRRRRRRRR"};

static const char* const img31_chat[] = { 
"140 160 32 1",
". c #e6edf5",
"b c #e7eef5",
"h c #e8eef6",
"D c #e8eff6",
"r c #e9eff6",
"A c #eaf0f6",
"g c #eaf0f7",
"q c #ebf0f7",
"u c #ebf1f7",
"C c #ecf1f7",
"a c #ecf2f8",
"y c #edf2f8",
"f c #eef3f8",
"m c #eff4f9",
"d c #f0f4f9",
"e c #f1f5f9",
"t c #f2f5fa",
"B c #f2f6fa",
"# c #f3f6fa",
"c c #f3f7fa",
"o c #f4f7fb",
"n c #f6f8fb",
"l c #f7f9fc",
"w c #f8fafc",
"p c #f9fafc",
"v c #f9fbfd",
"i c #fafcfd",
"s c #fcfdfe",
"z c #fdfdfe",
"k c #fdfefe",
"x c #fefeff",
"j c #ffffff",
"............................................................................................................................................",
"............................................................................................................................................",
"............................................................................................................................................",
"............................................................................................................................................",
"............................................................................................................................................",
"............................................................................................................................................",
"............................................................................................................................................",
"............................................................................................................................................",
"..................................................................#a........................................................................",
"........................................................bcdeefgh..ijklmh....................................................................",
".......................................................haljjjjjjinojjjjjllpla...............................................................",
"...................................................ae##dffkjjjjjjjjjjjjjjjjjje..............................................................",
"................................................apjjjjjjjjjjjjjjjjjjjjjjjjjjjjn.............................................................",
"................................................hijjjjjjjjjjjjjjjjjjjjjjjjjjjjjiaaq.........................................................",
"..............................................rmlijjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjknq......................................................",
"............................................rnjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj#.....................................................",
"..........................................hojjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjje....................................................",
".........................................qsjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjm...................................................",
"........................................mkjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj#r....qh...........................................",
".......................................#jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjipnokt...........................................",
".....................................uvjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjw...........................................",
"...................................roxjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjq..........................................",
"..................................aijjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjih.........................................",
".................................dxjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjkq........................................",
".................................y#zjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjlb......................................",
"..................................Azjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjwh.....................................",
"...............................h#pjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjsq....................................",
"..............................fkjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj#...................................",
".............................fzjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjpr.................................",
".............................rgBxjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjkf................................",
"..............................ijjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjn...............................",
".............................beovjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjr..............................",
"...........................buaaaejjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjn..............................",
"..........................hCgDraijjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjkh.............................",
"..........................b...gljjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj#.............................",
".............................bcjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjkh............................",
".............................Bjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj#............................",
"............................yxjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjja...........................",
"............................vjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjl...........................",
"...........................DBzjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjh..........................",
"...........................b.sjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjf..........................",
"............................#jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjo..........................",
"...........................ejjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjp..........................",
"........................brgijjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjk..........................",
".........................ruvjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj..........................",
"...........................vjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj..........................",
"..........................gxjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj..........................",
".........................bdjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjh.........................",
".........................rnjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjja.........................",
".........................ulepjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjja.........................",
".........................rh.kjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjm.........................",
".........................b.qjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj#.........................",
"...........................ejjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjw.........................",
"...........................#jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjzb........................",
"...........................hijjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjr........................",
"............................hjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjf........................",
".............................jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjo........................",
".............................jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjvh.......................",
".............................jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjwCh......................",
".............................jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjAuar.....................",
".............................jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjp..bhb....................",
".............................sjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjo.........................",
".............................pjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjji.........................",
".............................pjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjja........................",
".............................#jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjl........................",
".............................qjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjksa.......................",
"..............................xjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjkha.......................",
".............................mjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj#........................",
".............................kjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjkjkh.......................",
"............................ajjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjpnjo.......................",
"............................ajjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjk.#jq......................",
"............................ajjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjr.mp......................",
"............................hjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj#ja..mf.....................",
".............................jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjp.ia.........................",
".............................pjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj#............................",
".............................ojjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjja............................",
".............................fjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjh............................",
".............................hjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj.............................",
"..............................njjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjq............................",
"..............................fjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjja............................",
"...............................sjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjja............................",
"...............................mjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjja............................",
"................................sjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjja............................",
"................................fjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjja............................",
".................................pjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjq............................",
".................................fjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjs.............................",
".................................ajjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj#.............................",
".................................ajjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjkh.............................",
".................................ajjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjkq..............................",
"..................................jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjkq...............................",
".................................ajjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjiq................................",
".................................ajjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjnh.................................",
"..................................jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjn...................................",
"..................................pjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj#...................................",
"..................................rsjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjv...................................",
"....................................#jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjr..................................",
"....................................rjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj#xp..................................",
".....................................sjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjk.tze.................................",
".....................................njjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjp..dvb................................",
".....................................mjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjl...qB................................",
".....................................rjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjo....b................................",
"......................................sjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjp.....................................",
"......................................njjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjji.....................................",
"......................................fjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj.....................................",
".......................................sjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjfah.....................................",
".......................................mjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjji........................................",
"........................................sjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjje........................................",
"........................................ajjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjr........................................",
".........................................ojjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjl.........................................",
".........................................hsjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjja.........................................",
"..........................................fjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjn..........................................",
"..........................................ajjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjl...........................................",
"..........................................ajjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjn...........................................",
"..........................................ajjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjp...........................................",
"..........................................ajjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjk...........................................",
"..........................................ajjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjh..........................................",
"..........................................ajjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjja..........................................",
"..........................................ajjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjf..........................................",
"..........................................ajjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj#..........................................",
"..........................................ajjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjo..........................................",
"..........................................#jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjp..........................................",
"..........................................#jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjp..........................................",
"..........................................#jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjji..........................................",
"..........................................#jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj..........................................",
"..........................................#jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj..........................................",
"..........................................#jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj..........................................",
"..........................................#jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj..........................................",
"..........................................#jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj..........................................",
"..........................................#jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjji..........................................",
"..........................................#jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjka.........................................",
"..........................................#jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjimh......................................",
"..........................................njjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjler...................................",
".........................................qkjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjieq................................",
"......................................hf#sjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjpp#fr..........................",
"..................................a#lsjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjkp#fr.....................",
".............................qenijjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjkp#fr................",
"........................rfopjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjkp#fr...........",
".................aa##ppjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjkp#fr......",
"........haf#opijjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjkp#fr.",
"..qf#pijjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjk",
"pjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj",
"jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj",
"jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj",
"jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj",
"jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj",
"jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj",
"jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj",
"jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj",
"jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj",
"jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj",
"jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj",
"jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj",
"jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj",
"jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj",
"jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj",
"jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj",
"jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj",
"jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj",
"jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj",
"jjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjjj"};

static const char* const img32_chat[] = { 
"11 18 53 1",
"g c #0075e6",
"b c #0075ee",
"R c #0079e6",
"Y c #0079ee",
". c #0879ee",
"t c #1881ee",
"x c #2989ee",
"S c #298dee",
"X c #3191ee",
"U c #3991ee",
"L c #5aa5f6",
"C c #62aaf6",
"# c #73aae6",
"d c #73aee6",
"a c #73aeee",
"e c #7baee6",
"c c #7bb2ee",
"O c #7bb6ff",
"f c #83b6ee",
"P c #83baff",
"h c #8bbaee",
"i c #8bbeee",
"Q c #8bbeff",
"l c #94beee",
"j c #94c2ee",
"N c #94c6ff",
"k c #9cc2f6",
"n c #9cc6ee",
"m c #a4c6f6",
"q c #a4caf6",
"G c #a4cef6",
"p c #accaf6",
"o c #accef6",
"W c #acd2f6",
"M c #acd2ff",
"s c #b4d2f6",
"V c #b4d6ff",
"r c #bddaf6",
"y c #bddaff",
"w c #c5daf6",
"v c #c5deff",
"u c #cde2ff",
"z c #d5e6f6",
"B c #d5e6ff",
"A c #deeaff",
"T c #deeeff",
"H c #e6f2ff",
"E c #eef2ff",
"F c #eef6ff",
"D c #f6f6ff",
"J c #f6faff",
"K c #fffaff",
"I c #ffffff",
".#a#a#a#a#a",
"bcdcecdcdcd",
".ffffffffff",
"ghhhhhhihhh",
".jklkjkjkjk",
"bmnmnmnmnmn",
".oopopoooqo",
"grsssssssss",
"tuvwvwvwvwv",
"xyzABAzABAz",
"CCDEFEDEFEF",
"G.HIJIJIJIK",
"IxLIIIIIIII",
"IMgNIIIIIII",
"IIO.PIIIIII",
"IIIQRSuIJJF",
"IIIITU.LVBI",
"IIIIIIWLXYg"};

static const char* const img33_chat[] = { 
"21 18 90 2",
"#x c #0276e7",
".a c #6ea9e3",
".c c #6eaae3",
"Qt c #6eaae4",
".# c #6faae3",
".b c #6faae4",
".e c #76aee5",
".g c #76afe5",
".d c #77aee5",
".f c #77afe5",
".m c #7fb3e6",
".j c #7fb3e7",
".n c #7fb4e6",
".i c #7fb4e7",
".h c #80b3e6",
".k c #80b3e7",
".l c #80b4e6",
".p c #88b9e8",
".o c #88b9e9",
".r c #88bae8",
".q c #88bae9",
".t c #89b9e8",
".u c #89b9e9",
".s c #89bae8",
".x c #91beea",
".z c #91bfea",
".y c #92beeb",
".v c #92bfea",
".w c #92bfeb",
".D c #9bc4ec",
".F c #9bc5ec",
".C c #9bc5ed",
".B c #9cc4ec",
".E c #9cc4ed",
".A c #9cc5ec",
".J c #a5caee",
".G c #a5cbee",
".H c #a6caee",
".I c #a6cbee",
".N c #afd0f0",
".M c #afd1f0",
".K c #b0d0f0",
".L c #b0d1f0",
".S c #bfd9f3",
".O c #bfdaf3",
".P c #c0d9f2",
".Q c #c0d9f3",
".R c #c0daf3",
".X c #d5e6f7",
".U c #d5e6f8",
".Y c #d5e7f7",
".T c #d5e7f8",
".V c #d6e6f7",
".Z c #d6e6f8",
".W c #d6e7f7",
".0 c #d6e7f8",
".1 c #e8f1fa",
".7 c #e8f1fb",
".5 c #e8f2fa",
".4 c #e8f2fb",
".2 c #e9f1fa",
".3 c #e9f1fb",
".6 c #e9f2fa",
".8 c #e9f2fb",
"#u c #ecf4fc",
"#w c #ecf5fb",
"#v c #ecf5fc",
"#s c #edf4fb",
"#q c #edf4fc",
"#r c #edf5fb",
"#t c #edf5fc",
"#c c #f6f9fd",
"#d c #f6f9fe",
".9 c #f6fafd",
"## c #f6fafe",
"#a c #f7f9fe",
"#. c #f7fafd",
"#b c #f7fafe",
"#o c #f8fafd",
"#n c #f8fafe",
"#m c #f8fbfd",
"#l c #f8fbfe",
"#p c #f9fbfe",
"#g c #fefefe",
"#e c #fefeff",
"#f c #fefffe",
"#h c #feffff",
"#j c #fffefe",
"#i c #fffeff",
"#k c #ffffff",
"QtQt.#.#Qt.a.aQt.#.#.bQt.c.a.a.c.c.a.a.#.#",
".d.e.f.f.e.e.e.e.f.f.e.e.f.g.d.e.e.e.f.e.g",
".h.i.j.j.i.i.i.i.j.k.l.l.j.j.i.i.j.m.i.m.n",
".o.p.o.o.p.p.q.q.r.s.t.p.o.u.p.p.p.p.o.p.t",
".v.v.v.w.w.v.v.v.v.v.x.x.v.v.w.w.v.y.v.v.z",
".A.B.A.A.B.C.C.B.B.A.A.B.B.A.D.D.B.E.B.F.D",
".G.H.I.I.H.I.I.H.I.I.G.J.I.I.H.G.G.I.I.H.H",
".K.K.K.L.L.L.K.K.L.L.L.M.N.K.L.L.L.L.L.K.K",
".O.P.Q.O.O.Q.Q.R.R.R.R.Q.Q.R.R.Q.Q.R.S.O.R",
".T.U.V.W.W.V.X.Y.W.W.V.W.W.X.T.Z.V.Y.W.0.V",
".1.2.3.4.5.6.7.7.7.3.2.8.7.1.4.4.7.6.4.4.5",
".9.9#..9###a.9.9#a#b#####c#d##.9.9##.9.9.9",
"#e#e#f#f#e#g#h#e#g#h#h#e#e#h#e#e#e#h#f#e#e",
"#h#e#e#h#h#i#i#h#h#h#h#g#j#i#e#e#e#k#h#e#h",
"#l#m#m#m#m#l#n#n#l#n#o#l#l#m#l#o#o#m#m#p#l",
"#q#r#s#r#q#t#s#u#v#t#q#q#s#q#u#w#r#q#r#s#t",
"#k#k#k#k#k#k#k#k#k#k#k#k#k#k#k#k#k#k#k#k#k",
"#x#x#x#x#x#x#x#x#x#x#x#x#x#x#x#x#x#x#x#x#x"};

static const char* const img34_chat[] = { 
"11 18 51 1",
"d c #0075e6",
"g c #0075ee",
"M c #0079ee",
"a c #0879ee",
"T c #087dee",
"u c #107dee",
"K c #2085ee",
"z c #2089ee",
"R c #3191ee",
"V c #52a1f6",
"E c #5aa5f6",
"J c #62aaf6",
"D c #62aef6",
"# c #73aae6",
"b c #73aee6",
". c #73aeee",
"P c #73b6f6",
"c c #7bb2ee",
"e c #83b6ee",
"O c #83beff",
"f c #8bbaee",
"j c #94beee",
"i c #94c2ee",
"L c #94c6ff",
"h c #9cc2f6",
"k c #9cc6ee",
"m c #9cc6f6",
"l c #a4c6f6",
"I c #a4caf6",
"N c #a4ceff",
"o c #accaf6",
"n c #accef6",
"W c #acceff",
"p c #b4d2f6",
"S c #b4d6ff",
"q c #bddaf6",
"y c #bddaff",
"s c #c5daf6",
"r c #c5deff",
"t c #cde2ff",
"Q c #cde6ff",
"x c #d5e6f6",
"v c #d5e6ff",
"U c #d5eaff",
"w c #deeaff",
"B c #eef2ff",
"A c #eef6ff",
"C c #f6f6ff",
"F c #f6faff",
"H c #fffaff",
"G c #ffffff",
".#.#.#.#.#a",
"bcbcbcbcbcd",
"eeeeeeeeeea",
"ffffffffffg",
"hihihjhihja",
"klklklkmkld",
"nnnnnononna",
"pppppppppqg",
"rsrsrsrsrtu",
"vwvwvwxwvyz",
"ABABABABCDE",
"FGFHFGFGBuI",
"GGGGGGGGJKG",
"GGGGGGGLMNG",
"GGGGGGOaPGG",
"AFFGQRMOHGG",
"GvSETRUGGGG",
"gMRVWGGGGGG"};

static const char* const img35_chat[] = { 
"11 18 99 2",
".f c #0276e7",
".y c #0578e7",
".j c #0678e7",
".q c #0779e7",
".M c #0879e8",
".5 c #117ee8",
".J c #2589ea",
".0 c #288beb",
".r c #2a8beb",
".e c #3391ec",
".i c #3692ec",
".k c #56a3ef",
".d c #57a4ef",
".K c #58a4ef",
".R c #5ba6ef",
".S c #5ea8ef",
"#C c #6ea9e3",
"#F c #6eaae3",
"#E c #6eaae4",
"#D c #6faae3",
"#G c #6faae4",
".x c #72b3f2",
"#y c #76aee5",
"#B c #76afe5",
"#A c #77aee5",
"#z c #77afe5",
".z c #7db8f3",
"#x c #7fb3e6",
"#u c #7fb3e7",
"#w c #7fb4e6",
"#s c #7fb4e7",
"#v c #80b3e7",
"#t c #80b4e6",
".p c #83bcf3",
"#p c #88b9e8",
"#r c #88b9e9",
"#q c #88bae9",
"#o c #89b9e9",
".G c #8ec3f4",
"#n c #91bfea",
"#m c #92beea",
"#l c #92bfea",
"#k c #92bfeb",
"#j c #9bc4ec",
"#f c #9bc5ec",
"#g c #9cc4ec",
"#h c #9cc5ec",
"#i c #9cc5ed",
"#c c #a5caee",
"#e c #a5cbee",
".L c #a5cef7",
"#d c #a6caee",
"#b c #a6cbee",
".F c #a7d0f7",
".l c #a9d1f7",
".c c #aad1f7",
"#a c #abceef",
"## c #b0d0f0",
"#. c #b0d1f0",
".1 c #b6d7f7",
".9 c #bad6f2",
".8 c #bfdaf3",
".7 c #c0daf3",
".6 c #c8e0f6",
".s c #cbe3fa",
".m c #cde4fa",
".3 c #d5e7f7",
".2 c #d6e6f7",
".4 c #d6e7f7",
".h c #d6e9fb",
".N c #e4f1fc",
".V c #e8f1fa",
".Y c #e8f1fb",
".U c #e8f2fa",
".Z c #e8f2fb",
".W c #e9f1fa",
".X c #e9f1fb",
".T c #ecf4fb",
".w c #edf4fc",
".v c #f1f6fc",
".u c #f3f8fc",
".P c #f6fafd",
".O c #f6fafe",
".Q c #f7fafd",
".I c #f7fbfe",
".D c #f8fbfd",
".C c #f8fbfe",
".E c #f9fbfd",
".t c #f9fbfe",
".B c #f9fcfd",
".b c #f9fdff",
".A c #fafcff",
".o c #fbfdff",
"Qt c #fdfeff",
".g c #fdffff",
".H c #fefefe",
".# c #fefeff",
".a c #feffff",
".n c #ffffff",
"Qt.#.#.#.a.b.c.d.e.f.f",
".aQt.a.g.h.i.j.k.l.m.n",
".#.#.o.p.q.r.s.t.u.v.w",
"Qt.g.x.y.z.A.B.C.D.t.E",
"Qt.F.f.G.n.#.#.a.H.a.#",
".I.J.K.#.g.#.#.a.a.#.a",
".L.M.N.O.P.O.O.P.P.O.Q",
".R.S.T.U.V.W.X.Y.W.Y.Z",
".0.1.2.3.2.2.4.2.3.2.2",
".5.6.7.8.8.7.8.7.7.7.7",
".f.9#.#####.###.#.####",
".f#a#b#c#d#d#d#e#d#c#b",
".f#f#g#h#h#i#j#g#g#h#h",
".f#k#l#m#l#n#m#l#l#l#k",
".f#o#o#o#p#o#p#q#r#r#p",
".f#s#t#u#s#s#v#s#w#x#w",
".f#y#y#z#A#B#B#A#y#A#z",
".f#C#D#E#E#F#E#D#G#F#D"};

static const char* const img36_chat[] = { 
"21 18 90 2",
"Qt c #0276e7",
"#v c #6ea9e3",
"#x c #6eaae3",
"#t c #6eaae4",
"#u c #6faae3",
"#w c #6faae4",
"#q c #76aee5",
"#s c #76afe5",
"#p c #77aee5",
"#r c #77afe5",
"#n c #7fb3e6",
"#k c #7fb3e7",
"#o c #7fb4e6",
"#j c #7fb4e7",
"#i c #80b3e6",
"#l c #80b3e7",
"#m c #80b4e6",
"#c c #88b9e8",
"#b c #88b9e9",
"#e c #88bae8",
"#d c #88bae9",
"#g c #89b9e8",
"#h c #89b9e9",
"#f c #89bae8",
"#. c #91beea",
"#a c #91bfea",
"## c #92beeb",
".8 c #92bfea",
".9 c #92bfeb",
".5 c #9bc4ec",
".7 c #9bc5ec",
".4 c #9bc5ed",
".3 c #9cc4ec",
".6 c #9cc4ed",
".2 c #9cc5ec",
".1 c #a5caee",
".Y c #a5cbee",
".Z c #a6caee",
".0 c #a6cbee",
".X c #afd0f0",
".W c #afd1f0",
".U c #b0d0f0",
".V c #b0d1f0",
".T c #bfd9f3",
".P c #bfdaf3",
".Q c #c0d9f2",
".R c #c0d9f3",
".S c #c0daf3",
".L c #d5e6f7",
".I c #d5e6f8",
".M c #d5e7f7",
".H c #d5e7f8",
".J c #d6e6f7",
".N c #d6e6f8",
".K c #d6e7f7",
".O c #d6e7f8",
".z c #e8f1fa",
".F c #e8f1fb",
".D c #e8f2fa",
".C c #e8f2fb",
".A c #e9f1fa",
".B c #e9f1fb",
".E c #e9f2fa",
".G c #e9f2fb",
".e c #ecf4fc",
".g c #ecf5fb",
".f c #ecf5fc",
".c c #edf4fb",
".a c #edf4fc",
".b c #edf5fb",
".d c #edf5fc",
".x c #f6f9fd",
".y c #f6f9fe",
".s c #f6fafd",
".u c #f6fafe",
".v c #f7f9fe",
".t c #f7fafd",
".w c #f7fafe",
".k c #f8fafd",
".j c #f8fafe",
".i c #f8fbfd",
".h c #f8fbfe",
".l c #f9fbfe",
".p c #fefefe",
".n c #fefeff",
".r c #fefffe",
".m c #feffff",
".q c #fffefe",
".o c #fffeff",
".# c #ffffff",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
".#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#",
".a.b.c.b.a.d.c.e.f.d.a.a.c.a.e.g.b.a.b.c.d",
".h.i.i.i.i.h.j.j.h.j.k.h.h.i.h.k.k.i.i.l.h",
".m.n.n.m.m.o.o.m.m.m.m.p.q.o.n.n.n.#.m.n.m",
".n.n.r.r.n.p.m.n.p.m.m.n.n.m.n.n.n.m.r.n.n",
".s.s.t.s.u.v.s.s.v.w.u.u.x.y.u.s.s.u.s.s.s",
".z.A.B.C.D.E.F.F.F.B.A.G.F.z.C.C.F.E.C.C.D",
".H.I.J.K.K.J.L.M.K.K.J.K.K.L.H.N.J.M.K.O.J",
".P.Q.R.P.P.R.R.S.S.S.S.R.R.S.S.R.R.S.T.P.S",
".U.U.U.V.V.V.U.U.V.V.V.W.X.U.V.V.V.V.V.U.U",
".Y.Z.0.0.Z.0.0.Z.0.0.Y.1.0.0.Z.Y.Y.0.0.Z.Z",
".2.3.2.2.3.4.4.3.3.2.2.3.3.2.5.5.3.6.3.7.5",
".8.8.8.9.9.8.8.8.8.8#.#..8.8.9.9.8##.8.8#a",
"#b#c#b#b#c#c#d#d#e#f#g#c#b#h#c#c#c#c#b#c#g",
"#i#j#k#k#j#j#j#j#k#l#m#m#k#k#j#j#k#n#j#n#o",
"#p#q#r#r#q#q#q#q#r#r#q#q#r#s#p#q#q#q#r#q#s",
"#t#t#u#u#t#v#v#t#u#u#w#t#x#v#v#x#x#v#v#u#u"};

static const char* const img37_chat[] = { 
"11 18 99 2",
"Qt c #0276e7",
".D c #0578e7",
".k c #0678e7",
".u c #0779e7",
".P c #0879e8",
".8 c #117ee8",
".J c #2589ea",
".4 c #288beb",
".t c #2a8beb",
".# c #3391ec",
".l c #3692ec",
".j c #56a3ef",
".a c #57a4ef",
".I c #58a4ef",
".Z c #5ba6ef",
".Y c #5ea8ef",
"#G c #6ea9e3",
"#D c #6eaae3",
"#F c #6eaae4",
"#C c #6faae3",
"#E c #6faae4",
".E c #72b3f2",
"#A c #76aee5",
"#B c #76afe5",
"#z c #77aee5",
"#y c #77afe5",
".C c #7db8f3",
"#t c #7fb3e6",
"#w c #7fb3e7",
"#s c #7fb4e6",
"#u c #7fb4e7",
"#v c #80b3e7",
"#x c #80b4e6",
".v c #83bcf3",
"#o c #88b9e8",
"#p c #88b9e9",
"#q c #88bae9",
"#r c #89b9e9",
".G c #8ec3f4",
"#n c #91bfea",
"#m c #92beea",
"#l c #92bfea",
"#k c #92bfeb",
"#h c #9bc4ec",
"#j c #9bc5ec",
"#g c #9cc4ec",
"#f c #9cc5ec",
"#i c #9cc5ed",
"#b c #a5caee",
"#d c #a5cbee",
".Q c #a5cef7",
"#c c #a6caee",
"#a c #a6cbee",
".H c #a7d0f7",
".i c #a9d1f7",
".b c #aad1f7",
"#e c #abceef",
".9 c #b0d0f0",
"#. c #b0d1f0",
".3 c #b6d7f7",
"## c #bad6f2",
".6 c #bfdaf3",
".5 c #c0daf3",
".7 c #c8e0f6",
".s c #cbe3fa",
".h c #cde4fa",
".1 c #d5e7f7",
".0 c #d6e6f7",
".2 c #d6e7f7",
".m c #d6e9fb",
".O c #e4f1fc",
".V c #e8f1fa",
".S c #e8f1fb",
".W c #e8f2fa",
".R c #e8f2fb",
".T c #e9f1fa",
".U c #e9f1fb",
".X c #ecf4fb",
".o c #edf4fc",
".p c #f1f6fc",
".q c #f3f8fc",
".N c #f6fafd",
".M c #f6fafe",
".L c #f7fafd",
".K c #f7fbfe",
".y c #f8fbfd",
".z c #f8fbfe",
".x c #f9fbfd",
".r c #f9fbfe",
".A c #f9fcfd",
".c c #f9fdff",
".B c #fafcff",
".w c #fbfdff",
".f c #fdfeff",
".n c #fdffff",
".F c #fefefe",
".e c #fefeff",
".d c #feffff",
".g c #ffffff",
"QtQt.#.a.b.c.d.e.e.e.f",
".g.h.i.j.k.l.m.n.d.f.d",
".o.p.q.r.s.t.u.v.w.e.e",
".x.r.y.z.A.B.C.D.E.n.f",
".e.d.F.d.e.e.g.GQt.H.f",
".d.e.d.d.e.e.n.e.I.J.K",
".L.M.N.N.M.M.N.M.O.P.Q",
".R.S.T.S.U.T.V.W.X.Y.Z",
".0.0.1.0.2.0.0.1.0.3.4",
".5.5.5.5.6.5.6.6.5.7.8",
".9.9#.#..9#..9.9#.##Qt",
"#a#b#c#d#c#c#c#b#a#eQt",
"#f#f#g#g#h#i#f#f#g#jQt",
"#k#l#l#l#m#n#l#m#l#kQt",
"#o#p#p#q#o#r#o#r#r#rQt",
"#s#t#s#u#v#u#u#w#x#uQt",
"#y#z#A#z#B#B#z#y#A#AQt",
"#C#D#E#C#F#D#F#F#C#GQt"};

static const char* const img38_chat[] = { 
"6 32 52 1",
"b c #0075e6",
"d c #0075ee",
"c c #0079ee",
"e c #0879ee",
"U c #73aee6",
"T c #7baeee",
"Q c #83b6e6",
"R c #83b6ee",
"S c #83baee",
"O c #8bbae6",
"N c #8bbaee",
"P c #8bbeee",
"M c #94beee",
"L c #94c2ee",
"W c #94c2f6",
"J c #9cc2ee",
"H c #9cc6ee",
"K c #9cc6f6",
"G c #a4c6ee",
"I c #a4c6f6",
"E c #a4caee",
"C c #a4ceee",
"F c #accaf6",
"D c #acceee",
"A c #accef6",
"V c #acd2f6",
"B c #b4cef6",
"y c #b4d2ee",
"x c #b4d2f6",
"z c #b4d6f6",
"v c #bdd6f6",
"u c #bddaf6",
"t c #c5daf6",
"w c #c5daff",
"r c #c5def6",
"X c #c5deff",
"q c #cddef6",
"s c #cddeff",
"p c #cde2ff",
"o c #d5e2f6",
"n c #d5e2ff",
"l c #d5e6f6",
"m c #d5e6ff",
"k c #deeaf6",
"j c #deeaff",
"i c #deeeff",
"h c #e6eeff",
"g c #e6f2ff",
"f c #eef2ff",
"# c #eef6ff",
"a c #f6faff",
". c #ffffff",
"......",
"#abcdc",
"ade...",
"bcf#f#",
"efffff",
"dghghg",
"ehhhhh",
"bijhki",
"ejjjjj",
"djlmlm",
"enmnmo",
"bpqpqp",
"ersrsr",
"dtutut",
"evwvuv",
"bvxvyz",
"exxAxB",
"dACADA",
"eEFEFE",
"bGHIHG",
"eJKJKJ",
"dJLLLJ",
"eMLMLM",
"bMNMOP",
"eNNNNN",
"dNQNQN",
"eQNRSQ",
"bRQRQR",
"eRSQNR",
"dTUUUT",
"eVWRNR",
"bXtXum"};

static const char* const img39_chat[] = { 
"52 74 155 2",
"ae c #4179b4",
"ar c #417dbd",
"as c #4181bd",
"an c #4a79a4",
"#5 c #4a7db4",
"at c #4a81bd",
"am c #4a85c5",
"#W c #527dac",
"au c #5281b4",
"aq c #528dcd",
"#H c #5291cd",
"#Q c #5295de",
".K c #5a91cd",
".W c #5a95de",
"ag c #5a99de",
"#F c #5a9de6",
"#B c #5aa1e6",
"#O c #628dbd",
".y c #6295cd",
".L c #6299d5",
".8 c #629dde",
".z c #629de6",
".A c #62a1de",
"#i c #62a1e6",
"#r c #62a5e6",
"#m c #62a5ee",
"#o c #62aaee",
".q c #6a8dac",
"#f c #6aa1de",
".D c #6aa5e6",
"#v c #6aa5ee",
".C c #6aaae6",
".0 c #6aaaee",
"#w c #6aaeee",
"#D c #6aaef6",
".V c #738da4",
".p c #738dac",
".x c #7391ac",
"al c #7399bd",
"ad c #7399c5",
"ah c #739dc5",
"ap c #73a5de",
"#Y c #73aae6",
".B c #73aeee",
"## c #73aef6",
".6 c #73b2f6",
".3 c #7b91ac",
".o c #7b91b4",
".J c #7b95ac",
".n c #7b99b4",
"#4 c #7ba5d5",
"#Z c #7baede",
"#z c #838583",
"#a c #8395b4",
"#A c #8399b4",
".w c #839db4",
"#x c #839dbd",
"#t c #83a1bd",
".F c #83a5c5",
"ai c #83a5cd",
"#V c #83aad5",
"#7 c #83aed5",
"#J c #83b6ee",
"#y c #8b858b",
".m c #8ba1bd",
"#k c #8ba1c5",
".r c #8ba5c5",
".E c #8baacd",
".R c #8baecd",
"ac c #8baed5",
"#N c #8bb2de",
"#S c #8bb6e6",
"#K c #8bbeee",
"#e c #94a5bd",
"#s c #94aac5",
"#C c #94aecd",
"aj c #94aed5",
"ak c #94b2d5",
"#n c #9cbad5",
".1 c #9cbade",
".l c #a4a5ac",
"#6 c #a4b2c5",
"#G c #a4bede",
"#E c #a4c2de",
".7 c #a4c6e6",
"#h c #a4c6ee",
".U c #aca5ac",
".I c #acaaac",
"#3 c #acaeb4",
"ab c #acb2bd",
"af c #acbacd",
"#b c #acc2de",
".X c #acc6e6",
"#d c #acc6ee",
"#p c #accae6",
"#. c #accaee",
"#c c #accaf6",
".5 c #acceee",
".2 c #b4aeb4",
".v c #b4b2b4",
".s c #b4b2bd",
"aa c #b4babd",
"#U c #b4bac5",
"#8 c #b4bacd",
"#0 c #b4becd",
".Y c #b4cade",
".M c #b4cae6",
".Q c #b4ceee",
"#2 c #bdbec5",
"a. c #bdc2c5",
"#9 c #bdc2cd",
"#M c #bdc2d5",
"#P c #bdc6d5",
".P c #bdcade",
"ax c #bdcae6",
"ay c #bdcede",
".N c #bdcee6",
"aw c #bdd6ee",
"a# c #c5c2cd",
".k c #c5c6cd",
"#1 c #c5cad5",
".O c #c5cee6",
"ao c #c5d2e6",
"#I c #c5d6ee",
".S c #cdcacd",
".G c #cdcad5",
".d c #cdcecd",
"#T c #cdd6e6",
".e c #d5ced5",
".c c #d5d2d5",
".t c #d5d2de",
".u c #d5d6d5",
"#q c #d5d6de",
"av c #d5deee",
"#L c #d5e2f6",
"#R c #d5e2ff",
".f c #ded6de",
"#u c #dedade",
".j c #dedede",
"#g c #dee2e6",
"#X c #deeaff",
"#l c #e6dee6",
".b c #e6e2e6",
".T c #e6e6e6",
"#j c #eee6ee",
".H c #eeeaee",
".a c #eeeeee",
".9 c #eeeef6",
".g c #f6eef6",
".Z c #f6f2f6",
".h c #f6f6f6",
".4 c #f6f6ff",
".i c #fff6ff",
".# c #fffaff",
"Qt c #ffffff",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQt.#.a.b.c.c.d.e.d.e.d.e.d.e.d.e.d.e.d.e.d.e.d.e.d.e.d.e.d.e.d.e.d.e.d.e.d.e.d.f.b.g.hQtQtQtQtQt",
"QtQtQtQt.i.j.k.l.m.n.o.p.p.p.p.q.p.p.p.q.p.p.p.q.p.p.p.q.p.p.p.q.p.p.p.q.p.p.p.q.p.p.o.n.r.s.t.aQtQtQtQt",
"QtQtQt.h.u.v.w.x.y.z.A.B.C.B.C.B.C.B.C.B.C.B.C.B.C.B.C.B.C.B.C.B.C.B.C.B.C.B.C.B.C.B.C.D.D.E.F.G.H.#QtQt",
"QtQt.i.c.I.J.K.L.M.N.O.P.N.P.O.P.N.P.O.P.N.P.O.P.N.P.O.P.N.P.O.P.N.P.O.P.N.P.O.P.N.P.O.N.Q.C.B.R.S.TQtQt",
"Qt.i.u.U.V.W.X.Y.Z.i.h.i.h.i.h.i.h.i.h.i.h.i.h.i.h.i.h.i.h.i.h.i.h.i.h.i.h.i.h.i.h.i.h.i.Z.M.M.0.1.e.H.#",
"Qt.b.2.3.z.X.i.h.i.h.i.h.i.h.i.h.i.h.i.h.i.h.i.h.i.h.i.h.i.h.i.h.i.h.i.h.i.h.i.h.i.h.i.h.i.h.4.5.6.7.b.h",
".h.S.w.8.X.4.h.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.i.Z.9#.###..#",
".H.v#a.D#b.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.a#c.0#dQt",
".b#e#f.X.9.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.Z#g#h#i.Q",
"#j#k.0.X.i.h.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.g#l.X#m#n",
".b#k#o#p.Z.i.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.g#q.X#r#s",
"#j#t##.X.4.h.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.a#u.X#v.m",
".b.m#w.X.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.g#q.X#i#x",
"#j.m.6.X.4.h.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.a#u.X#m.w",
".b#k#w.X.Z.i.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.g#q.X#i#x",
"#j#t.6.X.4.h.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.a#u.X#m.w",
".b.m#w.X.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.g#q.X#i#x",
"#j.m.6.X.4.h.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.a#u.X#m.w",
".b#k#w.X.Z.i.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.g#q.X#i#x",
"#j#t.6.X.4.h.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.a#u.X#m.w",
".b.m#w.X.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.g#q.X#i#x",
"#j.m.6.X.4.h.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.a#u.X#m.w",
".b#k#w.X.Z.i.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.g#q.X#i#x",
"#j#t.6.X.4.h.i.Z.i.Z.i.Z#y#z#y#z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i#z#y.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.a#u.X#m.w",
".b.m#w.X.Z.h.Z.h.Z.h.Z.h.Z#y#z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.g#q.X#i#x",
"#j.m.6.X.4.h.i.Z.i.Z.i.Z.i#z#y.Z.i.Z#y#z#y#z#y.Z.i#z#y.Z.i#z#y.Z.i#z#y.Z.i#z#y#z#y.Z.i.Z.i.Z.i.a#u.X#m.w",
".b#k#w.X.Z.i.Z.h.Z.h.Z.h.Z#y#z.h.Z.h#z#y.Z.h#z#y.Z#y#z.h.Z#y#z.h.Z#y#z.h.Z.h.Z.h#z#y.Z.h.Z.h.Z.g#q.X#i#x",
"#j#t.6.X.4.h.i.Z.i.Z.i.Z.i#z#y.Z.i.Z#y#z.i.Z#y#z.i.Z#y#z#y#z.i.Z.i#z#y.Z.i#z#y#z#y#z.i.Z.i.Z.i.a#u.X#m.w",
".b.m#w.X.Z.h.Z.h.Z.h.Z.h.Z#y#z.h.Z.h#z#y.Z.h#z#y.Z.h#z#y#z#y.Z.h.Z#y#z.h#z#y.Z.h#z#y.Z.h.Z.h.Z.g#q.X#i#x",
"#j.m.6.X.4.h.i.Z.i.Z.i.Z.i#z#y.Z.i.Z#y#z.i.Z#y#z.i.Z.i#z#y.Z.i.Z.i#z#y.Z#y#z.i.Z#y#z.i.Z.i.Z.i.a#u.X#m.w",
".b#k#w.X.Z.i.Z.h.Z.h.Z.h#z#y#z#y.Z.h#z#y.Z.h#z#y.Z.h.Z#y#z.h.Z.h.Z#y#z.h.Z#y#z#y#z#y.Z.h.Z.h.Z.g#q.X#i#x",
"#j#t.6.X.4.h.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.a#u.X#m.w",
".b.m#w.X.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.g#q.X#i#x",
"#j.m.6.X.4.h.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.a#u.X#m.w",
".b#k#w.X.Z.i.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.g#q.X#i#x",
"#j#t.6.X.4.h.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.a#u.X#m.w",
".b.m#w.X.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.g#q.X#i#x",
"#j.m.6.X.4.h.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.a#u.X#m.w",
".b#k#w.X.Z.i.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.g#q.X#i#x",
"#j#t.6.X.4.h.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.a#u.X#m.w",
".b#k#w.X.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.g#q.X#i#x",
"#j.r.6.X.4.h.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.a#u.X#m#A",
".b#s.0.X.Z.i.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.g#u.X#B#A",
".H#C#D.X.4.h.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.H#u#E#F.w",
".a.1#m.Q.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.g.b.d#G#H.m",
"Qt#I#J#K#L.Z.h.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.i.Z.g#q#M#N#O#P",
"Qt.i#p#w#h.g.a.Z.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.h.Z.Z.Z.g.j.S#n#Q.3Qt",
"QtQt#R#J#S#T.b.T.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.g.H.j.S#U#V#W#PQt",
"QtQtQt#X#Y#Z#0#1#u.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b.b#l#u.S#2#3#4#5#6QtQt",
"QtQtQtQt#X.C#4#7#8#2#9a.a##9a#a.a##9a#a.a##9a#a.a##9a#a.a##9a#a.a##9a#a.a##9a#a.a##9#9aaabacadaeafQtQtQt",
"QtQtQtQtQt#X#Yagahai.Eaj.Rak.Rak.Rak.Rak.Rak.Rak.Rak.Rak.Rak.Rak.Rak.Rak.Rak.Rak.Raj.EaialamanaoQtQtQtQt",
"QtQtQtQtQtQt#R#Lap#Haqarasarasarasarasarasarasarasarasarasarasarasarasarasarasarasararatau#0avQtQtQtQtQt",
"QtQtQtQtQtQtQtQtaw.N.Y.N.Y.N.Y.N.Y.N.Y.N.Y.N.Y.N.Y.N.Y.N.Y.N.Y.N.Y.N.Y.N.Y.N.Y.N.Y.N.YaxayQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt"};

static const char* const img40_chat[] = { 
"14 21 5 1",
"c c #0075ee",
"b c #0879ee",
"a c #eef2ff",
"# c #f6f2ff",
". c #f6f6ff",
"..............",
"#.a.#.a.#.a.#.",
"..............",
"a.#.a.#.a.#.a.",
"..............",
"#.a.#.a.#.a.#.",
"..............",
"a.#.a.#.a.#.a.",
"..............",
"#.a.#.a.#.a.#.",
"..............",
"a.#.a.#.a.#.a.",
"..............",
"#.a.#.a.#.a.#.",
"..............",
"a.#.a.#.a.#.a.",
"..............",
"#.a.#.a.#.a.#.",
"..............",
"a.#.a.#.a.#.a.",
"bcbcbcbcbcbcbc"};

static const char* const img41_chat[] = { 
"22 32 50 1",
"b c #0075e6",
"# c #0075ee",
"a c #0079ee",
"U c #73aee6",
"V c #7baeee",
"R c #83b6e6",
"T c #83b6ee",
"S c #83baee",
"O c #8bbae6",
"Q c #8bbaee",
"P c #8bbeee",
"N c #94beee",
"M c #94c2ee",
"L c #9cc2ee",
"I c #9cc6ee",
"K c #9cc6f6",
"J c #a4c6ee",
"F c #a4caee",
"G c #a4caf6",
"E c #accaee",
"H c #accaf6",
"C c #accef6",
"B c #acd2f6",
"D c #b4cef6",
"y c #b4d2ee",
"A c #b4d2f6",
"z c #b4d6f6",
"v c #bdd6f6",
"t c #bddaf6",
"x c #bddaff",
"u c #c5daf6",
"w c #c5daff",
"s c #c5def6",
"o c #cddef6",
"r c #cddeff",
"q c #cde2f6",
"p c #cde2ff",
"m c #d5e2f6",
"n c #d5e2ff",
"j c #d5e6f6",
"k c #d5e6ff",
"l c #dee6ff",
"i c #deeaf6",
"g c #deeaff",
"h c #deeeff",
"e c #e6eeff",
"f c #e6f2ff",
"c c #eef2ff",
"d c #eef6ff",
". c #ffffff",
"......................",
"#aba#aba#aba#aba#aba#a",
"......................",
"cdcdcdcdcdcdcdcdcdcdcd",
"cccccccccccccccccccccc",
"efefefefefefefefefefef",
"eeeeeeeeeeeeeeeeeeeeee",
"ghgeghgeihgeihgeihgeih",
"gggggggggggggggggggggg",
"jkjkjljkjljkjgjgjgjgjg",
"kmknkmknkmknkmknkmknkn",
"opopopopoqopoqopoqopop",
"rsrsrsrsrsrsrsrsrsrsrs",
"tutututuvuvuvututututu",
"tvwvtvwvtvtvtvxvtvwvtv",
"yzAvyzAvyzAvyzAzyzAzyz",
"AAABAAACADACAAABAAABAA",
"ECFCECFCFCFCFCFCECFCEC",
"GFHFGFHFGFHFGFHFHFHFHF",
"IIIJIIIJIIIJIJIJIJIJII",
"KLKLKLKLKLKLKLKLKLKLKL",
"MLMLMLMLMLMLMLMLMLMLML",
"MNMNMNMNMNMNMNMNMNMNMN",
"OPQNOPQNOPQNOPQNOPQNOP",
"QQQQQQQQQQQQQQQQQQQQQQ",
"RQRQRQRQRQRQRQRQRQRQRQ",
"SRQTSRQTSRQTSRQTSRQTSR",
"RTRTRTRTRTRTRTRTRTRTRT",
"TTTRTTTRTTTRTTSRQTSRQT",
"UVUUUVUUUVUUUVUUUVUUUV",
"QTQTQTQTQTQTQTQTQTQTQT",
"pkpkpkpkpkpkpkpkpkpkpk"};

static const char* const img42_chat[] = { 
"25 31 294 2",
".# c #0075ff",
"Qt c #08a1ff",
"#k c #5271ff",
"#o c #5275ff",
"#x c #5291ff",
"aO c #62506a",
"cE c #6a91bd",
"cD c #6a95ff",
"cC c #6a99c5",
"bN c #737d73",
"ch c #73817b",
"bS c #738594",
"c. c #73899c",
"bD c #738d9c",
"ci c #7395bd",
"b2 c #7395ff",
"cn c #7399bd",
"cI c #73aeff",
"bg c #7b91ff",
"bO c #7ba1c5",
"#n c #7ba1ff",
"cw c #7ba5ff",
"cA c #7baade",
"cF c #7baede",
"b9 c #7bd2ff",
"bc c #83656a",
"aX c #837973",
"cp c #838573",
"a0 c #83857b",
"bl c #83a1bd",
"#z c #83aaff",
"b8 c #83b6e6",
"cl c #83b6ff",
"b4 c #83bae6",
"cx c #83baff",
"cz c #83daff",
"cy c #83deff",
"cJ c #83e2ff",
"av c #8b91a4",
"a# c #8ba5c5",
"ai c #8baac5",
"aH c #8baacd",
"#l c #8baec5",
"bz c #8bb2ff",
"a2 c #8bb6de",
"b6 c #8bbae6",
"ck c #8bbaee",
"bQ c #8bbaff",
"bB c #8bbee6",
"bA c #8bbeee",
"bP c #8bbeff",
"bC c #8bdeff",
"b5 c #8be2ff",
"bf c #94916a",
"aM c #94957b",
"#s c #949583",
"#E c #949da4",
"bh c #94bae6",
"a1 c #94c2ee",
"bj c #94c2ff",
"#w c #9c9d94",
".6 c #9cbab4",
"aK c #9cc6ff",
"a7 c #a44c5a",
"aV c #a45d6a",
"cg c #a4a16a",
".w c #a4a59c",
"#H c #a4bad5",
"#T c #a4bed5",
"#A c #a4beff",
"#j c #a4c2ac",
"as c #a4c6ee",
"aI c #a4caee",
"aQ c #ac5962",
"ct c #aca56a",
"aB c #acb6cd",
".l c #acbac5",
".k c #acbaff",
"an c #acbeff",
"#9 c #acceee",
"aj c #acceff",
"#N c #acd68b",
"aU c #b45d6a",
"aW c #b47dbd",
"cr c #b4ae6a",
"#b c #b4ae7b",
".r c #b4ae94",
".N c #b4c2d5",
"#B c #b4d294",
"#U c #b4d2ff",
"ba c #bd555a",
"bv c #bd756a",
"by c #bda5e6",
"#8 c #bdae7b",
"ac c #bdb6bd",
".X c #bdba7b",
"ax c #bdbac5",
".i c #bdc6d5",
"#f c #bdd6ee",
"#G c #bdd6f6",
"#F c #bddaff",
"a9 c #c5595a",
"aD c #c5aa83",
"cv c #c5b6ff",
"ay c #c5bac5",
"ca c #c5be62",
"#h c #c5bea4",
"aA c #c5c2cd",
"a5 c #c5ca73",
".9 c #c5d28b",
".p c #c5d2de",
".Z c #c5d6e6",
"#t c #c5d6f6",
".K c #c5d6ff",
"#e c #c5daf6",
"#d c #c5daff",
"b# c #cd595a",
"bL c #cd8573",
"cB c #cda1ff",
"b1 c #cdaac5",
"ag c #cdb28b",
"co c #cdb2e6",
"bx c #cdbe6a",
"b0 c #cdc26a",
"az c #cdc2cd",
"al c #cdc694",
"bM c #cdca6a",
"a4 c #cdce83",
"af c #cdd2de",
".x c #cddaee",
"cH c #cddaff",
".M c #cde2f6",
".0 c #cde2ff",
"br c #d57573",
"a3 c #d591e6",
"bJ c #d599a4",
"bX c #d5b67b",
"bG c #d5c67b",
"bo c #d5c683",
"aF c #d5ca6a",
"#R c #d5ca73",
"ce c #d5ce6a",
"cc c #d5d26a",
"be c #d5d273",
"bU c #d5d27b",
"bR c #d5d6ff",
"cm c #d5daff",
"ad c #d5deee",
"cj c #d5deff",
"bF c #d5e26a",
".L c #d5e2f6",
"cG c #d5e2ff",
"#K c #d5e66a",
".y c #d5e6ff",
"#L c #d5ea6a",
"ah c #ded26a",
"ak c #ded2ff",
".u c #ded6ac",
"b3 c #dedeff",
"ae c #dee2ee",
"b7 c #dee2ff",
"au c #deea94",
"ab c #deea9c",
".n c #deeaf6",
".o c #deeaff",
".e c #deeeff",
"c# c #e691c5",
"aC c #e69dff",
"cu c #e6bac5",
"aN c #e6bacd",
"ar c #e6d2ff",
"#Q c #e6da6a",
"aL c #e6daff",
"#P c #e6de62",
".s c #e6e2cd",
"#M c #e6e662",
".P c #e6e6de",
"bk c #e6e6ff",
"#m c #e6ee62",
"#i c #e6ee9c",
"#J c #e6eecd",
".f c #e6eeff",
".c c #e6f2ff",
"aw c #eea1ff",
".Y c #eea5ff",
"bm c #eec6cd",
"#V c #eedaff",
"#r c #eee26a",
".V c #eeea6a",
"bi c #eeeaff",
".U c #eeee62",
".t c #eeeecd",
"#y c #eeeeff",
".S c #eef262",
".Q c #eef2ac",
"bb c #f65062",
"a6 c #f67dcd",
"aP c #f681bd",
"#S c #f699cd",
"cq c #f6cabd",
".2 c #f6caee",
"#g c #f6d6ff",
"#c c #f6daff",
"aJ c #f6eeff",
"at c #f6f2ff",
"a8 c #ff5562",
"b. c #ff5962",
"bt c #ff5d62",
"aS c #ff5d6a",
"bK c #ff75c5",
"bu c #ff7db4",
"bq c #ff85b4",
"aR c #ff85bd",
"aT c #ff89bd",
"bH c #ff91cd",
"aG c #ff9dc5",
"bs c #ff9dcd",
".O c #ffa1e6",
"bI c #ffa1ff",
"bp c #ffaecd",
"aq c #ffb273",
"am c #ffba8b",
".I c #ffba94",
"#W c #ffc2a4",
"ap c #ffc673",
".z c #ffc6ff",
"#5 c #ffca7b",
"#3 c #ffca8b",
".m c #ffcaff",
"ao c #ffcef6",
".1 c #ffceff",
"bw c #ffd273",
"#1 c #ffd283",
"#Z c #ffd28b",
".B c #ffd2bd",
".A c #ffd2ee",
"bT c #ffd66a",
"bZ c #ffd673",
"#X c #ffd68b",
"bE c #ffd6c5",
"#I c #ffd6e6",
".J c #ffd6ff",
"#6 c #ffda73",
"bd c #ffda7b",
"cs c #ffdabd",
"#u c #ffdaff",
"#C c #ffde73",
"#Y c #ffde8b",
"#D c #ffdecd",
".3 c #ffded5",
"bW c #ffdee6",
".q c #ffdeff",
"#. c #ffe273",
"bn c #ffe27b",
"aZ c #ffe2c5",
".h c #ffe2ff",
"#a c #ffe66a",
"bV c #ffe6d5",
".v c #ffe6ee",
".j c #ffe6ff",
".g c #ffeaff",
"cf c #ffee6a",
"aY c #ffeecd",
".d c #ffeeff",
".7 c #fff262",
".E c #fff283",
".4 c #fff28b",
".G c #fff29c",
"bY c #fff2cd",
"#4 c #fff2d5",
"#p c #fff2ee",
"aa c #fff2f6",
"#v c #fff2ff",
".C c #fff694",
"cd c #fff6c5",
".b c #fff6ff",
"cb c #fffa6a",
"aE c #fffa73",
"#7 c #fffac5",
"#2 c #fffade",
"#0 c #fffae6",
"a. c #fffaff",
".T c #ffff62",
"#O c #ffff6a",
"#q c #ffff73",
".8 c #ffffb4",
"## c #ffffbd",
".R c #ffffc5",
".W c #ffffcd",
".5 c #ffffd5",
".D c #ffffde",
".F c #ffffe6",
".H c #ffffee",
".a c #ffffff",
"Qt.#Qt.#Qt.#Qt.#Qt.#Qt.#Qt.#Qt.#Qt.#Qt.#Qt.#Qt.#Qt",
".a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a",
".a.b.a.b.a.b.a.b.a.b.a.b.a.b.a.b.a.b.a.b.a.b.a.b.a",
".c.a.c.a.c.a.c.a.c.a.c.a.c.a.c.a.c.a.c.a.c.a.c.a.c",
".a.d.a.d.a.d.a.d.a.d.a.d.a.d.a.d.a.d.a.d.a.d.a.d.a",
".e.a.e.a.e.a.e.a.e.a.e.a.e.a.e.a.e.a.f.a.f.a.e.a.f",
".a.g.a.g.a.g.a.h.a.i.j.k.h.l.g.m.a.j.a.g.a.g.a.g.a",
".n.a.o.a.n.a.p.q.r.b.s.a.t.a.u.v.w.g.x.a.n.a.o.a.n",
".a.j.a.y.a.z.A.B.a.b.a.C.D.E.F.G.H.I.J.K.a.j.a.y.a",
".L.a.M.a.N.O.P.a.Q.R.S.T.U.T.U.T.V.W.X.Y.Z.a.M.a.M",
".a.0.a.1.2.3.a.4.5.6.F.7.8.9.j#.###a.R#b#c#d.a.h.a",
"#e.a#f#g#h.a#i.T#j#k#l.T#m#n#o#p#m#q#r.R#s.g#t.a#e",
".a#u#v#w.a#v##.7#v#x#y.7.8#z#A#B.8#C.R#.#D#E.b#F.a",
"#G.a#H#I#J.5#m.T#K.D#L.T#M.W#N#O#P#O#Q#q#R#S#T.a#G",
".a#U#V#W.a#a.W#X.F#Y.F#Z#0#1#2#3#4#5.R#6#7#8#V#U.a",
"#9a.a#aaab.Eac.bad.aae.aae.aae.aaf.hag#7ah#Caia.#9",
".bajakal.Ham#g#d.a.g.a.g.a.d.a.g.aanaoap#7aqaraj.b",
"asata##Yau#4avawax.hay.gaz.gaA.daBaCaDaEaFaGaHataI",
"aJaKaLaM.F#.aNaOaPaQaRaSaTaUaTaVaWaXaY#6aZa0aLaKaJ",
"a1#ya2a3a4#qa5a6a7a8a9b.b#b.babbbcbdbe.Rbfbgbh#ya1",
"bibjbkblbmbn##bobpa8bqbrbsbtbubv.3bw.Rbxbybzbibjbi",
"bAbkbBbCbDbEbF#ObGbHbrbIbJbKbLbnbe.RbMbNbObkbAbkbA",
"bkbPbkbQbRbSbEbT.RbUbV.IbWbXbYbZ.Rb0b1b2b3bPbkbPbk",
"b4b5b6b7b8b9c.c#cacbcccdbMaEcecfcgchcicjb4b5ckb7b4",
"b7clb7clb7clcmcncocpcqcrcsctcuchcvcwcjclb7cxb7cxb7",
"b8cjb8cyb8cjb8czcAcBcCcDcEcDcCcwcFcjb8cyb8cjb8cyb8",
"cGclb7clcGclb7clcGclb7clcGclb7clcGclb7clcGclb7clcG",
"b8cyb8cjb8cyb8cjb8cyb8cjb8cyb8cjb8cyb8cjb8cyb8cjb8",
"cHcIcHcIcHcIcHcIcHcIcHcIcHcIcHcIcHcIcHcIcHcIcHcIcH",
"b8b7b8cJb8b7b8cJb8b7b8cJb8b7b8cJb8b7b8cJb8b7b8cJb8",
".a.y.a.j.a.y.a.j.a.y.a.j.a.y.a.j.a.y.a.j.a.y.a.j.a"};

static const unsigned char img43_chat[] = { 
    0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
    0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x2b, 0x00, 0x00, 0x00, 0x20,
    0x08, 0x06, 0x00, 0x00, 0x00, 0x8b, 0x9a, 0x81, 0x03, 0x00, 0x00, 0x03,
    0x8c, 0x49, 0x44, 0x41, 0x54, 0x58, 0x85, 0xd5, 0x94, 0x51, 0x68, 0x1b,
    0x65, 0x00, 0xc7, 0xff, 0x57, 0xa3, 0x3b, 0x86, 0x91, 0x66, 0x0e, 0xec,
    0xc1, 0x26, 0x27, 0x1c, 0xb2, 0xfa, 0x34, 0x9f, 0x64, 0x0f, 0x0a, 0xcd,
    0x8b, 0x18, 0x9f, 0xf4, 0x51, 0xf0, 0xa5, 0x2f, 0x3e, 0xfa, 0x30, 0x3f,
    0xe1, 0x60, 0x7b, 0x98, 0x43, 0x64, 0x94, 0xbd, 0x0c, 0x26, 0x9c, 0xae,
    0x3e, 0x75, 0xa0, 0xae, 0x4c, 0x1c, 0xe1, 0x06, 0x95, 0xa6, 0x45, 0x97,
    0x14, 0xda, 0x65, 0xb8, 0x48, 0xb6, 0xac, 0x3d, 0xb3, 0x10, 0xd9, 0x65,
    0x09, 0xdb, 0x77, 0xa3, 0xad, 0x97, 0xd8, 0x05, 0xff, 0x3e, 0xe4, 0x26,
    0xb5, 0xa4, 0x69, 0x93, 0x26, 0x4b, 0xfc, 0x5e, 0x7e, 0xfc, 0xb8, 0xef,
    0x3e, 0x7e, 0xdf, 0xc7, 0x77, 0x07, 0xfc, 0x8f, 0x86, 0x02, 0x21, 0x57,
    0x11, 0x8a, 0xac, 0xa0, 0x5e, 0x4a, 0x20, 0xa4, 0x5d, 0x43, 0xdd, 0x5b,
    0xc2, 0xc4, 0x01, 0xb7, 0xdf, 0x61, 0xcd, 0x86, 0x42, 0xf2, 0x76, 0x62,
    0x05, 0x65, 0x6f, 0x1d, 0xea, 0x27, 0x57, 0xa1, 0xdf, 0x3f, 0x88, 0x50,
    0xcd, 0xc1, 0x8c, 0x6a, 0xe0, 0xab, 0x9a, 0x83, 0x24, 0x26, 0x94, 0xc7,
    0xfd, 0x8e, 0x7c, 0x32, 0x14, 0xb9, 0x4a, 0x46, 0xc2, 0x80, 0xb7, 0x06,
    0x44, 0xc2, 0x90, 0xa9, 0xbb, 0xc8, 0x7d, 0x3e, 0x87, 0xfd, 0xb6, 0xe3,
    0x1d, 0x01, 0x22, 0x57, 0x51, 0x2f, 0x9d, 0x43, 0x48, 0x4b, 0xe2, 0x8b,
    0xfe, 0x47, 0x2b, 0x24, 0x89, 0x35, 0x00, 0x61, 0x60, 0x13, 0x6b, 0x08,
    0xe3, 0xe6, 0xbb, 0xdf, 0x60, 0x5f, 0xa2, 0x8e, 0x23, 0x35, 0x07, 0xb6,
    0x6a, 0xe0, 0x5c, 0x70, 0xd2, 0xf5, 0xbe, 0xd5, 0xba, 0x92, 0x24, 0xc9,
    0x6d, 0x58, 0x4d, 0xe6, 0xb9, 0x10, 0x9b, 0xe4, 0xaf, 0x30, 0x5d, 0x1f,
    0x26, 0x2f, 0x41, 0xc8, 0x37, 0x61, 0x32, 0xd4, 0x97, 0x58, 0x92, 0x64,
    0x10, 0xd8, 0x82, 0x3e, 0xc9, 0x85, 0x31, 0x8b, 0x37, 0x55, 0x8b, 0x3e,
    0x04, 0xbf, 0x56, 0x2d, 0xbe, 0xfa, 0xd4, 0x63, 0xf3, 0x15, 0x9f, 0x24,
    0x99, 0xaf, 0x30, 0x60, 0x4b, 0xf7, 0xe3, 0x19, 0xff, 0xe7, 0xd1, 0xb3,
    0xbc, 0x0b, 0x21, 0xff, 0x80, 0xc9, 0x4f, 0x21, 0xdc, 0x03, 0x4f, 0x2d,
    0x96, 0x24, 0x19, 0x84, 0xb5, 0x41, 0x37, 0x9d, 0xe7, 0xfc, 0xf0, 0x49,
    0x4a, 0xd5, 0xe2, 0x22, 0x04, 0xdf, 0x57, 0x2d, 0xaa, 0x3d, 0x8f, 0xcd,
    0xba, 0x8d, 0x93, 0xeb, 0x90, 0xd9, 0x0f, 0x2e, 0xca, 0x05, 0xd5, 0x64,
    0x15, 0xc2, 0xfd, 0x16, 0x26, 0x8f, 0xf6, 0x34, 0x96, 0x24, 0xb3, 0xc5,
    0xe0, 0xc4, 0x02, 0xb6, 0xe9, 0x8f, 0xe3, 0x19, 0xa6, 0x8e, 0x5f, 0x61,
    0x0e, 0x82, 0xf7, 0x55, 0x8b, 0x9f, 0x41, 0x70, 0xa4, 0x27, 0xb1, 0xe9,
    0x7c, 0xe3, 0xa4, 0xba, 0xc0, 0x4a, 0xba, 0xc8, 0xb9, 0xe1, 0x53, 0xb2,
    0x0c, 0x93, 0xbf, 0x41, 0xc8, 0x71, 0x98, 0x7c, 0xbe, 0xab, 0xb1, 0x8d,
    0xaf, 0xa7, 0x71, 0x50, 0xc9, 0x80, 0x7b, 0xf2, 0x0d, 0xae, 0x8c, 0x7f,
    0xcf, 0x5f, 0x86, 0x27, 0xb9, 0x0e, 0xc1, 0x59, 0xd5, 0xe2, 0x3b, 0x10,
    0x7c, 0xae, 0x2b, 0xb1, 0xb3, 0xcb, 0x3e, 0xb9, 0x41, 0x76, 0x99, 0x7f,
    0x4f, 0x67, 0xfc, 0x1b, 0x31, 0x8b, 0x4b, 0x30, 0x65, 0x15, 0x26, 0xa7,
    0x20, 0xdc, 0xbd, 0xdf, 0x67, 0x6e, 0x90, 0xb3, 0xb7, 0x48, 0x6e, 0x90,
    0x0c, 0xd8, 0x45, 0xaf, 0xba, 0x15, 0x5e, 0x1b, 0x3d, 0xcb, 0x9c, 0x6a,
    0xf1, 0x01, 0x04, 0xcf, 0xa8, 0x16, 0x47, 0x21, 0xf8, 0x4c, 0x47, 0xb1,
    0xf1, 0x8c, 0xa4, 0xef, 0x93, 0xf1, 0x8c, 0x4f, 0xfa, 0x64, 0x8f, 0xfc,
    0xe1, 0xe9, 0x19, 0x39, 0x3f, 0x7a, 0x86, 0xbf, 0x43, 0xb8, 0x0f, 0x61,
    0xf2, 0x3b, 0x08, 0xf9, 0x36, 0xcc, 0x36, 0x7f, 0x77, 0xfe, 0x2a, 0x19,
    0xcf, 0x90, 0xfe, 0x2a, 0x39, 0x1d, 0xb0, 0x87, 0x2e, 0xf3, 0x2e, 0x53,
    0x63, 0xe7, 0x79, 0x5d, 0x9d, 0x64, 0x15, 0x82, 0x8b, 0xaa, 0xc5, 0x8f,
    0x21, 0xf8, 0xf2, 0xae, 0x62, 0xa7, 0x6f, 0x48, 0x4a, 0x49, 0xb6, 0xcb,
    0xa9, 0x27, 0xbe, 0xd8, 0x9c, 0x53, 0x3b, 0xf0, 0x42, 0x4a, 0x66, 0xc7,
    0x17, 0x39, 0x3f, 0x72, 0x4a, 0xde, 0x83, 0xc9, 0x7b, 0x10, 0xee, 0x97,
    0x30, 0xf9, 0x06, 0x84, 0x7c, 0x76, 0xbb, 0x56, 0x45, 0x56, 0x48, 0xbb,
    0x00, 0xc4, 0x74, 0xa0, 0x13, 0x46, 0x75, 0x20, 0xd1, 0xc4, 0xb7, 0xb2,
    0xc5, 0xfc, 0xf2, 0xe4, 0x75, 0xdc, 0x79, 0x54, 0xc3, 0x8b, 0xe7, 0x97,
    0x60, 0x40, 0x47, 0xb2, 0xe6, 0xe0, 0x92, 0x6a, 0xe0, 0x87, 0xda, 0x47,
    0x4a, 0xf9, 0x3f, 0xb1, 0x17, 0x52, 0x92, 0x51, 0x3d, 0x82, 0x44, 0xc1,
    0x43, 0x4c, 0x8f, 0xc0, 0x2e, 0x78, 0xd8, 0xea, 0x3b, 0x71, 0xa7, 0xf7,
    0x77, 0xb9, 0xde, 0x5f, 0xc7, 0x0e, 0x45, 0x6e, 0x9d, 0x9c, 0xf3, 0xd6,
    0x12, 0x85, 0xc8, 0xe8, 0xa3, 0x75, 0xaf, 0x8e, 0x50, 0xe4, 0x47, 0xd4,
    0x4b, 0x57, 0x10, 0xd2, 0x4a, 0xa8, 0x7b, 0x7f, 0x2a, 0x79, 0x97, 0x4c,
    0x38, 0x40, 0xd4, 0x00, 0x06, 0x88, 0xe5, 0x57, 0x0e, 0xe2, 0xce, 0x89,
    0x9f, 0xb0, 0xff, 0x75, 0x0d, 0xe1, 0xcb, 0x2b, 0xd8, 0x87, 0x43, 0xd0,
    0x87, 0x6c, 0xc7, 0x43, 0x54, 0x07, 0x6c, 0xc7, 0xc3, 0xb1, 0x80, 0xd1,
    0xfe, 0xf3, 0xa5, 0xdb, 0x0f, 0xbc, 0xb7, 0x2e, 0xbe, 0x87, 0xa3, 0xaf,
    0x8d, 0x78, 0x87, 0x53, 0x1f, 0xe2, 0x85, 0x13, 0x87, 0xbd, 0xb2, 0x92,
    0x2d, 0x92, 0x73, 0x0e, 0x30, 0x66, 0x00, 0x83, 0x4e, 0x65, 0x62, 0xc6,
    0x65, 0xcc, 0xd0, 0x60, 0x3b, 0x1e, 0x62, 0x46, 0x04, 0xb6, 0x53, 0xc2,
    0x56, 0x87, 0xa1, 0x01, 0x2d, 0xbc, 0xdd, 0xf9, 0x9d, 0xba, 0x92, 0x5e,
    0x26, 0x9b, 0x7d, 0xbd, 0x7b, 0xe6, 0x4e, 0x77, 0xb3, 0x83, 0x75, 0x87,
    0x6c, 0xa7, 0x14, 0xdc, 0x95, 0x12, 0x10, 0xb0, 0x2b, 0x9e, 0x0b, 0x3c,
    0xb7, 0x8d, 0x77, 0xb0, 0xfe, 0x50, 0xd4, 0xd0, 0x60, 0x3b, 0x40, 0xcc,
    0xd0, 0x50, 0x73, 0x80, 0x41, 0x76, 0xe5, 0xb4, 0xed, 0x12, 0xba, 0x06,
    0x14, 0x4a, 0x88, 0xea, 0x1a, 0x12, 0x85, 0x12, 0x06, 0xd5, 0x87, 0xa2,
    0xba, 0x06, 0x14, 0x1a, 0x3b, 0x48, 0x14, 0x1a, 0x3b, 0xd8, 0xec, 0xff,
    0x3e, 0xd7, 0x9b, 0xfb, 0xd6, 0xf9, 0xbb, 0xf6, 0x6d, 0xd6, 0x6b, 0xe5,
    0xca, 0xf1, 0xcb, 0x2e, 0x63, 0xba, 0x06, 0x7b, 0xd3, 0x0e, 0x06, 0xd5,
    0x95, 0xf4, 0x32, 0xd9, 0xb8, 0x13, 0xc0, 0xa0, 0x13, 0xe9, 0xa2, 0x2f,
    0x49, 0xca, 0x74, 0x91, 0x01, 0x07, 0xd7, 0xff, 0x01, 0x27, 0x8e, 0xd8,
    0x9a, 0xa5, 0xb0, 0xa5, 0xd3, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e,
    0x44, 0xae, 0x42, 0x60, 0x82
};

static const char* const img44_chat[] = { 
"28 12 28 1",
". c #0276e7",
"f c #2388e9",
"k c #5aa4ec",
"e c #66aaed",
"t c #73ade3",
"s c #80b4e5",
"r c #81b5e5",
"u c #83b6e6",
"p c #84b7e6",
"q c #85b7e6",
"o c #87b8e6",
"m c #8abbe7",
"n c #8bbae7",
"l c #8bbbe7",
"w c #8dbce9",
"i c #8ebde8",
"h c #8fbde8",
"v c #8fbde9",
"j c #90bde8",
"# c #a3cef7",
"g c #aed4f8",
"d c #b7d6f2",
"b c #b8d6f2",
"c c #b9d6f2",
"z c #cde3f7",
"y c #cfe3f8",
"x c #cfe4f8",
"a c #dbecfd",
"..........................#a",
"bbbbbbbbbbbbccccbbbbbbbddefg",
"hhhhhhhhhhhhhhhhiiiiiiihhjk.",
"lllllllllllllllllllllllmlnn.",
"ooooooooooooooooooooooooooo.",
"pppppppppppppppppppppppqqqq.",
"rrrrrrrrrrrrrrrrrrrrrrrrrrr.",
"rrrrrrrrrrrrrrrrrrrrrrrrrrr.",
"ssssrrrrrrrrrrrrsssssssssrr.",
"ttttttttttttttttttttttttttt.",
"uuuuuuuuuuuuuuuuuuuuuuuuuvw.",
"xyxxyxxyyxxxxyyxxxxxxxxzzzz."};

static const char* const img45_chat[] = { 
"24 12 31 1",
"b c #0276e7",
"a c #0376e7",
"# c #0578e7",
". c #0c7be7",
"A c #73ade3",
"y c #80b4e5",
"z c #80b5e5",
"w c #81b5e5",
"x c #82b5e5",
"v c #83b6e6",
"u c #84b6e6",
"s c #84b7e6",
"t c #85b7e6",
"r c #87b8e6",
"p c #8abae7",
"o c #8bbbe7",
"q c #8cbbe7",
"l c #8ebde8",
"m c #8fbde8",
"n c #90bde8",
"c c #9fc7ec",
"d c #a1c8ec",
"e c #a3caed",
"f c #a7ccee",
"g c #adcfef",
"h c #b2d2f0",
"k c #b7d6f2",
"i c #b8d6f1",
"j c #b8d6f2",
"B c #cfe3f8",
"C c #cfe4f8",
".#abbbbbbbbbbbbbbbbbbbbb",
"cdefghijjjjjjjjjjjjjjkkk",
"llllllmmnnnnnnmllllllmmm",
"ooooooppppppppooooooooqq",
"rrrrrrrrrrrrrrrrrrrrrrrr",
"ssssssttttttttssssssuuvv",
"wwwwwwwwwwwwwwwwwwwwwwxx",
"wwwwwwwwwwwwwwwwwwwwwwww",
"yyyyyyzzwwwwwwyyyyyyzzww",
"AAAAAAAAAAAAAAAAAAAAAAAA",
"vvvvvvvvvvvvvvvvvvvvvvvv",
"BBCCCCBBCCCCCBBBBCCBCCCB"};

static const char* const img46_chat[] = { 
"21 18 33 1",
"E c #0075e6",
"C c #0075ee",
"D c #0079ee",
"# c #73aae6",
"c c #73aee6",
". c #73aeee",
"a c #7baee6",
"b c #7bb2ee",
"d c #83b6ee",
"e c #8bbaee",
"f c #8bbeee",
"j c #94beee",
"h c #94c2ee",
"i c #94c2f6",
"g c #9cc2f6",
"k c #9cc6ee",
"m c #9cc6f6",
"l c #a4c6f6",
"o c #accaf6",
"n c #accef6",
"q c #acd2f6",
"p c #b4d2f6",
"s c #c5daf6",
"r c #c5deff",
"v c #d5e6f6",
"t c #d5e6ff",
"u c #deeaff",
"x c #eef2ff",
"w c #eef6ff",
"y c #f6f6ff",
"z c #f6faff",
"B c #fffaff",
"A c #ffffff",
".#.#.#.#.#.#.#.#.#.#.",
"abcbcbcbabcbabcbcbcbc",
"ddddddddddddddddddddd",
"eeeeeeefefeeeeeeeeeee",
"ghghghghghijghghgjghg",
"klklklklklklklkmklkmk",
"nonnnnnonnnonnnnnnnon",
"ppppppppppppqpppppppp",
"rsrsrsrsrsrsrsrsrsrsr",
"tuvutuvutuvutututuvut",
"wxyxwxwxwxyxwxwxwxwxw",
"zABAzBzAzAzAzBzAzAzAz",
"AAAAAAAAAAAAAAAAAAAAA",
"AAAAAAAAAAAAAAAAAAAAA",
"AAAAAAABABAAAAABAAAAA",
"wywywywywywywywywywyw",
"AAAAAAAAAAAAAAAAAAAAA",
"CDEDCDEDCDEDCDEDCDEDC"};


/*
 *  Constructs a Chat as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 */
Chat::Chat( QWidget* parent, const char* name, WFlags fl )
    : QWidget( parent, name, fl ),
      image0( (const char **) img0_chat ),
      image1( (const char **) img1_chat ),
      image2( (const char **) img2_chat ),
      image3( (const char **) img3_chat ),
      image4( (const char **) img4_chat ),
      image5( (const char **) img5_chat ),
      image6( (const char **) img6_chat ),
      image7( (const char **) img7_chat ),
      image8( (const char **) img8_chat ),
      image10( (const char **) img10_chat ),
      image11( (const char **) img11_chat ),
      image12( (const char **) img12_chat ),
      image13( (const char **) img13_chat ),
      image14( (const char **) img14_chat ),
      image15( (const char **) img15_chat ),
      image16( (const char **) img16_chat ),
      image17( (const char **) img17_chat ),
      image18( (const char **) img18_chat ),
      image19( (const char **) img19_chat ),
      image20( (const char **) img20_chat ),
      image21( (const char **) img21_chat ),
      image22( (const char **) img22_chat ),
      image23( (const char **) img23_chat ),
      image24( (const char **) img24_chat ),
      image25( (const char **) img25_chat ),
      image26( (const char **) img26_chat ),
      image27( (const char **) img27_chat ),
      image28( (const char **) img28_chat ),
      image29( (const char **) img29_chat ),
      image30( (const char **) img30_chat ),
      image31( (const char **) img31_chat ),
      image32( (const char **) img32_chat ),
      image33( (const char **) img33_chat ),
      image34( (const char **) img34_chat ),
      image35( (const char **) img35_chat ),
      image36( (const char **) img36_chat ),
      image37( (const char **) img37_chat ),
      image38( (const char **) img38_chat ),
      image39( (const char **) img39_chat ),
      image40( (const char **) img40_chat ),
      image41( (const char **) img41_chat ),
      image42( (const char **) img42_chat ),
      image44( (const char **) img44_chat ),
      image45( (const char **) img45_chat ),
      image46( (const char **) img46_chat )
{
    QImage img;
    img.loadFromData( img9_chat, sizeof( img9_chat ), "PNG" );
    image9 = img;
    img.loadFromData( img43_chat, sizeof( img43_chat ), "PNG" );
    image43 = img;
    if ( !name )
	setName( "Chat" );
    setMinimumSize( QSize( 440, 479 ) );
    setBaseSize( QSize( 550, 470 ) );
    setPaletteForegroundColor( QColor( 255, 255, 255 ) );
    setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    ChatLayout = new QGridLayout( this, 1, 1, 0, 0, "ChatLayout"); 

    textLabel1 = new QLabel( this, "textLabel1" );
    textLabel1->setMinimumSize( QSize( 50, 18 ) );
    textLabel1->setMaximumSize( QSize( 32767, 18 ) );
    textLabel1->setPaletteBackgroundPixmap( image0 );

    ChatLayout->addWidget( textLabel1, 0, 0 );

    frame16 = new QFrame( this, "frame16" );
    frame16->setMinimumSize( QSize( 50, 21 ) );
    frame16->setMaximumSize( QSize( 32767, 21 ) );
    frame16->setPaletteBackgroundPixmap( image1 );
    frame16->setFrameShape( QFrame::NoFrame );
    frame16->setFrameShadow( QFrame::Plain );
    frame16Layout = new QGridLayout( frame16, 1, 1, 0, 0, "frame16Layout"); 

    pixmapLabel1 = new QLabel( frame16, "pixmapLabel1" );
    pixmapLabel1->setMinimumSize( QSize( 166, 21 ) );
    pixmapLabel1->setMaximumSize( QSize( 166, 21 ) );
    pixmapLabel1->setPixmap( image2 );
    pixmapLabel1->setScaledContents( FALSE );

    frame16Layout->addWidget( pixmapLabel1, 0, 0 );

    pixmapLabel2_2 = new QLabel( frame16, "pixmapLabel2_2" );
    pixmapLabel2_2->setMinimumSize( QSize( 72, 21 ) );
    pixmapLabel2_2->setMaximumSize( QSize( 72, 21 ) );
    pixmapLabel2_2->setPixmap( image3 );
    pixmapLabel2_2->setScaledContents( FALSE );

    frame16Layout->addWidget( pixmapLabel2_2, 0, 2 );
    spacer67 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame16Layout->addItem( spacer67, 0, 1 );

    ChatLayout->addWidget( frame16, 1, 0 );
    spacer36 = new QSpacerItem( 20, 16, QSizePolicy::Minimum, QSizePolicy::Fixed );
    ChatLayout->addItem( spacer36, 3, 0 );

    layout34 = new QHBoxLayout( 0, 0, 0, "layout34"); 

    frame15 = new QFrame( this, "frame15" );
    frame15->setMinimumSize( QSize( 50, 31 ) );
    frame15->setMaximumSize( QSize( 32767, 31 ) );
    frame15->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    frame15->setPaletteBackgroundPixmap( image4 );
    frame15->setFrameShape( QFrame::NoFrame );
    frame15->setFrameShadow( QFrame::Plain );
    frame15->setLineWidth( 0 );
    frame15Layout = new QGridLayout( frame15, 1, 1, 0, 0, "frame15Layout"); 

    layout33 = new QVBoxLayout( 0, 0, 0, "layout33"); 
    spacer37 = new QSpacerItem( 20, 15, QSizePolicy::Minimum, QSizePolicy::Fixed );
    layout33->addItem( spacer37 );

    exitButtonPlaceHolder = new QLabel( frame15, "exitButtonPlaceHolder" );
    exitButtonPlaceHolder->setMinimumSize( QSize( 51, 16 ) );
    exitButtonPlaceHolder->setMaximumSize( QSize( 51, 16 ) );
    exitButtonPlaceHolder->setPixmap( image5 );
    exitButtonPlaceHolder->setScaledContents( FALSE );
    layout33->addWidget( exitButtonPlaceHolder );

    frame15Layout->addLayout( layout33, 0, 1 );
    spacer38 = new QSpacerItem( 40, 18, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame15Layout->addItem( spacer38, 0, 0 );
    layout34->addWidget( frame15 );

    aboutButtonPlaceHolder = new QLabel( this, "aboutButtonPlaceHolder" );
    aboutButtonPlaceHolder->setMinimumSize( QSize( 28, 31 ) );
    aboutButtonPlaceHolder->setMaximumSize( QSize( 28, 31 ) );
    aboutButtonPlaceHolder->setPixmap( image6 );
    aboutButtonPlaceHolder->setScaledContents( FALSE );
    layout34->addWidget( aboutButtonPlaceHolder );

    ChatLayout->addLayout( layout34, 5, 0 );

    frame17 = new QFrame( this, "frame17" );
    frame17->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)5, 0, 0, frame17->sizePolicy().hasHeightForWidth() ) );
    frame17->setMinimumSize( QSize( 50, 210 ) );
    frame17->setPaletteBackgroundPixmap( image7 );
    frame17->setBackgroundOrigin( QFrame::WidgetOrigin );
    frame17->setFrameShape( QFrame::NoFrame );
    frame17->setFrameShadow( QFrame::Plain );
    frame17->setLineWidth( 0 );
    frame17Layout = new QGridLayout( frame17, 1, 1, 0, 0, "frame17Layout"); 

    layout15 = new QHBoxLayout( 0, 0, 0, "layout15"); 
    spacer9_2 = new QSpacerItem( 15, 16, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout15->addItem( spacer9_2 );

    layout10 = new QVBoxLayout( 0, 0, 0, "layout10"); 

    pixmapLabel6 = new QLabel( frame17, "pixmapLabel6" );
    pixmapLabel6->setMinimumSize( QSize( 30, 12 ) );
    pixmapLabel6->setMaximumSize( QSize( 32767, 12 ) );
    pixmapLabel6->setPixmap( image8 );
    pixmapLabel6->setScaledContents( FALSE );
    layout10->addWidget( pixmapLabel6 );
    spacer11 = new QSpacerItem( 20, 18, QSizePolicy::Minimum, QSizePolicy::Fixed );
    layout10->addItem( spacer11 );
    layout15->addLayout( layout10 );

    upPiecePlaceHolder = new QLabel( frame17, "upPiecePlaceHolder" );
    upPiecePlaceHolder->setMinimumSize( QSize( 45, 31 ) );
    upPiecePlaceHolder->setMaximumSize( QSize( 45, 31 ) );
    upPiecePlaceHolder->setBackgroundOrigin( QLabel::AncestorOrigin );
    upPiecePlaceHolder->setPixmap( image9 );
    upPiecePlaceHolder->setScaledContents( FALSE );
    layout15->addWidget( upPiecePlaceHolder );

    frame6 = new QFrame( frame17, "frame6" );
    frame6->setMinimumSize( QSize( 170, 31 ) );
    frame6->setMaximumSize( QSize( 32767, 31 ) );
    frame6->setPaletteBackgroundPixmap( image10 );
    frame6->setFrameShape( QFrame::NoFrame );
    frame6->setFrameShadow( QFrame::Plain );
    frame6->setLineWidth( 0 );
    frame6Layout = new QGridLayout( frame6, 1, 1, 0, 30, "frame6Layout"); 
    spacer12 = new QSpacerItem( 57, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame6Layout->addItem( spacer12, 0, 0 );

    layout25 = new QHBoxLayout( 0, 0, 8, "layout25"); 

    chooseLabelPlaceHolder = new QLabel( frame6, "chooseLabelPlaceHolder" );
    chooseLabelPlaceHolder->setMinimumSize( QSize( 25, 31 ) );
    chooseLabelPlaceHolder->setMaximumSize( QSize( 25, 31 ) );
    chooseLabelPlaceHolder->setPixmap( image11 );
    chooseLabelPlaceHolder->setScaledContents( FALSE );
    layout25->addWidget( chooseLabelPlaceHolder );

    profilePlaceHolder = new QLabel( frame6, "profilePlaceHolder" );
    profilePlaceHolder->setMinimumSize( QSize( 25, 31 ) );
    profilePlaceHolder->setMaximumSize( QSize( 25, 31 ) );
    profilePlaceHolder->setPixmap( image12 );
    profilePlaceHolder->setScaledContents( FALSE );
    layout25->addWidget( profilePlaceHolder );

    addPlaceHolder = new QLabel( frame6, "addPlaceHolder" );
    addPlaceHolder->setMinimumSize( QSize( 25, 31 ) );
    addPlaceHolder->setMaximumSize( QSize( 25, 31 ) );
    addPlaceHolder->setPixmap( image13 );
    addPlaceHolder->setScaledContents( FALSE );
    layout25->addWidget( addPlaceHolder );

    stopPlaceHolder = new QLabel( frame6, "stopPlaceHolder" );
    stopPlaceHolder->setMinimumSize( QSize( 25, 31 ) );
    stopPlaceHolder->setMaximumSize( QSize( 25, 31 ) );
    stopPlaceHolder->setPixmap( image14 );
    stopPlaceHolder->setScaledContents( FALSE );
    layout25->addWidget( stopPlaceHolder );

    soundPlaceHolder = new QLabel( frame6, "soundPlaceHolder" );
    soundPlaceHolder->setMinimumSize( QSize( 25, 31 ) );
    soundPlaceHolder->setMaximumSize( QSize( 25, 31 ) );
    soundPlaceHolder->setBackgroundOrigin( QLabel::AncestorOrigin );
    soundPlaceHolder->setPixmap( image15 );
    soundPlaceHolder->setScaledContents( FALSE );
    layout25->addWidget( soundPlaceHolder );

    logPlaceHolder = new QLabel( frame6, "logPlaceHolder" );
    logPlaceHolder->setMinimumSize( QSize( 25, 31 ) );
    logPlaceHolder->setMaximumSize( QSize( 25, 31 ) );
    logPlaceHolder->setBackgroundOrigin( QLabel::AncestorOrigin );
    logPlaceHolder->setPixmap( image16 );
    logPlaceHolder->setScaledContents( FALSE );
    layout25->addWidget( logPlaceHolder );

    frame6Layout->addLayout( layout25, 0, 1 );
    layout15->addWidget( frame6 );

    pixmapLabel2 = new QLabel( frame17, "pixmapLabel2" );
    pixmapLabel2->setMinimumSize( QSize( 11, 31 ) );
    pixmapLabel2->setMaximumSize( QSize( 11, 31 ) );
    pixmapLabel2->setPixmap( image17 );
    pixmapLabel2->setScaledContents( FALSE );
    layout15->addWidget( pixmapLabel2 );
    spacer9_2_2 = new QSpacerItem( 15, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout15->addItem( spacer9_2_2 );

    frame17Layout->addMultiCellLayout( layout15, 3, 3, 0, 1 );

    layout17 = new QHBoxLayout( 0, 0, 0, "layout17"); 
    spacer14 = new QSpacerItem( 15, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout17->addItem( spacer14 );

    frame14 = new QFrame( frame17, "frame14" );
    frame14->setMinimumSize( QSize( 50, 10 ) );
    frame14->setPaletteForegroundColor( QColor( 3, 118, 231 ) );
    frame14->setFrameShape( QFrame::Box );
    frame14->setFrameShadow( QFrame::Plain );
    frame14Layout = new QGridLayout( frame14, 1, 1, 1, 0, "frame14Layout"); 

    otherChatPlaceHolder = new QTextEdit( frame14, "otherChatPlaceHolder" );
    otherChatPlaceHolder->setMinimumSize( QSize( 0, 10 ) );
    otherChatPlaceHolder->setMaximumSize( QSize( 32767, 32767 ) );
    otherChatPlaceHolder->setFrameShape( QTextEdit::NoFrame );
    otherChatPlaceHolder->setFrameShadow( QTextEdit::Plain );
    otherChatPlaceHolder->setLineWidth( 2 );

    frame14Layout->addWidget( otherChatPlaceHolder, 0, 0 );
    layout17->addWidget( frame14 );
    spacer15 = new QSpacerItem( 15, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout17->addItem( spacer15 );

    frame17Layout->addMultiCellLayout( layout17, 2, 2, 0, 1 );
    spacer14_3 = new QSpacerItem( 20, 2, QSizePolicy::Minimum, QSizePolicy::Fixed );
    frame17Layout->addItem( spacer14_3, 4, 0 );
    spacer13 = new QSpacerItem( 20, 12, QSizePolicy::Minimum, QSizePolicy::Fixed );
    frame17Layout->addItem( spacer13, 0, 1 );

    layout23 = new QHBoxLayout( 0, 0, 0, "layout23"); 
    spacer15_3 = new QSpacerItem( 14, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout23->addItem( spacer15_3 );

    frame7 = new QFrame( frame17, "frame7" );
    frame7->setMinimumSize( QSize( 0, 50 ) );
    frame7->setMaximumSize( QSize( 32767, 50 ) );
    frame7->setBackgroundOrigin( QFrame::AncestorOrigin );
    frame7->setFrameShape( QFrame::NoFrame );
    frame7->setFrameShadow( QFrame::Plain );
    frame7->setLineWidth( 0 );
    frame7Layout = new QGridLayout( frame7, 1, 1, 0, 0, "frame7Layout"); 

    layout16 = new QHBoxLayout( 0, 0, 0, "layout16"); 

    pixmapLabel4_3 = new QLabel( frame7, "pixmapLabel4_3" );
    pixmapLabel4_3->setMinimumSize( QSize( 127, 19 ) );
    pixmapLabel4_3->setMaximumSize( QSize( 127, 19 ) );
    pixmapLabel4_3->setBackgroundOrigin( QLabel::AncestorOrigin );
    pixmapLabel4_3->setPixmap( image18 );
    pixmapLabel4_3->setScaledContents( FALSE );
    layout16->addWidget( pixmapLabel4_3 );

    frame7Layout->addLayout( layout16, 0, 0 );

    frame8 = new QFrame( frame7, "frame8" );
    frame8->setMinimumSize( QSize( 50, 29 ) );
    frame8->setMaximumSize( QSize( 32767, 29 ) );
    frame8->setPaletteBackgroundPixmap( image19 );
    frame8->setBackgroundOrigin( QFrame::WidgetOrigin );
    frame8->setFrameShape( QFrame::NoFrame );
    frame8->setFrameShadow( QFrame::Plain );
    frame8->setLineWidth( 0 );
    frame8Layout = new QGridLayout( frame8, 1, 1, 0, 5, "frame8Layout"); 

    layout18 = new QHBoxLayout( 0, 0, 0, "layout18"); 

    pixmapLabel9 = new QLabel( frame8, "pixmapLabel9" );
    pixmapLabel9->setMinimumSize( QSize( 4, 29 ) );
    pixmapLabel9->setMaximumSize( QSize( 4, 29 ) );
    pixmapLabel9->setBackgroundOrigin( QLabel::AncestorOrigin );
    pixmapLabel9->setPixmap( image20 );
    pixmapLabel9->setScaledContents( FALSE );
    layout18->addWidget( pixmapLabel9 );

    pixmapLabel10 = new QLabel( frame8, "pixmapLabel10" );
    pixmapLabel10->setMinimumSize( QSize( 26, 24 ) );
    pixmapLabel10->setMaximumSize( QSize( 26, 24 ) );
    pixmapLabel10->setPixmap( image21 );
    pixmapLabel10->setScaledContents( FALSE );
    layout18->addWidget( pixmapLabel10 );

    layout17_2 = new QVBoxLayout( 0, 0, 0, "layout17_2"); 

    pixmapLabel11 = new QLabel( frame8, "pixmapLabel11" );
    pixmapLabel11->setMinimumSize( QSize( 67, 5 ) );
    pixmapLabel11->setMaximumSize( QSize( 67, 5 ) );
    pixmapLabel11->setLineWidth( 0 );
    pixmapLabel11->setPixmap( image22 );
    pixmapLabel11->setScaledContents( FALSE );
    layout17_2->addWidget( pixmapLabel11 );

    transmitBar = new QProgressBar( frame8, "transmitBar" );
    transmitBar->setMinimumSize( QSize( 130, 10 ) );
    transmitBar->setMaximumSize( QSize( 130, 9 ) );
    transmitBar->setProgress( 31 );
    transmitBar->setCenterIndicator( FALSE );
    transmitBar->setIndicatorFollowsStyle( FALSE );
    transmitBar->setPercentageVisible( FALSE );
    layout17_2->addWidget( transmitBar );
    layout18->addLayout( layout17_2 );

    frame8Layout->addLayout( layout18, 0, 0 );

    pixmapLabel13 = new QLabel( frame8, "pixmapLabel13" );
    pixmapLabel13->setMinimumSize( QSize( 5, 29 ) );
    pixmapLabel13->setMaximumSize( QSize( 5, 29 ) );
    pixmapLabel13->setPixmap( image23 );
    pixmapLabel13->setScaledContents( FALSE );

    frame8Layout->addWidget( pixmapLabel13, 0, 6 );

    pixmapLabel14 = new QLabel( frame8, "pixmapLabel14" );
    pixmapLabel14->setMinimumSize( QSize( 19, 24 ) );
    pixmapLabel14->setMaximumSize( QSize( 19, 24 ) );
    pixmapLabel14->setPixmap( image24 );
    pixmapLabel14->setScaledContents( FALSE );

    frame8Layout->addWidget( pixmapLabel14, 0, 5 );

    layout19 = new QVBoxLayout( 0, 0, 0, "layout19"); 

    pixmapLabel15 = new QLabel( frame8, "pixmapLabel15" );
    pixmapLabel15->setMinimumSize( QSize( 97, 5 ) );
    pixmapLabel15->setMaximumSize( QSize( 97, 5 ) );
    pixmapLabel15->setPixmap( image25 );
    pixmapLabel15->setScaledContents( FALSE );
    layout19->addWidget( pixmapLabel15 );

    receiveBar = new QProgressBar( frame8, "receiveBar" );
    receiveBar->setMinimumSize( QSize( 130, 10 ) );
    receiveBar->setMaximumSize( QSize( 130, 9 ) );
    receiveBar->setProgress( 39 );
    receiveBar->setCenterIndicator( FALSE );
    receiveBar->setIndicatorFollowsStyle( FALSE );
    receiveBar->setPercentageVisible( FALSE );
    layout19->addWidget( receiveBar );

    frame8Layout->addLayout( layout19, 0, 4 );
    spacer13_2 = new QSpacerItem( 97, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame8Layout->addItem( spacer13_2, 0, 2 );

    stopTransmitPlaceHolder = new QLabel( frame8, "stopTransmitPlaceHolder" );
    stopTransmitPlaceHolder->setMinimumSize( QSize( 13, 12 ) );
    stopTransmitPlaceHolder->setMaximumSize( QSize( 13, 12 ) );
    stopTransmitPlaceHolder->setPixmap( image26 );
    stopTransmitPlaceHolder->setScaledContents( FALSE );

    frame8Layout->addWidget( stopTransmitPlaceHolder, 0, 1 );

    stopReceivePlaceHolder = new QLabel( frame8, "stopReceivePlaceHolder" );
    stopReceivePlaceHolder->setMinimumSize( QSize( 13, 12 ) );
    stopReceivePlaceHolder->setMaximumSize( QSize( 13, 12 ) );
    stopReceivePlaceHolder->setPixmap( image26 );
    stopReceivePlaceHolder->setScaledContents( FALSE );

    frame8Layout->addWidget( stopReceivePlaceHolder, 0, 3 );

    frame7Layout->addMultiCellWidget( frame8, 1, 1, 0, 1 );
    spacer19 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame7Layout->addItem( spacer19, 0, 1 );
    layout23->addWidget( frame7 );
    spacer15_3_2 = new QSpacerItem( 14, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout23->addItem( spacer15_3_2 );

    frame17Layout->addMultiCellLayout( layout23, 5, 5, 0, 1 );

    layout40 = new QHBoxLayout( 0, 0, 0, "layout40"); 
    spacer14_2 = new QSpacerItem( 15, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout40->addItem( spacer14_2 );

    pixmapLabel4_2 = new QLabel( frame17, "pixmapLabel4_2" );
    pixmapLabel4_2->setMinimumSize( QSize( 0, 23 ) );
    pixmapLabel4_2->setMaximumSize( QSize( 11, 23 ) );
    pixmapLabel4_2->setPixmap( image27 );
    pixmapLabel4_2->setScaledContents( FALSE );
    layout40->addWidget( pixmapLabel4_2 );

    frame28 = new QFrame( frame17, "frame28" );
    frame28->setMinimumSize( QSize( 50, 23 ) );
    frame28->setMaximumSize( QSize( 32767, 23 ) );
    frame28->setPaletteBackgroundPixmap( image28 );
    frame28->setFrameShape( QFrame::NoFrame );
    frame28->setFrameShadow( QFrame::Plain );

    otherNickLabel = new QLabel( frame28, "otherNickLabel" );
    otherNickLabel->setGeometry( QRect( 0, 4, 275, 18 ) );
    otherNickLabel->setMinimumSize( QSize( 0, 18 ) );
    otherNickLabel->setMaximumSize( QSize( 32767, 18 ) );
    otherNickLabel->setPaletteForegroundColor( QColor( 0, 0, 0 ) );
    otherNickLabel->setBackgroundOrigin( QLabel::AncestorOrigin );
    QFont otherNickLabel_font(  otherNickLabel->font() );
    otherNickLabel_font.setBold( TRUE );
    otherNickLabel->setFont( otherNickLabel_font ); 
    layout40->addWidget( frame28 );

    pixmapLabel4 = new QLabel( frame17, "pixmapLabel4" );
    pixmapLabel4->setMinimumSize( QSize( 0, 23 ) );
    pixmapLabel4->setMaximumSize( QSize( 11, 23 ) );
    pixmapLabel4->setPixmap( image29 );
    pixmapLabel4->setScaledContents( FALSE );
    layout40->addWidget( pixmapLabel4 );
    spacer15_2 = new QSpacerItem( 15, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout40->addItem( spacer15_2 );

    frame17Layout->addMultiCellLayout( layout40, 1, 1, 0, 1 );

    ChatLayout->addWidget( frame17, 2, 0 );

    pixmapLabel9_2 = new QLabel( this, "pixmapLabel9_2" );
    pixmapLabel9_2->setMinimumSize( QSize( 50, 22 ) );
    pixmapLabel9_2->setMaximumSize( QSize( 32767, 22 ) );
    pixmapLabel9_2->setPaletteBackgroundPixmap( image30 );
    pixmapLabel9_2->setScaledContents( FALSE );

    ChatLayout->addWidget( pixmapLabel9_2, 6, 0 );

    layout54 = new QHBoxLayout( 0, 0, 0, "layout54"); 

    layout53 = new QHBoxLayout( 0, 0, 0, "layout53"); 
    spacer66 = new QSpacerItem( 13, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout53->addItem( spacer66 );

    frame16_2 = new QFrame( this, "frame16_2" );
    frame16_2->setMinimumSize( QSize( 98, 151 ) );
    frame16_2->setMaximumSize( QSize( 98, 151 ) );
    frame16_2->setFrameShape( QFrame::NoFrame );
    frame16_2->setFrameShadow( QFrame::Plain );
    frame16_2->setLineWidth( 0 );
    frame16_2Layout = new QGridLayout( frame16_2, 1, 1, 1, 0, "frame16_2Layout"); 

    userPicture = new QLabel( frame16_2, "userPicture" );
    userPicture->setMinimumSize( QSize( 96, 114 ) );
    userPicture->setMaximumSize( QSize( 96, 114 ) );
    userPicture->setPaletteForegroundColor( QColor( 3, 118, 231 ) );
    userPicture->setFrameShape( QLabel::Box );
    userPicture->setLineWidth( 1 );
    userPicture->setPixmap( image31 );
    userPicture->setScaledContents( TRUE );

    frame16_2Layout->addWidget( userPicture, 1, 0 );

    layout49 = new QHBoxLayout( 0, 0, 0, "layout49"); 

    pixmapLabel4_4_2 = new QLabel( frame16_2, "pixmapLabel4_4_2" );
    pixmapLabel4_4_2->setMinimumSize( QSize( 11, 18 ) );
    pixmapLabel4_4_2->setMaximumSize( QSize( 11, 18 ) );
    pixmapLabel4_4_2->setPixmap( image32 );
    pixmapLabel4_4_2->setScaledContents( FALSE );
    layout49->addWidget( pixmapLabel4_4_2 );

    frame29_2 = new QFrame( frame16_2, "frame29_2" );
    frame29_2->setMinimumSize( QSize( 74, 18 ) );
    frame29_2->setMaximumSize( QSize( 74, 18 ) );
    frame29_2->setPaletteBackgroundPixmap( image33 );
    frame29_2->setFrameShape( QFrame::NoFrame );
    frame29_2->setFrameShadow( QFrame::Raised );
    layout49->addWidget( frame29_2 );

    pixmapLabel6_2_2 = new QLabel( frame16_2, "pixmapLabel6_2_2" );
    pixmapLabel6_2_2->setMinimumSize( QSize( 11, 18 ) );
    pixmapLabel6_2_2->setMaximumSize( QSize( 11, 18 ) );
    pixmapLabel6_2_2->setPixmap( image34 );
    pixmapLabel6_2_2->setScaledContents( TRUE );
    layout49->addWidget( pixmapLabel6_2_2 );

    frame16_2Layout->addLayout( layout49, 2, 0 );

    layout48 = new QHBoxLayout( 0, 0, 0, "layout48"); 

    pixmapLabel4_2_2 = new QLabel( frame16_2, "pixmapLabel4_2_2" );
    pixmapLabel4_2_2->setMinimumSize( QSize( 0, 18 ) );
    pixmapLabel4_2_2->setMaximumSize( QSize( 11, 18 ) );
    pixmapLabel4_2_2->setPixmap( image35 );
    pixmapLabel4_2_2->setScaledContents( FALSE );
    layout48->addWidget( pixmapLabel4_2_2 );

    frame29 = new QFrame( frame16_2, "frame29" );
    frame29->setMinimumSize( QSize( 74, 18 ) );
    frame29->setMaximumSize( QSize( 74, 18 ) );
    frame29->setPaletteBackgroundPixmap( image36 );
    frame29->setFrameShape( QFrame::NoFrame );
    frame29->setFrameShadow( QFrame::Raised );
    layout48->addWidget( frame29 );

    pixmapLabel4_5 = new QLabel( frame16_2, "pixmapLabel4_5" );
    pixmapLabel4_5->setMinimumSize( QSize( 0, 18 ) );
    pixmapLabel4_5->setMaximumSize( QSize( 11, 18 ) );
    pixmapLabel4_5->setPixmap( image37 );
    pixmapLabel4_5->setScaledContents( FALSE );
    layout48->addWidget( pixmapLabel4_5 );

    frame16_2Layout->addLayout( layout48, 0, 0 );
    layout53->addWidget( frame16_2 );
    layout54->addLayout( layout53 );

    layout51 = new QVBoxLayout( 0, 0, 0, "layout51"); 

    frame11 = new QFrame( this, "frame11" );
    frame11->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)2, 0, 0, frame11->sizePolicy().hasHeightForWidth() ) );
    frame11->setMinimumSize( QSize( 10, 20 ) );
    frame11->setMaximumSize( QSize( 32767, 133 ) );
    frame11->setPaletteForegroundColor( QColor( 255, 255, 255 ) );
    frame11->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    frame11->setBackgroundOrigin( QFrame::WidgetOrigin );
    frame11->setFrameShape( QFrame::NoFrame );
    frame11->setFrameShadow( QFrame::Plain );
    frame11->setLineWidth( 0 );
    frame11Layout = new QGridLayout( frame11, 1, 1, 0, 0, "frame11Layout"); 
    spacer23_2 = new QSpacerItem( 16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    frame11Layout->addItem( spacer23_2, 1, 5 );
    spacer22_2 = new QSpacerItem( 16, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    frame11Layout->addItem( spacer22_2, 1, 0 );
    spacer20 = new QSpacerItem( 16, 18, QSizePolicy::Fixed, QSizePolicy::Minimum );
    frame11Layout->addItem( spacer20, 0, 0 );

    pixmapLabel16 = new QLabel( frame11, "pixmapLabel16" );
    pixmapLabel16->setMinimumSize( QSize( 6, 32 ) );
    pixmapLabel16->setMaximumSize( QSize( 6, 32 ) );
    pixmapLabel16->setPixmap( image38 );
    pixmapLabel16->setScaledContents( TRUE );

    frame11Layout->addWidget( pixmapLabel16, 0, 1 );

    frame10_2 = new QFrame( frame11, "frame10_2" );
    frame10_2->setMinimumSize( QSize( 50, 20 ) );
    frame10_2->setMaximumSize( QSize( 32767, 101 ) );
    frame10_2->setPaletteForegroundColor( QColor( 3, 118, 231 ) );
    frame10_2->setBackgroundOrigin( QFrame::AncestorOrigin );
    frame10_2->setFrameShape( QFrame::Box );
    frame10_2->setFrameShadow( QFrame::Plain );
    frame10_2->setLineWidth( 1 );
    frame10_2Layout = new QGridLayout( frame10_2, 1, 1, 0, 0, "frame10_2Layout"); 

    layout20 = new QVBoxLayout( 0, 0, 0, "layout20"); 

    sendButtonPlaceHolder = new QLabel( frame10_2, "sendButtonPlaceHolder" );
    sendButtonPlaceHolder->setMinimumSize( QSize( 52, 74 ) );
    sendButtonPlaceHolder->setMaximumSize( QSize( 52, 74 ) );
    sendButtonPlaceHolder->setMargin( 0 );
    sendButtonPlaceHolder->setMidLineWidth( 0 );
    sendButtonPlaceHolder->setPixmap( image39 );
    sendButtonPlaceHolder->setScaledContents( FALSE );
    layout20->addWidget( sendButtonPlaceHolder );

    frame10_2Layout->addLayout( layout20, 1, 5 );
    spacer40 = new QSpacerItem( 16, 61, QSizePolicy::Fixed, QSizePolicy::Minimum );
    frame10_2Layout->addItem( spacer40, 1, 6 );
    spacer41 = new QSpacerItem( 16, 62, QSizePolicy::Fixed, QSizePolicy::Minimum );
    frame10_2Layout->addItem( spacer41, 1, 4 );
    spacer50 = new QSpacerItem( 8, 44, QSizePolicy::Fixed, QSizePolicy::Minimum );
    frame10_2Layout->addItem( spacer50, 1, 0 );

    layout38 = new QHBoxLayout( 0, 0, 0, "layout38"); 
    spacer180 = new QSpacerItem( 1, 20, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout38->addItem( spacer180 );

    frame27 = new QFrame( frame10_2, "frame27" );
    frame27->setMinimumSize( QSize( 10, 21 ) );
    frame27->setMaximumSize( QSize( 32767, 21 ) );
    frame27->setPaletteBackgroundPixmap( image40 );
    frame27->setFrameShape( QFrame::NoFrame );
    frame27->setFrameShadow( QFrame::Plain );
    frame27->setMargin( 0 );
    frame27->setMidLineWidth( 0 );

    myNickLabel = new QLabel( frame27, "myNickLabel" );
    myNickLabel->setGeometry( QRect( 10, 2, 200, 16 ) );
    myNickLabel->setMinimumSize( QSize( 0, 16 ) );
    myNickLabel->setMaximumSize( QSize( 32767, 16 ) );
    myNickLabel->setPaletteForegroundColor( QColor( 0, 0, 0 ) );
    QFont myNickLabel_font(  myNickLabel->font() );
    myNickLabel_font.setBold( TRUE );
    myNickLabel->setFont( myNickLabel_font ); 
    layout38->addWidget( frame27 );
    spacer64 = new QSpacerItem( 1, 10, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout38->addItem( spacer64 );

    frame10_2Layout->addMultiCellLayout( layout38, 0, 0, 0, 6 );

    MyChat = new QTextEdit( frame10_2, "MyChat" );
    MyChat->setMinimumSize( QSize( 10, 10 ) );
    MyChat->setMaximumSize( QSize( 32767, 77 ) );
    MyChat->setPaletteForegroundColor( QColor( 3, 118, 232 ) );
    QPalette pal;
    QColorGroup cg;
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, QColor( 3, 118, 232) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 3, 118, 231) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, QColor( 3, 118, 232) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, QColor( 3, 118, 232) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 103, 141, 178) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 238) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 82, 24, 139) );
    pal.setDisabled( cg );
    MyChat->setPalette( pal );
    MyChat->setBackgroundOrigin( QTextEdit::WindowOrigin );
    MyChat->setFrameShape( QTextEdit::NoFrame );
    MyChat->setFrameShadow( QTextEdit::Plain );
    MyChat->setLineWidth( 1 );
    MyChat->setVScrollBarMode( QTextEdit::Auto );
    MyChat->setHScrollBarMode( QTextEdit::AlwaysOff );
    MyChat->setWrapPolicy( QTextEdit::Anywhere );

    frame10_2Layout->addWidget( MyChat, 1, 3 );

    frame11Layout->addMultiCellWidget( frame10_2, 1, 1, 1, 4 );

    frame9 = new QFrame( frame11, "frame9" );
    frame9->setMinimumSize( QSize( 120, 32 ) );
    frame9->setMaximumSize( QSize( 32767, 32 ) );
    frame9->setPaletteForegroundColor( QColor( 255, 255, 255 ) );
    frame9->setPaletteBackgroundPixmap( image41 );
    frame9->setBackgroundOrigin( QFrame::AncestorOrigin );
    frame9->setFrameShape( QFrame::NoFrame );
    frame9->setFrameShadow( QFrame::Plain );
    frame9->setLineWidth( 0 );
    frame9Layout = new QGridLayout( frame9, 1, 1, 0, 0, "frame9Layout"); 

    layout50 = new QHBoxLayout( 0, 0, 6, "layout50"); 

    smileyPlaceHolder = new QLabel( frame9, "smileyPlaceHolder" );
    smileyPlaceHolder->setMinimumSize( QSize( 25, 32 ) );
    smileyPlaceHolder->setMaximumSize( QSize( 25, 32 ) );
    smileyPlaceHolder->setBackgroundOrigin( QLabel::AncestorOrigin );
    smileyPlaceHolder->setPixmap( image42 );
    smileyPlaceHolder->setScaledContents( FALSE );
    layout50->addWidget( smileyPlaceHolder );

    boldPlaceHolder = new QLabel( frame9, "boldPlaceHolder" );
    boldPlaceHolder->setMinimumSize( QSize( 25, 32 ) );
    boldPlaceHolder->setMaximumSize( QSize( 25, 32 ) );
    boldPlaceHolder->setBackgroundOrigin( QLabel::AncestorOrigin );
    boldPlaceHolder->setPixmap( image42 );
    boldPlaceHolder->setScaledContents( FALSE );
    layout50->addWidget( boldPlaceHolder );

    italicPlaceHolder = new QLabel( frame9, "italicPlaceHolder" );
    italicPlaceHolder->setMinimumSize( QSize( 25, 32 ) );
    italicPlaceHolder->setMaximumSize( QSize( 25, 32 ) );
    italicPlaceHolder->setBackgroundOrigin( QLabel::AncestorOrigin );
    italicPlaceHolder->setPixmap( image42 );
    italicPlaceHolder->setScaledContents( FALSE );
    layout50->addWidget( italicPlaceHolder );

    underlinePlaceHolder = new QLabel( frame9, "underlinePlaceHolder" );
    underlinePlaceHolder->setMinimumSize( QSize( 25, 32 ) );
    underlinePlaceHolder->setMaximumSize( QSize( 25, 32 ) );
    underlinePlaceHolder->setBackgroundOrigin( QLabel::AncestorOrigin );
    underlinePlaceHolder->setPixmap( image42 );
    underlinePlaceHolder->setScaledContents( FALSE );
    layout50->addWidget( underlinePlaceHolder );

    colorPlaceHolder = new QLabel( frame9, "colorPlaceHolder" );
    colorPlaceHolder->setMinimumSize( QSize( 25, 32 ) );
    colorPlaceHolder->setMaximumSize( QSize( 25, 32 ) );
    colorPlaceHolder->setBackgroundOrigin( QLabel::AncestorOrigin );
    colorPlaceHolder->setPixmap( image42 );
    colorPlaceHolder->setScaledContents( FALSE );
    layout50->addWidget( colorPlaceHolder );

    fontPlaceHolder = new QLabel( frame9, "fontPlaceHolder" );
    fontPlaceHolder->setMinimumSize( QSize( 25, 32 ) );
    fontPlaceHolder->setMaximumSize( QSize( 25, 32 ) );
    fontPlaceHolder->setBackgroundOrigin( QLabel::AncestorOrigin );
    fontPlaceHolder->setPixmap( image42 );
    fontPlaceHolder->setScaledContents( FALSE );
    layout50->addWidget( fontPlaceHolder );
    spacer21_2 = new QSpacerItem( 50, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout50->addItem( spacer21_2 );

    frame9Layout->addLayout( layout50, 0, 0 );

    frame11Layout->addWidget( frame9, 0, 2 );

    downPiecePlaceHolder = new QLabel( frame11, "downPiecePlaceHolder" );
    downPiecePlaceHolder->setMinimumSize( QSize( 43, 32 ) );
    downPiecePlaceHolder->setMaximumSize( QSize( 43, 32 ) );
    downPiecePlaceHolder->setBackgroundOrigin( QLabel::AncestorOrigin );
    downPiecePlaceHolder->setLineWidth( 0 );
    downPiecePlaceHolder->setMargin( 0 );
    downPiecePlaceHolder->setMidLineWidth( 0 );
    downPiecePlaceHolder->setPixmap( image43 );
    downPiecePlaceHolder->setScaledContents( FALSE );
    downPiecePlaceHolder->setIndent( -1 );

    frame11Layout->addWidget( downPiecePlaceHolder, 0, 3 );

    layout25_2 = new QHBoxLayout( 0, 0, 0, "layout25_2"); 

    frame10 = new QFrame( frame11, "frame10" );
    frame10->setMinimumSize( QSize( 10, 32 ) );
    frame10->setMaximumSize( QSize( 32767, 32 ) );
    frame10->setBackgroundOrigin( QFrame::AncestorOrigin );
    frame10->setFrameShape( QFrame::NoFrame );
    frame10->setFrameShadow( QFrame::Plain );
    frame10->setLineWidth( 0 );
    frame10Layout = new QGridLayout( frame10, 1, 1, 0, 0, "frame10Layout"); 

    pixmapLabel1_2 = new QLabel( frame10, "pixmapLabel1_2" );
    pixmapLabel1_2->setMinimumSize( QSize( 28, 12 ) );
    pixmapLabel1_2->setMaximumSize( QSize( 28, 12 ) );
    pixmapLabel1_2->setPixmap( image44 );
    pixmapLabel1_2->setScaledContents( FALSE );

    frame10Layout->addWidget( pixmapLabel1_2, 2, 1 );

    layout24 = new QHBoxLayout( 0, 0, 2, "layout24"); 
    spacer22 = new QSpacerItem( 40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    layout24->addItem( spacer22 );

    fileReceptionLabel = new QLabel( frame10, "fileReceptionLabel" );
    fileReceptionLabel->setMinimumSize( QSize( 0, 0 ) );
    fileReceptionLabel->setPaletteForegroundColor( QColor( 3, 118, 231 ) );
    layout24->addWidget( fileReceptionLabel );

    receiveSwitch = new QCheckBox( frame10, "receiveSwitch" );
    receiveSwitch->setMinimumSize( QSize( 17, 12 ) );
    receiveSwitch->setMaximumSize( QSize( 17, 14 ) );
    receiveSwitch->setPaletteForegroundColor( QColor( 0, 0, 0 ) );
    receiveSwitch->setBackgroundOrigin( QCheckBox::AncestorOrigin );
    QFont receiveSwitch_font(  receiveSwitch->font() );
    receiveSwitch->setFont( receiveSwitch_font ); 
    layout24->addWidget( receiveSwitch );

    frame10Layout->addMultiCellLayout( layout24, 0, 0, 0, 1 );

    pixmapLabel18 = new QLabel( frame10, "pixmapLabel18" );
    pixmapLabel18->setMinimumSize( QSize( 10, 12 ) );
    pixmapLabel18->setMaximumSize( QSize( 32767, 12 ) );
    pixmapLabel18->setPaletteBackgroundPixmap( image45 );
    pixmapLabel18->setBackgroundOrigin( QLabel::WidgetOrigin );
    pixmapLabel18->setLineWidth( 0 );
    pixmapLabel18->setScaledContents( FALSE );

    frame10Layout->addMultiCellWidget( pixmapLabel18, 1, 2, 0, 0 );
    layout25_2->addWidget( frame10 );
    spacer21 = new QSpacerItem( 16, 28, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout25_2->addItem( spacer21 );

    frame11Layout->addMultiCellLayout( layout25_2, 0, 0, 4, 5 );
    layout51->addWidget( frame11 );

    layout76 = new QHBoxLayout( 0, 0, 0, "layout76"); 
    spacer114_2 = new QSpacerItem( 16, 11, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout76->addItem( spacer114_2 );

    layout22 = new QHBoxLayout( 0, 0, 0, "layout22"); 

    pixmapLabel4_4 = new QLabel( this, "pixmapLabel4_4" );
    pixmapLabel4_4->setMinimumSize( QSize( 11, 18 ) );
    pixmapLabel4_4->setMaximumSize( QSize( 11, 18 ) );
    pixmapLabel4_4->setPixmap( image32 );
    pixmapLabel4_4->setScaledContents( FALSE );
    layout22->addWidget( pixmapLabel4_4 );

    pixmapLabel5 = new QLabel( this, "pixmapLabel5" );
    pixmapLabel5->setMinimumSize( QSize( 170, 18 ) );
    pixmapLabel5->setMaximumSize( QSize( 32767, 18 ) );
    pixmapLabel5->setPaletteBackgroundPixmap( image46 );
    pixmapLabel5->setScaledContents( TRUE );
    layout22->addWidget( pixmapLabel5 );

    pixmapLabel6_2 = new QLabel( this, "pixmapLabel6_2" );
    pixmapLabel6_2->setMinimumSize( QSize( 11, 18 ) );
    pixmapLabel6_2->setMaximumSize( QSize( 11, 18 ) );
    pixmapLabel6_2->setPixmap( image34 );
    pixmapLabel6_2->setScaledContents( TRUE );
    layout22->addWidget( pixmapLabel6_2 );
    layout76->addLayout( layout22 );
    spacer114 = new QSpacerItem( 16, 10, QSizePolicy::Fixed, QSizePolicy::Minimum );
    layout76->addItem( spacer114 );
    layout51->addLayout( layout76 );
    layout54->addLayout( layout51 );

    ChatLayout->addLayout( layout54, 4, 0 );
    languageChange();
    resize( QSize(553, 479).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );
}

/*
 *  Destroys the object and frees any allocated resources
 */
Chat::~Chat()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void Chat::languageChange()
{
    setCaption( ( "Form1" ) );
    otherNickLabel->setText( ( "textLabel2g" ) );
    myNickLabel->setText( ( "textLabel2g" ) );
    fileReceptionLabel->setText( ( "Ricezione file" ) );
    receiveSwitch->setText( QString::null );
}

#include "chat.moc"
