
/****************************************************************************
** Form implementation generated from reading ui file './login_dlg.ui'
**
** Created: Sun Dec 17 12:39:12 2006
**      by: The User Interface Compiler ($Id: qt/main.cpp   3.3.4   edited Nov 24 2003 $)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/

#include "login_dlg.h"

#include <qvariant.h>
#include <qpushbutton.h>
#include <qframe.h>
#include <qlabel.h>
#include <qlineedit.h>
#include <qcombobox.h>
#include <qcheckbox.h>
#include <qlayout.h>
#include <qtooltip.h>
#include <qwhatsthis.h>
#include <qimage.h>
#include <qpixmap.h>

static const char* const img0_login_dlg[] = { 
"51 54 3 1",
". c #004991",
"# c #004a91",
"a c #004a92",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
".................#.................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"............#...................#..................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"....................................a..............",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"...................................................",
"..................................................."};

static const char* const img1_login_dlg[] = { 
"44 40 831 2",
".g c #000810",
".b c #000911",
".J c #000912",
"jp c #000913",
"i6 c #000a13",
".7 c #000a14",
"ie c #000b16",
"#x c #000b17",
"cQ c #000c17",
"ew c #000c18",
"hQ c #000d1a",
"#3 c #000d1b",
"j1 c #000e1c",
"kT c #000f1d",
"kc c #000f1e",
"aA c #000f1f",
"ki c #001020",
"dr c #001121",
"a9 c #001223",
"kU c #001224",
"k. c #001326",
"e1 c #001427",
"bI c #001428",
"kS c #00152a",
"jo c #00152b",
"jE c #00162b",
"i5 c #00162c",
"d1 c #00172d",
"iH c #00172e",
"gY c #00182f",
".l c #001830",
".f c #001931",
".a c #001932",
".I c #001a33",
"j0 c #001a34",
"k1 c #001b35",
".6 c #001b36",
"k0 c #001b37",
"kp c #001c37",
"fw c #001c38",
"k2 c #001d39",
"kZ c #001d3a",
"#w c #001d3b",
"ev c #001e3c",
"j9 c #001f3d",
"kY c #001f3e",
"kA c #00203f",
"#2 c #002040",
"k3 c #002142",
"kX c #002244",
"az c #002347",
"hp c #002448",
"dq c #002549",
"kW c #00254a",
"jD c #00264a",
"jn c #00264b",
"jO c #00264c",
"a8 c #00274d",
"jT c #00274e",
"e0 c #00284f",
"iG c #002850",
"kz c #002951",
"jZ c #002952",
"kR c #002a54",
"bH c #002b55",
"id c #002c56",
"d0 c #002c58",
"j8 c #002d59",
"cf c #002f5d",
"kV c #003060",
".e c #003161",
".# c #003162",
".H c #003262",
"gr c #003264",
".5 c #003365",
"cP c #003366",
"eu c #003466",
"#v c #003467",
"ko c #003569",
"jC c #00356a",
"jm c #00366a",
"#1 c #00366b",
"ho c #00376d",
"jY c #00376e",
"ay c #00386f",
"iF c #003870",
"dp c #003971",
"j7 c #003972",
"a7 c #003a74",
"k6 c #003b75",
"ic c #003c76",
"gX c #003c77",
"bG c #003d79",
"kn c #003d7a",
"dZ c #003e7b",
"ce c #003f7e",
"hP c #00407e",
"k5 c #00407f",
"fv c #004080",
".d c #004181",
"Qt c #004182",
"jX c #004282",
".4 c #004283",
"j6 c #004284",
"#u c #004384",
"iE c #004385",
"k8 c #004386",
"#0 c #004486",
"k7 c #004487",
"kQ c #004488",
"ax c #004588",
"do c #004589",
"eZ c #00458a",
"gW c #00468a",
"a6 c #00468b",
"jN c #00468c",
"jB c #00478c",
"bF c #00478d",
"i4 c #00478e",
"fu c #00488e",
"cd c #00488f",
"cO c #004890",
"dn c #004990",
"dY c #004991",
"k4 c #004a91",
"ky c #004a92",
"cK c #005aca",
"iu c #0063ca",
"im c #0066cb",
"in c #0068d2",
"iN c #0070d9",
"kd c #010911",
"iO c #0177e2",
"h5 c #0266ce",
"jx c #026ad4",
"io c #0358c3",
"gx c #0371e0",
"jy c #0377e4",
"j2 c #040a10",
"d2 c #040c12",
"kB c #040d15",
"g4 c #0550bc",
"c# c #056ad4",
"hq c #060c11",
"fZ c #060c13",
"cg c #070f17",
"cL c #0763ca",
"kC c #080f15",
"jg c #0878dc",
"e2 c #090f16",
"kj c #0a1016",
"jw c #0a6ed6",
"iW c #0b69c9",
"h4 c #0c66c7",
"ca c #0c6aca",
"k# c #0d1114",
"jh c #0e6ed2",
"iM c #0f72d1",
"ke c #101318",
"jU c #111519",
"hY c #1177d4",
"hZ c #127ad8",
"h6 c #137ad8",
"iv c #1671cb",
"jz c #1772d2",
"hH c #1779d0",
"bJ c #181d23",
"kq c #191b1e",
"bX c #1951a8",
"cu c #1a469d",
"am c #1a70b4",
"il c #1a7fd7",
"gw c #1b7bdc",
"jf c #1d81da",
"je c #1d86dd",
"gy c #1d87e5",
"hR c #1e2224",
"ds c #1e2226",
"#U c #20a3fb",
"gs c #222428",
"al c #22558b",
"dw c #23568d",
"ct c #236bc0",
"e8 c #244d7d",
"ja c #246ab7",
"j# c #2475d5",
"kD c #252a2f",
"eJ c #255e9e",
"aH c #2561a2",
"bW c #256ec2",
"iP c #2665aa",
"g3 c #2768bc",
"an c #27abf8",
"ar c #2872bd",
"dk c #2877d2",
"h0 c #288be0",
"jP c #292c2f",
"aa c #2b64a2",
"h7 c #2b81d4",
"#S c #2ba4f3",
"e7 c #2d5d8f",
"hG c #2d85d3",
"c. c #2d87db",
"ip c #2d89df",
"aq c #2eaaff",
"bD c #2f71b8",
"dj c #2f86dc",
"ex c #303133",
"fx c #303234",
"#V c #3060a2",
"#T c #30bfff",
"cJ c #3289d8",
"b. c #33373b",
"c4 c #3362ac",
"ao c #33baff",
"ap c #37b1ff",
"if c #383a3c",
"fb c #396699",
"aV c #3993d9",
"bC c #39a6f6",
"bg c #3a6da0",
"f8 c #3b6c9d",
"#G c #3d76b7",
"j3 c #3e4042",
"eI c #3e6da2",
"ab c #3e79b4",
"bo c #3e7bc4",
"jF c #3f4143",
"f7 c #3f6e9d",
"fT c #3f91dc",
"bn c #3f92d9",
"aW c #3fa9f8",
"eD c #416fa2",
"bf c #4175ad",
"#F c #4178b2",
"bP c #4179b7",
"iV c #419ae3",
"jd c #428edc",
"fB c #4372a8",
"co c #446791",
"a# c #4472a3",
"iw c #447bb5",
"fp c #4491d9",
"ij c #44a1ea",
"aZ c #44abf0",
"#P c #45709f",
"bu c #457cb9",
"aX c #45b4ff",
"kk c #46484b",
"f9 c #466e92",
"#Q c #46709d",
"fo c #4694d8",
"fH c #4773a7",
"eK c #4779b3",
"#R c #478dd9",
"#q c #4790ce",
"iI c #484a4c",
"e9 c #48709b",
"aI c #4977a7",
"g5 c #49a0f2",
"cR c #4a4b4d",
"fI c #4a6a90",
"aY c #4abcff",
"ac c #4b76ad",
"jq c #4c4e50",
"aU c #4c7ead",
"b3 c #4c83b9",
"a3 c #4c9cd6",
"kr c #4d4d4e",
"eX c #4d82bb",
"kE c #4e5054",
"ad c #4f80b4",
"i7 c #505254",
"#H c #5083be",
"hU c #509ce8",
"c3 c #5196d4",
"a0 c #519dda",
"a1 c #51b1fa",
"ik c #51b9fc",
"bv c #52a7f4",
"bx c #52b5fe",
"bQ c #536f8e",
"fC c #537998",
"es c #537aa8",
"ak c #537caa",
"f4 c #53a1e0",
"h1 c #53a9ed",
"hu c #547dc3",
"iL c #5482c4",
"#e c #548ac4",
"hF c #54a2e3",
"it c #54a7e9",
"bw c #54b4ff",
"aK c #5582b6",
"fG c #567eab",
"e6 c #5681af",
"ii c #5688cd",
"hI c #56a1e1",
"fs c #578bc4",
"f2 c #5790d5",
"fq c #579cdb",
"gZ c #58595a",
"ae c #598cbe",
"b4 c #59b3f9",
"by c #5ac0ff",
"eE c #5b85b4",
"f3 c #5ba9df",
"h3 c #5babec",
"ka c #5c5d5d",
"dv c #5c7fa5",
"fX c #5c89b9",
"hX c #5cb0f1",
"cC c #5d81a3",
"cv c #5d81bb",
"#r c #5d8ebb",
"gl c #5da0e1",
".S c #5e85ae",
"a2 c #5eccfe",
"kf c #5f6061",
"aB c #5f6163",
"cn c #5f91c7",
"cF c #5fb9f6",
"b6 c #5fbbff",
"aP c #609fd3",
"fS c #60a6df",
"bB c #60c8fb",
"gm c #6187b7",
"af c #6188b8",
"eC c #6189b5",
"iR c #6190d0",
"h8 c #61a6e5",
"b7 c #61bbff",
"b5 c #61c0ff",
"bz c #61cbff",
"iX c #627ea2",
"fU c #62aaed",
"#f c #6399d4",
"aT c #648ab7",
"g2 c #648ac5",
"#E c #648cbc",
"cE c #64b0e5",
"aG c #658bb4",
"#I c #6591c5",
".R c #6593c4",
"iz c #65a3e3",
"fr c #65b2f8",
".T c #6690c2",
"di c #66b6ef",
"d6 c #6784a1",
"cz c #6799d1",
"bA c #67cbff",
"cA c #6898cc",
".V c #689dd9",
"b8 c #68c2ff",
"aJ c #6a82a3",
"bc c #6a8bb2",
"d. c #6a94c1",
"e5 c #6c89ab",
"#j c #6c8fb7",
"ee c #6c94c3",
"aO c #6cb4e1",
"gz c #6cbbf5",
"b9 c #6cc1fd",
".W c #6d8195",
"fc c #6d829a",
"fV c #6daeed",
"gv c #6e94ce",
"bj c #6e98e0",
".U c #6ea0d9",
"cG c #6ec6ff",
"jV c #6f7071",
".D c #6f89a6",
"#k c #6f92ba",
"#p c #6fa0e2",
"kF c #707273",
"#g c #709cce",
"bY c #7192c7",
"hN c #7291b4",
"c5 c #7291bf",
"bT c #729ce8",
"jJ c #738eae",
"d7 c #7396bb",
"cD c #7399b6",
"ix c #748baa",
"#d c #749ecc",
"iQ c #758aad",
"dV c #75b0db",
"eW c #75befb",
"dx c #769ac2",
"iU c #76c7f8",
"jK c #7793b4",
"fD c #7797af",
"hx c #77c5fb",
"cZ c #789ebf",
"#O c #78a1cf",
"cH c #79caff",
"kP c #7a7d7f",
"iy c #7a99be",
"go c #7a9cc4",
"#J c #7aa1d0",
"#i c #7aa6d5",
"f5 c #7ac5fa",
"df c #7ac7f6",
"ks c #7b7b7b",
"dl c #7b8ba4",
"iC c #7b90a7",
"d# c #7b97b4",
"cq c #7ba3e6",
"ia c #7ba4c5",
"#h c #7ba6d6",
"i1 c #7bade2",
"gD c #7bb3cf",
"gk c #7bb6e8",
"cI c #7bc9fe",
"iT c #7ccbf8",
"d3 c #7d7e7e",
"fg c #7d8b9c",
"i2 c #7e90a9",
"ag c #7ea5d0",
"jv c #7ea6da",
"fW c #7ec3ff",
"au c #7fa2d0",
"fF c #7fa3c6",
"gE c #7facc7",
"iS c #7fcbfb",
"f0 c #808081",
".C c #819fbf",
"#c c #81a6ce",
"hE c #81c8f8",
"er c #81cdfb",
"aD c #82a5cc",
"eL c #82a7cc",
"de c #82b5dd",
"i. c #82b6e5",
"gC c #82bfdd",
"bV c #82c7f4",
"#4 c #838485",
".z c #8390a0",
"gp c #8395aa",
"eU c #83beee",
"aN c #83c0e4",
"eT c #83c2f0",
"hv c #83c4f1",
"hy c #83cafa",
"dg c #83d0ff",
"hr c #848585",
"#K c #84a7d1",
"aL c #84c0e4",
"gB c #85bcdd",
"bm c #85d4fe",
"kl c #878888",
"dW c #8796ab",
"jI c #87a5cc",
"#l c #87a8cd",
"fa c #87aacf",
"f6 c #87b9db",
"j. c #88a1cb",
"#b c #88a5c6",
"ah c #88afd6",
"hg c #88c4f2",
".y c #89a4c4",
"aS c #89a9cd",
"gF c #8aa9bc",
"ef c #8aaed9",
"#M c #8ab0d9",
"gQ c #8ab1d9",
"c0 c #8ab4d9",
"dh c #8ad1ff",
"cB c #8bbbef",
"dU c #8bcdf8",
"ch c #8c8c8c",
"eO c #8c939d",
"cM c #8c98a9",
"gn c #8ca1b9",
"#L c #8cb1d9",
"eV c #8cc5f1",
"dQ c #8cd1ff",
"jL c #8d9fb6",
"#m c #8da1b6",
"iA c #8dcaff",
"gJ c #8dd0fb",
"a4 c #8e9bad",
"ed c #8eadcf",
"b2 c #8eb2dd",
"dD c #8eb3d9",
"gG c #8eb8d0",
"dP c #8ecaf3",
"e3 c #8f8f8f",
"kG c #8f9091",
"iq c #8fd6ff",
"jA c #9099a5",
"fE c #90b8d3",
"hz c #90d4fe",
"is c #90d8ff",
"hm c #919aa9",
"aM c #91c3dd",
"h9 c #91c6f0",
"f. c #92b2d6",
"gA c #92c5e7",
"iB c #92c6e9",
"as c #939aab",
"cp c #93a2bd",
"da c #93a8bf",
"ge c #93c8ec",
"dS c #93d4fd",
"ji c #949da9",
"#s c #94a0b5",
"eH c #94b3d5",
"fn c #94ccf4",
"h2 c #94d5fe",
"aQ c #95b6da",
"gH c #95c7e8",
"gf c #95d3fb",
"dR c #95d6ff",
"gK c #95d7ff",
"jQ c #969696",
"bM c #96aabf",
"ff c #96bae3",
"el c #96d4fe",
"hw c #96d6ff",
"fA c #97a9c9",
"dK c #97acc0",
"bt c #97afce",
"hf c #97d3f7",
"em c #97d5ff",
"dT c #97d8fc",
"cs c #97d9f8",
"kO c #98999a",
"bh c #989fa4",
"av c #98a4b3",
"hA c #98d7ff",
"eA c #99b6d6",
"b0 c #99b8d6",
"bp c #99b8db",
"ai c #99b9dd",
"hM c #99cbfc",
".P c #9ab4d1",
"hD c #9ad5ff",
"j4 c #9b9c9c",
"#N c #9bbee7",
"hd c #9bdaff",
"jb c #9ca0a9",
"cb c #9ca5b1",
"gI c #9cd3f5",
"hC c #9cd5ff",
"fk c #9cd6fd",
"en c #9cd7ff",
"hB c #9cd9ff",
"#B c #9dafc4",
"fO c #9dd6fc",
"he c #9ddbff",
"h# c #9de3ff",
"aj c #9ebadd",
"cr c #9ed9fc",
"ha c #9ee4ff",
"db c #9fa4ac",
"gR c #9fa4b1",
"#. c #9fb1c6",
".Q c #9fc4ed",
"cU c #a0b2c6",
"ir c #a0deff",
"#y c #a1a1a2",
"bN c #a1b9d5",
"dC c #a1c1dd",
"hl c #a1c7eb",
"hb c #a1e0ff",
"dE c #a2bcd9",
"cV c #a2c1e1",
"g6 c #a2ddff",
"a. c #a3bedb",
"hV c #a3ebfe",
"hS c #a4a5a5",
"## c #a4bace",
"hc c #a4dcff",
"cy c #a5c0dd",
"e. c #a5c1e1",
"eF c #a5c2e0",
"fP c #a5dcff",
"gg c #a5ddff",
"#7 c #a6b4c3",
"aC c #a6bbd2",
"cY c #a6c3e3",
"fl c #a6daff",
"#9 c #a7bcd2",
"#a c #a7bdd1",
"b1 c #a7c3e2",
"eR c #a7dcff",
"c9 c #a8c5e4",
"ep c #a8ddff",
"eo c #a8deff",
"ht c #a9b6d6",
"ez c #a9b9cb",
"eN c #a9cbf0",
"i# c #a9e1fd",
"g7 c #a9e2ff",
"h. c #a9ebff",
"kH c #aaaaab",
"eM c #aacdf0",
"hh c #aad8f9",
"g. c #abb1b6",
"cW c #abc5e0",
"gh c #abddff",
"gL c #abe2ff",
"kg c #acacac",
"ck c #acc0d3",
"ei c #acc3db",
"fe c #adc6e0",
"eQ c #adddff",
"g8 c #ade7ff",
"g9 c #adedff",
"#8 c #aebac7",
"dB c #aec5db",
"eS c #aee0ff",
"hW c #aee6ff",
"kt c #afafaf",
"fh c #afb3b6",
"ej c #afb4ba",
"at c #afc0de",
"hJ c #afd9f6",
"kb c #b0b0b0",
"kN c #b0b1b2",
"bO c #b0c7e2",
"c6 c #b1cae4",
"#D c #b1cbe0",
"i0 c #b1cded",
"c1 c #b1dff6",
"bd c #b2cce4",
"fN c #b2dbf9",
"fQ c #b2e0ff",
"gM c #b2e2ff",
"bU c #b2e6ff",
"jG c #b3b3b3",
".E c #b3b7bc",
"jt c #b3b8c2",
"fd c #b3bdc8",
"e# c #b3cae6",
"gd c #b3d4ec",
"fR c #b3dffd",
"bb c #b4c1d0",
"cw c #b4cbe3",
"aR c #b4cbe5",
"dA c #b4ccdf",
"fm c #b7e5ff",
"bK c #b8b8b8",
"ea c #b8cfe8",
"fj c #b8ddfa",
"c2 c #b8e7f1",
"gt c #b9b9b9",
"eb c #b9cde4",
"d9 c #b9cde8",
"dz c #b9cee5",
"f# c #b9d3ed",
"ig c #babbbb",
"ec c #bad0e9",
".M c #bbc2ca",
"gi c #bbe4ff",
"bk c #bbedff",
".8 c #bcbcbd",
"ft c #bcbec2",
"cX c #bcd3ea",
"eB c #bcd6f1",
"hL c #bcddf7",
".x c #bdcbdb",
"bZ c #bdd0e7",
"ib c #bec1c5",
"jc c #becce5",
"eq c #bef3ff",
"kI c #bfbfbf",
"du c #bfc9d5",
".B c #bfcad6",
"dF c #bfd4eb",
"gj c #bfe3fc",
"bE c #c1c2c7",
"bq c #c1d5e8",
".A c #c2c8cf",
"be c #c2d5e7",
"dy c #c3d6ef",
"gN c #c3e7ff",
"kM c #c4c4c4",
"jr c #c4c5c5",
"js c #c4cbd9",
"d5 c #c4cdd8",
"br c #c4d6eb",
"dG c #c4d7ea",
".O c #c5ced8",
".X c #c6c8cb",
"cj c #c6cfda",
"iJ c #c7c7c7",
"e4 c #c7cfd7",
"bs c #c7d9f0",
"d8 c #c7daf0",
"ku c #c8c8c8",
"eY c #c8cace",
".Y c #c8cdd5",
"dd c #c8d2dc",
"eG c #c8dbef",
"fY c #c9cacd",
"dH c #c9d9ed",
"jM c #caccd1",
"c7 c #cadced",
"jW c #cbcbcb",
"i8 c #cccccc",
".N c #cccfd4",
"cm c #ccddf2",
"ey c #cecece",
"dL c #ced2d6",
"fJ c #cfcfcf",
"ih c #cfd7ed",
"fy c #d0d0d0",
"c8 c #d0deed",
"cx c #d0dfee",
".K c #d1d1d1",
"kL c #d1d1d2",
".s c #d1d4d6",
"iK c #d1d6e5",
"ek c #d2eafd",
"i3 c #d3d4d6",
"gO c #d3eeff",
"kv c #d4d4d4",
"#n c #d4d7dc",
"f1 c #d4dcf0",
"hi c #d4f1ff",
"bl c #d4ffff",
"fL c #d5dbe1",
".L c #d5dce4",
"gP c #d5f0fd",
"iY c #d6d6d8",
"#W c #d6d6da",
"hT c #d6def1",
"kx c #d7d7d7",
"eg c #d7e4f2",
"aE c #d7e7f5",
"#C c #d7ebf8",
"hO c #d8d9db",
"g1 c #d8deec",
"kJ c #d9d9d9",
"i9 c #d9dfeb",
"fK c #d9e0e7",
"gc c #d9edfb",
"kK c #dadadb",
"iD c #dadcdd",
"cl c #dae7f5",
"hK c #daf0fb",
".1 c #dbdde4",
".n c #dbdfe5",
"jk c #dbe1e9",
"km c #dcdcdc",
"dO c #dcedfa",
".r c #dde1e6",
"aF c #ddebf6",
"hj c #ddf3ff",
"kw c #dedede",
"b# c #dfdfdf",
"dm c #dfe1e4",
".o c #e0e1e2",
"#o c #e0e5ee",
"kh c #e1e1e1",
"fM c #e1effa",
"cS c #e2e2e2",
"et c #e2e3e6",
"#6 c #e2e9f1",
".u c #e3e3e3",
"dI c #e3eaf5",
"g0 c #e4e4e4",
"gq c #e4e6e7",
"jH c #e4eaf4",
"g# c #e6e8ea",
".Z c #e6eaed",
"j5 c #e7e7e7",
"bi c #e7e7ee",
"jl c #e7e8e9",
"dM c #e7e9eb",
"gT c #e7eaef",
"d4 c #e8e8e8",
".m c #e8ecf1",
".c c #e9e9e9",
"a5 c #e9e9eb",
"eh c #e9f2fc",
".k c #eaeaea",
".h c #ebebeb",
"dc c #ebeced",
"gU c #ebecee",
".j c #ececec",
"dJ c #ecf3fe",
".i c #ededed",
".2 c #edeff3",
"gb c #edf4f9",
".v c #eeeeee",
".G c #efefef",
"aw c #efeff0",
".t c #eff0f0",
"hs c #eff2f7",
"eP c #eff7ff",
"#X c #f0f0f0",
".9 c #f0f2f5",
"iZ c #f0f3f8",
".w c #f1f1f1",
".0 c #f1f4fa",
"fi c #f1f9ff",
"cc c #f2f2f2",
"#t c #f2f2f3",
"bL c #f2f4f6",
"gu c #f2f4f9",
"ju c #f2f4fa",
"cN c #f3f3f3",
"bS c #f3f3f8",
"gS c #f3f4f5",
"jR c #f4f4f4",
"dX c #f4f5f6",
"cT c #f4f6f8",
"#Y c #f4f6f9",
"hk c #f4ffff",
"bR c #f5f5f5",
"jS c #f6f6f6",
"#Z c #f7f8f9",
".q c #f7f8fa",
"ga c #f8f8f9",
"dN c #f8f9f9",
"fz c #f8f9fa",
"#A c #f9fafb",
"hn c #fafafa",
"ci c #fafafb",
"gV c #fafbfb",
"jj c #fafcfe",
".3 c #fcfcfd",
"dt c #fcfdfd",
".F c #fdfdfd",
"#z c #fdfdfe",
"ba c #fdfefe",
".p c #fefefe",
"#5 c #fefeff",
"Qt.#.a.b.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c",
".d.e.f.g.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.h.i.j.c.k.j.i.k.c.c.c.c.c.c.k.c.c.c.c.c.c.c.c.c.c",
".d.e.l.g.c.c.c.c.c.c.c.c.c.c.c.c.c.c.h.m.n.o.p.q.r.s.t.k.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c",
".d.e.f.g.u.c.c.c.c.c.c.c.c.c.k.p.p.v.w.x.y.z.A.B.C.D.E.F.G.j.c.c.k.j.h.c.c.c.c.c.c.c.c.c",
"Qt.H.I.J.K.c.c.c.c.c.c.c.c.k.q.L.M.N.O.P.Q.R.S.T.U.V.W.X.Y.Z.v.i.0.1.2.3.k.c.c.c.c.c.c.c",
".4.5.6.7.8.c.c.c.c.c.c.c.c.k.9#.###a#b#c#d#e#f#g#h#i#j#k#l#m#n#o#p#q#r#s#t.k.k.k.c.c.c.c",
"#u#v#w#x#y.c.c.c.c.c.c.c.j#z#A#B#C#D#E#F#G#H#I#J#K#L#M#N#O#P#Q#R#S#T#U#V#W#X#Y#Z.k.c.c.c",
"#0#1#2#3#4.c.c.c.c.c.c#5#6#7#8#9a.a#aaabacadaeafagahaiajakalamanaoapaqarasatauavaw.p.c.c",
"axayazaAaB.c.c.c.c.c.c.3aCaDaEaFaGaHaIaJaKaLaMaNaOaPaQaRaSaTaUaVaWaXaYaZa0a1a2a3a4a5.h.c",
"a6a7a8a9b.b#.c.c.c.c.cbabbbcbdbebfbgbhbibjbkblbmbnbobpbqbrbsbtbubvbwbxbybzbAbBbCbDbE.v.c",
"bFbGbHbIbJbK.c.c.c.c.c.kbLbMbNbObPbQbRbSbTbUbVbWbXbYbZbqb0b1b2b3b4b5b6b7b8b9c.c#cacbcc.c",
"cdcecf.lcgch.c.c.c.c.kcicjckclcmcncocpcqcrcsctcucvcwcxcyczcAcBcCcDcEcFcGcHcIcJcKcLcMcN.c",
"cO.4cP#wcQcRcS.c.c.c.kcTcUcVcWcXcYcZc0c1c2c3c4c5c6c7c8c9d.d#dadbdcdddedfdgdhdidjdkdldm.j",
"dndodpdqdrdsbK.c.c.c.cdtdudvdwdxdydzdAdBdCdDdEdFdGdHdIdJdKdLdMdN.h.GdOdPdQdRdSdTdUdVdWdX",
"dYbFdZd0d1d2d3d4.c.c.c.k#Zd5d6d7d8d9e.e#eaebecedeeefegeheiej.p.k.c#Xekelemeneoepeqereset",
"dYcO.4euevewexey.c.c.c.c.k.pezeAeBeCeDeEeFeGeHeIeJeKeLeMeNeOaw.k.iePeQeneReSeTeUeVeWeXeY",
"dYdneZa7e0e1e2e3d4.c.c.c.c.ve4e5e6e7e8e9f.f#fafbfcfdfefffgfhba.ififjfkflfmfnfofpfqfrfsft",
"dYdYfufv.#fw#xfxfy.c.c.c.c.kfzfAfBfCfDfEfFfGfHfIfJ.w#5fKfLcc#5fMfNfOfPfQfRfSfTfUfVfWfXfY",
"dYdYdneZa7e0e1fZf0d4.c.c.c.c.if1f2f3f4f5f6f7f8f9g.g#ga.pgbgcgdgegfggghgigjgkglgmgngogpgq",
"dYdYdYfufvgrev#3gsgt.c.c.c.c.kgugvgwgxgygzgAgBgCgDgEgFgGgHgIgJgKgLgMgigNgOgPgQgRgSgTgUgV",
"dYdYdYdngWgXbHgY.JgZg0.c.c.c.c.ig1g2g3g4g5g6g7g8g9h.h#hahbhchdhehfhghhhihjhkhlhmhn.h.h.c",
"dYdYdYdYcd#uhohpa9hqhr.c.c.c.c.c.ihshthuhvghhwhxhyhzhAhBhChDhEhFhGhHhIhJhKhLhMhNhO.j.c.c",
"dYdYdYdYdYbFhP.e#whQhRhS.c.c.c.c.c.ihThUhVhWhXhYhZh0h1h2hDhAh3h4h5h6h7h8h9i.i#iaib.G.c.c",
"dYdYdYdYdYdndoicid.aieifig.c.c.c.c.iihiiijikiliminioipiqirisitiuiviwixiyiziAiBiCiD.j.c.c",
"dYdYdYdYdYdYcdiEiFiGiH.7iIiJ.c.c.c.c.GiKiLiMiNiOiPiQiRiSiTiUiViWiXiY.FiZi0i1i2i3.G.c.c.c",
"dYdYdYdYdYdYdYi4.4hoa8i5i6i7i8.c.c.c.c.Gi9j.j#jajbbRjcjdjejfjgjhjicN.c.kjjjkjl.v.c.c.c.c",
"dYdYdYdYdYdYdYdnbF.djmjnjojpjqjr.c.c.c.c.j.pjsjtcN.kjujvjwjxjyjzjAcN.c.c.k.i.h.c.c.c.c.c",
"dYdYdYdYdYdYdYdYdnjB.djCjDjEi6jFjG.c.c.c.c.c.v#X.k.c.jjHjIjJjKjLjM.v.c.c.c.c.c.c.c.c.c.c",
"dYdYdYdYdYdYdYdYdYdnjNfvjCjOi5.7jPjQ.c.c.c.c.c.c.c.c.c.jjRjSbRcN.v.c.c.c.c.c.c.c.c.c.c.c",
"dYdYdYdYdYdYdYdYdYdYdnjN.d#1jTgY#xjUjVjW.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c",
"dYdYdYdYdYdYdYdYdYdYdYdnjBjXjYjZj0j1j2j3j4j5.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c",
"dYdYdYdYdYdYdYdYdYdYdYdYdnbFj6j7j8j9k.i6k#kakb.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c",
"dYdYdYdYdYdYdYdYdYdYdYdYdYdnfu#0bGgrjO.akckdkekfkgkhd4.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c.c",
"dYdYdYdYdYdYdYdYdYdYdYdYdYdYdYcdgWfvayd0#2iHkiiekjkkkliJkmj5.c.c.c.c.c.c.c.c.c.c.c.c.c.c",
"dYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdnfu#0knkoj8hpkpbI#3.gkqkrksktkukvkwj5.c.c.c.c.c.c.ckhkx",
"dYkydYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYcda6j6dZay.ekzkAi5j1kBkCkDkEkFkGkHkIfJkJkKkLkMkNkOkP",
"dYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYcObFkQfvic#vkR#2.akSk.drkThQie.7i6jp.7ieewj1kikU",
"dYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdncda6.4gXjCkVd0kzkWkXkYkZk0k1k1.6k2j9k3hpe0",
"dYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYk4cda6iEk5dZicj7jYjC#v.5grgr.5eukohodpk6",
"dYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdYdncOfujNeZk7k8j6.4jXjX.4j6iEk7axa6"};

static const char* const img2_login_dlg[] = { 
"240 54 24 1",
". c #004991",
"# c #004a91",
"a c #004a92",
"o c #034c95",
"l c #065099",
"i c #08539d",
"r c #08539e",
"k c #0b57a2",
"h c #0e5aa6",
"m c #115eaa",
"b c #1361ae",
"e c #1665b2",
"j c #1968b6",
"n c #1c6cba",
"s c #1c6cbb",
"f c #1e6fbe",
"p c #1e6fbf",
"u c #2172c2",
"q c #2172c3",
"g c #2476c6",
"t c #2476c7",
"c c #2779cb",
"d c #297dcf",
"v c #297dd0",
"................................##..............................................................................................................................................................................................................",
"...................................................................................................................a.......#................#...................................................................................................",
"................................................................................................................................................................................................................................................",
"................................................................................................................................................................................................................................................",
"....................................................................................................................................#....................................................a......................................................",
".....................................................................................................a..........................................................................................................................................",
"...................................................................................................................................................................................................................................a............",
".....................................................................................................................................................................................................................#......a...................",
"................................................................................................................................................................................................................................................",
"................................................................................................................................................................................................................................................",
"........................................................................................................#.......................................................................................................................................",
"................................................................................................................................................................................................................................................",
"..............................................................................................................a.....................................a...........................................................................................",
".............................................................................................................................................................................................#..................................................",
"................................................................................................................................................................................................................................................",
"..........................................................................................................................................................................a.....................................................................",
"................................................................................................................................................................................................................................................",
"..................................................................................................................................................a.............................................................................................",
"..............aaa...........................................................................................................................................................a...................................................................",
"................................................................................................................................................................................................................................................",
"....................................................................................................................................................................................................................a...........................",
"................................................................................................................................................................................................................................................",
".................................................................................................................................................................................................................................a..............",
"................................................................................................................................................................................................................................................",
"............................................................................................................................................................................#...................................................................",
"................................................................................................................................................................................................................................................",
"................................................................................................................................................................................................................................................",
"....................................................................................................................................................................................................................................a...........",
"...............................................aaa..............................................................................................................................................................................................",
"................................................................................................................................................................................................................................................",
"................................................................................................................................................................................................................................................",
"................................................................................................................................................................................................................................................",
".....................................................................................................................................bcddddddddddde...fdddddddddddddgh...igdddddddddddddf..ddddddddddddddj....eddddddddddddddk..jddddddddddddddf",
"......................................................................................................#.............................hdddddddddddddde..fdddddddddddddddk.lcddddddddddddddf..ddddddddddddddde..edddddddddddddddk.mdddddddddddddddf",
"...................................................................................................................a................fddddddddddddddd..fdddddddddddddddn.bdddddddddddddddf..dddddddddddddddd..ddddddddddddddddk.ndddddddddddddddf",
"...........odddddddph.....................................................................e..................oddq...................ddddddddddddddddk.fddddfffffffcdddd.fdddddddddddddddf..ddddddddddddddddkkddddddddddddddddk.fdddcfffffffffffe",
"...........rdddddddddh..................................................................lqq..................rdde...................ddddk.......ddddk.fdddd.......fdddd.fdddb..............ddddk.......ddddkkdddd.........#....fdddf............",
"...........mddr...rcds..................................................................pde.........................................ddddk.......ddddk.fdddd.......fdddd.fdddb..............ddddk.......ddddkkdddd..............fdddf............",
"...........bddo....qds...hpddth...edqojdde..edt....pdp..hpddth...edqojdde...bddo..jdc.bddddc..ksdddeo........eddk.edqojdde..........ddddk.......ddddk.fdddd..mbbbbgdddd.fdddb..effffffff...ddddk.......ddddkkdddd..............fdddgbbbbbbbbbh..",
".###.......sdc....bddh..bddddddk..sdttddddm.bdd...kddr.bddddddk..sdttddddm..sdc...qdq.sdddds.mddddddto.......sddo.sdttddddm.........ddddk.......ddddk.fdddd..fddddddddu.fdddb..fdddddddd...ddddk.......ddddkkdddd..............fddddddddddddddj.",
"...........qdddddddth..rdds..qdp..tddsolddj.rddr..qdj.rdds..qdp..tddsolddj..tds...cde..bdd..lddtr.mddb.......tdc..tddsolddj.........ddddk.......ddddk.fdddd..fddddddddm.fdddb..fdddddddd...ddddk.......ddddkkdddd..............fdddddddddddddddk",
"...........cddddddddb..jdc...mdc..ddp...cde.oddh.mdcl.jdc...mdc..ddp...cde.oddb..lddb..edq..eddk...qdp......oddp..ddp...cde.........ddddk.......ddddk.fdddd..fddddddde..fdddb..effffffff...ddddk.......ddddkkdddd..............fdddddddddddddddj",
"..........lddb....pddk.tdddddddd.rddb..lddb..qdb.tdb..tdddddddd.rddb..lddb.kddh..hddk..qde..qdq....pdp......rdde.rddb..lddb.........ddddk.......ddddk.fdddd..ikkkkkkl...fdddb..............ddddk.......ddddkkdddd..............fdddukkkkkkkudddf",
"..........kddh....kddb.ddddddddt.hddr..kddh..sdjmdto..ddddddddt.hddr..kddh.bddl..bddo.oddb..tds....cds......mddb.hddr..kddh.........ddddk.......ddddk.fdddd.............fdddb..............ddddk.......ddddkkdddd..............fdddf.......fdddf",
"..........mddr....mddh.cdb.......bdd...bddl..bdqcdm...cdb.......bdd...bddl.jdc...qdc..kddr..tdq...mddm......eddk.bdd...bddl.........ddddddddddddddddk.fdddd.............fdddddddddddddddf..ddddk.......ddddkkddddddddddddddddk.fdddcfffffffcdddf",
"..........eddo...rtdco.jdtr.hddk.edt...edc...hdddq....jdtr.hddk.edt...edc..pdclosdds..bddo..jddm.kcdto......pddo.edt...edc..........fddddddddddddddd..fdddd.............bdddddddddddddddf..ddddk.......ddddk.ddddddddddddddddk.bdddddddddddddddb",
"..........svddddddddb..lcdddddj..pdp...sdq...odddk....lcdddddj..pdp...sdq..sddddtcde..bddds.lcddddvcr.......cdc..pdp...sdq..........hdddddddddddddde..fdddd.............lcddddddddddddddf..ddddk.......ddddk.edddddddddddddddk.ocdddddddddddddco",
"..........qdddddddsh....ljddtm...tdj...tdj....cds......ljddtm...tdj...tdj..lqddeoddm..lqddb..ljdddel.......oddp..tdj...tdj...........bcddddddddddde...fdddd..............igdddddddddddddf..ddddk.......ddddk..eddddddddddddddk..mcdddddddddddui.",
"................................................................................................................................................................................................................................................",
"................................................................................................a...............................................................................................................................................",
"................................................................................................................................................................................................................................................",
"............................................................................................................................#.............................................a...................#..................................a..............",
"................................................................................................................................................................................................................................................",
"...........................................................................................................................................................................................a...................................................."};

static const char* const img3_login_dlg[] = { 
"51 19 47 1",
"R c #414041",
"Q c #5a9de6",
"P c #5aa1e6",
"N c #62a1e6",
"O c #62a5e6",
"K c #6aa5e6",
"L c #6aaae6",
"J c #6aaaee",
"G c #73aae6",
"M c #73aaee",
"I c #73aee6",
"H c #73aeee",
"F c #7bb2e6",
"E c #7bb2ee",
"D c #83b2ee",
"y c #83b6e6",
"A c #83b6ee",
"z c #83baee",
"C c #8bb6ee",
"B c #8bbaee",
"w c #8bbeee",
"v c #94beee",
"x c #94bef6",
"s c #94c2ee",
"q c #9cc2ee",
"r c #9cc2f6",
"u c #9cc6ee",
"t c #9cc6f6",
"p c #a4caee",
"o c #a4caf6",
"n c #accaf6",
"k c #acceee",
"m c #accef6",
"l c #b4d2f6",
"h c #bdd6f6",
"j c #bdd6ff",
"g c #bddaf6",
"i c #bddaff",
"S c #c5c2c5",
"d c #cde2f6",
"f c #cde2ff",
"e c #d5e2ff",
"c c #deeeff",
"b c #e6eeff",
"# c #eef6ff",
"a c #f6f6ff",
". c #ffffff",
"...................................................",
"...................................................",
"...................................................",
"#a#a#a#a#a#a#a#a#a#a#a#a#a#a#a#a#a#a#a#a#a#a#a#a#a#",
"bbbbbbbbbbbbbbbbbbbcbbbcbbbbbbbbbbbcbbbbbbbcbbbbbbb",
"dedededededededededfdedfdedfdedfdedfdedededededfded",
"ghihihihghihghihghihjhihjhihihihihihghihghihghihihi",
"klmlklmlklmlmlmlklmlklmlklmlklmlklmlklmlmlmlklmlklm",
"noopnonpnonpnoopnonpnooonoopnoopnoopnooononpnoopnon",
"qrsqstsuqtsrqrsusrsuqtsuqrstqrsrqtsuqtsqqrsusrsqsrs",
"vwxwvwxwvwxwxwxvvwxwxwxwvwxvvwxvvwxwvwxwvwxwvwxvvwx",
"yzAByzAAyAACyAAAyzAByzAAyzAAAAAzyzAAyzAAAzACyAAzAzA",
"DEEEDEEFDEEEDEEFDEEFDEEEDEEEDEEFDEEFDEEFDEEFDEEFDEE",
"GHGHGHGHGHGHGHGHGHGHGHGHGHGHGHGHGHGHGHGIGHGHGHGIGHG",
"JKJLJKMKJKJKJKMKJKMKJKJKJLJKJKMKJKJKJKMKJKJKJKMKJKJ",
"NONONONONONONONONONONONONONONONONONONONONONONONONON",
"NPNPNPNQNPNQNPNQNPNQNQNPNQNPNPNPNPNPNPNPNPNPNPNPNPN",
"RRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRR",
"SSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS"};

static const char* const img4_login_dlg[] = { 
"51 54 3 1",
"# c #004894",
"a c #004c94",
". c #004c9c",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a",
"###################################################",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.",
"###################################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a",
"#################a#################################",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.",
"###################################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a",
"###################################################",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.",
"###################################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a",
"###################################################",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.",
"###################################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a",
"###################################################",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.",
"###################################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a",
"###################################################",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.",
"###################################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a",
"###################################################",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.",
"###################################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a",
"###################################################",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.",
"###################################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a",
"###################################################",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.",
"###################################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a",
"###################################################",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.",
"###################################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a",
"###################################################",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.",
"###################################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a",
"###################################################",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.",
"###################################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a",
"###################################################",
"a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.",
"###################################################",
".#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a#.#a",
"###################################################"};

static const char* const img5_login_dlg[] = { 
"42 19 98 2",
".4 c #000000",
".3 c #000408",
".T c #000810",
".p c #000c18",
".n c #001020",
".o c #001420",
".m c #001429",
".l c #001831",
".k c #001c39",
".C c #002041",
"#p c #00244a",
".j c #002852",
".S c #002c52",
".f c #002c5a",
".i c #003062",
".e c #00346a",
".d c #00386a",
".c c #003873",
".h c #003c73",
".B c #003c7b",
".b c #004083",
".q c #00448b",
".g c #00488b",
".# c #004894",
".a c #004c94",
"Qt c #004c9c",
".Z c #080808",
"#F c #080c08",
".D c #081420",
"#B c #100c10",
"#f c #101010",
"#v c #101410",
".J c #101418",
"#x c #181418",
"#o c #181818",
".2 c #181c18",
".r c #182029",
"#l c #201c20",
".Y c #202020",
"#d c #292829",
"#. c #292c29",
".R c #312c31",
".8 c #313031",
"#C c #313431",
".7 c #393439",
".1 c #393c39",
".N c #413c41",
"#s c #414041",
"#n c #414441",
".O c #4a444a",
"## c #4a484a",
"#E c #4a4c4a",
"#D c #524c52",
".X c #525052",
".I c #5a555a",
"#c c #5a595a",
"#A c #5a5d5a",
".K c #626562",
".s c #62656a",
"#q c #6a656a",
".E c #6a6d6a",
".6 c #736d73",
".A c #737173",
"#e c #737573",
".U c #7b757b",
"#u c #7b797b",
"#m c #7b7d7b",
".M c #837d83",
"#z c #838183",
"#k c #8b858b",
".t c #8b898b",
".H c #8b8d8b",
".0 c #948d94",
"#b c #949194",
".9 c #949594",
"#y c #9c959c",
"#j c #9c999c",
".Q c #9c9d9c",
".5 c #a4a1a4",
"#r c #a4a5a4",
".z c #aca5ac",
".u c #acaaac",
"#i c #b4aeb4",
"#a c #b4b2b4",
"#g c #b4b6b4",
".W c #bdb6bd",
".G c #bdbabd",
".P c #bdbebd",
"#h c #c5bec5",
".y c #c5c2c5",
".V c #c5c6c5",
".L c #cdc6cd",
".F c #cdcacd",
".v c #cdcecd",
".x c #d5ced5",
".w c #d5d2d5",
"#t c #dedede",
"#w c #eeeaee",
"Qt.#.a.#Qt.#.a.#Qt.#.a.#Qt.#.#.b.b.c.c.d.c.c.c.d.c.c.c.d.c.c.c.d.c.c.c.d.c.c.c.d.e.f",
".#.#.#.#.#.#.#.#.#.#.#.g.b.h.i.j.k.l.m.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.o.n.p",
".a.#Qt.#.a.#Qt.#.a.q.b.i.j.l.m.r.s.t.u.v.w.x.w.x.w.v.w.x.w.v.w.x.w.v.w.v.x.v.x.y.z.A",
".#.#.#.#.#.#.#.#.B.e.C.m.D.E.u.x.v.x.v.x.v.x.v.x.v.x.v.x.v.x.v.x.F.v.F.x.F.v.F.G.H.I",
"Qt.#.a.#Qt.#.g.c.j.m.J.K.L.v.x.v.x.v.x.v.x.v.x.v.x.v.x.F.x.F.x.F.x.F.v.F.x.F.L.u.M.N",
".#.#.#.#.g.b.i.C.p.O.G.v.F.x.F.v.F.v.F.v.F.v.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.P.Q.K.R",
".a.#Qt.#.b.S.l.T.U.F.x.F.v.F.x.F.v.F.x.F.F.F.F.F.F.F.F.F.F.F.F.F.F.L.F.L.F.V.W.t.X.Y",
".#.#.#.b.j.o.Z.0.F.F.F.F.F.F.F.F.V.F.L.F.V.F.V.F.V.F.V.F.V.F.V.L.V.L.V.L.V.y.u.M.1.2",
"Qt.#.g.i.l.3.0.F.F.L.F.L.F.L.4.4.4.4.4.V.F.L.F.V.L.V.L.V.L.V.L.V.L.V.4.4.L.P.5.6.7.8",
".#.#.c.C.T.A.V.L.V.L.V.L.V.L.4.4.V.L.y.V.y.L.y.V.y.V.y.V.y.V.y.y.y.y.y.y.y.G.9.K#.##",
".#.B.j.p.O.V.L.V.L.V.L.V.L.y.4.4.L.y.L.y.V.y.4.4.4.4.y.y.4.4.4.4.y.y.4.4.y#a#b#c#d#e",
".q.i.n#f#g.V.y.y.y.y.y.y.y.y.4.4.4.4.4.y.P.4.4.y.P.y.P.4.4.y.P#h.P#h.4.4.P#i.t.X.Y#j",
".b.C.T.A.y.y.y.y.y.y.y.y.y#h.4.4.y#h.y.P.y.4.4.4.4#h#h.4.4.P#h.P#h.P.4.4#h.u#k###l#a",
".i.m.J.P.P.y.P#h.P#h.P#h.P#h.4.4.P#h.P.P.G#h.4.4.4.4.G.4.4.P.G.P.G.G.4.4.G.z#m#n#o.F",
"#p.T#q.P#h.P#h.P#h.P#h.P#h.G.4.4#h.G#h.G.P.G#h.G.4.4.G.4.4.G.G.G.G.G.4.4.G#r.M#s#o#t",
".m.3#r.P.G.P.G.P.G.G.G.G.G.G.4.4.4.4.4.G#g.4.4.4.4.G#g.G.4.4.4.4#g.W.4.4#g.5#u.N#v#w",
".n#d.G.G.G.G.G.G.G.G.G.G.G.G.G.W.G.W.G.W.G.W.G#g.G#g.W#g.W#g.W#g.W#g.W#g.W.5#u.1#x#w",
".2##.9#y.9#y.9#y#b#y#b.9#b.9#b.9#b.9#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#b#z#A.8#B#h",
"#x#C.X.X.X.X.X.X.X.X.X.X.X.X.X#D.X#D.X#D.X#D.X#D.X#D.X#D.X#E.X#D.X#E.X#D.X#n.7#o#F#q"};

static const char* const img6_login_dlg[] = { 
"39 39 484 2",
"c7 c #000306",
"bB c #000810",
"#Y c #000911",
".X c #000a13",
".W c #000a14",
".V c #000b15",
".Y c #000b16",
"a. c #000b17",
".U c #000c17",
".Z c #000c18",
"#Q c #000d19",
".3 c #000d1a",
".T c #000d1b",
"cR c #000f1d",
".S c #000f1f",
"bh c #001121",
"#X c #001123",
".R c #001223",
"#n c #001224",
"#H c #001325",
".Q c #001428",
"bA c #00162b",
".P c #00162c",
"#P c #00172d",
"ah c #00182f",
"#9 c #001830",
"aI c #001932",
".O c #001a33",
"#3 c #001a34",
".D c #001b35",
".E c #001b36",
".C c #001c38",
"#G c #001d39",
"#W c #001d3b",
"cD c #001e3b",
".B c #001e3c",
".N c #001f3f",
".A c #002040",
".F c #002141",
"bg c #002345",
".z c #002346",
".G c #002347",
"#O c #002447",
"#m c #00254a",
"#A c #00264b",
".2 c #00264c",
".y c #00274d",
"#8 c #002850",
".M c #002951",
"#2 c #002a52",
"#F c #002a53",
".x c #002a54",
"aH c #002b55",
"#V c #002c57",
".w c #002d5a",
"#l c #002f5d",
".1 c #002f5e",
"a0 c #00305e",
".v c #003161",
".L c #003162",
".l c #003264",
".k c #003366",
".j c #003468",
".m c #003569",
".u c #00356a",
".i c #00366b",
"#7 c #00376e",
"ag c #00386e",
".h c #00386f",
".0 c #003870",
"#U c #003971",
".K c #003a72",
".g c #003a73",
".n c #003a74",
"#z c #003b75",
".t c #003b76",
"#N c #003c77",
".f c #003c78",
".o c #003d79",
"aZ c #003e7c",
".e c #003f7d",
".J c #003f7e",
"#k c #00407e",
".s c #004080",
".d c #004181",
"bf c #004282",
"#1 c #004283",
"#y c #004284",
".c c #004385",
"#M c #004386",
".I c #004487",
"aG c #004588",
".r c #004589",
".b c #00468b",
"aY c #00468c",
"#x c #00478c",
".H c #00478d",
".q c #00478e",
"#j c #00488e",
".a c #00488f",
".p c #004890",
".# c #004990",
"Qt c #004991",
".4 c #010a13",
"cS c #04090d",
"#o c #060c13",
".5 c #060d14",
"#4 c #080e13",
"dj c #0a121a",
"#R c #0d1217",
"bi c #0f1319",
"#B c #11161c",
".6 c #151a20",
"#I c #171b21",
"a# c #1a1d21",
"ca c #1b2024",
"a1 c #1c2022",
"#p c #1d2022",
"ai c #24262a",
"dx c #24282a",
"aJ c #25282b",
"as c #282b2e",
"c8 c #2f2f2f",
"#Z c #2f3134",
"cE c #303235",
"b3 c #3c93e9",
".7 c #3d4145",
"bU c #3e4043",
"bJ c #4799ea",
"#C c #4d4e4f",
"#S c #505253",
"dO c #525354",
"bK c #53a0ea",
"#5 c #545557",
"#q c #5a5a5b",
"#J c #5c5d5f",
"b0 c #5ea6ec",
"az c #5f90ba",
"fn c #616462",
"#i c #616468",
"ay c #6196bd",
"aA c #6399be",
"fu c #647676",
"e2 c #647c7c",
".8 c #656768",
"aV c #6599c0",
"e1 c #666563",
"fH c #666666",
"eR c #667a7b",
"aB c #669dbf",
"bC c #676869",
"bl c #6aa0c2",
"bZ c #6aadee",
"bX c #6c97bf",
"cH c #6ca1c2",
"b2 c #6cadec",
"cp c #6d6e6e",
"dn c #6e9ec6",
"cV c #6ea5c4",
"f# c #727676",
"cs c #73a9c6",
"fe c #748589",
"bc c #74a0c9",
"dQ c #75aacc",
"a4 c #76a9c9",
"dA c #76acc9",
"ek c #76b1d4",
"fk c #779e9e",
"ax c #77aac6",
"d4 c #77aacd",
"aO c #789fc3",
"c0 c #78b4ec",
"dk c #797a7a",
"fv c #798282",
"aU c #799fca",
"fa c #7a9a9a",
"aa c #7b7c7c",
"eV c #7bafd3",
"bF c #7bb0c9",
"bS c #7bb2cf",
"d8 c #7bb2d0",
"fj c #7c7f7f",
"eL c #7caed0",
"ff c #7d7873",
"d# c #7fb2ca",
"e5 c #7fb4cd",
"fo c #808282",
"cT c #818181",
"da c #81a9d3",
"bx c #81aed3",
"aN c #81b5cd",
"#h c #828486",
"ft c #82a9a9",
"aC c #83b6cc",
".9 c #848687",
"dd c #85bbed",
"ep c #85bdd8",
"fm c #87b1af",
"dv c #87bfd9",
"cd c #88a8ce",
"bd c #88bdd3",
"cc c #89bacf",
"eU c #89bcd0",
"bj c #8b8b8c",
"cC c #8bc2d8",
"eC c #8cbec4",
"#r c #8d8d8d",
"fd c #8dc3d4",
"bI c #8ec1f2",
"cQ c #8ec5d9",
"dM c #8fbcd8",
"e6 c #8fbcdb",
"b9 c #8fc0dc",
"cn c #8fc3d7",
"#D c #909191",
"aW c #90c0d2",
"eo c #90c3d5",
"eK c #91cada",
"fq c #929595",
"ct c #93b3d7",
"f. c #949495",
"d6 c #949595",
"cW c #94bade",
"fB c #94bfbf",
"dB c #94c0e1",
"d9 c #94c5e2",
"dN c #94c6d6",
"eq c #94c7e1",
"aj c #969696",
"fr c #98c6c6",
"aT c #99bce0",
"eS c #99c2c1",
"eQ c #9aa8af",
"eB c #9ac5e4",
"by c #9acbda",
"cI c #9cbddd",
"ci c #9dc9ee",
"dh c #9dd0e7",
"#g c #9e9fa0",
"aP c #9eb8d4",
"c5 c #9ed0de",
"#. c #9fa0a0",
"bG c #9fb4d2",
"c. c #a0ccda",
"e0 c #a19f9e",
"a2 c #a1a1a1",
"dR c #a1cfec",
"eu c #a1d1e8",
"er c #a3d1e7",
"et c #a3d2e9",
"cm c #a3d5ec",
"at c #a4a5a5",
"fA c #a4c7c7",
"eH c #a4d4e0",
"d5 c #a5cfda",
"b1 c #a6cef0",
"a5 c #a8bcd7",
"e3 c #a8cdcd",
"aw c #a8cfda",
"fC c #a8d1d1",
"dm c #a8d1db",
"aK c #a9a9a9",
"bb c #a9d4ee",
"eI c #a9d7e1",
"#K c #aaaaaa",
"ej c #aad9f3",
"aS c #accbe7",
"es c #acd8ed",
"#T c #adadad",
"bR c #aedbf3",
"fw c #afb2b2",
"eG c #afdae2",
"cB c #b0ddf1",
"cf c #b1d6f5",
"an c #b2d3dd",
"bL c #b2d5f0",
"eJ c #b2dfe5",
"aQ c #b3cbe2",
"c4 c #b3ddf1",
"aR c #b4cee7",
"d7 c #b4dae2",
"#f c #b5b6b6",
"cP c #b5def1",
"fg c #b6b7b6",
"bm c #b6c4dc",
"cx c #b6d6f0",
"bw c #b6e3fa",
"## c #b7b7b7",
"fi c #b7b7b8",
"e8 c #b8bcbd",
"am c #b8d5de",
"aD c #b8dae1",
"bW c #b8dbe1",
"di c #b8dfe4",
"eM c #b8e3f5",
"do c #b8e4fa",
"dP c #badde3",
"e. c #bae6fa",
"fp c #bbbbbb",
"e7 c #bcd2d9",
"a3 c #bcdee3",
"fG c #bdbdbd",
"ao c #bddae0",
"em c #bebebe",
"el c #bedcdf",
"d3 c #bee3f4",
"dy c #bfbfbf",
"bT c #bfdde3",
"fy c #bfe3e3",
"#s c #c1c1c1",
"cv c #c1e2f6",
"dC c #c1eefd",
"aM c #c2e0e4",
"eF c #c2e0e5",
"b8 c #c4f0fd",
"dS c #c4f1fe",
"bQ c #c4f2fc",
"fD c #c5e8e8",
"ba c #c5f0fd",
"bv c #c5f3fc",
"#e c #c6c7c7",
"ap c #c6dee2",
"bk c #c6e2e5",
"ev c #c6e7f3",
"#6 c #c7c7c7",
"en c #c7e4e6",
"#a c #c8c8c8",
"dw c #c8e9e9",
"dp c #c9f0f9",
"fs c #cae5e5",
"cF c #cccccc",
"cU c #cce2e5",
"bu c #cceff6",
"#E c #cdcdcd",
"cG c #cde2e5",
"e4 c #cde4e6",
"eW c #cdf3fe",
"e9 c #cecccc",
"b4 c #cee4f1",
"cl c #cef1fd",
"ei c #cef4fd",
"cX c #cef5fd",
"fz c #cfe5e5",
"fc c #cfe6e7",
"b# c #cff5fc",
"be c #d0e6e7",
"dD c #d0f0f7",
"e# c #d0f3ff",
"eN c #d0f5fc",
"eZ c #d1d5da",
"al c #d1e3e6",
"aX c #d1e7e8",
"fl c #d2e9e9",
"b7 c #d2f0f7",
"c9 c #d3d3d3",
"dz c #d3e8e9",
"bP c #d3eef4",
"#d c #d4d4d4",
"eD c #d4e9e9",
"db c #d4f2f6",
"dT c #d4f3fb",
"#b c #d5d5d5",
"fx c #d5e0e0",
"eT c #d5e9e9",
"ey c #d5eef5",
"d. c #d6e5e7",
"fb c #d6e9e9",
"du c #d6f2fb",
"bV c #d7d7d7",
"aq c #d7e5e7",
"av c #d7e9e9",
"bE c #d8e8e9",
"cr c #d8e9e9",
"dH c #d8eaf2",
"b. c #d8f7fd",
"fh c #d9d9d9",
"#c c #d9dada",
"fF c #d9e7e7",
"cw c #d9ebf2",
"co c #dae9e9",
"ds c #daebf2",
"cA c #daf4fb",
"cJ c #dafbfd",
"ab c #dbdbdb",
"bz c #dbe8e8",
"aE c #dce9e9",
"eE c #dddddd",
"fE c #dde9e9",
"#0 c #dedede",
"c6 c #dee9e9",
"dg c #def3fc",
"ex c #def4f5",
"cb c #dfe9e9",
"eh c #dff3f4",
"cY c #dff3f6",
"bD c #e0e0e0",
"c# c #e0e9e9",
"bt c #e0f3f5",
"dL c #e0f9fc",
"#t c #e1e1e1",
"dl c #e1e8e9",
"aL c #e1e9e9",
"cg c #e1f0f3",
"ak c #e2e9e9",
"ar c #e3e9e9",
"ez c #e3f7fc",
"#u c #e4e4e4",
"ae c #e4e9e9",
"eP c #e4f1f4",
"dq c #e4f5f3",
"dU c #e4f6f8",
"cO c #e4f7fb",
"eA c #e4ffff",
"cq c #e5e5e5",
"ad c #e5e9e9",
"a6 c #e5eaf4",
"bY c #e5ecf6",
"ed c #e5f9fd",
"ew c #e5fcf9",
"#L c #e6e6e6",
"aF c #e6e9e9",
"ea c #e6fdff",
"#v c #e7e7e7",
"ac c #e7e9e9",
"cL c #e7f1f3",
"ck c #e7f5f5",
"c3 c #e7f8fd",
"a9 c #e7f9fd",
"au c #e8e8e8",
"af c #e8e9e9",
"dE c #e8f5f3",
"cK c #e8f7f8",
"#w c #e9e9e9",
"eO c #e9f7fb",
"ee c #e9f9f7",
"cu c #e9fefe",
"d2 c #eafbf8",
"eY c #ebf4f7",
"ec c #ecfdff",
"dV c #edf8f6",
"bs c #f0f8f8",
"bO c #f0f9f4",
"cN c #f0f9f5",
"cz c #f0f9f6",
"df c #f0f9f8",
"c2 c #f0faf6",
"ce c #f0fbfe",
"eb c #f0ffff",
"b6 c #f1f9f4",
"bH c #f2f8fe",
"dW c #f2faf6",
"dt c #f2faf7",
"dI c #f3f8f3",
"br c #f4fafb",
"a8 c #f4fdff",
"dK c #f5fcf4",
"dX c #f5fcf7",
"bq c #f5fcfc",
"dY c #f5fdf5",
"a7 c #f6fafd",
"dc c #f6fbf4",
"dF c #f6fcf3",
"ef c #f6fef4",
"eX c #f7fefe",
"eg c #f8fcf3",
"dZ c #f9fdf4",
"dG c #fafdf3",
"de c #fafdf4",
"d1 c #fafef4",
"bM c #fbfdf5",
"dr c #fbfef4",
"cj c #fcfff4",
"c1 c #fdfef3",
"cM c #fdfef4",
"bN c #fdfef5",
"bn c #fdfefe",
"cy c #fdfff4",
"bp c #fdffff",
"cZ c #fefdf4",
"d0 c #fefef4",
"dJ c #fefff3",
"ch c #fefff4",
"b5 c #fffff4",
"bo c #ffffff",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.#.a.b.c.d.e.f.g.h.i.j.k.l.l.l.k.m.i.h.n.o",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.p.q.r.s.t.u.v.w.x.y.z.A.B.C.D.D.E.C.B.F.G.y.x",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQt.p.H.I.J.K.L.M.N.O.P.Q.R.S.T.U.V.W.X.W.Y.Z.T.S.R.Q",
"QtQtQtQtQtQtQtQtQtQtQtQt.#.q.I.e.0.1.2.C.Q.3.4.5.6.7.8.9#.###a#b#c#d#e#f#g#h#i",
"QtQtQtQtQtQtQtQtQtQt.##j.r#k.0#l#m.D#n.Y#o#p#q#r#s#t#u#v#w#w#w#w#w#w#w#w#w#v#u",
"QtQtQtQtQtQtQtQtQt.p#x#y#z.v#A.D.R.W#B#C#D#E#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w",
"QtQtQtQtQtQtQtQt.a.r.J.i#F#G#H.W#I#J#K#L#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w",
"QtQtQtQtQtQt.##j#M#N.v#O#P#Q#R#S#T#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w",
"QtQtQtQtQt.#.q#y#U#V#W#X#Y#Z#D#0#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w",
"QtQtQtQt.#.H#1.h#2#3.T#4#5#6#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w",
"QtQtQt.#.H#1#7#8#9a.a#aaab#w#w#w#w#w#w#wacadaeadacaf#w#w#w#w#w#w#w#w#w#w#w#w#w",
"QtQt.#.q#1ag#8ah.Yaiaj#u#w#w#w#w#w#wacakalamanaoapaqaraf#w#w#w#w#w#w#w#w#w#w#w",
"QtQt#j.c.0.Mah.Yasatau#w#w#w#w#w#waeavawaxayazaAaBaCaDaEaF#w#w#w#w#w#w#w#w#w#w",
"Qt.paG#zaHaI.YaJaK#w#w#w#w#w#w#waLaMaNaOaPaQaRaSaTaUaVaWaXad#w#w#w#w#w#w#w#w#w",
".#aYaZa0.C.3a1a2#w#w#w#w#w#w#waka3a4a5a6a7a8a9b.b#babbbcbdbeaF#w#w#w#w#w#w#w#w",
".qbf.mbgbhbibjau#w#w#w#w#w#wadbkblbmbnbobpbqbrbsbtbubvbwbxbybzaf#w#w#w#w#w#w#w",
".I.K#8bAbBbCbD#w#w#w#w#w#wafbEbFbGbobHbIbJbKbLbMbNbObPbQbRbSbTad#w#w#w#w#w#w#w",
"aZ#l.E.UbUbV#w#w#w#w#w#w#wadbWbXbYbpbZb0b1b2b3b4b5b5b6b7b8b9c.c##w#w#w#w#w#w#w",
".ubgbhca#K#w#w#w#w#w#w#w#wcbcccdcecfb3cgchb5b3cib5b5cjckclcmcnco#w#w#w#w#w#w#w",
".x#PbBcpcq#w#w#w#w#w#w#w#wcrcsctcucvb3cwb5b5b3cxb5b5cyczcAcBcCcr#w#w#w#w#w#w#w",
"cD.3cEcF#w#w#w#w#w#w#w#wafcGcHcIcJcKbKcLb5b5b3b4b5b5cMcNcOcPcQco#w#w#w#w#w#w#w",
"cRcScT#v#w#w#w#w#w#w#w#waccUcVcWcXcYcZb5b5b5bJc0b5b5c1c2c3c4c5c6#w#w#w#w#w#w#w",
"c7c8c9#w#w#w#w#w#w#w#w#wafd.d#dabadbdcb5b5b5ciddcLb5dedfdgdhdiae#w#w#w#w#w#w#w",
"djdkcq#w#w#w#w#w#w#w#w#w#wdldmdndodpdqdrb5b5b5cib3dsdedtdudvdwaF#w#w#w#w#w#w#w",
"dxdy#w#w#w#w#w#w#w#w#w#w#wacdzdAdBdCdDdEdFdGdGdHc0dIdJdKdLdMdNcoac#w#w#w#w#w#w",
"dO#t#w#w#w#w#w#w#w#w#w#w#w#wardPdQdRdSdTdUdVdWdXdYdZd0d1d2d3d4d5c6af#w#w#w#w#w",
"d6#w#w#w#w#w#w#w#w#w#w#w#w#w#wcbd7d8d9e.e#eaebecedeeefegeheiejekelae#w#w#w#w#w",
"em#w#w#w#w#w#w#w#w#w#w#w#w#w#wafc#eneoepeqereseteuevewexeyezeAeBeCeDaF#w#w#w#w",
"eE#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#wadcoeFeGeHeIeJeKeLeMeNeObnePeQeReScrac#w#w#w",
"#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#wadakc#akakeTeUeVeWeXeYeZe0e1e2e3cb#w#w#w",
"#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#wade4e5e6e7e8e9#af.f#fafb#w#w#w",
"#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#waefcfdfefffgfhfifjfkfb#w#w#w",
"#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#waFflfmfnfofpfpfqfraE#w#w#w",
"#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#waefsftfufvfwfxfyak#w#w#w",
"#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#warfzfAfBfCfDeTaF#w#w#w",
"#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#waFaLfEfFc6ad#w#w#w#w",
"#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w#w",
"fGfGfGfGfGfGfGfGfGfGfGfGfGfGfGfGfGfGfGfGfGfGfGfGfGfGfGfGfGfGfGfGfGfGfGfGfGfGfG",
"fHfHfHfHfHfHfHfHfHfHfHfHfHfHfHfHfHfHfHfHfHfHfHfHfHfHfHfHfHfHfHfHfHfHfHfHfHfHfH"};

static const char* const img7_login_dlg[] = { 
"51 16 34 1",
"# c #737173",
"b c #73aae6",
"c c #73aee6",
"a c #73aeee",
"e c #7baee6",
"d c #7bb2ee",
"f c #83b6ee",
"g c #8bbaee",
"h c #8bbeee",
"l c #94beee",
"j c #94c2ee",
"k c #94c2f6",
"i c #9cc2f6",
"m c #9cc6ee",
"o c #9cc6f6",
"n c #a4c6f6",
"s c #a4caf6",
"r c #a4cef6",
"q c #accaf6",
"p c #accef6",
"u c #acd2f6",
"t c #b4d2f6",
"w c #c5daf6",
"v c #c5deff",
". c #d5d2d5",
"x c #d5e6f6",
"z c #d5e6ff",
"y c #deeaff",
"B c #eef2ff",
"A c #eef6ff",
"C c #f6f6ff",
"D c #f6faff",
"F c #fffaff",
"E c #ffffff",
"...................................................",
"###################################################",
"abababababababababababababababababababababababababa",
"cdedcdcdcdcdcdcdcdedcdedcdedcdedcdcdcdedcdcdcdedcde",
"fffffffffffffffffffffffffffffffffffffffffffffffffff",
"ghggggggggggggggggggggggggggggggggggggggggggggggggg",
"ijijijijkjijijijijijklijijijijilijijilijilijklijiji",
"mnmnmomnmnmnmnmnmnmnmomnmnmnmnmnmnmnmnmnmnmnmnmnmnm",
"pqprpqpqpqpppqpppppqpqpqpppqpppspqprpqpppqpqpqpqppp",
"ttttttttttttttttttttttttttutttttttutttttttttttttttt",
"vwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwvwv",
"xyzyxyzyxyzyxyzyxyzyxyzyxyzyzyzyxyzyxyzyzyzyxyzyxyz",
"ABABCBABABABABABABABCBABABABABABCBABCBABABABABABCBA",
"DEDEDEDEDEDEFEDEDEDEDEDEDEDEDEDEDFDEDFDEDEDEDEDEDED",
"EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE",
"EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE"};

static const char* const img8_login_dlg[] = { 
"27 224 111 2",
".a c #0075e6",
"Qt c #0075ee",
".c c #0079e6",
".# c #0079ee",
".e c #0879e6",
".b c #0879ee",
".d c #087dee",
".f c #107dee",
".g c #107df6",
".h c #1081ee",
".k c #1081f6",
".j c #1881ee",
".i c #1881f6",
".m c #1885ee",
".l c #1885f6",
".o c #2085ee",
".n c #2085f6",
".q c #2089ee",
".p c #2089f6",
".s c #2989ee",
".r c #2989f6",
".u c #298dee",
".t c #298df6",
".x c #318dee",
".v c #318df6",
".y c #3191ee",
".w c #3191f6",
".A c #3991ee",
".z c #3991f6",
".D c #3995ee",
".B c #3995f6",
".F c #4195ee",
".C c #4195f6",
".H c #4199ee",
".E c #4199f6",
".J c #4a99ee",
".G c #4a99f6",
".K c #4a9dee",
".I c #4a9df6",
".N c #529dee",
".L c #529df6",
".O c #52a1ee",
".M c #52a1f6",
".R c #5aa5ee",
".P c #5aa5f6",
".Q c #5aaaf6",
".S c #62aaf6",
".T c #62aaff",
".U c #62aef6",
".V c #6aaef6",
".W c #6aaeff",
".X c #6ab2f6",
".Y c #6ab2ff",
".Z c #73b2f6",
".0 c #73b2ff",
".2 c #73b6f6",
".1 c #73b6ff",
".3 c #7bb6f6",
".4 c #7bb6ff",
".6 c #7bbaf6",
".5 c #7bbaff",
".7 c #83baf6",
".8 c #83baff",
"#. c #83bef6",
".9 c #83beff",
"#a c #8bbef6",
"## c #8bbeff",
"#c c #8bc2f6",
"#b c #8bc2ff",
"#f c #94c2f6",
"#d c #94c2ff",
"#h c #94c6f6",
"#e c #94c6ff",
"#j c #9cc6f6",
"#g c #9cc6ff",
"#l c #9ccaf6",
"#i c #9ccaff",
"#n c #a4caf6",
"#k c #a4caff",
"#p c #a4cef6",
"#m c #a4ceff",
"#r c #accef6",
"#o c #acceff",
"#s c #acd2f6",
"#q c #acd2ff",
"#w c #acd6f6",
"#v c #acd6ff",
"#u c #b4d2ff",
"#A c #b4d6f6",
"#t c #b4d6ff",
"#y c #b4daff",
"#z c #bdd6ff",
"#x c #bddaff",
"#B c #bddeff",
"#D c #c5daff",
"#C c #c5deff",
"#E c #c5e2ff",
"#F c #cde2ff",
"#G c #cde6ff",
"#H c #d5e6ff",
"#I c #d5eaff",
"#J c #deeaff",
"#K c #deeeff",
"#L c #e6eeff",
"#M c #e6f2ff",
"#N c #eef2ff",
"#O c #eef6ff",
"#P c #f6f6ff",
"#Q c #f6faff",
"#R c #fffaff",
"#S c #ffffff",
"QtQt.#QtQtQtQtQtQtQt.#Qt.#QtQtQtQtQt.#QtQtQtQtQtQtQt.#",
"QtQt.aQtQtQt.aQtQtQt.aQtQtQt.aQtQtQt.aQtQtQt.aQtQtQt.a",
".#QtQtQt.#Qt.#QtQtQt.#QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
".aQtQtQt.aQtQtQt.aQtQtQtQtQtQtQt.aQtQtQt.aQtQtQt.aQtQt",
".bQt.bQt.bQt.bQt.bQt.bQt.bQt.bQt.bQt.#Qt.bQt.bQt.bQt.#",
"QtQt.aQtQt.b.a.#Qt.b.a.#Qt.#.a.#Qt.#.a.#Qt.#QtQtQt.b.a",
".bQt.bQt.b.#.bQt.b.#.bQt.bQt.bQt.bQt.bQt.bQt.bQt.b.#.b",
"Qt.bQt.b.a.bQt.bQt.bQt.bQt.bQt.b.a.bQt.b.a.bQt.bQt.bQt",
".b.b.b.b.b.b.b.#.b.b.b.#.b.b.b.#.b.b.b.#.b.b.b.b.b.b.b",
".b.b.c.b.#.b.c.b.b.b.#.b.#.b.#.b.b.b.#.b.#.b.#.b.#.b.a",
".d.b.d.b.d.b.b.b.d.b.b.b.b.b.d.b.d.b.d.b.b.b.d.b.b.b.b",
".e.b.b.b.b.b.b.b.e.b.b.b.b.b.b.b.b.b.b.b.e.b.b.b.b.b.b",
".f.b.d.b.f.b.f.b.f.b.f.b.f.b.f.b.f.b.f.b.f.b.d.b.f.b.d",
".b.f.b.d.b.f.b.d.b.f.b.d.b.f.b.d.b.f.b.d.b.f.b.d.b.f.b",
".f.d.f.d.f.d.f.d.f.d.f.d.f.d.f.d.f.d.f.d.f.d.f.d.f.b.f",
".d.f.d.f.b.f.d.f.b.f.d.f.b.f.d.f.d.f.b.f.b.f.b.f.d.f.d",
".g.f.f.f.h.f.f.f.g.f.f.f.g.f.f.f.f.f.f.f.h.f.f.f.f.f.f",
".f.f.f.f.f.f.d.f.f.f.f.f.f.f.f.f.f.f.f.f.f.f.d.f.f.f.d",
".h.f.i.f.h.f.j.f.h.f.i.f.h.f.i.f.h.f.k.f.h.f.i.f.h.f.i",
".f.h.f.h.f.h.f.j.f.h.f.h.f.h.f.h.f.h.f.h.f.h.f.h.f.h.f",
".i.h.j.h.i.h.j.h.i.h.j.h.i.h.j.h.i.h.j.h.i.h.j.h.j.h.j",
".h.j.h.j.h.j.h.j.f.j.h.j.h.j.h.j.h.j.h.j.h.j.h.j.h.j.f",
".j.j.i.j.j.j.i.j.j.j.l.j.l.j.l.j.j.j.i.j.j.j.l.j.j.j.l",
".j.j.j.j.h.j.j.j.j.m.j.j.h.j.j.j.h.j.j.m.h.j.j.m.h.j.j",
".n.j.m.j.n.j.l.j.n.j.m.j.n.j.o.j.n.j.m.j.n.j.m.j.n.j.l",
".j.o.j.m.j.m.j.m.j.o.j.m.j.o.j.m.j.o.j.m.j.m.j.m.j.m.j",
".o.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n.m.n",
".m.o.m.o.m.o.m.o.m.o.m.o.m.o.m.o.m.o.m.o.m.o.m.o.m.o.m",
".p.o.p.o.p.o.p.o.p.o.p.o.p.o.p.o.p.o.p.o.p.o.p.o.p.o.p",
".o.q.o.q.o.q.o.q.o.q.o.q.o.q.o.q.o.q.o.q.o.q.o.q.o.q.o",
".r.q.r.o.r.q.r.q.r.q.r.q.r.q.r.q.r.q.r.q.r.q.r.q.r.o.r",
".o.q.o.s.q.q.o.s.q.q.o.s.q.s.o.s.q.s.q.s.q.q.q.r.q.s.q",
".t.s.t.q.t.s.r.q.t.s.t.q.r.s.r.q.r.s.r.q.t.s.r.q.t.s.r",
".s.r.q.s.s.s.q.s.s.r.q.s.q.u.q.u.s.s.q.u.q.t.q.u.s.u.q",
".t.u.v.s.t.s.v.s.t.s.t.u.t.s.v.s.t.s.v.s.t.s.t.s.t.s.v",
".s.u.s.t.s.u.u.t.s.u.s.t.s.u.u.t.s.u.s.t.u.u.u.t.u.u.s",
".v.u.v.u.v.u.w.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v.u.v",
".u.v.u.x.u.v.u.v.u.v.u.x.u.v.u.x.u.v.u.x.u.v.u.x.u.v.u",
".w.x.w.x.w.x.w.x.w.x.w.x.w.x.w.x.w.x.w.x.w.x.w.x.w.x.w",
".x.y.x.w.x.w.x.w.x.y.x.w.x.y.x.w.x.y.x.w.x.y.x.w.x.w.x",
".z.y.z.y.z.y.z.y.z.y.z.y.z.y.z.y.z.y.z.y.z.y.z.y.z.y.z",
".y.z.y.z.y.z.y.z.y.z.y.z.y.z.y.A.y.z.y.z.y.z.y.z.y.z.y",
".B.A.B.A.B.A.B.A.B.A.B.A.B.A.B.A.B.A.B.A.B.A.B.A.B.A.B",
".y.B.A.B.A.B.A.B.A.B.A.B.A.B.A.B.A.B.A.B.A.B.A.B.A.B.A",
".C.D.C.D.C.B.B.D.C.B.B.D.C.D.B.D.C.B.C.D.C.B.C.D.C.B.B",
".D.C.D.C.D.C.D.B.D.C.D.B.D.C.D.B.D.C.D.C.D.C.D.B.D.C.D",
".E.D.E.F.E.D.E.F.E.F.E.F.E.D.E.C.E.D.E.C.E.D.E.C.E.D.E",
".D.E.F.E.D.E.F.E.D.E.F.E.D.E.F.E.D.E.F.E.D.E.F.E.D.E.F",
".G.E.E.H.G.E.E.H.G.E.E.H.G.E.E.H.G.E.E.H.G.E.E.H.G.E.E",
".H.G.H.E.H.G.H.E.H.G.H.E.H.E.H.E.H.G.H.E.H.E.H.E.H.G.H",
".I.E.I.G.I.E.I.G.I.H.I.G.I.H.I.E.I.H.I.G.I.E.I.G.I.H.I",
".H.I.H.I.H.I.J.I.H.I.H.I.H.I.J.I.H.I.H.I.H.I.J.I.H.I.J",
".I.I.I.I.I.I.I.K.L.I.I.I.I.I.I.I.L.I.I.I.I.I.I.I.I.I.I",
".K.I.K.I.K.I.K.I.K.L.K.I.K.I.K.I.K.L.K.I.K.I.K.I.K.I.K",
".M.I.M.I.M.I.M.I.M.I.M.I.M.I.M.I.M.I.M.I.M.I.M.I.M.I.M",
".K.M.I.M.K.M.I.M.K.M.I.M.K.M.N.M.K.M.K.M.K.M.I.M.K.M.I",
".M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M",
".M.M.O.M.M.M.O.M.M.M.O.M.M.M.O.M.M.M.O.M.M.M.O.M.M.M.O",
".P.M.P.M.P.M.P.M.P.M.P.M.P.M.P.M.P.M.P.M.P.M.P.M.P.M.P",
".O.P.M.P.O.P.M.P.O.P.M.P.M.P.M.P.M.P.M.P.O.P.M.P.O.P.M",
".Q.P.P.P.P.P.P.P.P.P.Q.P.Q.P.P.P.P.P.P.P.Q.P.P.P.P.P.P",
".P.P.P.P.P.P.P.P.P.Q.R.P.P.P.R.P.P.P.R.Q.P.P.P.Q.P.P.R",
".S.P.S.P.S.Q.S.P.S.P.S.P.S.P.S.P.S.Q.S.P.S.P.S.P.S.Q.S",
".P.S.P.S.Q.S.P.S.R.S.P.S.Q.S.Q.S.Q.S.Q.S.Q.S.P.S.P.S.Q",
".T.S.U.S.U.S.S.S.S.S.S.S.S.S.U.S.S.S.S.S.S.S.S.S.S.S.U",
".S.S.S.U.S.S.S.U.S.S.S.U.S.S.S.S.S.S.S.U.S.U.S.S.S.U.S",
".V.S.W.S.V.S.V.S.V.S.V.S.V.U.W.S.V.S.V.U.V.S.V.U.V.U.V",
".U.V.U.V.U.V.U.V.U.V.U.V.U.V.U.V.S.V.U.V.U.V.U.V.S.V.U",
".V.V.X.V.Y.V.X.V.Y.V.X.V.Y.V.X.V.Y.V.X.V.Y.V.X.V.Y.V.X",
".V.X.V.X.V.X.V.X.V.X.V.X.V.X.V.X.V.X.V.X.V.X.V.X.V.X.V",
".Z.X.0.X.Z.X.0.X.Z.X.0.X.Z.X.0.X.0.X.0.X.Z.X.0.X.0.X.0",
".X.Z.X.Z.X.Z.X.Z.X.Z.X.Z.X.Z.X.Z.X.Z.X.Z.X.Z.X.Z.X.Z.X",
".1.Z.1.Z.1.Z.1.Z.1.Z.1.Z.1.Z.2.Z.1.Z.2.Z.1.Z.2.Z.1.Z.1",
".Z.2.Z.2.Z.2.Z.2.Z.2.Z.2.Z.2.Z.2.Z.3.Z.2.Z.2.Z.2.Z.2.Z",
".4.2.4.2.4.2.4.2.4.2.4.2.4.2.4.3.4.2.4.2.4.2.4.2.4.2.4",
".2.3.2.3.2.3.2.3.2.3.2.3.2.3.2.3.2.3.2.3.2.3.3.3.2.3.3",
".5.3.5.3.5.3.5.3.5.3.5.3.5.3.5.3.5.3.5.3.5.3.5.3.5.3.5",
".3.5.3.6.3.7.3.6.3.8.3.6.3.6.3.6.3.5.3.6.3.8.3.6.3.6.3",
".8.6.8.6.8.6.8.6.8.6.8.6.8.6.8.7.8.6.8.6.8.6.8.7.8.6.8",
".6.7.6.9.6.7.7.8.6.7.6.7.6.7.6.8.6.7.6.8.6#..7.8.6.7.7",
"###..9.7##.7.9.7###..9.7.9#..9.7.9.7.9#..9.7.9.7.9.7.9",
"#.##.7#..7##.7.9.7##.7#..7.9.7.9.7.9.7#.#.###.#.#..9#.",
"###.###a#b#.#b#a###.###a#b#.###a###.#b#.#b#.###a###.#b",
"#.###a#b#.#c#a###.###a#b#.#a#a###.#c#.#b#.#b#a#b#.###.",
"#b#a#b#c#d#c#b#c#b#c#b#c#d#c#b#c#d#c#b#a#b#c#b#a#d#c#b",
"#c#d#c#b#a#d#c#b#c#b#c#b#c#d#c#b#c#b#c#b#c#d#c#b#a#d#c",
"#e#c#e#d#e#c#e#f#e#c#e#c#e#c#e#d#e#c#d#f#e#c#e#c#e#c#e",
"#c#e#f#e#c#e#f#e#c#e#f#e#c#e#f#e#c#e#f#e#c#e#f#e#c#e#f",
"#g#e#e#h#g#e#e#h#g#h#e#h#g#e#e#h#g#h#e#h#g#h#e#h#g#e#e",
"#h#g#h#e#h#g#h#e#h#g#h#e#h#g#h#e#h#g#h#e#h#g#h#e#h#g#h",
"#i#h#i#g#i#h#i#g#i#h#i#g#i#h#i#g#i#h#i#g#i#h#i#g#i#h#i",
"#h#i#j#i#h#i#j#i#h#i#j#i#h#i#j#i#h#i#j#i#h#i#j#i#h#i#j",
"#k#i#i#i#k#i#i#l#k#i#i#l#k#i#i#l#k#i#i#l#k#i#i#l#k#i#k",
"#l#k#l#i#l#k#l#i#l#k#l#i#l#k#l#i#l#k#l#i#l#k#l#i#l#k#l",
"#m#i#m#k#m#i#m#k#m#i#m#k#m#i#m#k#m#n#m#k#m#i#m#k#m#i#m",
"#l#m#n#m#l#m#n#m#l#m#n#m#l#m#n#m#l#m#n#m#l#m#n#m#l#m#n",
"#o#m#m#m#o#m#m#m#o#m#m#m#o#m#m#m#o#m#m#m#o#m#m#m#o#m#o",
"#p#o#p#m#m#o#p#m#p#o#p#m#m#o#p#m#m#o#p#m#p#o#p#m#p#o#p",
"#q#m#q#o#q#m#q#o#q#m#q#q#q#m#q#o#q#m#q#o#q#m#q#o#q#m#q",
"#p#q#o#q#r#q#o#q#p#q#q#q#p#q#o#q#s#q#r#q#p#q#q#q#p#q#q",
"#t#q#q#q#t#q#q#q#u#q#v#q#u#q#q#q#u#q#v#q#u#q#q#q#t#q#q",
"#q#t#s#q#q#u#s#v#q#u#s#q#q#u#s#q#q#u#s#u#q#t#s#u#q#t#s",
"#t#q#t#t#t#q#t#u#t#q#t#u#t#v#t#t#t#q#t#t#t#q#t#u#t#q#t",
"#q#t#u#t#s#t#u#t#v#t#t#t#s#t#t#t#s#t#u#t#w#t#u#t#q#t#t",
"#t#t#t#t#x#t#y#t#z#t#y#t#x#t#t#t#x#t#y#t#x#t#y#t#x#t#t",
"#t#z#t#y#t#z#A#y#t#x#A#t#t#z#t#y#t#z#t#y#t#t#t#t#t#z#A",
"#x#t#x#t#x#t#x#z#x#y#x#t#x#t#x#x#x#t#x#z#x#t#x#x#x#t#x",
"#t#x#z#x#t#x#t#x#y#x#x#x#y#x#x#x#t#x#x#x#y#x#t#x#y#x#x",
"#B#x#B#x#B#x#B#x#C#x#B#x#D#x#B#x#x#x#B#x#B#x#x#x#D#x#x",
"#x#B#x#B#x#C#x#B#x#C#x#B#x#B#x#B#x#x#x#x#x#B#x#x#x#B#x",
"#C#B#C#B#C#B#C#B#C#B#C#C#C#B#C#C#C#x#C#B#C#B#C#D#C#x#C",
"#B#C#C#C#B#C#B#C#x#C#B#C#B#C#x#C#B#C#B#C#x#C#C#C#x#C#C",
"#E#C#C#C#E#C#E#C#C#C#E#C#E#C#E#C#C#C#C#C#E#C#E#C#E#C#E",
"#C#E#C#C#C#E#C#E#C#E#C#E#C#E#C#E#C#E#C#E#C#C#C#E#C#E#C",
"#F#E#F#E#F#E#F#E#F#C#F#C#F#E#F#E#F#E#F#C#F#E#F#E#F#C#F",
"#E#F#C#F#E#F#E#F#C#F#C#F#E#F#E#F#E#F#E#F#E#F#E#F#C#F#E",
"#F#F#F#F#G#F#G#F#G#F#G#F#F#F#G#F#F#F#G#F#G#F#F#F#G#F#F",
"#F#F#F#F#F#G#F#F#F#G#F#G#F#F#F#F#F#G#F#G#F#F#F#F#F#G#F",
"#H#G#H#F#H#G#H#F#H#G#H#G#H#F#H#G#H#G#H#F#H#F#H#G#H#F#H",
"#G#H#G#H#F#H#G#H#G#H#G#H#F#H#G#H#G#H#G#H#F#H#F#H#F#H#G",
"#I#H#H#H#I#H#H#H#I#H#I#H#I#H#I#H#H#H#I#H#H#H#I#H#H#H#I",
"#H#I#H#H#H#H#H#H#H#I#H#I#H#H#H#I#H#H#H#H#H#H#H#H#H#H#H",
"#J#H#J#H#J#H#J#H#I#I#J#H#I#H#J#H#J#H#J#H#J#H#J#H#J#H#J",
"#I#I#H#J#H#I#H#J#H#I#H#J#H#J#H#J#H#I#I#J#H#J#H#J#H#I#H",
"#K#J#J#I#J#J#J#I#J#J#J#I#J#J#J#I#J#J#J#I#J#J#J#I#J#J#J",
"#J#J#I#J#I#J#I#J#J#J#I#K#I#J#I#J#J#J#I#K#I#J#I#J#J#J#I",
"#K#J#L#J#K#J#K#J#K#J#K#J#K#J#L#J#K#J#L#J#K#J#K#J#K#J#L",
"#J#K#J#K#J#K#J#K#J#K#J#K#J#K#J#K#J#K#J#K#J#K#J#K#J#K#J",
"#L#K#L#K#L#K#L#K#L#K#L#K#L#K#L#K#L#K#L#K#L#K#L#K#L#K#L",
"#K#L#K#L#K#L#K#L#K#L#K#L#K#L#K#L#K#L#K#L#K#L#K#L#K#L#K",
"#M#L#M#L#M#L#M#L#M#L#M#L#M#L#M#L#M#L#M#L#M#L#M#L#M#L#M",
"#L#M#L#M#L#M#L#M#L#M#L#M#L#M#L#M#L#M#L#M#L#M#L#M#L#M#L",
"#N#M#N#M#N#M#N#M#N#M#N#M#N#M#M#M#N#M#N#M#N#M#N#M#N#M#N",
"#M#N#M#M#L#N#M#M#M#N#M#M#M#N#M#M#M#N#M#M#L#N#M#M#L#N#L",
"#O#M#O#N#N#M#N#N#O#M#N#M#N#M#O#N#N#M#N#M#O#M#N#N#O#M#N",
"#M#N#M#N#M#N#M#N#M#N#M#N#M#O#M#N#M#N#M#O#M#N#M#N#M#N#M",
"#O#N#O#N#O#N#O#N#O#N#O#N#O#N#O#O#O#N#O#N#O#N#O#N#O#N#O",
"#N#O#N#O#N#O#N#O#N#O#N#O#N#O#N#O#N#O#N#O#N#O#N#O#N#O#N",
"#P#O#P#O#P#O#P#O#P#O#P#O#P#O#P#O#P#O#P#O#P#O#P#O#P#O#P",
"#O#O#O#P#O#O#O#P#O#O#O#P#O#P#O#P#O#O#O#P#O#P#O#P#O#O#O",
"#Q#P#Q#O#Q#P#Q#O#Q#P#Q#O#Q#P#Q#O#Q#P#Q#O#Q#O#Q#O#Q#O#Q",
"#O#Q#O#Q#O#Q#O#P#O#P#O#Q#O#Q#O#Q#O#Q#O#Q#O#Q#O#Q#O#P#O",
"#Q#Q#Q#Q#Q#P#Q#Q#Q#Q#Q#P#Q#P#Q#P#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q#Q",
"#P#Q#P#Q#Q#Q#P#Q#P#Q#P#Q#P#Q#P#Q#P#Q#P#Q#P#Q#P#Q#P#Q#Q",
"#R#Q#R#Q#R#Q#Q#Q#R#Q#R#Q#R#Q#R#Q#R#Q#Q#Q#R#Q#R#Q#R#Q#R",
"#Q#R#Q#Q#Q#R#Q#Q#Q#R#Q#Q#Q#R#Q#Q#Q#R#Q#Q#Q#R#Q#Q#Q#R#Q",
"#S#Q#S#Q#S#Q#S#R#S#Q#S#Q#S#Q#S#Q#S#Q#S#Q#S#Q#S#Q#S#Q#S",
"#Q#S#Q#S#Q#S#Q#S#Q#S#Q#S#Q#S#Q#S#Q#R#Q#S#Q#R#Q#R#Q#R#Q",
"#S#R#S#R#S#R#S#R#S#R#S#R#S#R#S#S#S#S#S#S#S#S#S#R#S#R#S",
"#R#S#R#S#R#S#Q#S#R#S#Q#S#R#S#Q#S#R#S#R#S#R#S#Q#S#R#S#Q",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S",
"#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S#S"};

static const char* const img9_login_dlg[] = { 
"97 66 294 2",
"bO c #9c99a4",
"bP c #9c99ac",
"ao c #9c99b4",
"ap c #9c99bd",
"aq c #9c99c5",
"bT c #9c9db4",
"bZ c #9c9dbd",
"au c #9c9dc5",
"aj c #9c9dcd",
"aE c #9ca1c5",
"aO c #9ca1cd",
"aG c #9ca5cd",
"ai c #9ca5d5",
"aM c #9caacd",
"an c #9caad5",
"#8 c #9caed5",
".6 c #9cb2f6",
".V c #9cb6ee",
"az c #9cbaf6",
"#0 c #9cc2f6",
".2 c #9cc2ff",
"ak c #9cc6ff",
"bU c #a49dac",
"bS c #a49db4",
"bY c #a49dbd",
"av c #a49dc5",
"aF c #a4a1cd",
"cp c #a4a5c5",
"aN c #a4aacd",
"aT c #a4aecd",
"aW c #a4aed5",
"aV c #a4b2cd",
"at c #a4b2d5",
"bJ c #a4b2de",
"af c #a4b2e6",
"#s c #a4b6de",
".J c #a4b6e6",
".e c #a4b6ee",
"cs c #a4bad5",
"cj c #a4bade",
"b0 c #a4bae6",
".g c #a4baee",
"a0 c #a4baf6",
"#B c #a4beee",
"aB c #a4bef6",
"#a c #a4c2ff",
"aH c #a4c6f6",
"#v c #a4c6ff",
"bn c #a4caee",
"#F c #a4caf6",
".5 c #a4caff",
"as c #a4ceff",
"be c #a4d2ff",
"aP c #acaec5",
"aX c #acaecd",
"al c #acaede",
"aU c #acb2d5",
".c c #acb2e6",
".Z c #acb2f6",
"bE c #acb6cd",
"a3 c #acb6d5",
"aC c #acb6de",
"#n c #acb6e6",
".d c #acb6ee",
"#H c #acbad5",
"bK c #acbade",
"ab c #acbae6",
".M c #acbaee",
".f c #acbaf6",
"ct c #acbed5",
"cm c #acbede",
"bf c #acbee6",
"#p c #acbeee",
"#R c #acc2ee",
".O c #acc2f6",
"cv c #acc6de",
"bG c #acc6e6",
"bI c #acc6f6",
"bg c #accaee",
".T c #accaff",
"bj c #accef6",
"#i c #acceff",
"## c #acd2ff",
"aJ c #acd6ff",
"cw c #b4aec5",
"ck c #b4b2cd",
"#e c #b4b2d5",
"bm c #b4b6c5",
"cg c #b4b6de",
".m c #b4b6e6",
"#y c #b4bad5",
"a5 c #b4bade",
".y c #b4bae6",
"ar c #b4baf6",
"a9 c #b4bed5",
"aD c #b4bede",
"#f c #b4beee",
"bC c #b4c2d5",
"cr c #b4c2de",
"bt c #b4c2e6",
".n c #b4c2ee",
"#u c #b4c2f6",
"ae c #b4c2ff",
"cu c #b4c6de",
"bR c #b4c6e6",
"#C c #b4c6ee",
".A c #b4c6f6",
"bB c #b4caee",
".u c #b4caf6",
"cc c #b4cef6",
"ci c #b4d2ee",
"b9 c #b4d2f6",
"#b c #b4d2ff",
"b3 c #b4d6f6",
"#l c #b4d6ff",
"ay c #b4daff",
"cn c #bdb6c5",
".B c #bdb6e6",
"a6 c #bdbabd",
"cd c #bdbac5",
"c# c #bdbacd",
".X c #bdbad5",
".G c #bdbade",
".h c #bdbae6",
"b5 c #bdbebd",
"bD c #bdbecd",
".v c #bdbede",
"#M c #bdbee6",
"cG c #bdc2d5",
"aL c #bdc2de",
"#T c #bdc2e6",
"#I c #bdc2ee",
"aS c #bdc6de",
"#X c #bdc6e6",
"ce c #bdcade",
"bL c #bdcae6",
"ah c #bdcaee",
".F c #bdcaf6",
"cx c #bdcede",
"b1 c #bdcee6",
"bz c #bdcef6",
"cA c #bdd2ee",
"bW c #bdd2f6",
"cy c #bdd6f6",
"#d c #bdd6ff",
"#. c #bddaff",
"#Q c #bddeff",
"aR c #bde2ff",
"cl c #c5bec5",
"bk c #c5becd",
"#G c #c5bed5",
".U c #c5bede",
".b c #c5beee",
"c. c #c5c2c5",
"cE c #c5c2cd",
"b2 c #c5c2d5",
"#N c #c5c2de",
"#J c #c5c2ee",
"bl c #c5c6c5",
"cz c #c5c6d5",
"aI c #c5c6de",
"#Y c #c5c6e6",
"cH c #c5cacd",
"b7 c #c5cad5",
"bd c #c5cade",
"a2 c #c5cae6",
"#7 c #c5caee",
"aK c #c5cede",
"#Z c #c5cee6",
"#5 c #c5ceee",
"#K c #c5cef6",
"co c #c5d2de",
"ad c #c5d2e6",
"bN c #c5d2ee",
"#L c #c5d2f6",
"#9 c #c5d6ee",
"ac c #c5d6f6",
"cf c #c5daee",
"b6 c #c5daf6",
".9 c #c5daff",
"ca c #c5def6",
"#j c #c5deff",
"#m c #c5e2ff",
"bu c #c5e6ff",
"cC c #cdc6cd",
".3 c #cdc6d5",
".P c #cdc6de",
"a. c #cdcacd",
"#r c #cdcad5",
".i c #cdcade",
"bi c #cdcae6",
".8 c #cdcaee",
"#E c #cdcecd",
"#h c #cdced5",
"a# c #cdcede",
"#z c #cdcee6",
".l c #cdceee",
"bA c #cdd2d5",
"aA c #cdd2de",
"bo c #cdd2e6",
"a8 c #cdd2ee",
"#U c #cdd2f6",
"a1 c #cdd6de",
"cq c #cdd6e6",
"bc c #cdd6ee",
"b# c #cdd6f6",
"cI c #cddaee",
"aw c #cddaf6",
"aa c #cddaff",
"bV c #cddef6",
"#D c #cddeff",
"ch c #cde2f6",
"#c c #cde2ff",
"#q c #cde6ff",
"aZ c #cdeaff",
"#w c #d5ced5",
"bM c #d5cede",
"ax c #d5cee6",
".x c #d5ceee",
"#6 c #d5d2d5",
"bq c #d5d2de",
"#O c #d5d2e6",
".a c #d5d2ee",
".7 c #d5d6de",
".D c #d5d6e6",
"br c #d5d6ee",
"bQ c #d5dae6",
"b. c #d5daee",
"#3 c #d5daf6",
"#W c #d5daff",
"cB c #d5deee",
"by c #d5def6",
".o c #d5deff",
"a7 c #d5e2f6",
".t c #d5e2ff",
"cb c #d5e6f6",
".0 c #d5e6ff",
"#g c #d5eaff",
"a4 c #d5eeff",
"#1 c #ded6de",
"aY c #ded6e6",
"#P c #ded6ee",
"bF c #dedade",
".K c #dedae6",
"bs c #dedaee",
"bH c #dedede",
"bX c #dedee6",
"ag c #dedeee",
"cF c #dedef6",
"bw c #dee2f6",
"#V c #dee2ff",
"bb c #dee6f6",
"bx c #dee6ff",
"cJ c #deeaf6",
"#k c #deeaff",
"cD c #deeef6",
".1 c #deeeff",
"#A c #def2ff",
"b4 c #def6ff",
"aQ c #e6dee6",
"#S c #e6def6",
".C c #e6e2e6",
".j c #e6e2f6",
"ba c #e6e2ff",
"#o c #e6e6e6",
".w c #e6e6ee",
"bp c #e6e6f6",
"#4 c #e6e6ff",
"am c #e6eaf6",
".z c #e6eaff",
".p c #e6eeff",
".s c #e6f2ff",
"#x c #e6f6ff",
"b8 c #e6faff",
".S c #eee6ee",
"#t c #eeeaee",
"#2 c #eeeaf6",
".Y c #eeeeee",
".L c #eeeef6",
"bh c #eeeeff",
".E c #eef2ff",
".N c #eef6ff",
".W c #eefaff",
"bv c #eeffff",
".4 c #f6eef6",
".# c #f6eeff",
".H c #f6f2f6",
".Q c #f6f6f6",
".k c #f6f6ff",
".q c #f6faff",
".r c #f6ffff",
".I c #fff6ff",
".R c #fffaff",
"Qt c #ffffff",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.#.a.b.c.d.e.f.g.e.c.h.i.j.kQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.k.l.m.n.o.p.q.rQtQtQt.r.q.s.t.u.e.v.wQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.k.x.y.zQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.p.A.B.CQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.D.n.zQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.E.F.G.HQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.I.h.tQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.p.J.KQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.L.M.NQtQt.rQt.rQtQtQtQtQt.qQt.qQtQtQt.rQtQtQtQtQtQtQtQt.r.O.P.Q.R.I.R.R.R.R.R.R.R.R.R.RQt.RQtQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.S.g.qQtQt.qQt.rQt.rQt.rQtQtQtQtQtQtQtQtQtQtQt.rQt.rQt.rQtQtQt.T.U.H.I.Q.I.I.R.Q.R.I.R.I.R.R.R.RQtQtQtQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.L.V.N.q.q.q.q.q.q.q.r.q.r.qQt.q.r.N.q.q.r.qQt.q.r.q.r.q.q.q.q.q.W.T.X.Y.H.H.H.H.H.H.Q.H.Q.H.I.Q.R.I.R.RQtQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.I.Z.0.q.q.q.q.q.q.q.q.q.r.q.r.qQt.q.q.qQt.q.r.qQt.q.r.q.q.q.q.q.q.q.1.2.3.4.H.H.H.H.H.H.H.H.Q.H.I.Q.R.I.R.RQtQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.y.5.1.W.N.q.N.q.N.q.N.q.q.q.W.q.q.q.N.q.q.q.q.q.q.q.W.q.N.q.N.q.N.q.N.5.6.7.Y.4.Y.H.Y.H.4.H.Y.H.H.H.H.I.Q.R.RQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.8.T.9.k.p.N.N.q.N.q.N.q.q.q.q.q.q.q.q.N.N.r.q.q.q.q.q.q.q.q.N.q.N.q.N.s#.##.J.S.4.H.Y.H.4.H.4.H.H.H.H.I.H.I.I.RQtQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.S#a#b#c.N.N.1.E.N.N.N.W.N.q.N.q.W.q.W.q.s.q.W.q.W.q.W.q.N.q.N.W.N.N.s.1.N.1.T#d#e.4.Y.4.Y.4.Y.4.Y.H.Y.H.H.H.H.I.Q.R.RQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt#f#.#b.0.N.N.q.s.s.s.N.N.q.W.q.q.q.W.q.q.N.N.r.q.q.W.q.q.q.W.q.N.s.1.E.N.q#g#b#..T#h.H.4.H.Y.H.4.H.4.H.H.H.H.I.Q.R.RQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.K#i#j#b#g.s.s.s.q.N.N.p.s.s.N.N.q.W.q.q.r.s.W.q.q.q.q.N.N.s.s.1.s.s.q.N.N.s#k#d#l#m#n#o.4.Y.4.Y.4.Y.4.Y.H.Y.H.H.H.H.R.RQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt#p#c#.#..0.E.s.N.s.N.N.q.q.N.p.N.s.N.s.N.s.s.s.s.s.E.s.E.p.p.N.q.q.q.N.N.N.N.0#c#b#q#i#r.Y.H.4.H.Y.H.4.H.4.H.H.H.H.I.Q.R.RQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.K#b#m#d#j#q.1.E.s.N.s.N.N.W.s.N.q.r.q.q.W.q.N.q.N.q.q.r.q.q.p.q.N.W.N.N.s.N.p.0#q#l#j#c#s#t.Y.4.Y.4.Y.4.Y.H.Y.H.Y.H.H.I.Q.R.RQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt#u#j#c#d.0#q.1.s.N.N.N.N.q.W.s.s.q.N.q.W.q.W.q.W.q.W.q.W.q.N.p.N.q.N.W.N.N.N.1#g#k.9.9.0#v#w.H.Y.H.4.H.Y.H.4.H.H.H.H.Q.H.R.RQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.L#v.9#j.9#q#g#g.s.s.N#x.N.N.W.1.N.N.W.N.W.N.W.N.W.N.W.N.W.N.W#k.N.N.W.N.N.N.s#g#k#g#q#l#c#i#y#t.4.Y.4.Y.4.Y.4.Y.H.4.H.H.H.H.R.RQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt#z#j#c#d#c#g#g.1.1#x.N.N.N.W.N.s.N.W.N.q.N.q.N.q.N.q.N.q.N.W.N.p.N.W.N.W.N.N#A.s.1.1#g#d#b.0#B.C.4.H.Y.H.4.H.Y.H.4.H.H.H.H.I.Q.RQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt#C#m#g#D#j.0.1#k.1.1#x#x.N#x.N.1.N.N.W.N.W.N.q.W.q.W.W.N.W.N.W.1.s.N.N.N.N#A.s.1.s.1.0#b.0#g###E.4.Y.4.Y.4.Y.4.Y.H.Y.H.H.H.H.I.IQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.I#F.0#c.1#g#c.0.s.s.s.s#x#x.N.N.p.N.W.N.q.N.s.1.1#k.s#x.q.W.q.N.s.s.W.N.N.s.s.s#x.1#c#j.p#g#g#j#G.Y.H.4.H.Y.H.4.H.4.H.H.H.H.I.Q.R.RQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.C#l#q.0#q.1.s#k#q.1.1.s.s#x.s.N.1.N.N.N.0#c#c.0#g#g#q#c#c.s.N.W.1.s#x.N.s#x.s.1#c#c#k#x.1#g.0.0#H#t.Y.4.Y.4.Y.4.Y.H.Y.H.Y.H.H.I.Q.RQt",
"QtQtQtQtQtQtQtQtQtQtQtQt.R.j.x#I#J#I#K#K#L.F#J#M#N#O.4QtQtQt#P#Q#g.0#k#g.1#x.N.0.1#k.p#A#x.s.s.W.p#c#k.s.W.N.W.N.W#x.p#c.0.N.E#k.N.s.1.0#g#j.p.N.N.1.1#k#k#g#R.C.H.Y.H.4.H.Y.H.4.H.H.H.H.Q.Q.R.RQt",
"QtQtQtQtQtQtQtQtQtQt.R#S#T#U#V.qQtQtQtQtQtQtQtQt.s#W#X#Y#oQt#Z#c#q#g#g.1.1.s.1#k.N.N.s.s#A.1.1#k#c.s.N.N.s.s.1.p.1.N.N.N.0#c#k#g#g.1.1.N.N#k#g.s#A.s.1.1#g.1#0#1.Y.4.Y.4.Y.4.Y.4.Y.H.4.H.H.Q.Q.R.R",
"QtQtQtQtQtQtQtQtQt#2#Y#3.kQtQtQtQtQtQtQtQtQtQtQtQtQtQt#4#5.i#X#m#k#g.1.1.s.s.s.1.N.s.N.N.q.q.s#c.N.N.s#g#k.1.s.p.p.0#k.s.q#g.0.q.q.W.W#x.N.1#k.s.s.s.s.1.p#c#v#6.H.4.H.Y.H.4.H.Y.H.H.H.H.I.Q.R.RQt",
"QtQtQtQtQtQtQtQt#P#7.kQtQtQtQtQtQtQtQtQtQtQt.rQtQtQtQtQtQt#V#8#9#c.1#k.s#A.s.1#A.s#x.s.N.s.N#c.N.N#k#c.N.W.q.N.W.N.q.p#c#k.W.0.1.N.N.s.N.s.s#q#x.s.s#A.s#g#j#.a..Y.4.Y.4.Y.4.Y.H.Y.H.Y.H.H.I.Q.R.R",
"QtQtQtQtQtQtQta#aaQtQtQtQt.rQtQtQt.rQt.rQtQtQtQtQt.rQtQtQtQt.Nab#Z#q.s.s.s.s.1.s.N#x.N.N.W#k.p.N#k.s.N.1.W.N.q.N.W.N.1.s.p#k.N.0.W.N.N.N.N.s#g.s#x.s.N#g#j.1#ma..H.Y.H.4.H.Y.H.4.H.H.H.H.Q.Q.R.RQt",
"QtQtQtQtQtQt.iac.r.r.W.q.q.q.q.r.q.r.q.q.W.r.q.r.q.r.q.q.W.rQt#x.Jad.0.s.s.s.1#x.s.N.s.N#x#g.N.1.s.q.N.1.W.W.s.N.W.N#k.q.W.1.1.1.1.W.N.N.s.N.0.s.s.s#c#c.p.s#Qa..Y.4.Y.4.Y.4.Y.H.Y.H.4.H.H.Q.Q.RQt",
"QtQtQtQtQt#Pae.W.q.N.q.W.q.q.r.q.r.q.r.N.q.q.r.q.r.q.r.W.q.W.q.r#gafag.1.1.1.s#x.N.N.N.N.N.1.s.s.q.N.r.1ahaiajajab.9.q.W.W.W.1.1.1.W.W.N.N.N.1#g.1.0.p.N.s.1#ma..H.4.H.Y.H.4.H.4.H.H.H.H.I.Q.R.RQt",
"QtQtQtQt.C.Z#j.N#x.N.N.N.N.q.N.q.W.q.W.N.N.q.W.q.W.q.N.W.N.N.N.q.1akalam.N.s.1.s.s.N#x.W.s.s.1.W.N.r.1anaoapaoaoaoaqah.r.N.W.s#k#k.q.N.W.s.s#g#g.p.N.s.s.1.s#Qa..Y.4.Y.4.Y.4.Y.H.Y.H.H.H.H.I.QQtQt",
"QtQtQt.Haras.s.s.s.s.N.N.W.N.q.W.q.W.q.s.W.W.q.W.q.W.q.N.W.N.N.s.s#.#v#y.s.N.q.N.q.N.N.N.s.1.N.q.q.Watapauapavapauapavaw.r.N.q#k#k.N.N.s.s.s.q.W.N.s.s.s.s.s#ma..H.Y.H.4.H.Y.H.4.H.H.H.H.I.Q.RQtQt",
"QtQtQtaxakay#k.N.s.s.p.s#x.W.N.q.W.q.q.N.N.r.W.q.W.W.N.N.s.s.1.s.N#j#iazaA.s.s.N.N.q.q.q.s.1.N.q.r#3apaqapauaqauapaqapat.N.q.N.s.0.N.N.q.W.W#x.N.s#x.s.s#A.s#.a..Y.4.Y.4.Y.4.Y.H.Y.H.H.Q.Q.R.RQtQt",
"QtQt#taBay#l.1.s.N.E.N.s.s.s.N#x.W.N.q.s.N.W.W.N.N.s.s.p.s.s.N.N.N#m#iayaC#k.N#x.N.N.W.W.N.1.N.N.qaDauaEaFaEaGaEaFaEauaE#k.N.N.1.1.q.q.N.W.N.N#x.N.s#x.s#x.saH#E.H.4.H.Y.H.4.H.4.H.H.Q.Q.R.RQtQtQt",
"QtQtaIaJ#l#d#g.s.s.N.s.W.N.s.p.N.s.N.s.s.p.s.s.N.s.1.1.N.N.N.s#x.1#q#i#.#vaK.s.N.s.N.N.W.s.p.qQtQtaLauaMaGaNaMaMaGaGaEaO#kQt.q.N#k.q.N.W.N.N.s.N.s#x.s#x.sayaPaQ.Y.4.Y.4.Y.4.Y.H.4.H.H.Q.Q.R.RQtQt",
"Qt.Y.OaR#d#..0.1.s.s.N.N.W#A.N.W.q.W.q.W.q.N.q.W.q.p.s.W.W#x.N.s.1#q#.#b#jaC.p#x.N.N.q.W.N.1.q.qQtaSaNaTaUaVaUaWaUaTaWaM.p.r.r.N.p.q.q.N.W.N.N#x.N.s.N.sayaX#6#t.H.Y.H.4.H.4.H.H.H.H.I.I.R.RQtQtQt",
"QtaY.5#Q#l#m#m.1#A#x.s.N#x.1#x.W#x.W.N.W#x.W.N.W.N.s.1.N#x.N#x.s#qaZ#m#baya0a1.N#x.N.N.q#x.s.W.rQta2aTa3a3#Ha3a3a3a3aTat.pQt.q.N.1.q.W.W.N.N#x.N#x.NaZ.5aP#w#o.4.Y.4.Y.4.Y.H.4.H.H.Q.Q.I.QQtQtQtQt",
".R#TaR#b.9#q#g#g.s#x.N#x.N.1.N.N.W.N.W.W.W.N.W.N.q.s.1#x.N#x.N.1.1#ga4#b#b#baL.s.N.N.W.W.W.s.r.rQt#Za3#y.vaDaLaD.v#ya5a3.EQt.r.N.s.q.q.W.q.N.q.Na4##aCa6#1#t.H.Y.H.4.H.4.H.H.H.H.I.Q.R.I.RQtQtQtQt",
".Y#a#q#m#.#c#q.1.1.s.s#x.s.1#x.N.N.N#x#x.s.N.N.W.N.s#g#x.s.s.1#A.1.1#m#l#m#q#sa7.N.q.W.q.N.N.W.r.ra8#yaLaL#XaSaSaLaLa9aD.p.r.N.N.s.Eb.a8b#babb.z#4babca2bd.K.Y.4.Y.4.Y.H.Y.H.H.H.H.I.Q.R.RQtQtQtQt",
".Cbe#q#q#g#c.0#g.1.1.s.s.s.1.W.N#A#q.0#q.0#q#g.s.q.s.1.s#x#A.s.1#g#m#c#g#g#qbfaPbg#..1#x.W.NQtQtQtbc#Xa2#Za2#za2#ZaI#YaL.NQtQt.k#3a8bh.RQtQtQtQtQtQtQtQt.kb.bi.C.4.Y.H.4.H.H.I.H.I.Q.R.RQtQtQtQtQt",
"a##Q#m#q#q.1.1.0.0.1a4.sa4.s.s.0#m#g.1#A.1.1#q#c#g#x#g#A.1.1.0#c#m.1#A.1#q#gbjbk#6blbm#Hbn#x.rQtQtb.aIbobobcbobcbo#za2#Y.EQt.Na8bpQtQtQtQtQtQtQtQtQtQtQtQtQt.k.lbq.Y.Y.H.H.H.H.I.Q.I.I.R.RQtQtQtQt",
"#7#m#q#q#g.1.s#g.s.s.s#A.s#k#q#g.N.s.s.1.s#A#x#A.0#c#g#g.1.1.s.0#g.s#Aa4#k#g#l.X.H#t.S.C#G#AQtQtQtaga8brbsb.agb.bsbra8#Z.k.k#Z.NQtQtQt.rQtQtQt.qQtQtQt.rQt.rQtQtb#a#.4.Y.H.H.I.Q.I.I.R.RQtQtQtQtQt",
"bt#m#q#g#g#A#g#g#A#x.s.N#x.0#g#x#g#k#g.p.1#k.0.1#A#q#g.N#x.N#x.1#q.1.1.1a4#gas#y.Y.4#t.4#6bu.W.Wbv.tbca7bwbxbbbxa7bybcbc.s#7.sQt.N.q.q.q.q.r.q.q.qQt.q.q.q.q.W.r.rbzbA.4.Y.H.H.Q.H.I.Q.R.RQtQtQtQt",
"bB#q#c#g.1#A.1.1.s#A#x#x.1#g#x#g.0.s.r.W.r.W.s#c#k#A#g.s.N.s.N.1#g.1.s#Aa4#j#jbC.4#t.4#t#tbD#ybE#Ha3#y#H#H#H#y#H#HbE#HbEaW#d.q.N.q.W.q.q.q.q.r.N.q.q.r.q.q.W.q.W.raZ#pbF.4.Y.H.H.Q.Q.R.RQtQtQtQtQt",
"bGa4.0#g#g#A#g#A#A.s.s.s.0.1#g.N.s#x.W.s.sbv#A.s.s.1.0.1#x#x.s.s#q.1#A#g#j#g#qbC#t#t#t#t#t.SbH.C.C#o#o.S#o.S#o.S.C#o.C#hbIa4.N.E.s.N.N.q.N.q.q.N.N.q.W.q.N.q.N.N.s.s#laL#o.Y.Y.4.Y.H.H.R.RQtQtQtQt",
"bBa4.1.1.1.1.1#A#x.s.N.s.1.1#x.W.rawbJaEaFbK.0bv.r.s#g#g.W.N.N.s#g#q#g.0.p.saZbC.4#t.Y#t.4.4.Q.QQtQtQtQtQtQtQtQtQtQt.QbL#Q#g.N.N.N.E.N.N.q.W.r.N.q.q.q.N.N.E.N.s.q.s#j#bbM#t.4#t.4.4.Q.Q.R.RQtQtQt",
"bGa4#g#A.s.s#A.s.s#x#x#A#g.s.W.rbNapbObObObPau#g.r.W#g#g.s#x#A.1#g#k.1.s.1#A#qbC#t#t#t#t#t.4.H.I.RQtQtQtQtQtQtQt.RQtbQ#d#Q.0.s.N.N.q#x.s.N.N.N.N.s.N.N.N.s.q.N.N.N.p#j#jbR.C#t#t#t.4.Y.Q.Q.R.RQtQt",
"bBa4.1.1#A#A.N.N.W.N.q.s.1#xQt.1aubPbSaobTbPbUaW.W.r.s#q.s#x.N.s.N#x#x#A#A#A#gbC.4#t.4#t.4.Y.I.IQtQtQtQtQtQtQtQtQt.Q#5#m#c#q.s.N.N.W.N.N.q.W.q.q.q.W.q.N.E.W.q.N.N#k.0#j#d#h#t#t.Y.Y.H.H.I.RQtQtQt",
"bta4#g.1.1#A#A.s.s.N.W#x#g.sbvbLaoapapapaoapaoapbV.r.1.0.N.W.N.N.s.s#A.s.1#x#Q#y#t#t#t#t#t.H.H.R.RQtQtQtQtQtQtQt.R.wbW#m#c#g.1.N.N.W.s.N.N.W.N.q.W.W.N.N.1.N.N.N#A.1#g#j#.aSbX#t#t.Y.Y.H.H.R.RQtQt",
"#1aJ#x#A.s#A.s.s#x#x.W.s.p.qQtaSbYapauaqavaqbZapbyQt.q#g.W.W.W#x.N.s.s#A#xa4b0bl.4#t.Y#t.4.H.I.RQtQtQtQtQtQtQtQtQt.D#c#g.0#g.s.s.N.N.s.N.q.N.N.s.N.N.q.W.s.N.W.s#x#A#g#D.1b1.7#t.4.Y.4.H.I.I.RQtQt",
".Rb2b3b4#x#x#A.s.s.N#x#x.1.qQt#ZapauaEaOaEaOapaubyQt.N.1.N.W#x.N.s#x#x#xbub0b5.C#t#t#t.Y.Y.H.H.R.RQtQtQtQtQtQtQt.Rbo#q#k#k.1#k.1#A#x#A.N.p#k#g.1#g#k#k.N.s.s.s.s#g#k#g.1.1b6b7#t#t.4.Y.H.H.I.QQtQt",
"Qt.R#rbG#qb4.Wb8.W#x.W#x.s.qQtadaOaGaWaTaWaMaFaGbbQt.q.1.W.W.q.Wbvb8#Ab9aUc..S.Y.Y#t.4#t.4.H.I.RQtQtQtQtQtQtQt.R.RbN.1#g#A.s.p.s#x.s.s.1.1.s.E.s.s.s.s#g.1.1.s.p#k.1.N.1.s#ja2#t.4.Y.4.4.H.Q.R.RQt",
"QtQtQt.Cc#bRca#Ab8bv.r.q.s.qQtbcaMaUa3aCa3a3aMaWcbQt.N.s.r.rbvb8#qccatcd#6#t#t.Y#t#t#t.Y.Y.H.Q.RQtQtQtQtQtQtQtQt.RbW#g.1.1.s.1.N#x.W.p.1#A.p.p.N.s.s.1.1#g.N.N.N.1.1.s.s.1#jce.Y#t.Y.Y.4.H.Q.Q.R.R",
"QtQtQtQt.R.C#r#ybBcf#gb4.W.rQtb.cgaD#TaL#TaDbKa3.zQt.r.s#Achcicjckcl#1#o.4#t.Y#t.4#t.Y.Y.H.H.R.RQtQtQtQtQtQtQt.R.Rac.1#g.s.s.s#x.N.N.p.s.s.s.r.r.r.N.p.p.p.s.q.N.s.1#x.1#k#qad#t.4.Y.H.4.H.Q.R.RQt",
"QtQtQtQtQtQt.R.HbH#wbDcm#AQtQtagaD#Ybd#Za2a2a9aDamQtQt#maXcnc.#6bH#t#t.Y#t#t#t#t#t#t#t.Y.4.I.QQtQtQtQtQtQtQtQtQt.Rb6#A.p.1.s#A#x.N.s.1.s.q.NbNaLaS.0.W.W#k.p.N.N.s.1#g#k.1.1co.Y#t.4.Y.H.4.Q.Q.R.R",
"QtQtQtQtQtQtQtQtQtQt.R#6#gQtQt.pb##3bxbw#Vbyb##5.WQtQtbg#w#o#t#t.Y#t.4#t.Y#t.4#t.Y#t.4.4.Q.Q.RQtQtQtQtQtQtQtQtQtQtb6.s.s.N.s.N.N.W.s.s.q.raLbYaobTcpbx.r.N.1.N.N.s.1.s.s.N.1cq.Y.4.Y.H.4.H.H.R.RQt",
"QtQtQtQtQtQtQtQtQtQtQt.Ha9crcrbKat#H#HbKcs#HatatctcucvcwbH#t#t#t#t#t#t#t#t#t#t#t#t.Y.Y.H.H.R.RQtQtQtQtQtQtQtQtQt.Rb6.s.s#A#x.N.q.W#x.p.rb.bZapauapapaU.W#x.1.N.W.N.N.s.s.s#Acx.4.Y.4.Y.4.Y.H.Q.R.R",
"QtQtQtQtQtQtQtQtQtQtQtQt.4aQaQbFbF#1#1#6#6#w#6#E#6#w#w#6#t#t.Y#t.4#t.Y#t.4#t.4.Y.4.4.H.Q.R.RQtQtQtQtQtQtQtQtQtQtQt#Zb4#x.s.s.N.N.q.E.N.ra8auaGaGaNauaN.p.q.p.q.W.W#x#x#xbvcycz.Y.4.Y.H.Y.H.H.I.RQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.R.Q.Q.H.H.Y.4#t.4#t.Y#t#t#t#t#t.Y#t.Y#t.4.Y.4.4.H.Q.R.RQtQtQtQtQtQtQtQtQtQtQt.R#tce#A#x.N#x.N.N.N#xQtcqaNaVa3ataTat.N.r.s.N.W.N.N.W#xcAbDbH.Y.Y.4.Y.4.4.Q.Q.R.R",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.R.R.Q.I.H.H.4.H.4.4.Y.4.Y.4.Y.H.4.H.H.I.Q.R.I.R.RQtQtQtQtQtQtQtQtQtQtQtQtQt.R.4bdb6.1.W.W.r.W.qQtcBa3.vaD.va3aD.N.r#xQt.r.r#x#ccrcC#o.4.Y.4.Y.H.4.H.Q.R.RQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.R.R.Q.I.H.Q.H.H.H.H.H.H.H.I.Q.R.I.R.RQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.R.IbFb7aKbVcD.N.WQtcB.vaSa2aSaLaL.k.q.N.scbb1bCcEbF#t.Y#t.4.Y.4.Y.H.H.I.I.RQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.R.R.R.R.R.R.R.R.RQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.R.R.Q.S.7#hce.rQtbhbocFagcFa8bcQtQtchcGcH#1.C.4.Y.4.Y.4.Y.H.4.H.H.I.I.R.RQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.RQt.R.R.Q.Q.HbFcIbbcI#5bcawbcbNb1bbcJaS.C.Y.Y.4.Y.4.Y.4.Y.H.4.H.H.H.Q.R.RQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.R.R.R.R.HbF#h#h#r#h#r#h#r#h#r#r#6.H.H.H.H.H.H.H.H.I.H.Q.H.I.Q.R.RQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.RQt.R.R.R.R.Q.I.Q.I.H.Q.H.I.H.Q.H.I.Q.I.Q.I.Q.I.Q.I.Q.I.Q.R.RQt.RQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.RQt.RQt.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.R.RQtQtQtQtQt",
"QtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQtQt.RQt.RQt.RQt.RQt.RQtQtQtQtQtQt"};

static const char* const img10_login_dlg[] = { 
"326 198 1050 2",
"as c #000000",
"bl c #071f36",
"bb c #071f37",
"a4 c #07223b",
"bB c #081f36",
"aV c #082644",
"cu c #092035",
"bO c #092036",
"aK c #092e53",
"cL c #0a2137",
"aD c #0b3966",
"dx c #0c2136",
".a c #0c7ae8",
".d c #0c7ae9",
".# c #0c7be8",
".b c #0c7be9",
"dE c #0d2136",
"dL c #0d2236",
"av c #0d4a85",
".Y c #0d6ccb",
".w c #0d6dcd",
"Qt c #0d7ae8",
".c c #0d7be8",
".e c #0d7be9",
".f c #0d7ce8",
".h c #0d7ce9",
"dR c #0e2236",
"d4 c #0e2336",
"dr c #0e2841",
"cY c #0e2b49",
"#s c #0e6fcd",
".k c #0e7be8",
".j c #0e7be9",
".i c #0e7ce8",
".g c #0e7ce9",
".l c #0e7de8",
"d9 c #0f2336",
"ae c #0f59a2",
"#6 c #0f64b6",
".v c #0f7be5",
".m c #0f7ce8",
".x c #0f7ce9",
".y c #0f7de8",
".Z c #0f7de9",
"ec c #102336",
"ep c #102436",
"dl c #102f4d",
"c8 c #102f4e",
"bc c #104579",
"a5 c #104980",
"an c #1059a3",
"#U c #1069c1",
".0 c #107ce9",
".A c #107de8",
".z c #107de9",
"et c #112436",
"bm c #114477",
"aW c #115290",
".3 c #117de8",
"#t c #117de9",
".2 c #117ee8",
".1 c #117ee9",
"ey c #122437",
"eD c #122536",
"eI c #122537",
"de c #123658",
"bC c #124577",
"#X c #127ee8",
"#v c #127ee9",
"#V c #127fe8",
"#W c #127fe9",
"eS c #132537",
"bI c #134677",
"aL c #135ea8",
"#7 c #137ee7",
"#u c #137fe8",
"#8 c #137fe9",
"fc c #142537",
"fq c #142637",
"bP c #144678",
"af c #147ae0",
"#Y c #147fe9",
"cK c #152536",
"fz c #152637",
"b3 c #154677",
"cv c #154778",
"aE c #156bc0",
"ao c #157be1",
"ag c #157fe6",
"ai c #157fe8",
"ah c #157fe9",
"#9 c #1580e9",
"fH c #162637",
"fT c #162737",
"aw c #1675d5",
"g. c #172737",
"cM c #174879",
"aX c #176cc2",
"ax c #177ee5",
"ap c #177fe8",
"aq c #1780e9",
"gk c #182737",
"gs c #182837",
"cJ c #182a3c",
"#5 c #1865b1",
"bd c #1866b2",
"a6 c #1868b8",
"aM c #1873cf",
"aF c #187adb",
"ay c #1880e8",
"gC c #192937",
"cI c #192a3c",
"cH c #192b3c",
"cG c #192b3d",
"aH c #197fe5",
"az c #1980e5",
"aG c #1981e8",
"gI c #1a2937",
"gP c #1a2938",
"cF c #1a2b3d",
"cE c #1a2c3d",
"cD c #1a2c3e",
"cZ c #1a5086",
"bs c #1a66b1",
"bD c #1a67b1",
"aN c #1a7fe4",
"g5 c #1b2938",
".X c #1b74ce",
"a7 c #1b7bda",
"aY c #1b7cde",
"#r c #1b7edd",
"aO c #1b81e5",
"he c #1c2a38",
"dy c #1c4a78",
"dF c #1c4b79",
"aZ c #1c81e5",
"hs c #1d2a38",
"cC c #1d354c",
"dM c #1d4b79",
"ds c #1d5083",
"c9 c #1d5892",
"bJ c #1d67b1",
"bn c #1d7bd8",
"be c #1d7bd9",
"hA c #1e2b38",
"dS c #1e4c79",
"bQ c #1e68b2",
"b4 c #1e69b2",
"a8 c #1e83e4",
"hJ c #1f2b38",
"dY c #1f4c79",
"dm c #1f5890",
"#T c #1f71c2",
"bt c #1f7cd8",
"bf c #1f83e5",
"h1 c #202c38",
"d5 c #204c79",
"df c #205f9d",
"cw c #2069b2",
"bE c #207dd9",
"h7 c #212c38",
"ie c #212d38",
"e. c #214d79",
"cN c #216bb3",
"bo c #2184e5",
"ij c #222d38",
"cB c #224669",
"ed c #224e79",
"bK c #227dd9",
"bu c #2284e5",
"it c #232d38",
"iC c #232e38",
"eh c #234f79",
"c0 c #236fb8",
"b6 c #2374c3",
"iH c #242e38",
"el c #244f79",
"bR c #247ed9",
"bF c #2485e6",
"iN c #252e38",
"iT c #252f38",
"eq c #255079",
"b5 c #257fd9",
"i3 c #262f38",
"eu c #265079",
"d. c #2672c0",
"bL c #2686e5",
"jg c #272f38",
"jr c #273039",
"ez c #27517a",
"cx c #2780d9",
"bS c #2788e6",
"jz c #283038",
"eE c #285179",
"jE c #293138",
"jP c #293139",
"eJ c #29527a",
"dz c #296eb3",
"dt c #2970b8",
"dn c #2974bf",
"dg c #2977c3",
"cO c #2981d9",
"cy c #2984dd",
"op c #2a2a2a",
"jU c #2a3239",
"eT c #2a527a",
"am c #2a5f93",
"cA c #2a5f94",
"dG c #2a6fb3",
"c1 c #2a83da",
"oo c #2b2b2b",
"j7 c #2b3239",
"e5 c #2b537a",
"oj c #2c2c2c",
"kl c #2c3339",
"fd c #2c537a",
"dN c #2c70b3",
"d# c #2c85dc",
"kw c #2d3339",
"kG c #2d3439",
"fj c #2d547a",
"dT c #2d71b3",
"dh c #2d87de",
"n4 c #2e2e2e",
"kN c #2e3439",
"dZ c #2e71b3",
"c2 c #2e8be7",
"o# c #2f2f2f",
"kW c #2f3439",
"l# c #2f3539",
"fA c #2f557a",
"do c #2f86dc",
"da c #2f8ce7",
"aj c #2f8deb",
"on c #303030",
"le c #30353a",
"fI c #30567a",
"d6 c #3072b3",
"e# c #3073b4",
"du c #3086da",
"lj c #31353a",
"lp c #31363a",
"fU c #31567a",
"di c #318de7",
"lu c #32363a",
"f2 c #32577b",
"dA c #3286d9",
"#Z c #328feb",
"lL c #33363a",
"g# c #33577a",
"ee c #3374b4",
"cz c #337bc3",
"dH c #3387d9",
"dp c #338de7",
"n8 c #343434",
"lW c #34363a",
"l2 c #34373a",
"gd c #34577b",
"ei c #3475b4",
"mh c #35373a",
"mm c #35383a",
"gl c #35587b",
"dO c #3588d9",
"dv c #358ee7",
"mr c #36383a",
"gt c #36597b",
"em c #3675b4",
"dU c #3689da",
"dB c #3690e7",
"n7 c #373737",
"mN c #37383a",
"gx c #37597b",
"om c #383838",
"m1 c #38393a",
"gD c #385a7b",
"ev c #3877b4",
"dI c #3890e7",
"ar c #3893ec",
"np c #393a3a",
"gJ c #395b7b",
"d0 c #398ada",
".n c #3993ec",
"nH c #3a3a3a",
"gQ c #3a5b7b",
"eA c #3a78b4",
"d7 c #3a8ada",
"n2 c #3b3b3b",
"gW c #3b5c7b",
"eF c #3b78b4",
"ea c #3b8bda",
"dP c #3b92e7",
"oe c #3c3c3c",
"g6 c #3c5c7b",
"dV c #3c92e8",
"eK c #3d79b4",
"h# c #3e5d7c",
"eU c #3e7ab5",
"ef c #3e8ddb",
"d1 c #3e94e8",
"hk c #3f5e7c",
"ej c #3f8ddb",
"#w c #3f96ed",
"ht c #405e7c",
"e6 c #407bb5",
"d8 c #4094e8",
"o. c #414141",
"fe c #417bb6",
"en c #418edb",
"eb c #4195e9",
"hB c #425f7c",
"hF c #42607c",
".4 c #4298ed",
"fk c #437cb5",
"er c #438fdb",
"eg c #4397e8",
"hK c #44607c",
"hR c #44617c",
"fr c #447db6",
"ew c #4490db",
"#q c #4494e3",
"a. c #4499ed",
"ek c #4597e8",
"hW c #46617c",
"fB c #467eb6",
"n1 c #474747",
"h2 c #47627c",
"fJ c #477fb6",
"eB c #4792db",
"eG c #4893db",
"eo c #4899e9",
"i# c #49637d",
"fV c #4980b6",
"es c #4999e9",
"if c #4a637d",
"f3 c #4a81b6",
"eL c #4a93db",
"oq c #4b4b4b",
"ik c #4b647d",
"ex c #4b9be9",
"cP c #4b9eee",
"io c #4c647d",
"ga c #4c81b6",
"eV c #4c94db",
"eC c #4c9ce9",
"iu c #4d657d",
"ge c #4d82b6",
"e7 c #4d95dc",
"iy c #4e667d",
"eH c #4e9dea",
"iD c #4f667d",
"gm c #4f83b6",
"ff c #4f96dc",
"of c #505050",
"iI c #50677d",
"gu c #5084b6",
"eM c #509eea",
"ok c #515151",
"iO c #51677d",
"fl c #5197dc",
"iU c #52687e",
"gy c #5284b6",
"eW c #529fea",
"iZ c #53697d",
"gE c #5385b6",
"fs c #5398dd",
"i4 c #54697e",
"e8 c #54a0ea",
"ov c #555555",
"ja c #556a7e",
"gK c #5586b7",
"fC c #5599dd",
"ou c #565656",
"jh c #566b7e",
"gR c #5687b7",
"fg c #56a1ea",
"od c #575757",
"jn c #576b7e",
"fK c #579add",
".u c #57a4ef",
"js c #586c7e",
"gX c #5888b7",
"fW c #589cdd",
"fm c #58a2ea",
"oa c #595959",
"jA c #596c7e",
"jF c #5a6d7e",
"g7 c #5a89b7",
"f4 c #5a9cdd",
"ft c #5aa4ea",
"ot c #5b5b5b",
"jJ c #5b6d7e",
"ha c #5b8ab7",
".B c #5ba5ef",
"ow c #5c5c5c",
"jQ c #5c6e7e",
"ad c #5c7c9c",
"hf c #5c8bb7",
"gb c #5c9ddd",
"fD c #5ca4eb",
"n5 c #5d5d5d",
"jV c #5d6e7e",
"ol c #5e5e5e",
"j1 c #5e6f7e",
"hl c #5e8bb8",
"gf c #5e9fdd",
"fL c #5ea5eb",
"oh c #5f5f5f",
"j8 c #5f6f7e",
"hu c #5f8db8",
"kd c #60707f",
"gn c #609fde",
"fX c #60a6eb",
"kh c #61707f",
"km c #62717f",
"hC c #628db9",
"gv c #62a0de",
"f5 c #62a7ec",
"kq c #63717f",
"kx c #63727f",
"hG c #638eb8",
"gz c #64a2de",
"gc c #64a8ec",
"kC c #65727f",
"kH c #65737f",
"hL c #658eb8",
"gF c #65a2df",
"kO c #66737f",
"hS c #6690b9",
"gg c #66aaec",
"os c #676767",
"kS c #67737f",
"hX c #6791b9",
"gL c #67a4de",
"kX c #68747f",
"go c #68abec",
"k2 c #697580",
"h3 c #6991b9",
"gS c #69a5df",
"n9 c #6a6a6a",
"k7 c #6a7580",
"gw c #6aacec",
"ox c #6b6b6b",
"la c #6b7580",
"h8 c #6b92b9",
"gY c #6ba6df",
"lf c #6c7680",
"ia c #6c93b9",
"gA c #6cadec",
"n3 c #6d6d6d",
"lk c #6d7680",
"lq c #6e7780",
"ig c #6e94b9",
"g8 c #6ea7e0",
"gG c #6eaeec",
"og c #6f6f6f",
"lv c #6f7780",
"lA c #6f7880",
"il c #6f94b9",
"hb c #6fa8df",
"lF c #707880",
"hg c #70a9df",
"gM c #70afed",
"or c #717171",
"lM c #717880",
"lQ c #727980",
"ip c #7295b9",
"iv c #7296b9",
"gT c #72afed",
"ob c #737373",
"lX c #737980",
"l3 c #737a80",
"hm c #73aae0",
"oi c #747474",
"l8 c #747a80",
"mc c #747b81",
"iz c #7497b9",
"gZ c #74b1ee",
"mi c #757b81",
"iE c #7598b9",
"hv c #75aae0",
"mn c #767b80",
"g9 c #76b2ee",
"ms c #777c81",
"iJ c #7798ba",
"hD c #77ace0",
"mz c #787c81",
"mG c #787d81",
"iP c #789aba",
"mO c #797d81",
"hH c #79ace0",
"hc c #79b3ee",
"mS c #7a7e81",
"iV c #7a9aba",
"hM c #7aade1",
"hh c #7ab4ee",
"j. c #7b7b7b",
"mX c #7b7e81",
"i0 c #7b9bba",
"hT c #7bafe0",
"hy c #7c7c7c",
"m6 c #7c7e81",
"hn c #7cb5ee",
"i9 c #7d7d7d",
"n. c #7d7f81",
"i5 c #7d9cbb",
"hw c #7db7ee",
"hp c #7e7e7e",
"nq c #7e8081",
"jb c #7e9dbb",
"hY c #7eb0e1",
"h0 c #7f7f7f",
"nx c #7f8081",
"au c #7f8e9c",
"ho c #808080",
"nB c #808182",
"ji c #809dbb",
"h4 c #80b1e2",
"hE c #80b8ef",
"gV c #818181",
"nJ c #818182",
"nN c #818282",
"jo c #819fbb",
"hI c #81b8ee",
"fO c #828282",
"h9 c #82b2e2",
"gh c #838383",
"jt c #839fbb",
"ak c #83bbf2",
".o c #83bcf3",
"f0 c #848484",
"jB c #84a0bb",
"ib c #84b3e1",
"hN c #84b9ee",
"fZ c #858585",
".W c #85b8eb",
"fF c #868686",
"jG c #86a1bb",
"ih c #86b5e2",
"hU c #86bbef",
"f7 c #878787",
"jK c #87a2bc",
"im c #87b6e2",
"hZ c #87bbef",
"gB c #888888",
"gH c #898989",
"jR c #89a3bc",
"fR c #8a8a8a",
"jW c #8aa3bc",
"iq c #8ab6e2",
"h5 c #8abdef",
"fv c #8b8b8b",
"ct c #8b8d8e",
"iw c #8bb6e3",
"fw c #8c8c8c",
"j2 c #8ca3bc",
"i. c #8cbef0",
"fn c #8d8d8d",
"fy c #8d8e8e",
"iA c #8db7e2",
"e9 c #8e8e8e",
"gr c #8e8f8f",
"j9 c #8ea5bc",
"ke c #8ea6bc",
"ic c #8ebff0",
"e0 c #8f8f8f",
"iF c #8fb9e2",
"eZ c #909090",
"cr c #909192",
"cq c #909293",
"cs c #909294",
"ki c #90a7bc",
"ii c #90c0f0",
"eY c #919191",
"fp c #919292",
"cm c #919294",
"kn c #91a7bc",
"iK c #91b9e3",
".5 c #91c4f5",
"e2 c #929292",
"cp c #929394",
"cl c #929495",
"in c #92c1f0",
"e1 c #939393",
"d3 c #939394",
"hQ c #939494",
"cn c #939496",
"kr c #93a7bd",
"iQ c #93bbe3",
"fG c #949494",
"f9 c #949595",
"co c #949596",
"ck c #949697",
"ky c #94a9bc",
"iW c #94bbe3",
"ir c #94c2f0",
"dX c #959595",
"dD c #959596",
"fS c #959696",
"a3 c #959697",
"ch c #959698",
"e3 c #969696",
"eR c #969697",
"dK c #969797",
"cj c #969798",
"ci c #969899",
"#4 c #96a6b7",
"kD c #96aabc",
"i1 c #96bde3",
"ix c #96c4f1",
".p c #96c5f5",
"eX c #979797",
"dw c #979798",
"dd c #979799",
"gO c #979898",
"bA c #979899",
"cg c #97989a",
"cf c #97999a",
"kI c #97aabc",
".r c #97c6f5",
".s c #97c6f6",
".t c #97c7f5",
".q c #97c7f6",
"fa c #989898",
"fb c #989899",
"ba c #989999",
"ce c #98999b",
"cb c #989a9b",
"kP c #98abbd",
"i6 c #98bee4",
"iB c #98c4f0",
"fo c #999999",
"bH c #99999a",
"dq c #99999b",
"is c #999a9a",
"aU c #999a9b",
"c# c #999a9c",
"g0 c #9a9a9a",
"b2 c #9a9b9b",
"ca c #9a9b9c",
"cc c #9a9c9d",
"c. c #9a9c9e",
"b9 c #9a9da0",
"kT c #9aabbe",
"jc c #9ac0e4",
"iG c #9ac5f1",
"fi c #9b9b9b",
"g4 c #9b9b9c",
"br c #9b9c9d",
"cd c #9b9c9e",
"b8 c #9b9fa4",
"kY c #9bacbd",
"f. c #9c9c9c",
"h6 c #9c9c9d",
"bk c #9c9d9d",
"jj c #9cc1e4",
"iL c #9cc7f1",
"fu c #9d9d9d",
"id c #9d9d9e",
"aC c #9d9ea0",
"k3 c #9dadbe",
"k8 c #9daebe",
"g1 c #9e9e9e",
"iY c #9e9e9f",
"aJ c #9e9f9f",
"jp c #9ec2e4",
"iR c #9ec8f1",
"eP c #9f9f9f",
"lb c #9faebe",
"ju c #9fc2e5",
"eO c #a0a0a0",
"lg c #a0afbe",
"iX c #a0c9f1",
"eQ c #a1a1a1",
"ll c #a1b0be",
"jC c #a1c2e4",
"fN c #a2a2a2",
"lr c #a2b0bf",
"i2 c #a2caf2",
"eN c #a3a3a3",
"lw c #a3b1bf",
"jH c #a3c4e5",
"b1 c #a4a4a4",
"jL c #a4c4e5",
"i7 c #a4ccf2",
"b0 c #a5a5a5",
"b7 c #a5abb2",
"lB c #a5b2bf",
"f8 c #a6a6a6",
"lG c #a6b2be",
"jS c #a6c5e5",
"hO c #a7a7a7",
"lN c #a7b3bf",
"jd c #a7ccf1",
"bZ c #a8a8a8",
"lR c #a8b3bf",
"jX c #a8c7e5",
"jk c #a8cdf2",
"a2 c #a9a9a9",
"al c #a9b0b7",
"bY c #aaaaaa",
"lY c #aab4bf",
"l4 c #aab5bf",
"j3 c #aac8e5",
"oc c #abaaaa",
"b# c #ababab",
"n6 c #abacac",
"k. c #abc9e5",
"jq c #abcff2",
"bz c #acacac",
"l9 c #acb6bf",
"jv c #accff3",
"hV c #adadac",
"bN c #adadad",
"md c #adb6bf",
"#S c #adcae7",
"je c #aeaead",
"bj c #aeaeae",
"mj c #aeb6bf",
"kf c #aecae5",
"jD c #aed1f2",
"bG c #afafaf",
"mo c #afb7bf",
"kj c #afcbe5",
"jI c #afd1f3",
"bX c #b0b0b0",
"mt c #b0b8bf",
"bU c #b1b1b1",
"mF c #b1b2b1",
"ko c #b1cce6",
"jM c #b1d3f3",
"aT c #b2b2b2",
"mw c #b2b9bf",
"bV c #b3b3b3",
"mA c #b3b9bf",
"ks c #b3cce6",
"jT c #b3d4f3",
"bW c #b4b4b4",
"mP c #b4babf",
"jY c #b4d4f3",
"aB c #b5b5b5",
"ac c #b5b6b7",
"mT c #b5bbc0",
"kz c #b5cee5",
"no c #b6b6b5",
"bw c #b6b6b6",
"mY c #b6bbbf",
"kE c #b6cee6",
"lK c #b7b7b6",
"by c #b7b7b7",
"nW c #b7b8b7",
"mE c #b7b8b8",
"m2 c #b7bbbf",
"kJ c #b7cee6",
"j4 c #b7d6f3",
"gj c #b8b7b7",
"mL c #b8b7b8",
"bx c #b8b8b8",
"mM c #b8b9b8",
"nd c #b8b9b9",
"m7 c #b8bcc0",
"k# c #b8d6f4",
"jy c #b9b8b9",
"ni c #b9b9b8",
"ab c #b9b9b9",
"mK c #b9bab9",
"n# c #b9bcc0",
"nf c #b9bdc0",
"kQ c #b9d0e6",
"mJ c #bab9b9",
"a0 c #bababa",
"kB c #babbba",
"f1 c #babbbb",
"nk c #babdc0",
"kU c #bad1e6",
"a1 c #bbbbbb",
"gp c #bbbbbc",
"j# c #bbbcbb",
"hr c #bbbcbc",
"kg c #bbd8f4",
"g3 c #bcbbbc",
"aS c #bcbcbc",
"gq c #bcbcbd",
"kv c #bcbdbc",
"nr c #bcbec0",
"ny c #bcbfc1",
"kZ c #bcd1e6",
"kk c #bcd9f4",
"#0 c #bcdaf8",
"jf c #bdbcbd",
"mW c #bdbdbc",
"#3 c #bdbdbd",
"nX c #bdbdbe",
"nR c #bdbebd",
"kp c #bdd9f4",
"iS c #bebdbe",
"lV c #bebebd",
"#P c #bebebe",
"bi c #bebebf",
"iM c #bebfbe",
"nF c #bebfbf",
"nC c #bebfc1",
"k4 c #bed3e6",
"bh c #bfbfbe",
"#N c #bfbfbf",
"nZ c #bfbfc0",
"nK c #bfbfc1",
"nG c #bfc0bf",
"jx c #bfc0c0",
"at c #bfc0c1",
"kt c #bfdaf5",
"ma c #c0bfbf",
"kc c #c0bfc0",
"hP c #c0c0be",
"lz c #c0c0bf",
"#O c #c0c0c0",
"hj c #c0c0c1",
"hz c #c0c1c1",
"k9 c #c0d3e6",
"dc c #c1c0c0",
"dC c #c1c0c1",
"j0 c #c1c1c0",
"#M c #c1c1c1",
"ku c #c1c1c2",
"aR c #c1c2c1",
"mb c #c1c2c2",
"lc c #c1d4e7",
"l7 c #c2c1c1",
"ne c #c2c1c2",
"#L c #c2c2c2",
"n0 c #c2c2c3",
"dk c #c2c3c3",
"lh c #c2d5e7",
"kA c #c2dcf4",
"nj c #c3c2c3",
"#K c #c3c3c3",
"gi c #c3c3c4",
"fx c #c3c4c3",
"hd c #c3c4c4",
"#x c #c3def9",
"bM c #c4c4c2",
"j6 c #c4c4c3",
"#J c #c4c4c4",
"nY c #c4c4c5",
"nU c #c4c5c4",
"lm c #c4d6e7",
"kF c #c4ddf4",
"nV c #c5c5c4",
"#I c #c5c5c5",
"e4 c #c5c6c5",
"hq c #c5c6c6",
"kK c #c5ddf5",
"aQ c #c6c5c5",
"#G c #c6c6c6",
"dJ c #c6c7c7",
"ls c #c6d7e7",
".C c #c6e0f9",
"nT c #c7c6c6",
"db c #c7c6c7",
"#H c #c7c7c7",
"lx c #c7d8e7",
"kR c #c7def5",
"h. c #c8c8c7",
"#F c #c8c8c8",
"lC c #c8d9e8",
"kV c #c8dff6",
"kb c #c9c8c8",
"g2 c #c9c9c8",
"#E c #c9c9c9",
"dQ c #cac9c9",
"dj c #cac9ca",
"gN c #cacac9",
"#D c #cacaca",
"hi c #cbcaca",
"#C c #cbcbcb",
"lH c #cbd9e7",
"k0 c #cbe0f5",
"#B c #cccccc",
"lO c #ccd9e8",
"k5 c #cce1f5",
"jm c #cdcdcc",
"fh c #cdcdcd",
"l. c #cde1f5",
"#Q c #cecece",
"lS c #cedae8",
"lZ c #cedce8",
"fP c #cfcfcf",
"ld c #cfe2f5",
"aa c #d0d0d0",
"kM c #d0d1d0",
"l5 c #d0dce8",
"f# c #d1d1d1",
"m. c #d1dde8",
"li c #d1e3f6",
"a# c #d1e4f7",
"#2 c #d2d2d2",
"fQ c #d3d2d2",
"#A c #d3d3d3",
"me c #d3dde8",
"ln c #d3e4f7",
"bq c #d4d4d4",
"mk c #d4dee8",
"lt c #d4e5f6",
".6 c #d4e7fa",
"c7 c #d5d5d5",
"mp c #d5dfe9",
"c6 c #d6d6d6",
"jO c #d6d7d6",
"ly c #d6e6f7",
"c5 c #d7d7d7",
"mu c #d7e0e9",
"b. c #d8d8d8",
"lD c #d8e7f7",
"#R c #d9d9d9",
"mx c #d9e0e9",
"mB c #d9e1e9",
"lI c #d9e8f7",
"#o c #dadada",
"mH c #dae3e9",
"lP c #dae8f7",
"#n c #dbdbdb",
"mQ c #dbe3ea",
"#l c #dcdcdc",
"#p c #dcdee0",
"lT c #dce9f7",
"#m c #dddddd",
"mU c #dde3ea",
"mZ c #dde4ea",
"#k c #dedede",
"l0 c #deeaf8",
"#j c #dfdfdf",
"m3 c #dfe5ea",
"l6 c #dfeaf7",
"#i c #e0e0e0",
"m8 c #e0e5ea",
"m# c #e0ecf7",
"c4 c #e1e0e0",
"#g c #e1e1e1",
"bT c #e1e2e3",
"na c #e1e6ea",
"mf c #e1ecf8",
"#f c #e2e2e2",
"ng c #e2e6ea",
"ml c #e2edf8",
"#h c #e3e3e3",
"#e c #e4e4e4",
"nl c #e4e6ea",
"ns c #e4e7ea",
"mq c #e4eef8",
"#c c #e5e5e5",
"nu c #e5e7eb",
".V c #e5ecf2",
"mv c #e5eff8",
"#d c #e6e6e6",
"nz c #e6e8eb",
"nD c #e6e9ea",
"my c #e6f0f8",
"#b c #e7e7e7",
"k6 c #e7e8e8",
"nI c #e7e9eb",
"## c #e8e8e8",
"mC c #e8f0f8",
"#a c #e9e9e9",
"nL c #e9eaeb",
"mI c #e9f1f8",
"#. c #eaeaea",
"k1 c #eaebeb",
"mR c #eaf1f9",
".D c #eaf3fc",
"nO c #ebeaeb",
".9 c #ebebeb",
"fM c #ebeced",
"nS c #ececec",
"ka c #ececed",
"hx c #ecedee",
"mV c #ecf2f8",
"m5 c #ededed",
"jZ c #ededee",
"fY c #edeeef",
"m0 c #edf3f8",
"nc c #eeeeee",
"jw c #eeeeef",
"lJ c #eeefef",
"gU c #eeeff0",
"m4 c #eef3f9",
"nn c #efefef",
"bp c #eff0f1",
"m9 c #eff4f9",
"nP c #f0f0f0",
"i8 c #f0f0f1",
"l1 c #f0f1f1",
"f6 c #f0f1f2",
"fE c #f0f2f3",
"nb c #f0f5f9",
"nQ c #f1f1f1",
"lo c #f1f1f2",
"lE c #f1f2f2",
"d2 c #f1f2f3",
"nh c #f1f5fa",
"cX c #f2f2f2",
"jN c #f2f2f3",
"lU c #f2f3f3",
"a9 c #f2f3f4",
"aP c #f2f4f6",
"nm c #f2f6f9",
"mD c #f3f3f3",
"j5 c #f3f3f4",
"mg c #f3f4f4",
"dW c #f3f4f5",
".U c #f3f4f6",
"nt c #f3f6f9",
"nw c #f4f4f4",
"kL c #f4f4f5",
"bg c #f4f5f6",
"c3 c #f4f5f7",
"aI c #f4f6f7",
"nv c #f4f7f9",
"cW c #f5f5f5",
"jl c #f5f5f6",
".T c #f5f6f6",
"bv c #f5f6f7",
"nA c #f5f8f9",
".8 c #f6f6f6",
".Q c #f6f6f7",
".P c #f6f7f8",
"nE c #f6f8fa",
"#y c #f6fafd",
"cV c #f7f7f7",
".R c #f7f7f8",
".N c #f7f8f9",
"cU c #f8f8f8",
".O c #f8f9f9",
".S c #f8f9fa",
"cT c #f9f9f9",
".M c #f9f9fa",
"nM c #f9fafa",
".L c #f9fafb",
"aA c #f9fbfd",
"cS c #fafafa",
".K c #fafbfc",
"#1 c #fbfbfb",
".E c #fbfbfd",
".J c #fbfcfc",
".F c #fbfcfd",
"cR c #fcfcfc",
".G c #fcfcfd",
".H c #fcfdfe",
"cQ c #fdfdfd",
".I c #fdfeff",
"#z c #fefefe",
".7 c #ffffff",
"Qt.#Qt.#.a.#.#.#.a.#.#.a.#.#.#.#.#.#.#.#.#.a.#.#.#.b.#.#.b.#.#.#.#.#.#.#.#.#.#Qt.#.#.b.b.#.c.#.#.#.#.b.c.#.#.#.c.b.#.#.a.#.#.#.b.a.#.b.#.#.#.#.#.#.#.a.#.#.a.#.#.#.#.#.#.c.a.#.#.#.a.b.b.#.#.a.#.b.#.#.#.c.b.a.#.#.#.#.#.#.#.#.#.b.a.#.#.#.a.#.#.#.#.#.#.#.#.a.#.#.b.#.b.#.#.#.#.d.#.#.a.#.#.#.#.#.b.#.a.b.#.#.#.#.#.#.#.a.b.a.a.#.#.#.#.c.#.#.#.#.#.#.#.#.#.#.#.#.a.#.a.#.#.#.a.#.#.#.e.#.#.a.#.#.#.#.b.#.#.#.#.#.#.#.#.#.#.a.#.#.#.b.a.#.b.a.a.#.#.#.#.#.#.#.#.#.#.a.#.#.#.#.b.d.#.#.#.#.#.#.#.#.#.a.#.#.a.#.a.b.#.a.#.a.#.c"
".#.b.#.#.#.#.b.b.#.a.e.d.#.#.a.#.#.#.#.#.a.#.#.#.#.b.#.b.#.#.#.#.#.#.a.#.#.c.#.a.b.#.b.#.#.#.a.#.#.#.#.#.#.#.#.#.b.#.#.b.a.#.#.b.#.b.#.#.#.#.#",
".f.c.c.c.f.f.c.g.f.f.g.h.f.f.i.j.f.h.h.c.c.f.h.k.c.c.f.f.f.h.k.f.i.f.c.c.c.k.e.c.f.c.i.c.h.h.k.c.k.c.f.c.c.c.c.c.f.h.g.f.f.c.j.k.c.j.c.f.e.i.f.c.f.c.f.e.k.k.i.h.k.c.f.c.h.g.c.f.f.e.k.c.f.e.c.c.e.f.c.c.c.h.h.c.h.f.f.e.i.f.f.k.k.k.c.h.f.g.f.c.f.f.f.f.c.j.e.g.i.i.c.c.f.c.f.e.e.j.f.f.c.c.c.c.f.c.f.c.c.c.h.c.e.f.c.c.f.c.f.c.i.h.c.c.f.c.k.e.c.c.f.e.f.f.k.c.h.j.c.h.c.f.c.f.c.c.f.h.c.f.f.f.c.c.f.c.k.i.f.c.c.k.f.e.j.f.f.c.f.k.f.f.c.f.f.f.e.i.f.f.c.c.f.f.k.f.f.h.c.f.f.k.k.h.f.f.f.i.c.f.f.k.c.f.j.i.c.f.j.c.i.f.c.k.f"
".f.k.f.f.f.f.c.c.k.c.f.c.c.h.k.i.h.c.f.e.f.f.i.c.f.c.c.f.f.h.k.k.f.f.f.f.f.f.e.c.f.f.c.f.c.k.f.c.c.f.c.c.k.c.f.i.c.h.j.e.c.i.e.e.c.k.f.c.f.g.c",
".g.l.m.i.i.m.n.o.p.q.r.s.s.r.r.r.r.s.r.q.r.s.r.q.q.q.r.s.t.r.t.s.r.t.r.r.r.r.q.s.r.r.q.r.r.q.s.r.r.r.s.s.r.s.t.r.r.r.s.s.r.r.r.r.r.s.s.r.r.r.q.t.r.s.s.r.r.r.s.q.s.r.r.q.s.r.r.r.r.r.r.r.q.q.s.s.r.t.r.s.r.t.s.r.r.r.s.s.r.r.t.r.s.r.s.r.r.r.t.r.t.r.t.r.r.r.r.r.r.r.r.r.s.s.r.r.r.t.s.r.s.q.s.s.r.r.s.s.r.r.r.s.r.r.r.r.r.r.r.q.r.r.r.r.r.q.s.r.s.r.r.q.r.t.s.q.r.q.s.t.t.s.s.r.s.r.q.s.t.r.r.r.s.r.r.r.q.r.s.s.r.s.s.s.s.r.r.s.r.r.r.r.s.r.r.r.q.s.r.r.r.r.r.s.r.s.q.r.s.r.r.r.r.r.q.t.r.s.r.r.s.t.r.r.r.r.r.s.r.r.s.r.r.q.s"
".r.s.s.t.r.t.r.r.r.s.r.r.r.r.t.r.q.s.r.s.r.s.r.r.t.r.r.s.r.s.s.r.t.r.r.r.r.t.q.r.t.t.r.r.r.s.q.t.r.s.r.r.r.s.s.t.r.r.r.u.v.w.m.i.x.x.i.m.y.m.m",
".z.z.z.z.A.B.C.D.E.F.G.G.G.H.H.G.G.H.H.H.F.G.H.H.I.H.H.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.I.H.I.I.I.I.I.I.I.I.H.I.I.I.H.H.G.H.I.H.H.H.I.I.I.H.H.H.G.H.H.H.H.G.H.G.G.H.J.K.G.G.K.L.K.K.K.K.L.L.L.K.J.M.N.M.L.L.N.L.M.N.O.N.N.N.P.Q.P.N.P.Q.N.N.P.N.P.Q.M.O.N.P.R.P.N.N.R.Q.Q.P.P.P.R.Q.N.N.Q.N.N.Q.P.O.N.Q.Q.P.N.N.R.N.N.N.O.O.R.P.N.O.N.N.S.N.R.N.N.M.O.P.P.L.N.P.N.M.N.N.N.T.N.M.N.R.R.P.N.N.N.N.P.R.N.N.N.R.P.O.N"
".P.N.P.T.P.N.N.T.R.N.N.O.P.N.O.S.L.S.P.N.O.O.N.S.M.N.O.N.M.L.N.N.S.K.O.N.M.L.O.S.N.P.L.L.O.M.N.N.O.O.N.P.R.N.N.N.N.Q.U.V.W.X.Y.z.A.z.z.Z.0.z.z",
".1.2.3.4.5.6.7.7.8.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9.9#..9.9.9.9.9.9.9.9.9.9.9.9#..9#.###a#a#b#a.9.9##.9.9.9#a#a###a#b#b#b#c#b#.#.#d#c#a#c#d#a###c#c#c#e#c#b#e#e#c#e#f#c#c#c#c#f#g#h#h#f#c#c#i#g#f#c#c#h#f#e#c#f#g#h#i#j#g#e#h#f#c#c#e#h#f#h#f#j#j#j#k#i#c#g#k#f#h#g#e#c#g#i#i#k#j#h#j#k#i#g#l#k#i#i#f#g#l#m#k#m#i#h#m#n#k#k#i#k#l#m#g#i#l"
"#m#m#n#n#m#k#n#m#i#i#k#k#j#g#j#k#m#n#n#i#g#m#l#g#i#j#f#g#k#k#j#m#j#f#j#k#j#j#l#m#i#g#f#l#n#k#j#k#e#f#m#k#k#i#f#k#m#j#k#o#m#p#q#r#s.1.3#t#t#t#t",
"#u#v#w#x#y.7#z#d#A#B#B#C#D#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#C#C#B#B#D#B#B#B#B#B#B#B#C#D#D#C#C#B#B#B#B#B#C#B#C#C#C#D#D#D#E#D#D#D#C#C#D#C#D#F#D#C#F#G#E#E#G#E#C#E#H#F#I#H#D#H#G#G#I#J#K#L#J#G#G#K#G#G#H#F#H#F#D#G#K#I#G#G#G#H#F#F#F#F#F#G#G#G#I#J#J#J#I#I#H#H#J#G#G#J#I#G#G#K#L#I#I#J#H#G#I#I#J#L#G#G#J#G#I#J#K#M#N#L#I#O#L#J#L#G#I#K#G#G#L#N"
"#M#M#L#K#L#K#K#J#J#J#L#K#M#O#O#O#M#L#L#G#I#J#G#G#L#J#G#K#O#L#I#M#K#G#J#L#J#L#M#I#I#J#I#K#L#L#O#O#L#K#P#L#L#L#L#L#K#I#K#G#Q#R###S#T#U#V#W#V#X#v",
"#Y#Z#0.K#1#a#k#2#E#D#F#D#C#D#C#D#D#C#C#C#D#C#C#D#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#C#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#C#C#B#B#B#B#D#B#B#D#B#D#D#D#E#E#D#D#D#D#D#D#D#D#E#D#E#G#H#G#H#E#H#H#H#H#G#J#J#I#J#I#I#I#L#K#G#I#J#I#G#K#M#K#L#I#G#L#K#I#J#O#O#L#G#G#K#L#J#L#L#L#M#K#M#P#L#J#K#K#I#I#J#K#L#M#L#P#N#M#O#L#K#J#J#J#K#L#M#L#L#M#L#L#O#P#M#K#L#L#L#J#O#N#O#M#I#L#3#O#L#N#P#N#M#L#L#O#L#M#P#M#N#P#O#P#3#O"
"#M#M#L#K#M#O#M#M#L#M#P#O#O#L#J#L#L#K#I#J#L#J#J#K#J#J#G#M#L#G#G#I#G#G#G#K#J#J#G#H#L#L#G#J#M#M#L#G#I#K#L#L#M#M#L#M#L#P#3#N#M#F#A#Q#4#5#6#7#Y#8#Y",
"#9a.a##1#gaa#E#F#E#E#H#D#D#F#E#D#D#D#D#C#C#C#D#D#C#C#B#C#C#B#B#B#B#B#B#B#B#B#B#C#C#B#C#B#B#B#B#B#C#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#D#D#C#D#D#D#E#E#D#F#H#F#E#E#D#D#D#F#H#G#H#H#E#F#G#H#H#H#G#G#G#G#G#J#G#I#L#I#I#I#G#K#J#G#M#L#I#G#K#N#I#J#J#K#J#I#J#J#J#J#K#M#J#L#O#L#M#M#I#L#O#M#O#N#M#L#L#J#L#P#M#L#K#I#L#K#J#J#K#L#J#L#K#L#K#K#O#O#L#L#J#K#O#I#M#P#L#I#I#M#M#G#J#K#J#G#G#G#G#J#G#L#L#I#L#L#J#M#K#I"
"#L#L#M#O#L#L#K#G#I#L#O#L#L#J#J#K#I#I#G#K#I#J#I#G#G#G#J#L#G#G#G#F#I#J#G#L#L#G#G#I#L#G#I#I#L#I#I#K#J#J#J#L#N#M#M#N#N#N#P#M#P#P#Nabacadaeafagahai",
"ajak#1#eaa#F#E#E#E#D#D#D#a.7.7#a#D#D#C#..7.7.7.7.7#.#C#a.7.7.7.7#.#..7.7.7.7#..7.7#.#D#..7#.#B#B#D#C#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#C#B#B#B#B#B#C#C#B#B#B#B#B#B#C#B#B#C#B#B#B#B#B#B#B#B#B#B#C#C#C#D#C#E#E#C#D#D#D#E#F#F#F#E#E#D#D#E#D#E#H#G#G#H#G#F#I#J#G#G#I#I#I#J#J#G#L#L#M#L#L#L#K#K#O#L#L#O#L#J#L#O#L#I#M#L#O#L#M#O#N#O#O#O#N#L#O#N#L#L#N#M#N#M#L#L#K#M#L#J#M#P#N#L#M#M#L#3#M#L#L#O#M#M#O#K#L#O#N#N#M#M#O#L#O#N#L#O#N#L#L#L#M#K#L#M#M#L#L#L#L#M#N#M#P#N#K#N#L#K#L#M#O"
"#O#L#L#L#J#L#K#K#L#N#L#J#M#K#L#P#L#J#J#L#K#L#I#G#J#K#L#J#G#G#J#I#L#L#K#M#K#G#J#L#J#G#L#K#K#K#K#M#M#O#O#M#P#O#O#P#O#L#P#N#3#P#O#M#Malamanaoapaq",
"ar.6#z#j#B#B#B#B#B#B#B#B.7asas.7#B#B#..7asasasasas.7#..7asasasas.7.7asasasas.7asas.7#..7as.7#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#C#B#B#B#B#B#C#B#B#C#C#C#C#C#B#B#C#C#B#B#B#B#B#C#C#B#C#B#B#B#C#C#B#C#C#C#B#B#B#B#B#D#B#B#C#B#B#B#B#C#C#B#B#B#B#B#B#C#B#D#D#B#C#D#D#D#D#D#C#C#D#E#F#D#D#E#H#F#E#H#E#F#H#H#H#H#H#D#C#D#D#E#C#H#G#G#J#H#E#E#G#I#G#H#G#F#H#H#E#F#I#F#F#E#E#D#D#G#F#H#I#H#F#E#G#G#F#G#E#E#H#G#G#H#F#D#G#J#G#G#H#F#G#G#I#G#G#F#D#F#E#F#H#H#J#K#L#L#I#H#G#K#K#G#J#J#G#I#G#G#K#L#K"
"#G#G#I#H#I#G#G#M#L#G#I#I#L#I#I#J#H#G#J#K#J#G#H#H#J#I#G#G#G#G#I#I#K#J#J#H#F#H#G#G#F#G#M#L#M#K#I#G#K#M#L#J#L#J#J#K#J#J#O#L#L#I#K#H#Datauavawaxay",
"azaA#e#A#C#C#B#B#B#B#B#B.7asas.7#B#B.7asas.7.7.7asas.7asas.7.7.7as.7.7asas.7.7asasas.7.7as.7#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#C#C#B#B#D#B#C#B#B#C#B#B#B#B#B#B#D#B#B#C#H#H#D#D#D#D#E#F#D#C#B#B#B#D#C#C#B#D#D#D#H#D#B#B#B#D#B#B#C#E#B#B#B#B#B#B#C#C#D#D#D#E#D#C#H#E#C#F#C#E#F#B#B#B#B#E#C#D#C#D#E#G#H#D#E#D#D#G#H#F#C#D#C#C#F#D#D#E#H#F#H#H#E#D#D#F#H#E#D#H#H#D#E#E#E#H#E#E"
"#F#H#H#H#G#F#H#I#D#H#H#F#G#H#F#E#E#H#H#H#F#F#H#G#J#G#H#H#H#G#I#G#F#E#H#H#G#G#G#G#I#I#K#L#K#G#G#G#K#K#G#G#K#G#G#J#I#I#K#K#L#L#M#O#MaBaCaDaEaFaG",
"aHaI#R#E#F#D#E#F#E#D#D#D.7asas.7#D#D.7asas.7#C.7asas.7asas.7.7.7.7#..7asas.7.7asasasas.7as.7#B#C#C#B#B#C#C#C#B#B#B#B#B#B#C#C#C#D#C#C#B#C#C#B#D#D#D#C#D#C#C#B#B#C#C#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#C#B#B#B#B#C#B#B#B#B#C#C#B#B#C#B#B#C#D#C#D#C#D#C#D#D#C#C#D#D#D#D#D#C#D#D#D#E#D#D#E#D#D#D#C#C#D#D#D#D#B#D#F#H#F#H#H#F#D#E#G#G#D#B#C#F#G#H#H#G#H#I#F#E#G#D#C#D#G#G#E#E#H#H#D#H#F#D#E#H#F#E#F#H#F#F#E#G#I#F#F#G#F#H#E#D#E#E#F#G#E#D#H#K#I#G#G#G#G#G#I#L#I#F#D#H#I#K#I#J#G#I#J#H#G#H#D#D#G#K#I#I#I#K#K#G#L#G#H#K#J#G"
"#I#I#G#G#G#G#L#I#G#J#I#G#G#H#H#G#G#G#H#D#E#G#I#G#G#G#H#H#H#G#I#H#C#D#G#G#G#G#G#G#I#H#F#G#D#D#E#G#K#G#G#I#J#G#K#J#H#I#L#M#K#M#M#M#LaBaJaKaLaMaN",
"aOaP#R#D#D#D#D#E#D#E#H#E.7asas.7#D#D.7asas.7#C.7asas.7asas.7asasas.7.7asas.7.7as.7asasasas.7#B#C#C#B#B#C#C#C#B#B#B#B#C#D#C#C#C#D#C#C#B#C#C#B#D#D#D#C#D#C#C#B#B#C#C#B#B#B#B#B#B#B#B#B#B#B#B#B#C#C#B#B#B#B#C#C#B#C#B#B#B#C#E#D#C#C#C#D#C#C#C#C#B#D#E#D#D#D#D#D#D#D#F#C#F#G#F#D#E#F#D#D#D#H#H#F#G#H#F#H#F#E#G#G#G#G#G#H#L#O#K#G#I#I#H#K#L#I#K#K#I#L#N#N#L#L#M#O#L#K#M#LaQ#J#O#O#L#L#L#K#L#J#L#J#I#N#O#L#J#K#K#J#J#L#M#L#K#K#K#L#J#G#J#L#L#L#L#L#L#P#P#K#G#K#G#J#M#K#K#K#J#J#O#P#N#L#M#M#O#K#L#M#J#I#L#P#O#K#O#K#MaR#K#N#J#M#P#M#K"
"#L#M#K#J#K#L#O#J#M#J#K#K#J#G#J#J#I#K#J#J#L#O#L#G#I#G#H#K#L#I#I#J#G#I#M#L#J#K#L#L#K#I#K#K#G#G#L#M#L#L#L#L#M#K#M#L#K#3aS#N#M#N#P#N#MaTaUaVaWaXaY",
"aZaI#o#B#C#B#B#B#B#C#C#B.7asas.7#B#B.7asas.7#B.7asas.7asas.7.7asas.7.7asas.7.7as.7.7asasas.7#B#B#B#B#B#B#B#B#B#B#B#B#B#C#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#C#B#B#B#B#B#B#B#B#B#B#B#B#C#C#C#C#B#B#B#B#B#B#B#B#D#D#B#C#C#B#C#C#B#B#B#D#D#C#B#B#D#D#B#D#F#E#D#F#D#E#E#D#F#G#G#H#G#J#G#K#K#G#E#G#G#G#J#I#G#J#J#I#L#O#K#I#I#K#K#G#K#O#M#O#N#N#J#J#O#L#K#L#K#J#I#L#O#J#I#J#L#L#J#K#O#M#L#L#J#K#M#K#J#M#N#L#L#P#O#L#N#M#I#I#L#K#K#O#K#K#L#J#K#N#N#L#J#L#O#L#I#M#O#M#O#P#L#I#L#O#K#N#M#J#K#J#M#L#G#J"
"#M#O#L#K#M#O#L#J#L#G#L#L#I#J#O#L#J#L#O#L#K#L#K#G#J#L#I#M#M#K#M#O#K#O#N#O#L#L#N#P#L#O#P#N#P#P#3#N#O#P#P#NaS#P#N#N#Pa0#3#NaSa1a0a0a0a2a3a4a5a6a7",
"a8a9b.#D#E#D#D#D#D#D#D#D.7asas.7.7.7.7asas.7.7.7asas.7asas.7.7asas.7.7asas.7.7as.7#a.7asas.7#C#B#B#B#B#C#B#B#B#C#C#B#B#B#B#C#C#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#C#C#B#B#B#B#B#B#B#B#C#B#B#B#B#C#B#B#D#D#D#D#B#B#D#E#D#D#D#D#D#C#D#D#D#D#D#D#D#D#D#F#D#D#E#E#F#G#G#H#G#G#G#G#J#I#H#G#G#G#G#L#L#G#L#M#L#M#L#J#O#L#K#J#K#M#O#J#M#P#P#N#P#O#K#O#3#O#M#M#M#L#L#O#M#L#L#M#L#L#L#L#P#L#L#M#L#N#P#M#L#N#P#L#N#P#M#L#O#M#K#O#P#O#M#P#O#N#P#L#M#N#M#L#L#L#N#L#K#O#P#O#M#M#J#J#N#O#L#L#L#J#J#L#L#J#I#J"
"#J#K#J#G#L#K#J#L#J#L#O#L#J#L#O#L#I#L#L#I#I#I#G#G#L#L#G#L#M#K#L#K#J#L#L#K#I#I#O#N#I#M#P#P#O#N#N#L#PaS#P#N#P#P#P#PaSa1aSaSa1a1a0a1a0b#babbbcbdbe",
"bfbg#R#D#D#D#E#D#D#D#D#D.7asasasasas.7.7asasasasas.7#..7asasasasas.7asasasas.7as.7#C#..7as.7#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#D#D#C#D#B#B#C#C#B#B#C#C#C#C#B#D#C#B#D#C#D#F#F#E#E#F#E#H#H#H#E#F#G#G#G#G#H#G#I#G#G#I#G#J#L#G#J#M#L#L#M#L#J#M#M#L#L#L#L#L#N#P#P#N#N#N#L#3#P#O#3#P#P#P#O#P#P#N#3#P#N#P#3#3#O#3#N#P#P#P#O#M#P#P#N#N#O#N#P#P#N#M#N#O#3#P#K#Mbhbi#O#O#L#M#O#L#M#O#M#M#O#3aS#P#P#3#M#OaS#M#L#P#O#P#M#L#P#N#M#N#L#L#N#P#M#M#O#L#M#M#L#J#I#J#L#J#L#J#L#M#L"
"#I#K#J#J#O#J#G#L#L#M#K#J#G#K#J#G#I#I#I#I#L#O#O#L#M#L#G#O#O#I#K#L#J#K#J#L#L#J#L#L#I#L#O#O#L#N#M#L#O#N#O#L#O#P#P#P#P#PaS#3#P#PaS#Pa0bjbkblbm#5bn",
"bobpbq#G#G#H#H#F#E#E#F#E#a.7.7.7.7.7#a#a.7.7.7.7.7#a#D#a.7.7.7.7.7#a.7.7.7.7#..7#a#B#D#a.7#.#B#C#C#B#B#D#C#C#C#C#D#C#C#C#C#D#D#C#D#C#C#D#D#D#D#D#D#D#D#D#D#D#D#D#D#E#D#D#D#D#D#C#E#D#D#E#E#E#F#E#D#D#D#D#E#E#D#H#F#D#E#E#E#H#F#H#G#H#H#G#G#F#H#G#H#G#G#I#I#J#I#I#I#I#J#J#K#I#J#K#G#J#J#G#L#L#K#J#J#K#K#K#L#L#K#L#M#N#P#N#M#N#O#P#O#P#O#PaS#P#M#M#M#P#P#N#P#N#N#N#N#N#O#P#O#P#3aS#3#P#3#3#P#3#P#P#3#P#P#3#3#PaS#P#O#3#P#O#O#N#P#P#P#3#3#P#P#3aSa0#3#P#3#3#P#P#P#M#3a1#O#O#N#O#P#O#N#P#O#O#O#O#L#K#K#L#O#O#N#M#N#O#O#L#O#M#N#M#L"
"#M#O#L#O#N#J#L#O#M#I#G#J#L#K#K#M#K#K#O#M#O#O#L#K#L#M#K#M#K#L#P#O#J#L#L#O#M#L#O#N#M#N#N#N#M#N#M#P#P#3#3#P#3aS#3aS#3aSa1#3aSa0a0#3abbjbrblbmbsbt",
"bubv#R#C#C#C#C#C#C#C#D#C#B#B#B#B#C#B#B#B#C#B#C#B#B#C#B#B#C#B#B#C#C#C#B#B#B#B#B#B#B#B#B#C#B#B#B#B#B#B#B#B#B#B#B#C#B#B#B#B#B#B#C#C#B#B#C#C#C#C#D#D#D#D#D#C#B#C#C#D#D#C#B#C#D#D#D#D#E#C#D#D#D#D#D#C#C#C#C#C#C#D#D#D#D#C#C#C#D#D#D#E#D#C#D#E#F#D#D#D#E#E#G#G#F#E#E#H#F#E#F#G#G#H#G#G#H#H#G#G#I#G#G#G#I#J#J#I#K#I#H#J#K#J#J#G#G#G#I#J#G#K#K#O#O#J#I#K#M#M#L#O#N#M#L#O#P#O#O#M#M#N#PaS#P#N#O#N#P#O#O#P#3#P#N#N#N#O#O#M#O#O#M#L#M#P#3#O#P#P#K#O#N#N#P#N#L#K#L#O#L#L#L#L#P#O#J#K#L#O#L#K#O#N#L#L#O#N#M#M#L#L#L#N#N#O#L#K#M#O#M#M#N#N#M"
"#M#N#M#M#M#L#O#M#J#J#M#N#O#O#N#M#K#M#O#O#O#M#L#J#L#L#K#M#L#N#N#L#J#L#P#N#M#PaS#P#O#Pa1#3#P#3#3a1a0a0a0a1#3a0aba0a0a0bwabbxbxbya0bxbzbAbBbCbDbE",
"bFbg#o#D#D#D#E#D#D#D#D#D#D#D#D#D#D#D#D#D#C#C#C#D#C#B#C#B#B#C#D#C#B#B#D#B#B#B#C#B#D#D#D#D#D#D#D#C#D#D#D#C#B#D#D#D#C#D#D#C#C#C#B#B#B#B#C#D#D#D#D#C#C#D#C#B#B#C#D#D#C#B#C#D#C#B#B#B#B#B#D#D#C#B#B#C#B#B#D#C#B#C#C#E#C#C#D#D#D#D#E#F#D#D#E#E#D#D#F#D#E#E#E#D#B#D#E#H#H#H#G#G#H#G#G#G#G#H#I#I#J#G#G#J#L#I#G#G#I#G#I#L#L#G#G#K#K#J#L#L#K#L#L#O#M#J#J#O#N#O#N#N#O#J#L#P#N#L#O#L#K#M#M#M#I#G#I#L#M#K#L#O#O#M#M#M#L#J#K#O#N#L#J#L#O#N#L#K#L#L#I#M#N#L#L#L#M#L#J#L#K#K#L#L#P#L#J#K#O#L#M#O#O#L#G#L#L#K#K#L#J#K#K#L#I#G#H#G#K#K#J#I#L#K#L"
"#L#K#J#I#I#L#M#J#J#J#O#L#K#K#I#G#G#L#K#J#J#K#J#G#I#K#I#K#K#L#L#I#I#L#M#L#L#O#M#J#L#O#M#L#O#N#M#P#P#N#L#I#L#P#P#P#P#3#P#NaSaS#3#M#NbGbHbBbIbJbK",
"bL.N#l#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#C#C#B#B#C#C#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#C#B#B#B#B#B#B#B#C#B#B#C#D#B#B#C#B#B#D#C#B#C#D#D#C#B#D#D#D#D#D#D#F#E#C#D#H#G#E#C#E#G#H#E#E#F#F#D#D#H#H#E#G#G#D#E#I#G#D#G#G#J#I#F#F#J#J#I#K#J#G#H#I#J#G#H#I#G#G#I#G#G#G#G#G#H#G#G#G#I#G#H#G#G#H#E#G#L#J#H#H#J#K#I#H#G#G#H#F#G#K#H#G#I#H#D#E#I#F#E#G#G#J#H#E#H#I#G#I#J#G#E#H#I#G#E#G#G#F#H#H#F#H#H#H#H#E#G#H#G#G#H#H"
"#G#F#D#F#G#J#G#E#G#K#I#G#G#G#G#H#F#I#G#H#G#G#D#E#J#G#E#G#G#J#K#G#F#J#J#G#L#L#G#HbM#L#I#I#M#L#K#O#L#K#M#O#N#M#O#O#N#P#N#N#3#P#N#L#3bNbabObPbQbR",
"bSbT#PbUaTbVaTaTbVaTbVbWbWbWbWbWbWbVbWbWbWbWbWbWbWbWbWbWbWbWbVbWbVbVbWbWbWbWaBbWaTbVbWbWbWbWbWaBbWbWaBaBaBbVbWbWbWbWbWbWbWaBbWbVbWbWbWbVbWbWbVaBaBaBaBaBaBbVbVbWbWbWbWbWaBbWbWbWbWbWbWbWbWbWbWaBaBbWbWaBbWbWbWbWbWbWbVbVaTbUaTbVbWaTbUaTbUbXbUbVbUbUaTbGbXaTbUbUbUbUbXbXbUbUbXbXbUbGbjbjbXbGbjbjbGbGbjbjbjbGbGbNbGbGbzbGbGbNbzbGbGbzbNbzbjbXbNbYb#b#b#bNbGbjbYbzbjbzb#bjbjbzbjbzbYbNbjbNbzbNbzb#bzbjbGbjbGbjbYb#bGbGbNbzbjbGbNbzbzbGbjbjbjbXbjbzbXbGbNbGbUbjbzbGbGbUbUbNbjbjbNbNbGbXbGbNbGbGbzbjbUbGbGbUbjbGbUbXbXbGbXbGbGbUbU"
"bUbUaTbGbGbGbUbUbGbGbXbXbXbGbGbXbXbGbXbGbNbXbUbGbGbUbXbNbjbjbGbUbGbzbjbNbNbjbGbGbzb#bjb#a2bjbNb#bzbzbZb#bNbYbYbYbYbZa2bYbYbZbza2b0b1b2bOb3b4b5",
"b6b7b8b9c.c#cacacbcbcacacccacccccccdcdcccdcdcdcdcdcdcdcccccdcdcdcdcdcdcccccdcdcacccdcdcdcdcdcdcdcdcdcdcdcdcacdcdcdcdcdcdcccdcccccdcdcdcdcdcdcdcdcdcdcdcdcdcdcdcdcdcdcdcdcdcdcdcdcdcdcdcdcdcacdcacbcccdcacbc#cacacccccec#cccacacdcccbc#cccacacccacfcbc#c#cdcdcac#c#cbcfcacdcacecaccc#cccbcecac#cec#cac#c#cfcfcfcbcbcfcecbcgcgcccbchcicfcgcfcecicjcecfcfc#c#cfcicfcecicgcbcgchcfcgcfcbcfcgcicichcjcbc#cgcgc#cececbcicgcbcgcgc#cecbcbcjcjcec#cgcjcgcfchcecacgckcicicicbcecjcgcecgcecbcbcjcjcbcfcicecbcicicfcgcbc#cbcfcfcgcgcbccca"
"cecacacec#cbcecbcbcecbc#cecacfcgcec#cbcgcgcbcicjcbcechcjcjcicicfcicjcgcgcicgcecjclcjcickchcickcmcncocncjchcnclcpcqcrclcncscschcncpcoctcucvcwcx",
"cyczcAcBcCcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcDcEcDcDcDcFcEcDcDcFcEcDcDcFcFcFcDcDcFcFcFcGcFcEcGcEcDcDcFcEcEcDcDcFcEcDcDcGcGcFcEcGcFcEcGcGcFcGcGcGcFcGcGcGcGcGcGcGcGcGcGcGcGcGcGcGcGcGcGcGcGcGcGcGcGcGcGcFcGcGcGcGcGcGcGcGcFcFcGcGcGcGcEcGcGcFcGcGcGcGcGcGcGcFcGcGcGcFcGcGcFcFcGcGcGcGcGcGcGcFcEcGcGcGcEcGcGcGcEcFcGcGcFcGcGcGcGcDcDcF"
"cGcFcGcGcFcGcGcDcFcGcGcGcGcDcGcGcDcFcGcGcGcFcGcGcFcGcGcGcGcGcGcGcGcGcGcGcGcGcGcGcGcGcGcGcGcGcGcHcGcGcGcHcHcGcIcJcJcGcGcGcJcJcJcJcJcIcKcLcMcNcO",
"cP#z#z#z#z.7.7#z#z#z.7.7#z.7#z#z.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7.7#z.7.7#z.7.7#z.7.7.7#z.7.7#z#z#z#z#z.7#zcQ#z.7#zcRcQ.7cQcQcQ#zcQcRcRcR#z#zcRcRcRcRcRcQ#1cQ#zcQcRcQcQcQ#zcRcQ#zcQcR#1cRcQcRcRcQ#1#1cRcR#1cRcRcScScR#1#1#1#1cS#1#1cScTcR#1cTcTcRcRcScTcScScTcTcT#1cR#1cS#1cScS#1#1cScQcR#1#1cR#1cQ#1#1cRcR#1cTcT#1#1cTcRcRcT#1cQcS#1cRcRcS#1cR#1#1cRcRcRcRcR#1cRcQcRcS#1cQcRcS#1cRcRcR#1cRcQcQcR"
"cRcR#1#1cR#1cR#zcR#1cRcRcRcQ#1cR#zcR#1#1cRcQ#1#1cQ#1cScRcRcS#1cRcScS#1#1#1#1cScS#1#1cScTcR#1cTcUcTcScTcUcUcUcVcV.8cUcScU.8.8.8cWcVcX#GcYcZc0c1",
"c2c3#d#h#c#c#c#e#c#c#d#c#c#b#d#c#d#d#d#b#b#b#c#b#####b#b#####b#b#b#a#a#b#a#.#a#a#####a#.#.#a#a#a#.#.###.#a#a#..9#.#.#.#a#a#..9#a###a###b#a###.#.#a#.#a###b###a#a#.#b#d#b#a#b#b#c#####b#c#c#c#b#c#c#b###b#####c#b###d#c#d#d#d#c#e#c#c#c#c#c#b#c#f#h#c#c#e#h#h#c#g#f#h#g#f#h#f#h#f#k#i#g#h#c#e#j#l#i#g#j#l#j#h#f#k#m#m#k#k#l#j#f#i#f#e#i#m#f#g#k#k#j#j#m#l#k#m#l#k#k#g#g#n#R#l#j#l#l#m#i#m#l#m#m#m#i#m#i#f#m#l#k#k#f#h#k#o#l#m#l#n#o#k#i#l#R#o#n#m#l#n#i#i#k#f#f#n#k#j#k#l#k#m#k#m#l#m#l#m#j#i#h#g#l#m#i#i#k#k#i#g#m#k#i#j#g#g#i"
"#hc4#k#i#i#f#e#f#k#m#i#h#g#j#j#h#f#j#k#k#i#f#m#j#h#i#g#e#j#m#f#g#k#l#k#k#m#n#n#n#R#o#n#m#m#Rc5#R#Rc5c6c6c5c5c7c6bqbqc7bqc6b.bq#2c7#Pcac8c9d.d#",
"dac3#R#D#C#D#D#D#D#D#D#C#C#C#C#C#C#C#C#B#C#D#D#B#B#C#C#B#C#C#C#D#D#C#D#D#C#C#C#C#D#D#C#C#C#C#C#C#C#C#D#C#C#C#C#B#D#D#D#D#D#D#C#C#D#C#D#C#C#C#C#B#B#C#B#D#C#C#C#C#C#D#E#E#D#E#F#D#H#H#F#F#F#H#H#H#F#E#F#F#H#G#F#F#F#F#G#E#D#Edb#H#E#H#G#F#G#G#J#I#I#G#H#G#G#I#G#G#G#G#J#I#G#I#G#K#K#K#K#G#I#L#M#L#L#L#L#L#L#O#M#L#L#M#N#N#P#O#M#O#L#N#N#O#M#O#N#N#L#L#M#O#L#L#M#L#M#N#3aS#3#P#O#M#M#P#N#O#N#N#N#N#M#M#N#M#N#N#O#O#M#O#P#3#P#N#P#3#PaSaS#P#P#P#P#3#3#P#O#N#O#N#3#P#O#P#P#P#O#M#M#P#N#M#P#N#M#N#P#3#P#P#N#L#L#L#N#O#N#M#M#N#L#K#O"
"#L#Ldc#L#M#K#L#O#N#N#O#M#O#M#O#3#P#N#P#N#P#3#P#N#N#P#N#3#3#P#P#P#3aS#P#N#3a1#3#3a1#3a1a0bxbybyaba0a1a1abbxabababbybwbxbwbwbwaBbwbwbZdddedfdgdh",
"dibv#o#D#C#C#C#C#B#B#C#C#C#C#C#C#C#C#C#C#C#B#C#C#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#C#B#B#B#B#B#B#B#C#C#C#C#B#B#C#B#B#C#B#C#B#B#B#B#C#D#C#B#C#D#D#C#B#B#B#C#B#C#D#B#D#D#D#F#D#D#Edj#D#C#D#E#E#F#H#F#D#D#C#B#D#H#E#D#D#D#E#E#D#E#F#F#G#H#H#H#D#F#G#H#H#G#H#E#E#G#G#F#H#G#G#G#F#E#F#G#H#F#I#I#G#I#I#K#K#F#I#J#G#F#G#H#G#G#L#J#F#H#G#E#E#G#K#I#G#G#G#G#G#G#I#I#I#L#J#L#K#G#K#L#L#L#K#J#G#K#P#M#K#L#P#M#O#L#J#K#L#J#M#P#L#L#O#N#3#O#M#P#P#O#L#M#O#O#N#P#L#J#L#L#G#J#O#L#L#K#J#J#I#G#I#K"
"dk#L#L#M#L#J#L#M#M#M#M#L#J#I#M#P#L#L#P#O#O#M#L#L#O#M#K#P#P#M#P#3a1a1#P#PaS#3#P#P#3aSa1a0a0#P#PaS#P#Na1aba0a0a1a0aba0a1abbxbxbwbybwbYbHdldmdndo",
"dpbg#R#E#D#D#D#D#C#C#D#D#D#C#C#D#D#C#C#D#D#C#D#C#C#B#C#C#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#C#B#B#C#B#B#B#B#B#C#B#C#C#C#C#B#C#C#B#C#C#D#D#D#D#D#D#C#C#C#C#D#D#D#C#D#E#D#B#C#D#D#C#C#C#C#D#D#C#D#D#D#E#E#D#F#D#E#H#H#G#F#G#G#F#F#F#F#F#H#F#E#G#G#H#H#H#H#H#H#H#G#G#F#H#G#G#H#H#G#H#G#J#J#G#G#K#K#F#H#I#L#I#I#H#H#G#I#G#I#L#J#K#L#L#L#L#I#M#M#L#M#K#M#L#K#L#J#G#L#L#K#L#N#M#L#L#L#L#L#L#L#L#K#J#L#M#M#J#K#L#L#M#P#O#K#L#P#O#G#K#L#N#K#J#J#K#K#K#J#L#N#L#O#M#O#P#L#M#P#M#O#L#L#O#L#L#L#J#K#L#L#K#M#N#L#L#L#L#L#J#K#K#J"
"#G#J#L#M#K#J#K#K#L#M#M#L#K#L#N#K#I#L#O#M#K#J#L#L#L#L#L#N#N#N#P#P#3#P#O#3#3#PaS#3aSa1#Pa1#3#3aSa0aSa1aba0a0bxbxbyabbxbxbya0a0bybwbwbNdqdrdsdtdu",
"dv.N#l#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#C#B#C#B#B#B#B#B#B#B#B#B#B#C#C#C#B#B#B#C#C#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#C#C#B#B#B#B#B#D#D#D#D#D#C#B#D#D#B#D#D#D#D#D#D#E#D#D#C#D#D#C#E#E#E#D#F#F#F#D#D#E#F#H#F#E#G#G#H#H#H#E#H#G#G#G#G#G#G#F#H#G#I#I#F#H#I#H#G#K#L#K#J#L#L#J#K#M#J#K#L#L#L#O#O#M#M#L#K#L#L#L#L#P#N#L#M#N#P#P#L#O#P#P#P#M#M#N#P#O#O#M#M#P#O#N#P#N#P#L#L#M#M#N#M#K#O#M#L#N#P#P#P#P#3#P#M#P#N#L#N#O#M#N#P#P#P#N#N#O#O#O#M#P#P#L#O#O#N#N#M#L#L#O#N#L#K#L#M#L#L#L#K#L#M#K#M#M#L#L#G#J"
"#K#L#M#G#I#L#I#J#O#M#O#L#L#M#L#L#O#L#K#M#M#N#P#P#O#N#L#L#M#N#M#M#3#P#O#P#PaSaS#3#Pa1a0a0#P#3a1a0a1a1aSaSababa0bxabbxa0a0a0a0bybx#3bNdwdxdydzdA",
"dB.P#n#C#C#B#B#C#C#C#C#C#D#C#B#B#B#B#B#B#C#B#B#B#B#B#C#B#C#B#B#C#B#B#B#B#C#B#C#B#B#C#C#C#D#D#C#C#C#D#D#C#B#B#D#D#C#C#D#D#C#C#C#D#D#D#C#D#D#D#D#D#D#E#E#D#C#D#D#E#E#F#D#D#D#D#D#D#E#G#D#E#H#F#F#F#F#E#F#F#E#H#G#H#H#I#I#G#F#G#I#G#G#F#G#I#I#H#H#I#I#G#G#G#I#I#I#G#I#G#G#K#G#L#K#J#G#F#J#L#G#L#L#K#J#I#J#J#K#O#L#I#L#M#L#M#M#M#L#L#K#L#L#N#M#O#3#O#L#L#N#N#M#L#L#PaS#O#L#M#N#O#L#L#M#N#N#L#O#N#L#P#O#O#3#N#N#K#L#P#MdC#3#P#O#M#O#O#L#NaS#L#L#P#P#N#P#P#O#N#O#O#O#P#P#P#3aS#N#O#N#P#O#M#L#N#P#P#L#L#O#O#L#K#K#L#L#L#L#L#J#J#M#L#O"
"#O#M#J#G#L#M#K#O#O#L#M#K#K#K#K#O#N#J#L#N#O#N#N#O#M#O#L#L#M#P#P#PaS#P#M#O#3#3#P#P#3a1a0#3#N#3a0aS#3aSa1ababa0bxbxa0bwbxbyaBbwbwa1aSbZdDdEdFdGdH",
"dIbv#R#D#C#D#D#C#C#C#C#C#D#C#B#B#C#B#B#B#C#B#B#B#B#B#C#B#C#B#B#C#B#B#B#B#B#B#B#B#B#B#C#D#C#D#C#C#C#D#C#B#C#C#D#C#B#C#D#D#C#C#D#D#D#D#E#D#D#D#D#D#D#D#D#C#D#E#E#D#E#E#D#C#D#C#D#D#E#D#C#D#F#E#D#D#D#D#D#H#F#F#H#G#G#I#I#H#F#G#G#F#H#G#G#G#F#F#H#G#H#FdJ#I#I#H#I#I#H#H#G#G#F#G#G#F#E#I#L#J#I#L#K#G#I#I#G#G#L#L#G#G#L#L#K#J#J#J#G#L#L#L#L#O#N#L#N#M#J#L#M#M#K#L#O#M#M#L#K#M#L#K#K#M#N#L#L#N#M#K#K#L#L#M#O#L#K#L#3#P#N#P#P#M#M#O#O#L#L#P#M#K#O#P#N#N#O#K#I#L#P#N#L#N#P#O#P#P#M#L#M#O#L#L#O#P#N#L#L#M#O#L#L#K#M#L#K#L#O#K#G#J#K#J#L"
"#K#I#G#K#N#L#K#M#L#L#K#L#K#J#L#M#K#J#O#O#M#M#M#L#K#N#O#N#N#P#P#P#3#P#M#N#3#3#O#Pa0a1#3#N#Pa0a0aS#3a1abaSa0byaba0a1aba1a0a0a1aSa1bwbZdKdLdMdNdO",
"dPbv#R#C#B#D#B#B#B#B#B#B#B#B#B#B#C#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#C#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#C#B#B#B#B#B#B#B#B#B#C#C#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#C#C#B#C#D#C#D#E#D#D#D#D#C#D#D#C#D#D#D#D#D#D#C#C#C#D#DdQ#F#C#D#F#E#C#D#D#D#D#D#E#D#D#I#H#D#D#E#E#C#D#F#E#F#F#D#D#E#F#H#D#D#F#D#F#G#H#G#I#G#G#E#H#H#F#G#F#H#G#G#J#G#G#G#H#F#E#H#H#I#G#E#I#K#H#F#H#H#G#G#G#G#G#L#P#L#G#I#K#I#G#M#L#K#L#L#I#L#M#M#O#L#L#L#L#M#N#L#M#O#O#K#L#L#K#L#L#L#L#O#O#O#O#L#L#L#I#J#K#L#M#I#K#L#L#I#I#J#J#J#K"
"#K#I#J#P#P#L#J#L#L#I#L#M#L#L#O#L#L#L#L#N#O#O#O#O#N#P#P#P#3aS#P#N#P#P#P#3#P#3aSa0aba1a1aSaSa1#3a0a0bxabaSbxaBaba0a0a0ababbxbya1aBbUbZdDdRdSdTdU",
"dVdW#R#H#F#D#D#D#D#D#D#D#D#D#C#D#D#D#D#D#D#D#D#D#D#E#D#D#D#D#D#D#D#D#D#D#D#E#D#D#D#E#D#D#D#D#D#D#C#C#D#D#D#D#D#D#D#D#D#D#D#D#D#E#E#D#B#D#D#D#D#D#E#D#E#D#D#D#D#D#E#E#D#D#E#D#D#D#D#D#E#D#F#E#D#E#D#E#H#H#H#G#H#E#F#E#F#F#E#D#D#G#F#E#F#F#E#E#E#F#G#H#E#D#F#H#H#D#E#H#D#F#G#F#H#E#F#J#G#G#G#G#I#H#J#G#J#J#G#G#K#K#K#L#L#L#L#K#O#O#L#O#N#L#L#L#L#L#M#L#J#M#N#O#N#N#N#M#O#N#N#P#O#M#N#P#P#O#L#N#O#O#P#N#M#N#M#P#3#M#N#PaS#P#N#3#PaS#3#O#PaS#P#3#3#N#N#P#Pa0aS#Pa1#3#N#P#O#P#N#N#M#M#3#N#M#N#O#K#L#O#M#O#M#J#L#L#O#M#K#L#L#K#L#O#L"
"#L#I#K#P#L#J#L#O#O#J#L#O#M#N#K#L#O#M#O#P#P#N#N#PaSaS#P#Pa0aS#P#3#P#3a1#3#Na1aba1a0aba0a0a0ababbyaba0bybwbwbxa0bwbwbxbwbybxbwabbWbVb#dXdRdYdZd0",
"d1d2b.#H#F#F#F#F#F#F#F#F#D#E#D#D#H#D#D#H#F#H#F#H#H#F#F#F#F#H#F#H#H#E#F#H#H#H#H#F#G#G#H#H#H#F#F#F#F#H#G#F#F#H#F#F#F#H#H#H#F#H#G#G#G#F#G#G#F#F#G#H#F#H#H#H#G#G#G#G#G#I#G#I#J#G#G#G#G#I#L#L#L#L#J#L#L#L#M#L#L#O#L#L#M#L#M#O#M#L#M#N#L#L#O#K#K#M#L#M#M#M#J#M#O#J#L#M#O#L#L#O#M#L#L#L#M#P#M#M#O#M#O#O#P#P#P#N#M#N#P#3#P#3#3#3aS#Pa1aS#O#P#P#NaS#3#3aSaS#P#3a0aSaSa0a1aSaSa0aSaSa0a1aSabaS#PaSaSa1#Pa1a0#3#3#P#3a0a0a1ababa0a0abbyaba0a1#3a0a0a0a0a0a1a0aba0bxa0a0abaSaSa0aSaSa0aS#Pa1a0#P#P#3#P#N#P#P#P#P#P#O#P#3#O#N#P#3#N#N#P#P#O"
"#M#M#Na1#P#P#3#P#P#P#3aS#P#P#N#NaSaSaSa1aSaSa0a1a0a0#Pa1a0aSa1a0a1a0a0aSa0bwa0a1a0aba0abbwbxbybwbxa0aBbxa0bybwbwbxaBbWbybwbybwaTbUbZd3d4d5d6d7",
"d8.P#n#C#B#C#C#B#B#C#D#B#C#B#B#D#D#B#B#D#B#C#D#D#C#B#C#C#D#F#D#C#D#D#D#C#C#D#D#D#D#D#D#D#D#D#D#D#D#D#C#C#D#D#D#D#D#D#D#D#E#E#E#E#D#D#F#E#D#E#G#D#D#G#F#G#J#G#F#G#G#G#G#G#H#E#H#G#G#J#K#I#I#L#J#J#J#J#K#J#K#K#G#J#L#K#L#O#O#O#M#J#J#L#L#J#J#J#I#L#L#M#K#O#L#I#L#O#K#J#M#M#G#J#L#K#O#N#K#J#M#K#K#L#L#K#I#K#K#L#P#M#I#L#O#N#L#K#L#L#L#O#J#G#L#K#K#M#O#O#N#L#J#K#O#L#I#K#J#J#O#O#N#N#P#K#L#P#P#L#N#3#L#L#P#O#Pa0aS#N#P#3#PaSa1#P#N#N#3#3a0a0aS#P#P#3aS#P#PaS#3#3#3#M#N#N#N#N#3#3#P#P#O#L#P#P#L#L#L#K#L#O#N#N#P#N#K#N#3#O#L#P#N#L#M"
"#P#P#Pa1#P#N#P#N#N#P#P#M#M#P#P#Pa1#3#N#P#3aS#3#N#3aS#3aS#P#O#3#3#3a1a0a0a0aS#P#3a0a1aSaS#3#3a1a0ababbwaSaSbwbwa0abbWbxa1bwbybwaTaTb#dwd9e.e#ea",
"ebdW#R#E#D#F#F#E#H#H#F#F#H#G#F#G#F#D#D#F#E#E#E#D#D#D#E#D#H#H#D#D#E#D#D#D#D#E#F#F#F#D#E#F#E#E#H#E#D#D#D#D#D#H#D#C#C#C#D#D#D#D#D#D#D#E#E#D#D#E#D#B#D#F#D#D#F#D#B#C#D#D#D#D#D#B#D#D#D#H#H#D#D#F#D#C#D#D#E#F#D#C#C#D#F#D#E#H#D#D#C#C#F#H#H#D#D#D#F#F#F#H#H#E#D#F#I#G#F#I#I#E#F#J#J#I#L#K#H#H#J#G#G#G#G#G#G#I#I#J#M#I#G#K#K#G#H#G#K#K#J#G#H#J#M#L#L#O#O#L#K#J#L#O#P#O#L#L#L#N#N#N#M#L#L#L#N#P#M#L#P#L#I#M#3#N#Pa1#M#K#N#P#N#O#N#M#M#N#N#OaS#3#M#O#P#L#K#J#M#O#N#L#G#J#M#N#L#M#P#O#K#I#J#L#P#M#J#J#K#M#M#N#M#K#J#I#J#M#L#I#K#L#G#G#L"
"#N#M#N#N#J#J#M#L#L#M#L#K#L#O#O#Na1#P#O#P#P#P#M#O#3#3#P#O#L#OaSa1aSa0a0aS#P#P#Pa1bxa0#3aSa0abbxbxbyababa0byaBbyabaBbya0bwbXaTbVbXbWb#dDecedeeef",
"egbv#R#D#D#D#D#D#D#D#D#D#D#D#D#E#D#C#C#D#D#D#D#D#C#B#C#D#C#C#B#B#B#B#B#C#C#D#D#D#D#D#F#E#D#D#D#C#B#B#B#D#D#D#C#C#D#D#D#E#E#D#B#B#D#D#D#C#E#D#D#E#F#F#E#F#E#D#D#F#F#D#D#H#F#E#F#F#F#E#E#E#E#D#D#E#E#H#H#F#D#D#H#G#G#F#H#F#D#E#F#F#I#G#F#F#H#G#G#G#G#G#F#F#F#F#H#H#F#F#E#F#G#G#H#F#G#F#C#F#G#F#D#H#G#G#H#G#G#G#G#H#H#G#E#E#G#I#I#G#F#D#H#K#K#G#G#G#H#F#F#F#I#L#K#G#I#J#K#M#L#M#K#G#H#G#I#J#G#G#H#H#G#J#J#G#I#M#H#D#J#K#H#G#I#J#I#G#L#M#I#G#G#J#J#G#I#I#J#J#J#H#H#L#N#M#I#J#J#G#G#G#G#L#L#I#G#K#L#M#M#O#L#G#G#G#I#K#J#J#J#G#I#K#K"
"#J#J#M#K#H#I#L#J#G#K#L#L#J#L#N#L#J#J#K#M#L#L#M#N#P#N#L#J#N#3aS#3#P#3#N#M#N#NaSa0a0#P#PaSa0a0abbxa1#P#P#3a1a0a0a0aS#3a0bxaba0abbw#3aTbHeceheiej",
"eka9b.#H#H#F#F#E#H#G#G#F#F#H#F#E#E#E#G#G#G#G#G#G#H#F#G#G#H#F#F#D#E#D#E#D#E#E#D#D#E#F#E#D#D#D#D#B#C#C#C#D#B#C#B#C#C#B#C#B#B#B#B#B#B#C#B#B#D#D#D#D#B#B#D#D#B#C#D#D#D#D#D#D#C#C#D#H#F#D#E#F#E#D#H#G#H#F#H#F#F#G#I#G#H#H#H#F#H#G#H#G#G#H#E#F#G#E#F#E#H#D#B#D#D#D#F#D#D#H#G#G#F#F#H#F#E#D#E#G#G#H#F#G#F#H#E#G#J#H#H#G#H#H#G#I#G#G#I#G#G#G#K#J#G#H#G#G#G#G#J#J#K#J#I#G#L#K#G#J#I#J#F#H#G#G#J#J#G#J#K#L#L#G#I#J#J#G#H#J#O#L#J#K#J#I#G#G#M#M#H#G#I#G#G#G#J#G#G#I#G#G#L#O#K#G#G#H#F#G#J#G#I#J#G#H#G#K#G#G#G#G#F#D#F#F#F#G#F#F#G#G#I#G#H"
"#G#G#F#E#E#G#I#H#G#G#G#G#H#I#L#I#H#I#I#G#G#L#K#J#J#J#J#J#N#P#L#K#L#K#K#L#O#O#P#P#O#M#P#P#M#N#O#P#L#L#O#O#P#P#O#Pa1a0a0#3#3a1#3#P#ObGdwecelemen",
"eo.N#l#B#B#B#B#B#C#B#B#B#B#B#B#B#B#C#D#B#B#B#B#B#B#B#D#C#B#B#C#B#B#B#B#B#B#B#B#B#C#D#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#C#B#B#B#B#B#B#B#B#C#E#D#B#B#B#B#B#C#D#F#C#B#E#E#C#C#D#D#D#D#D#C#D#E#D#C#D#D#B#E#D#D#D#C#D#D#E#H#F#D#D#E#F#D#E#F#E#F#G#D#E#G#E#E#F#F#F#E#E#F#G#J#H#H#G#F#F#G#I#K#J#G#J#L#I#G#J#J#L#K#K#K#J#L#L#I#G#I#G#I#L#J#J#I#K#I#K#L#L#K#G#K#L#L#I#I#J#J#L#L#I#M#L#K#L#L#L#M#I#G#L#P#O#K#K#L#I#Kdc#O#P#L#I#N#O#L#M#M#O#O#M#M#K#L#P#O#J#J#K#G#L#L#J#G#I#K#L#L#L#L#G#I#I#K#G#G#I#G#I#L#I#I#L#I#G#J#J"
"#J#I#F#G#L#M#L#G#J#G#G#J#L#M#L#G#K#N#L#K#L#M#N#M#M#M#L#P#P#L#J#M#J#K#N#M#M#L#N#P#3#3aS#P#O#3#P#3#N#P#3#3a0aba1ababa1a0a0abab#3#PabbZdXepeqemer",
"es.N#n#B#C#D#D#D#D#D#D#D#D#F#D#D#D#D#B#B#B#B#C#D#F#D#D#D#D#D#D#C#C#D#D#D#C#C#C#C#D#B#B#C#C#B#C#C#B#D#C#C#C#C#B#B#B#B#C#D#C#B#B#B#B#B#B#C#B#B#B#B#B#B#D#B#B#B#C#B#B#B#B#C#F#D#D#D#B#D#E#D#D#D#D#D#D#D#D#E#H#E#C#D#F#C#C#E#D#E#E#E#E#D#E#D#C#C#D#F#H#D#D#D#C#B#D#D#E#D#C#D#C#D#E#E#C#D#F#D#B#C#C#C#F#G#E#F#D#D#F#F#D#E#H#H#E#D#D#F#H#G#D#C#F#F#D#H#F#F#H#F#G#F#H#F#D#D#D#H#G#G#E#F#E#D#E#F#H#H#D#F#D#C#H#G#F#E#G#H#D#C#D#D#E#I#G#G#H#F#G#I#G#G#G#I#I#G#H#H#G#J#G#D#H#I#G#G#G#G#G#G#G#G#H#H#F#D#E#F#I#K#E#E#F#D#D#H#H#H#H#E#H#D#F"
"#I#G#H#H#I#G#E#H#H#F#I#K#K#I#G#H#J#J#G#G#J#J#I#G#G#I#K#O#G#G#L#M#I#L#N#O#N#O#N#O#P#O#L#L#L#Na1aS#M#P#N#M#P#P#PaS#P#P#P#NaSa0a1aSa0bNb2eteuevew",
"exdW#R#E#E#H#F#D#D#E#E#D#F#E#D#D#D#E#D#C#D#C#D#D#B#B#B#B#C#C#B#B#B#C#B#B#C#B#D#D#B#B#C#C#B#D#D#C#B#B#B#B#B#B#C#B#B#B#B#B#B#B#B#B#B#B#C#B#B#B#B#B#B#D#B#B#B#C#D#B#B#B#B#C#B#B#B#B#B#C#C#C#B#C#D#B#B#C#B#E#D#B#B#C#C#B#F#F#D#C#B#D#C#B#C#D#D#D#C#D#C#B#C#D#C#D#E#D#C#B#C#B#B#D#D#C#C#D#F#D#B#D#C#B#E#D#B#C#B#E#F#D#D#D#F#D#B#D#D#F#I#D#C#E#G#H#I#K#G#H#H#H#G#H#H#G#G#G#G#G#G#D#D#G#G#F#J#I#G#H#G#G#D#G#J#H#H#G#I#K#G#F#G#E#G#G#H#G#E#H#J#J#I#G#G#K#G#G#G#G#L#L#D#D#G#J#I#M#L#G#I#H#G#G#G#G#G#G#I#G#I#H#D#D#G#H#G#J#G#H#F#G#F#D#I"
"#G#H#G#G#J#I#F#G#G#H#K#I#G#G#H#L#M#M#L#J#M#O#J#K#K#N#3#M#G#K#N#M#Pa0#P#M#M#M#N#O#M#N#O#P#3#P#3#O#L#P#3#Pa0aba0aS#3aS#O#3bx#3#3aSa0b#bHeyezeAeB",
"eC.P#o#B#D#D#B#C#C#D#D#D#D#D#D#D#D#E#D#D#D#D#D#D#D#D#D#D#D#C#D#D#D#F#C#D#E#D#D#D#D#D#D#D#D#D#D#B#B#B#B#C#B#B#D#C#B#B#B#B#B#B#B#B#B#C#B#B#B#B#B#B#C#B#B#B#C#D#D#C#B#B#B#D#B#D#C#B#D#D#D#D#B#C#D#B#D#D#D#E#C#B#D#C#C#D#D#B#B#B#B#C#D#B#E#F#D#D#D#B#B#D#E#E#D#E#E#C#B#C#D#B#C#D#B#B#C#D#F#D#C#D#C#D#D#D#D#D#E#E#E#E#D#C#G#D#D#H#E#H#G#D#F#G#G#G#J#H#E#F#H#E#H#H#H#J#G#G#I#F#E#H#J#L#L#L#L#I#H#H#I#J#G#L#J#H#I#I#J#O#K#J#J#G#K#K#K#J#J#L#L#L#O#I#M#P#G#K#M#L#P#O#K#M#M#L#O#P#L#G#M#K#J#L#J#L#O#L#L#J#H#F#G#L#M#K#M#L#G#G#G#J#I#K#M"
"#I#G#K#J#L#M#J#J#I#J#L#K#L#L#L#M#M#N#K#K#3#O#M#P#O#PaS#O#O#3#N#Pa0aS#L#N#3#N#P#P#Pa0aSaSaS#P#O#NaSbxbxabbya0#3#Pa0bxa1byab#3a0ababbZdDeDeEeFeG",
"eH.N#n#B#B#B#C#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#C#B#B#B#B#B#B#C#B#C#B#B#B#B#C#B#B#B#B#B#B#B#B#B#B#B#B#C#D#D#D#D#D#D#D#D#C#C#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#B#D#C#B#B#B#B#D#C#B#C#B#B#B#B#B#B#B#C#C#B#B#B#D#B#B#B#D#D#B#B#B#B#B#C#D#B#C#B#B#B#C#C#B#C#C#B#C#C#D#B#B#C#B#B#C#C#C#C#D#B#D#G#E#E#D#B#E#G#D#D#F#D#E#D#D#D#D#D#H#E#C#C#H#G#E#E#G#G#G#F#D#E#D#D#I#G#H#I#G#D#H#G#G#K#I#G#G#J#I#J#G#F#I#F#H#K#I#G#J#I#G#M#L#K#K#G#E#O#L#F#K#I#I#I#G#I#J#G#J#M#G#E#H#M#K#G#G#J#K#J#E#E#E#D#G#J#G#I#I#H#D#H#F#G#J#G#H#G"
"#G#G#G#E#G#G#F#I#I#G#G#I#G#J#O#K#J#I#D#I#P#G#G#M#K#M#L#K#L#M#L#P#P#I#G#Na1#P#N#PaSaS#P#O#P#O#Na0a0a1aba0#3aSa0a0bybya0a0abbxbya0a0b#dweIeJeKeL",
"eM.N#R#D#B#C#D#B#C#C#B#B#D#D#B#B#B#B#B#B#B#B#B#C#C#C#D#C#C#D#C#C#D#C#C#D#D#D#D#D#D#C#B#C#D#B#B#B#C#B#B#C#Ga0bjbZeNeOePeQeNa2bX#3#F#D#D#C#B#C#C#C#C#D#D#C#C#C#C#C#C#C#C#C#D#D#F#H#D#D#E#D#D#E#D#E#H#F#F#D#F#E#D#D#G#H#C#D#F#F#D#D#F#F#D#D#D#D#D#D#H#E#D#F#E#B#D#H#E#E#E#E#E#G#G#F#E#E#H#F#D#F#F#H#H#I#G#K#G#F#G#G#H#I#I#I#L#J#K#K#I#K#I#G#I#L#I#H#I#L#J#G#J#M#L#I#I#G#G#J#K#M#K#K#M#I#G#M#O#L#L#L#L#M#P#N#L#J#L#L#K#K#L#M#L#M#L#N#P#L#L#O#K#L#O#L#O#P#M#O#L#L#L#J#J#O#O#H#G#L#L#I#J#K#L#I#J#G#G#I#I#L#K#G#J#G#F#G#L#K#I#I#G#I#L"
"#L#I#F#G#I#G#G#G#I#J#I#L#L#P#M#I#L#L#J#M#M#L#P#P#O#N#N#N#M#L#3a0#N#I#Oa1#P#P#Pa1a1#3a1#PaSa1a0bya1abbyaS#3bwaBbybwbwbxbwaTbVbwbybwbZeReSeTeUeV",
"eW.P#o#D#B#D#E#B#D#E#C#B#D#C#B#C#D#C#C#C#D#D#C#C#D#E#D#C#D#D#D#D#E#D#E#D#C#D#D#C#D#D#B#C#D#B#B#C#Fa0eQeXeYeZe0eYe1e1e2e2e2eYeZe0e2e3b0#N#I#E#D#D#E#D#D#D#D#E#E#D#D#E#E#D#E#H#H#E#C#F#F#E#H#G#G#I#G#H#G#H#G#G#G#G#I#G#G#G#G#F#G#G#I#G#H#G#G#F#G#H#G#G#H#F#F#E#G#G#F#H#G#H#H#I#G#H#H#G#G#G#G#G#I#G#G#K#L#J#H#H#G#G#I#J#I#J#J#H#G#I#G#J#K#I#I#K#G#I#J#G#H#G#K#J#G#G#J#H#H#I#K#L#I#G#G#H#G#L#J#G#G#J#I#L#L#Ie4#J#L#G#J#J#J#J#J#L#M#M#K#H#L#M#L#M#M#L#O#L#K#L#L#L#N#L#L#M#L#I#L#K#I#I#L#O#K#J#L#K#I#J#L#L#M#K#J#I#G#K#O#G#G#K#J#L#L"
"#K#I#G#K#K#I#J#J#J#I#J#M#M#M#I#I#L#K#L#O#M#N#O#L#M#N#M#N#3#M#NaS#O#N#3#N#N#Na1a1#P#3a1#P#PaSa1a0a0a1a1#PaSbwbxa1bybybxbwbwbybybyaBb#dweSe5e6e7",
"e8bv#R#C#D#E#D#B#D#C#B#C#B#B#B#C#C#C#C#D#D#E#D#E#E#C#C#C#D#D#D#D#D#C#C#C#B#B#C#D#D#C#B#C#D#HbyeNe9e9f.b#a0#I#D#Q#A#A#2#2f##Q#D#KabbYfae9e2bY#N#D#D#D#C#D#C#D#D#D#D#E#D#D#E#D#C#B#B#E#E#C#D#D#C#D#D#D#D#F#H#G#D#D#G#H#E#D#F#H#D#D#E#D#D#E#D#C#E#H#H#H#E#E#E#E#H#F#D#F#H#E#F#E#C#D#D#E#E#D#D#G#G#E#F#H#E#D#D#E#G#E#D#D#D#D#D#D#D#D#H#G#H#D#H#I#F#D#E#H#H#F#G#H#F#G#H#E#F#G#J#L#I#I#J#I#K#L#H#G#L#J#L#L#G#I#I#K#M#L#L#O#P#O#M#N#N#L#J#J#N#O#K#I#I#G#J#L#J#J#L#O#P#J#I#M#L#J#G#J#L#J#J#L#J#J#L#G#G#K#O#O#L#L#L#L#J#L#K#F#J#L#J#L#J"
"#G#G#I#J#K#I#J#L#L#K#K#M#J#I#H#L#O#K#J#K#I#I#L#L#L#O#P#P#P#J#Ma1#P#O#N#P#P#O#3aS#P#P#3#P#3a1bxaba0a0a0a0a0bx#P#Pa0a0abbxa1aSa0a0bxbzfbfcfdfeff",
"fgbg#R#E#F#F#D#D#E#F#F#E#D#D#D#E#D#D#D#D#E#D#C#E#D#B#B#C#C#B#D#C#B#C#D#H#C#B#C#C#B#B#B#EbYdXe9f.bxfhc6#o#m#k#m#m#k#m#k#k#k#k#k#k#m#oc6#Bbwfie9fia1#C#B#B#C#B#C#D#E#E#C#D#F#D#C#D#D#E#E#D#D#B#D#H#H#D#D#H#F#F#D#D#I#E#D#D#G#H#E#H#H#D#D#H#E#E#F#F#E#D#D#D#E#D#H#D#D#F#H#F#E#D#D#D#E#E#D#D#F#G#H#E#Gdb#F#D#E#F#F#F#E#D#D#E#I#H#D#F#G#H#E#D#J#K#F#D#H#J#H#G#I#G#E#G#G#G#G#I#G#G#H#H#G#G#J#I#F#I#J#L#L#K#G#G#J#K#L#J#L#N#P#L#L#N#O#M#L#L#O#L#O#K#J#J#M#P#K#K#P#N#M#L#Oa1#P#L#K#P#P#M#O#N#L#J#O#L#L#M#O#K#I#J#I#J#K#M#I#G#L#L#L#K#J"
"#G#I#J#L#L#L#L#P#N#L#N#N#M#L#L#L#L#L#O#L#J#La1#P#L#Na1#P#O#La1ab#P#O#Pa0#3#3a0a1#Pa1a1a0a0bxbxa0aSa1aSa0bwbyaSa0bybwbwbwaba0bxbybwbYdXfcfjfkfl",
"fmdW#R#E#E#F#F#F#E#F#F#E#E#E#E#F#E#E#F#D#D#D#B#D#C#C#C#D#B#D#F#D#B#E#H#F#D#D#D#C#B#Hbxe2e0a2#E#R#n#m#n#o#o#n#R#R#o#R#o#o#o#o#o#n#o#o#l#l#nb.#Ib0fnfo#J#E#D#C#D#F#E#D#C#F#H#E#D#F#E#F#G#H#E#F#K#K#J#H#H#G#H#H#I#G#G#G#G#G#K#I#G#J#I#H#G#J#G#G#G#H#E#E#G#E#H#H#G#H#H#H#G#G#H#G#F#H#G#F#E#G#G#G#F#H#I#G#G#G#G#G#I#K#G#H#K#M#O#J#I#J#J#J#K#M#L#J#K#L#L#M#L#M#N#L#K#O#N#O#M#M#M#K#L#L#L#M#O#O#O#N#O#P#M#N#M#M#N#P#O#MaSaS#N#M#P#P#P#P#P#P#P#3a1#P#Na0a0a1#P#P#3#N#Na1a0aS#3#3#3a0aS#3a1a1#P#NaS#3#P#P#3#M#M#N#M#O#P#P#O#N#P#P#P#O#O"
"#M#O#P#P#OaSaS#3#P#PaS#P#N#P#3#N#NaS#P#LaSabbxa0aSa1a0#PaSa0a0aS#3a1a0aba0abbwa0a1bxbyabbybwbxa1ababa0abbwbwbwaBaBbVbwaBbwbwaBbwbwa2fpfqfjfrfs",
"ftbv#n#B#B#C#B#B#B#C#C#C#B#D#C#C#C#C#E#C#B#B#C#C#B#B#C#C#C#D#C#B#B#F#D#C#D#D#B#C#Kfufva2#C#l#m#o#R#R#Rb.#R#o#R#R#R#R#R#R#Rb.#R#Rb.b.#ob.b.b.#n#n#EeNfwbY#I#D#F#G#D#D#E#F#E#D#E#H#F#I#G#E#F#I#L#I#I#G#H#G#G#I#I#G#K#L#J#G#I#J#G#J#I#G#J#K#I#G#K#I#G#K#J#G#G#I#J#G#I#I#K#K#J#J#L#L#J#I#J#O#L#J#J#L#Lfx#J#L#L#L#P#M#L#K#P#P#M#M#L#J#L#O#N#O#L#N#P#L#L#O#L#O#O#L#M#P#P#N#PaS#P#Pa0aS#P#3aS#3#P#Pa1a1aSa1a1a0aSaS#3a0ab#3#PaSa0a1aSaSa0a0bybxa1aSa0bwaba0a0aSaSa0a0a0a0a0bxa0#3a0aba1a0a0a1a0a0aSa1aba0aSa0abaSaSaSa0a1a1a0a0a0a0a0"
"a0a0a0aSa1bybxa0a1abbxaba0a0bxbxaBbwa0a0aBaBabbybya0bxbxbwbwabbwbwaba0bybwbybwbxbyaBbwbyaBaTbwbyaTaTaBbWaTaTbVbVaTbXaTbXbUbGbUbUbVb0fyfzfAfBfC",
"fDfEc5#G#I#I#H#H#F#H#G#G#G#I#H#G#G#G#K#H#H#G#F#H#H#F#G#G#G#G#F#G#G#G#G#F#H#F#FbUfFdX#K#ob.#Af#f#f##2bqc6c5c6c6c7c6c6c6c6c6c7c6c6c7bqc7c6c6c7bqc6#n#o#PfGe3#3#J#G#F#H#G#H#H#G#G#J#I#J#H#G#J#J#J#I#G#I#H#G#J#G#G#I#K#K#G#G#I#I#G#I#G#H#G#G#G#G#I#G#G#I#H#E#F#G#G#H#F#F#G#G#G#G#I#G#F#H#I#J#H#G#I#G#H#G#H#I#K#J#G#H#I#J#J#K#H#I#I#E#K#I#G#G#J#L#J#H#G#J#G#G#G#E#I#I#I#G#I#J#G#J#J#G#G#J#M#K#I#I#I#L#M#K#K#M#J#J#L#N#O#J#L#M#L#L#K#L#O#M#M#G#J#N#O#O#L#L#M#K#L#P#L#K#L#P#P#L#J#N#P#L#O#K#K#M#N#M#L#O#L#L#N#L#K#K#N#N#M#L#L#O#P#N#M"
"#P#O#L#L#NaS#P#N#P#P#P#P#M#Pa0#3#P#O#3a0a0a1#Pa1a1#Pa0abaSaSa0byabaSa1aba0a0a0aSa0bybxabbxbwbxbybwbxa0bwaTaBbwbwbwbVaTbWaBaTbyaBaBb0eYfHfIfJfK",
"fLfMf##L#O#M#L#J#I#L#L#I#I#I#G#I#J#J#K#G#G#G#G#G#I#G#G#I#G#H#G#I#G#H#G#G#G#IfNfOb0f#b.fP#D#E#E#H#F#E#Efhf#bqbqbqc7c7bqbqbqbqc7bqbqbqbqc7bqc7fQbqbqc6#l#2b1fRaB#B#C#C#D#D#E#D#D#H#D#D#D#G#G#F#F#H#H#G#E#H#G#D#G#G#G#F#D#E#G#E#D#D#D#D#D#E#D#C#C#D#C#C#D#D#D#E#H#E#C#B#F#F#D#D#C#B#B#D#F#D#B#D#D#D#F#E#C#F#F#D#D#E#G#H#E#F#F#G#G#E#I#F#D#G#H#F#D#D#H#G#E#E#D#E#F#F#H#D#C#D#E#E#D#F#D#H#I#G#H#C#F#I#H#E#F#F#D#H#G#I#H#D#F#F#H#G#E#E#G#H#E#F#K#K#G#G#G#I#K#H#I#J#E#I#K#I#G#E#G#L#J#H#G#H#G#G#I#I#H#H#G#G#G#G#I#G#M#M#L#G#H#L#L#G#G"
"#I#H#H#I#K#L#G#G#J#J#L#K#G#L#M#I#J#L#P#P#O#N#P#P#P#Oa1#N#MaSaS#3#P#Pa1a0#3#3#P#Pa1aSa0#3#P#3aS#3#3a1a1a0bwbwab#Pa1bwaba1a0a1#Pa0bya2fSfTfUfVfW",
"fXfY#A#I#J#J#I#G#I#K#I#G#G#G#I#I#I#L#I#G#I#J#J#G#H#G#K#G#G#I#I#G#H#F#G#G#PfGfZaTc5aa#J#Ff#c5#o#n#l#R#2#E#G#C#2#A#2#2#2#2#2#2f##2#2f##2#2#2f#f##A#2#2#2c7c5bGf0b0#E#H#G#G#H#F#I#J#H#H#I#I#G#H#G#G#I#G#H#G#H#G#L#M#J#G#G#G#I#F#G#G#G#H#H#H#G#E#E#G#F#F#I#I#G#G#I#H#H#G#J#H#E#H#F#E#H#G#G#I#H#G#G#I#I#H#G#M#K#G#J#K#I#G#G#I#I#I#G#G#G#H#G#M#K#G#F#H#J#G#F#I#K#I#J#J#L#K#G#L#K#G#K#P#M#L#N#O#J#I#O#M#G#G#I#I#K#L#L#O#L#L#M#N#N#M#L#P#3#M#M#P#P#O#M#O#N#P#O#L#M#L#L#P#3#M#K#L#M#N#L#L#M#O#L#L#L#O#L#L#O#L#L#PaS#N#PaS#N#L#NaS#N#K#M"
"#O#O#P#N#P#3#M#P#3aSaS#N#Pa1#3#N#3aS#3#N#P#3a0a1#N#Pa1#PaSbya0aSaSa1a0a0aSa0bxa0a0a0bxbxa0bxbyf1bybVbVbwbWbWbxbxbWbVbxabbwbyaBbWbVb1eYfTf2f3f4",
"f5f6#R#D#G#G#D#F#H#D#D#D#D#E#G#G#E#G#D#C#E#E#D#D#D#D#E#D#D#E#D#C#D#D#C#Ne0fRaS#o#Q#JfP#l#m#k#m#m#m#k#m#m#2#I#Eaa#2#2#2f#f#f#f#f##2#2f#f#aaaaaa#2f##2f#aa#Ab.aBf7fN#F#D#D#D#D#E#E#D#E#F#E#D#E#E#D#D#C#D#C#E#F#D#D#D#D#F#E#D#D#G#G#F#F#H#G#G#F#E#G#F#G#G#H#D#G#H#D#F#G#F#D#D#H#H#G#G#F#G#H#F#G#I#G#H#G#I#I#I#I#K#G#G#G#G#G#I#H#F#H#H#G#I#G#G#H#H#G#G#G#I#L#O#J#J#L#M#O#J#K#M#L#O#N#K#K#P#L#J#O#P#L#I#K#K#M#P#O#O#P#L#L#P#P#L#L#P#P#P#N#P#3#P#N#PaS#P#P#M#M#M#N#P#N#P#N#M#P#N#O#M#PaS#P#O#P#3aS#P#O#P#P#Pa1#3#NaSa0#M#Pa0aS#N#N#P"
"#PaSa1#3aS#3#PaSa1#P#O#Pa1a1#3#Pa0aS#P#Pa1#3a1#3#M#N#Pa1a1aSa0#P#PaS#P#N#PabbxaSaSa0bxbwa1a0abbxbwbwaba0aBaba1bwbWbxaSa0bybwbVbWbWf8f9g.g#gagb",
"gcdW#R#D#D#C#B#C#C#C#B#D#D#C#D#D#D#B#B#B#C#C#C#D#D#D#D#D#D#E#D#B#D#D#Me0fR#3b.#C#Of##k#l#l#n#n#l#l#n#l#k#kbq#I#Gaaf#fPfPaaaaaaf#fPfh#B#Bfh#Qfhfhfh#Qaaf#aa#2c5byfFeQ#C#B#E#D#B#D#D#D#D#C#D#D#E#D#D#C#F#H#I#G#D#E#D#F#H#F#F#E#H#E#C#B#D#E#D#C#D#H#E#D#D#B#B#B#D#D#C#D#B#D#F#F#D#E#F#F#F#C#C#D#D#C#H#G#E#F#H#F#H#E#D#D#F#F#E#D#E#H#G#J#D#D#D#D#H#F#H#H#G#G#E#D#E#G#I#H#E#I#K#G#G#G#H#G#G#G#G#G#H#G#J#L#J#K#M#M#L#K#G#K#L#J#L#N#N#L#M#O#N#N#L#O#N#P#M#M#L#N#N#3#P#K#M#M#N#O#O#P#O#P#P#K#J#L#O#O#L#L#P#P#O#N#L#M#O#N#O#O#O#O#O#N#P"
"#N#P#P#P#P#M#O#N#N#M#O#3#P#P#3aSa1aS#P#3#3#3aS#N#Pa0a0bwa0a1a0a0ababbxababbwbxa0a0bxbyaba0byaBbwbxbwabbybwbwbwbwbybyaBbVaBbWbXbXaTbZdKg.gdgegf",
"ggbpbq#I#G#J#J#I#G#I#J#I#I#J#L#G#G#G#G#G#H#H#G#G#F#F#G#H#D#E#E#D#D#Le1fFbV#A#C#M#D#o#Rb.#R#o#n#o#o#n#o#o#n#nfP#L#G#B#C#C#B#Q#B#H#J#H#Bf#bqc7#Af#fh#E#H#Efh#BfP#2bNgheN#H#D#D#D#G#F#E#H#E#D#F#G#G#H#G#J#G#G#F#F#H#G#G#H#I#I#H#G#G#H#F#F#H#F#F#G#G#F#D#H#F#G#F#G#G#F#F#F#G#G#H#H#G#H#D#E#H#G#G#G#G#I#G#G#I#K#G#I#I#G#G#G#G#G#G#L#K#K#L#G#L#L#L#L#K#L#K#I#L#I#G#I#K#J#G#I#L#J#G#G#J#K#J#J#L#K#G#Ggi#L#L#M#M#N#L#G#G#L#L#I#L#O#L#J#L#M#L#K#L#K#J#L#O#O#M#O#N#O#P#L#L#O#O#O#L#P#P#M#O#N#M#M#N#N#M#O#P#P#N#O#P#N#P#O#P#P#N#O#N#P#P#3"
"#PaS#P#O#M#OaS#P#N#3#3#3#Pa1a1#3aS#3#N#N#3aS#P#Pa1a1a1a0#Pa1a0a0a0a0byaba0aba0a0a0abbxa0abaBbybxa0abbybwbybwgjabbxbwbWbWbWbVaTbWbwb#dXgkglgmgn",
"gobpbq#G#G#I#G#H#H#G#G#H#H#G#G#H#H#H#I#G#F#H#F#H#H#F#H#G#F#D#D#D#KfGghb0fP#C#K#I#A#R#R#o#R#o#n#n#o#n#n#n#n#nc5#C#K#E#B#B#B#D#K#Kfhb.#m#k#k#k#l#k#mb.#Q#J#H#B#CfhfPfNfZbz#B#C#C#E#D#D#D#B#D#G#H#E#G#G#D#B#C#C#D#D#F#D#D#C#D#B#B#D#E#D#D#E#F#E#D#B#B#D#F#F#C#C#F#E#C#D#F#F#D#C#E#F#D#B#C#F#E#C#B#D#E#F#F#H#G#H#F#D#D#I#I#H#G#K#I#E#E#F#H#G#G#G#G#H#H#E#D#H#G#I#H#G#I#J#I#G#H#G#L#N#K#I#K#O#J#G#L#L#L#I#L#O#L#J#I#L#P#N#K#L#O#N#P#N#3aS#P#P#P#Pa0a0aSa0a0aS#N#P#P#P#P#3#P#P#P#P#O#N#3aS#3#P#P#3#3#P#O#O#Pa1a1#3#PaSaS#N#3aSgpgq#P"
"a1a0#P#3#Pabbxa1#Pa1a1abababbybybxa0a0bwaBbwbwaBbwabbxbybybwbWbwbwaBbwbwbybwbWbVbwbWaTaTbVbwbwaBaTaTaTbVbWbXaTbWbVbUbGaBbVbGaTbVbwb0grgsgtgugv",
"gwd2c6#G#G#G#G#H#H#G#F#E#E#G#F#F#G#G#K#H#H#F#G#J#I#G#H#H#F#H#F#HeQghdX#J#Q#K#L#Cc7b.c6c5b.b.b.b.b.c5c5c5c5#Rc6aa#G#L#F#E#G#M#Kf##m#l#n#n#l#o#o#l#l#n#R#Q#O#M#G#FfP#Ke9fObw#G#F#H#F#D#H#H#G#G#D#G#I#D#D#F#H#H#H#G#F#F#G#D#F#D#H#G#H#H#H#G#G#F#F#H#H#I#G#F#F#D#F#F#D#F#H#G#D#D#I#G#H#G#L#L#H#F#H#I#K#K#I#G#I#G#G#I#J#L#I#G#M#J#G#I#J#J#K#L#M#J#J#I#G#I#J#L#L#L#I#L#M#L#K#I#J#M#M#K#K#I#I#M#I#G#J#K#I#H#J#M#J#L#M#N#M#G#J#M#P#P#N#O#N#M#L#P#N#P#P#M#P#3#O#M#O#N#P#N#P#N#O#N#J#M#M#N#P#N#N#O#P#P#N#N#O#NaS#3#N#N#O#P#3#M#P#3#3#M#L"
"aS#P#Pa1a0ab#P#P#3a1bxbxa0a0aba0a1ababbya0aSbwbxa0abbxbybybwbwabbxaba0a0bxbwbwbwbybwbWbWbwbwbwaBbVbwbwaBaBbVbwbybWbVaBabbwbXbWaTbUfNgrgsgxgygz",
"gAd2c7#G#G#L#G#G#I#K#G#H#I#J#J#L#K#G#H#G#G#G#G#G#H#H#F#H#F#F#FbVghgBbW#Q#G#M#G#Qbqc5c6c6c6c5c5c5c7c7c6c7c5#ob.c5aa#K#I#J#N#Mfhb.#nb.b.#o#ob.b.#R#Rc5b.c6#F#N#M#H#H#EbNghfn#M#F#G#H#F#G#G#G#E#D#F#F#D#G#H#H#H#H#H#F#E#E#E#E#G#G#F#G#G#F#H#F#F#E#D#F#F#D#F#D#D#G#F#D#H#G#H#E#H#G#G#L#J#G#F#F#G#J#G#I#G#I#G#I#I#J#J#K#J#G#G#I#H#G#K#G#I#J#K#J#J#I#I#J#M#O#L#M#P#L#M#L#L#L#L#L#O#L#K#M#K#L#N#J#L#O#O#L#K#N#N#N#3#N#M#I#L#N#N#N#L#M#L#O#O#L#N#N#P#M#K#M#M#L#N#N#O#N#P#N#O#M#O#O#OaSaS#Pa1aS#P#3#P#N#P#O#PaS#N#N#N#Oa1#P#MaSa1aS#N#3"
"a0a1ababa1#3#OaSa1a1aS#3#P#PaS#3aSaba0a0#P#3aS#3aSa0aSa0a0a0a0a0a0a0a0abbwbybxbwababbyababa0a0bybyabbya0byaBa0a0bwaBbyabaBbWbWbGbVbZdKgCgDgEgF",
"gGa9c6#H#H#G#F#H#G#H#E#E#H#G#G#I#E#D#D#E#F#C#D#E#D#D#D#H#D#B#LgHf0f.#G#F#K#L#D#2#2c6c5c5c5c5c5c5c5c5c5#Rb.#IbXbj#P#I#J#M#IfPc7#R#o#R#o#o#o#o#o#o#o#o#R#R#2#E#O#K#I#E#KfafZfu#E#D#D#C#C#D#C#C#C#D#D#D#C#D#E#F#E#E#F#D#D#F#D#F#B#B#D#B#B#B#B#B#B#B#B#C#B#B#B#C#E#C#D#E#D#C#B#D#F#F#H#D#D#D#E#G#D#F#H#F#H#H#G#H#E#E#H#F#F#H#G#I#H#H#H#G#H#G#G#G#F#G#G#J#J#H#I#I#F#F#D#H#G#G#G#J#K#I#G#G#K#J#I#J#I#I#F#F#J#J#O#L#G#G#K#O#K#I#L#L#K#L#M#O#J#L#M#K#I#K#K#M#L#L#M#O#O#M#O#N#L#L#O#L#P#L#K#M#K#G#H#G#J#J#I#L#L#K#J#J#J#O#J#L#O#L#K#G#K"
"#M#O#P#L#I#J#L#N#I#K#M#J#M#M#N#N#K#M#N#K#L#M#P#3#N#P#P#3#3#PaS#3#P#3aSa0a0#Pa1a1#N#N#L#O#P#N#3aSa1#3aS#3a0a0aSababa0#3#PbxbyaBaBa0bjeXgIgJgKgL",
"gMbg#R#D#F#F#F#H#E#E#F#E#G#G#F#F#D#E#H#E#D#E#G#G#F#E#D#D#D#EfoghgHbU#H#O#N#L#Cf#f##2#Abqbqbqbqbqbqc7c6bqaSbGbxf8eYb0aS#L#B#2c5b.b.c5c5c5c5b.b.c5c5c6c5c6#2fh#K#3#L#K#GbYfZghbj#D#H#E#E#G#D#D#F#H#G#E#D#D#D#D#E#E#D#C#D#C#C#D#C#C#D#C#D#D#D#D#D#D#D#C#C#C#C#D#F#D#D#E#D#D#D#F#G#F#E#D#H#G#D#D#E#J#I#H#G#F#F#F#E#H#H#D#F#G#G#G#E#H#FgN#G#G#F#F#E#E#F#H#E#D#H#D#E#F#H#I#G#G#I#G#H#F#E#G#I#G#I#J#G#G#G#G#L#K#G#G#G#K#K#I#G#L#P#L#L#J#K#K#G#J#L#I#G#L#N#N#L#J#L#K#K#M#O#M#K#K#K#K#L#I#K#I#H#J#K#L#L#L#L#K#G#I#G#I#L#O#L#L#O#I#K#I#M"
"#P#O#M#K#L#P#O#K#LaSaS#O#P#O#N#N#M#P#3#M#Na1a0a0#PaSa1#3aSa0a0aS#P#P#PaS#P#N#3#N#O#PaSaS#3#3a1#P#P#N#M#3a0a0a0a0a1#P#3#3bwbxa0a1#3bNgOgPgQgRgS",
"gTgU#A#G#J#I#I#I#G#I#J#J#M#M#J#M#L#K#J#G#I#J#J#I#G#I#G#I#HbVgVgVe1#3#M#3#3#L#Daaf#aaf#aaf##2#A#2#2#2c6#ObZ#Naa#CfifFa2aBeOf.bwf#c6c7c7c7bqc7bqbq#A#2#A#AfP#Q#F#P#3#3#Lbye0fOgH#L#F#D#E#G#G#H#G#G#G#H#H#G#G#G#F#H#G#H#D#D#G#E#D#F#F#E#H#H#H#E#H#H#H#D#E#D#D#F#F#F#F#E#E#H#H#G#G#F#H#G#G#H#H#G#K#K#G#H#H#H#H#F#E#G#G#H#G#G#I#G#F#I#G#G#I#H#H#G#H#E#G#G#F#F#H#H#K#K#G#H#H#G#J#I#G#I#G#J#J#I#G#K#G#L#L#L#P#L#J#M#M#L#K#L#O#P#N#L#O#M#O#M#K#L#P#N#M#N#N#P#O#O#N#M#O#M#L#M#L#L#L#O#M#L#M#O#O#3#P#L#M#N#N#P#O#O#M#M#N#O#O#M#M#L#P#N#P"
"aS#M#N#3#N#M#L#NaS#P#N#L#P#N#P#O#L#PaS#N#P#3aSaS#Oa1#P#PaS#P#P#P#P#M#N#3#L#O#P#PaSa0#P#P#NaSa1a0aS#3#PaSa1aSa1a1#Pa1aba0aBbxaSbxbyb#fogPgWgXgY",
"gZgU#A#K#K#K#J#I#J#J#G#G#K#I#G#L#K#G#G#G#I#G#H#H#H#G#H#F#JfnfOfOeO#K#Pa1#3#L#Cf#f#f#f#aaaa#2#Af#f##2bqbVg0b#bGbVfighfGg1a2fNfnaBc6bq#Abq#A#Abqbqbq#2#2f#f#f##B#Ma1#3#M#Mfughf0b0#C#D#D#F#D#B#C#D#C#B#D#C#B#B#B#D#E#E#B#C#F#C#B#D#D#B#C#B#B#C#B#B#C#B#B#B#C#C#C#B#B#B#D#B#B#B#B#B#C#D#B#B#B#C#B#B#B#B#B#B#B#B#B#D#D#C#B#C#D#B#B#D#B#C#B#B#D#F#C#B#E#E#B#D#F#Dg2#F#B#C#E#D#E#F#D#D#G#G#H#D#D#E#H#G#C#D#H#D#H#J#G#D#E#I#G#F#E#D#H#H#F#H#D#G#J#J#F#H#J#G#E#G#G#H#G#F#G#J#I#E#G#L#I#G#K#J#J#M#I#E#G#J#G#L#J#G#K#L#L#K#G#J#K#M#L#G#L"
"#L#J#N#P#L#I#O#P#L#K#J#L#O#M#O#L#L#P#3#O#M#P#P#M#O#3#N#P#P#Og3a0#3#Na0ab#P#3a0aSa1a0#O#NaSaSaSa0#3#Pa0a0aba1#3a0a0by#P#3bxa1a1bwa0bXg4g5g6g7g8",
"g9dWc7#G#F#H#F#E#F#E#D#F#H#E#H#G#E#D#E#F#D#D#D#D#F#E#D#FbYghfOf7b##Ma0a0a0#M#CaaaafPaaaaaaaaf#aaaa#2#AaTgHfRe9e9f7f0fRfo#Pa0f7f.aa#Aaaf#aaf##2#2f#fPaafPfPaa#C#Oaba1aS#Nf8f0fOf0a1#G#G#I#F#D#H#G#D#E#G#D#D#G#G#H#G#G#C#F#G#E#F#G#E#D#D#C#D#H#E#F#H#D#D#F#H#D#D#C#D#E#D#B#E#G#F#F#G#H#E#D#E#D#D#D#D#E#F#D#F#H#H#G#G#D#D#G#H#D#H#D#D#D#G#H#F#G#F#D#H#H#E#G#I#Fh.#E#E#G#G#G#I#I#D#H#J#G#G#H#F#G#G#D#D#J#J#G#K#K#I#G#I#I#E#E#H#G#J#J#I#K#K#J#L#I#D#G#L#G#J#K#G#H#K#L#K#L#M#G#I#M#K#K#M#M#K#K#J#L#O#M#M#P#L#I#N#P#M#O#K#L#O#L#G#L#P"
"#N#N#3#P#N#M#P#L#I#L#O#N#3#P#Pa1aSaSa1#O#La1aS#PaS#P#O#Pa0a0aSaba1#Pababa1bxbya0a1#3#Pabbxa0bxbx#3#3bwababa0#3a0a0#3#Pbxbwabbwbwa0bzbHg5h#hahb",
"hcdW#A#G#F#G#E#F#D#E#H#I#G#H#H#E#D#D#D#D#D#D#D#E#E#F#D#HfwghghfnaTa1byabbx#O#Daaaa#Qaaf#aaf##2aaaaf##A#3e0ghghghghfFeXfwfvfvfZeNf##Aaaaaf#aaaafP#QfPaafPf#fP#D#Obxbxbxa1bGfvgVfOg0#H#H#F#D#F#G#F#F#H#H#E#H#K#G#F#G#H#C#D#G#H#H#H#C#D#H#D#D#E#G#G#H#E#D#I#G#E#F#D#E#E#D#E#I#I#G#G#F#E#G#F#F#H#F#H#I#G#G#G#G#I#G#G#G#F#K#J#G#J#J#I#G#L#M#J#G#K#I#H#J#J#J#M#L#H#K#K#I#J#M#P#N#M#J#L#O#L#L#L#L#L#J#I#M#P#O#L#Mhd#K#L#L#L#L#L#O#M#O#N#O#O#L#L#L#J#L#O#L#J#O#O#K#M#3#P#L#M#O#J#J#N#M#O#N#K#J#N#M#M#O#3a1aS#N#NaS#3#N#P#N#P#O#L#MaSaS"
"#3#P#O#O#N#O#O#O#O#Pa0aSa0a1#3a1aSaS#3#P#3a1#P#3a0#3#Pa1byaS#Pa1aS#NaSa1aSaba0#NaSa0a1a0bxbwbwbxa0bybWbxbwbybxbya0a0bwaTaBaBbwbxabb#gOheh#hfhg",
"hhd2bq#G#G#G#F#G#G#H#J#G#F#H#G#H#G#H#E#E#E#D#F#G#E#E#CbjfZf0fZeZaBabbwbybw#P#F#QfPfPfPfP#QfPaafPfPfP#2fhb#gHfZfZfZfobXeOgHgBe3#3#2fPfP#Q#QfPfhfh#QfP#Q#QfPfh#HaSaBaBbwbwbXfngVghf0#O#F#E#E#G#F#E#F#F#E#D#H#G#E#C#D#D#E#D#H#H#H#D#B#E#G#D#C#E#H#Dhi#C#C#E#D#F#F#D#F#F#F#I#H#D#F#F#D#D#E#D#D#D#D#H#I#H#F#E#E#H#E#E#E#F#G#H#F#H#H#E#F#J#G#E#E#F#G#H#H#J#I#G#H#F#L#J#H#I#M#L#G#G#G#J#K#K#O#L#L#O#J#N#3#L#L#O#M#L#M#O#M#O#O#O#3#P#N#O#J#L#K#L#K#L#O#M#L#L#L#L#K#M#P#L#J#I#J#L#Jhj#P#O#L#G#L#P#L#J#M#N#M#L#L#L#P#M#P#P#O#P#P#Pa0aS#O"
"#P#P#P#N#P#P#P#3#PaSbxaSa1#P#PaS#3#P#Pa1a1#3#PaS#3#3#Pa0a0#P#N#PaS#3#Pa0aba0#P#PababaSa1bxabaS#3#Pa0a0a0bwa0bxbwbybwaTbwbxbwbwbxbxb#gOhehkhlhm",
"hnbpbq#I#L#L#J#L#J#I#K#I#J#L#J#G#G#G#G#H#E#H#J#G#F#H#He9fOghgheYbWaBaTbVbVab#K#C#QfhfhfPfPfhfP#Qfhfh#Qaa#DaBeNePb#bxbxa0bWaB#LfPfh#B#Qfh#Bfh#B#B#Q#B#B#C#C#E#MbwaTaTbXbUaTeZhogVhpfN#G#I#K#J#J#J#J#K#K#K#L#K#J#J#G#J#L#H#K#L#G#H#G#K#G#F#G#G#G#FhqaQ#G#I#H#L#K#G#K#K#I#L#J#K#L#K#K#K#K#K#G#G#J#O#M#K#L#I#L#L#K#J#K#L#J#L#K#J#L#K#L#M#L#L#K#K#O#L#K#P#O#K#K#L#O#K#K#L#L#K#K#L#L#L#L#OaS#O#N#3#O#P#3#O#3aS#3#3hr#3#P#N#Na1a0aSaSaS#Pa1aS#P#PaSa1aSa0a1a1a1a1a0a0a0a0#3a0abaSa0bwa1#PaSa0aS#P#P#3#P#PaSaS#3aS#3aba0#Pa0a0aSa0a0aS"
"a0a0a1a1a1aS#3#3a1bxbxa1a0aSa1bya0a1a0aba0a0aba0aba0abbxa0a0a0aSbxaba1aBbwa1aSa0bya1a1a0a0a0a1a0a0a0a0bxaBbxbyaBbwbwbWbwaBbVaBaBaBa2eXhshthuhv",
"hwhxfP#K#L#L#K#K#I#I#L#J#J#I#H#G#H#F#G#H#G#I#G#F#H#HaBghgVghfOeZaTbXbGbUbXbV#N#H#Bfh#Bfhfh#C#B#Bfh#QfhfhfPaa#Q#E#JbwbNbw#K#C#B#B#B#C#B#B#C#B#B#C#C#C#C#C#E#Ja0bXbjbNbzbNbXe0hphphyfZ#P#M#N#O#P#N#L#O#P#P#P#N#N#P#O#P#P#O#P#M#L#M#O#M#K#M#N#N#O#Lhzdc#O#P#M#N#N#M#P#O#M#P#P#N#N#N#N#L#M#O#L#N#3#P#P#O#P#N#3#3#O#P#P#3#3aS#P#N#Pa1a1aS#PaSaS#3a0a1aSa1#P#P#3aS#P#Pa0a1a0a1#3aSaSa0a0a1a0a1a0a0a1a1bxa0aba0a0a0a1a0a0a0bxbwbxabbxbxbxaBbybybwbwbwbwbwabbyaBbwbwbxbybwbwbWbWaBbWaBbybwaBbwbxbwbwbwbwbwbybybwbWbwaBaBbwbWbwbxbwaBbw"
"bwbybxbxbxbwbxbwbVbWaBbwbWbwaBbVbybwaBaBaBbVbwbyaBbWbVaBbwbwbWbwaTbVbWbVbwbybwbwbyabaBbWbVbWaBaBbVbUaTaTbUbVaTaTaBbwbUaTaTbWbWaBbwbZf9hAhBhChD",
"hEfYbq#H#G#G#F#F#H#F#G#F#F#E#E#D#E#F#D#D#I#E#D#D#E#HfughghghgheZbGbGbjbGbNbzab#I#Dfhfhfh#B#B#B#B#Qfh#B#D#F#H#I#L#3bxbxabaS#N#N#J#H#E#Bfhfhfhfh#Bfh#B#C#E#H#OaTbjb#b#bNbjbXeYfOfOfOghbx#H#G#G#F#D#F#J#I#G#G#H#F#G#I#J#G#G#G#E#G#H#F#H#G#J#K#K#J#G#H#G#J#J#F#I#G#H#G#G#G#I#I#G#G#J#J#G#J#G#G#L#I#G#I#I#L#J#I#G#G#I#K#L#K#J#I#M#N#L#L#M#K#M#N#N#P#O#L#J#L#L#K#M#L#N#3#3#3#N#O#L#P#3#O#M#P#O#O#N#P#P#3#P#P#P#P#P#NaS#Pa1a0#P#3#3a0a1#3aS#P#Pa1a1a0a1#3#Pa0a0#3#P#3#3a1aSa0a0a0a1#Pa0a1a1a0a0bybybwbxa0a0a0bxbxa0bxbya0bxbxabbybyby"
"bxbxbyabbybwbybWbwbybybyaBbwbxbyabbxbwaBaBbwbxbwaTbwbwbwbwbyaBaBbWbwbwbybwbwbwaBbwaBaTaTaTbWaBbwaBaTaBbwbVaBbwbwbwbwbVbwbwbyaBbwbwbZeXhAhFhGhH",
"hIbv#o#D#H#H#E#F#E#D#D#E#E#F#E#E#E#E#C#E#E#B#D#D#C#KfnfZf0f0ghe0bzbGbzbzb#a2bG#P#G#C#Bfhfh#Qfhfh#C#F#I#I#H#Dfhf##2c7c6c7f##Q#D#G#L#P#K#Cfhfh#Bfh#B#D#H#J#PbVb#b#a2b#bYb#b#fnfOghghghg0#H#D#D#E#H#G#I#G#H#H#F#H#I#H#E#B#D#E#F#G#H#E#H#G#H#G#G#H#D#F#G#G#H#F#G#G#F#H#F#H#G#G#J#L#L#L#L#M#L#O#O#K#O#M#L#O#M#L#L#L#N#O#M#L#O#P#3#3#P#N#O#M#N#P#O#L#I#L#M#N#N#M#O#P#P#NaS#P#N#M#P#P#N#M#NaS#P#P#P#O#N#P#PaSaSaSaSaS#3#3a0aS#3a1#3a1aS#PaS#P#3a1aSaS#3a0abbxaba1a1a1a0bxa0a1#P#3a0a0aba0a0abbxbxbwbwbxa0a0bwbybxabbwbwbxbwbxbxbybwbw"
"bwaBaBaBaBbyaBbWbyaBbwbybWbybxbxbxbwbwbybybwbWaTaTaTbWbWaBbVaTaBbwbxbwbwbWbVaBbVbVaTaTbXaTbWbwbVbUbWbwaBbXbVbwaBbwbwbWbVbVaTaTaTaTf8dXhJhKhLhM",
"hNd2c7#G#G#H#G#J#F#G#L#J#G#I#I#I#G#G#I#L#G#I#L#G#GbzfZghfOgVgVfvhObYf8hObZhOf8bU#P#I#F#D#C#B#B#E#G#N#Fc7b.#o#l#l#n#l#l#l#o#n#n#R#2a1bx#K#H#E#G#H#G#J#NbxbGhOf8b1b1f8b0bZfNgBgVgVhohogVhP#G#G#M#N#L#J#L#K#G#L#L#O#L#G#H#L#M#L#J#L#L#M#K#G#J#I#F#H#L#M#J#M#L#L#L#J#M#G#K#N#O#L#L#L#L#L#L#O#P#M#L#N#O#O#O#K#L#O#O#P#M#J#M#P#P#L#O#N#L#O#N#P#P#M#J#L#PaS#P#P#3#PaS#O#O#P#K#L#NaS#3#P#3#P#P#PaS#3#OaSa0aS#3aSaS#P#P#Pa0a0#3aSa1#3#3#P#N#P#3aSaS#P#PaSa0aS#3a1#3#3aSa0a0a0#P#NaSbxaba0a0bxbxabaSa0a1#P#3abbwbxbwbxbwbybybVbxbybVbWbw"
"bwbwbwbwbwbwbVbwbwbVbwbwaBbxbxbybwbWbwabbybVaTaBaBbWbybwaBbWbVbwbxbwbVaTbWaBaTbVaTbWbWaTbybxbwbUbUaTaTaTaTbWaTaTbwaTbGaTaBaTbVbWaBbZhQhJhRhShT",
"hUfYf##K#L#K#K#L#K#M#O#J#I#J#J#I#I#J#L#J#I#J#J#I#Gg0gVgVhohohofZePf8fNb1b1b1eNb1bjaS#J#H#F#D#E#G#L#3#Jc6#R#R#Rc5b.c5c6bqc7c6c5b.#EbXbXbwa1aSa1a1a1bWbNf8eQeQeOeOeOeOeOeNfoghhphyhyhyhyhV#N#Pa1aS#O#L#O#L#M#P#O#O#O#M#O#P#3#O#L#O#N#N#L#M#O#L#L#P#P#M#M#O#O#N#O#O#O#K#Pa1#P#M#N#N#M#M#M#P#M#M#O#M#M#O#L#K#O#N#O#O#O#M#PaS#P#J#M#O#K#P#N#M#O#O#M#Pa1aS#O#M#N#P#M#M#N#N#L#OaS#3#O#N#P#O#N#L#N#L#Ma1#3#N#O#N#N#M#M#P#P#L#M#N#L#L#L#J#L#O#O#O#O#M#O#3#3#L#I#L#J#L#P#L#J#M#L#M#PaS#P#N#N#3#3#N#PaS#N#Na1ab#3#OaS#NaS#P#PaS#Oabbwa0#3"
"a1a1#3#3aSaba0a1a0aSaSa0aSaSa0a0a0a0a0a1abbWbx#PaSa0#Pabbya0a0aba0abaBbwa0a0bxbwbxa0bxa0#3a0bwbya0a0aba0aba1aba0a1bWaBaba0aba0a0a1bNeXhJhWhXhY",
"hZdWc5#D#F#F#D#D#D#H#E#D#E#E#E#D#D#F#D#D#E#C#C#D#GeZghghghf0ghfZg0a2b0b0b0b0b0b1b1bja1#K#I#G#I#I#MbxbV#M#2bq#A#Abqc7bqc7c5c6bq#CbxbWbxaS#PbybNbYbNf8eQeOeQeQePeQeOeQeNb0fGfOgVh0hphohodX#J#G#J#G#D#E#K#G#G#I#G#J#J#H#I#K#J#G#H#G#K#G#G#L#L#J#L#L#G#H#K#K#G#K#K#G#G#I#L#J#H#G#J#L#K#J#L#M#K#L#L#I#L#L#I#L#3#O#K#O#P#K#K#L#J#G#K#M#I#M#L#J#M#L#G#L#O#J#I#G#J#L#G#J#M#L#M#M#M#G#J#O#K#K#O#L#J#J#O#P#K#J#L#O#O#M#M#P#O#M#O#K#L#N#K#L#N#P#M#M#P#N#L#M#L#G#I#M#L#L#O#K#L#P#K#L#P#N#L#K#O#P#L#K#3#3#P#3aS#M#J#PaS#O#P#P#N#M#O#3#P#L#L"
"#P#3#P#Na0a0#3aS#P#N#3aS#Pa1byaba1abbxa1a1a0#3#NaSa0#3a0a0aSaba0#3a0bya0#P#3a0ab#3a0bwbxbxbwby#Pa1byaba0bya0a1aSa0bxaS#Pa1ababa0a0a2eXh1h2h3h4",
"h5f6c5#D#E#E#D#D#E#E#D#E#E#D#F#D#D#H#B#B#B#B#D#EbxgBghghfZf0ghfZe2b0fNeNeNfNfNeNeOeOhObNaB#3aSaSbxaTa2bG#Lfh#C#D#D#Bfhaa#2bqfPaSbx#JfPc6c5#2#NhOf.eOfNeNeNfNeQeNfNeQeNfNe9ghghfOghf0ghfv#F#B#D#D#C#D#F#D#C#H#D#D#D#B#D#E#D#D#D#D#F#C#D#G#G#F#F#E#D#D#G#G#D#D#E#D#D#G#H#G#G#G#F#G#F#E#J#F#D#G#F#G#G#H#D#F#G#E#D#G#F#D#F#H#E#H#K#I#C#I#J#G#I#G#H#I#G#H#H#H#I#J#D#G#K#K#I#J#G#G#K#N#L#I#J#J#G#J#K#J#J#K#J#G#I#G#G#J#F#G#G#G#L#L#G#G#J#J#F#G#J#G#F#G#G#H#I#M#G#H#M#J#I#K#G#J#K#I#G#G#K#L#I#J#N#P#O#L#M#J#L#P#P#M#O#O#M#M#P#N#P#P#P"
"#M#O#O#LaS#P#M#P#PaSa0aS#P#Pa0#P#PaS#3#O#N#3#P#Pa0a0#Ma1a0aSa1aS#PaSaS#3#P#Pa0a1#Pa1bxabaSa0aS#Pa0bya0a0a0a1#3aSa0a0a0a0a1#Pa1#P#PbNh6h7h2h8h9",
"i..P#o#B#C#D#C#C#C#B#D#D#B#B#C#B#D#D#B#B#D#D#B#BbYfZfZfZfZfZfZfZfvfueQeOeOeQeQeQeOePg0eQ#3#Qfh#E#I#K#Pbwby#J#D#F#F#F#I#G#H#F#ObW#3#E#2#n#l#m#ofhaBePfiePePfug1eOg1f.eOf.gBf0ghghghghghfZa1#E#I#J#G#G#H#D#H#I#D#E#G#D#E#D#D#H#D#D#D#D#D#F#G#D#D#D#D#D#D#D#C#D#F#H#E#E#E#G#G#F#E#E#D#H#I#C#D#G#G#E#D#D#D#E#E#D#D#D#D#E#G#L#L#G#G#F#D#L#G#D#G#I#G#G#H#I#I#G#I#G#H#G#J#J#F#I#G#G#I#I#G#H#I#K#I#K#I#I#L#J#G#G#I#G#N#L#F#K#M#K#I#G#G#I#I#G#G#G#G#I#J#P#P#M#L#L#H#K#O#G#G#L#I#I#G#G#L#J#I#K#J#I#L#P#L#L#L#J#M#O#M#J#M#P#P#P#P#O#3aS#P"
"#P#P#P#3ab#P#MaSa0#P#P#P#P#P#3#P#P#N#P#Pa0bybxa0a0aS#Obxa1#Pa1a1#Pa1#PaSa0#3aSaS#Pa1aba0#Paba0a0aba0a1#Pa0bxa0a0a0a1bxa0a1aSa0aSbxbzfuh7i#iaib",
"icf6bq#H#G#F#H#H#G#G#G#H#H#G#G#E#E#D#C#E#F#C#B#CfughghfOfOghghfOghe2ePfufuf.fifug0e3b1#Kc5#l#l#oc5c7fh#ObWbW#K#F#H#G#I#K#M#3bVaB#L#Bbqc5#R#R#o#Rc6#OfufGfofofig0fog0fueZfOhohohohphogVhpbZ#O#M#J#G#J#L#J#K#I#I#O#L#H#H#G#G#G#F#G#J#H#G#J#I#G#G#H#G#G#J#L#J#J#G#I#G#I#G#K#J#I#K#K#I#K#J#G#L#L#G#F#F#I#I#G#I#J#H#H#K#L#M#I#H#H#K#L#G#L#I#L#N#J#F#G#I#J#H#H#J#J#G#I#J#G#H#G#G#J#L#O#O#M#L#L#K#K#K#L#M#J#K#O#M#K#O#I#J#N#L#I#G#J#L#L#J#M#L#J#M#N#N#N#L#G#K#O#K#L#L#K#P#O#J#I#J#L#L#G#K#O#L#L#M#O#K#I#I#J#L#N#3#N#N#O#M#M#O#O#P#P#O"
"#3aS#P#P#P#K#P#P#M#G#J#O#N#P#3a1#P#N#3a1a0#3#N#O#Pa1#Pa1#Pa1bya1#O#P#3a0#3#Pa0a0a1a1a1a1#3#3#3a1a0ababa0a0a0a1a0a1a0abaSa0bxa0#3a0bUidieifigih",
"iid2b.#D#D#E#E#F#D#F#H#H#F#F#F#D#D#D#D#E#B#D#D#Lfwghghghf0f0ghghfZfvf.fuf.f.f.g0eXbGaa#l#k#m#m#m#m#R#2#B#Kbyby#K#F#F#H#I#LbxaB#Mfhc5#o#l#l#l#o#o#l#n#CbZeXfog0fofof.fogBgVhofOgVgVf0fOgVfu#J#F#F#D#C#E#D#D#D#E#G#D#C#D#D#E#D#D#H#E#C#D#F#F#E#E#D#E#D#F#F#D#C#C#D#D#D#D#G#G#E#F#F#E#D#D#F#H#D#C#D#I#G#G#H#I#H#E#I#G#I#G#H#H#D#G#G#E#G#G#J#I#D#D#H#G#G#H#I#J#F#F#G#K#G#I#J#G#K#K#M#K#G#G#K#L#K#K#L#N#M#M#M#L#I#J#K#L#L#G#G#J#M#O#J#M#O#G#K#O#M#M#L#L#J#I#L#L#L#M#M#N#L#I#J#M#O#L#L#N#M#J#J#M#N#O#O#L#O#O#P#P#L#K#L#P#N#N#Pa1a1#3"
"#3a1#P#N#P#3a1#P#N#OaSa1a1#3a0aS#Na1a0a1a1#3#P#O#Pa1#PaSaSa0bx#3#Pa1a0a1a1a0a0a1a1a0bxa0ababa0aba0byabaS#PaSa0a1aSa0bxaba0a0abaSaSbGb2ijikilim",
"inbpc5#H#G#G#G#G#G#I#I#G#I#I#H#H#E#G#J#I#D#H#Kg0fOfOfOfOghghgVfOghgheZfig0g0e3eXbWc7#n#o#l#l#o#o#ob.c7#2#C#PaTaB#J#I#I#KabbV#3#E#Ac5#R#R#R#R#R#R#R#R#Raabje2e1dXe3eXfvhphphohohogVgVhoh0fZb0#K#G#E#E#G#E#E#H#G#J#G#E#G#I#G#I#J#G#F#H#G#G#H#H#G#H#G#G#G#H#D#D#F#G#G#G#I#G#H#G#J#I#E#E#G#K#K#F#G#J#K#I#G#G#G#G#G#M#K#G#I#K#J#G#K#L#I#L#K#L#M#G#I#L#O#M#P#P#M#I#L#O#L#J#M#L#K#M#L#L#I#G#K#M#O#O#O#N#M#L#N#N#L#G#K#P#P#M#L#O#P#P#L#M#L#L#L#M#P#L#L#L#M#K#K#N#M#L#O#P#3#N#M#N#3#P#PaS#3#O#Na1a1#P#PaS#PaSa1a1#3#L#N#PaSaSaSa1a0a1a1"
"a0aS#P#OaSaba0#P#3a0bxa0#3#3#3#P#Pa0a1#P#3a0aS#N#3a0#Pa1a0a0byaS#Pa0a0a1bxbya0#Pa1bxa0aSa0a0a1aba0a0#3#N#3a1a0a1a1a1#3#3a0a0#3#N#Pbjfoijioipiq",
"irbvc5#H#F#E#E#F#E#H#H#H#H#F#F#E#F#I#I#F#D#KfNeXf7ghfOghghghghghf0ghgBdXg0e1fGbyb.#l#R#n#m#l#n#o#R#R#Rb.#2#H#PaBby#M#I#PbVa1#HfPc7#R#o#R#o#o#o#n#n#o#R#lc7bNe9e1fae2fOhogVfOgVfOghghghgVfnfoeQ#F#D#G#G#D#E#G#J#J#F#D#G#G#F#I#I#H#D#H#K#G#F#G#G#G#I#G#F#J#J#J#H#G#J#I#J#I#G#I#I#G#H#I#M#M#I#H#L#M#L#K#K#K#K#J#I#L#L#K#N#L#J#K#P#M#I#M#N#P#O#I#I#L#M#O#N#M#J#I#M#O#J#K#L#L#L#M#K#J#M#O#M#L#M#M#O#O#L#K#M#O#I#I#O#P#M#J#L#N#N#O#K#L#L#K#I#K#M#J#L#O#K#G#L#M#G#J#M#O#P#K#J#O#P#O#P#P#M#L#NaS#P#OaSaS#P#P#P#Pa1a1a1#3#Pa0#3a0a0aSa1"
"a0aS#Pa1bxbya0#3abbxaba1a1a0a1#3#3a0a0a1bxa0#P#3bxa1#Pa0ababab#P#Pa0a0a0aba0aS#Pa0bxa1a1a0a1aSa1#P#Pa0a1aS#PaS#3aS#3#3#P#P#3#M#L#3bNisitiuiviw",
"ixf6f##G#G#F#G#G#H#G#G#H#H#G#G#H#G#G#G#G#Kf.bybjfZfOgVgVgVgVfOghfOgVfOgBeZeYbWc6#o#R#R#l#l#n#o#n#o#n#l#nc5aa#E#NbWbw#Pbxby#J#B#A#R#o#R#R#R#R#R#R#o#o#R#R#Rf#a2fneYfFhogVhohogVh0h0hohohofR#3b1hO#J#J#H#G#L#L#L#L#G#G#K#J#J#L#K#G#H#K#L#I#G#K#J#G#K#J#J#N#K#G#J#L#M#L#N#M#K#K#L#I#G#M#L#L#L#L#M#L#L#L#L#L#O#O#O#L#L#M#N#L#O#N#M#J#PaS#P#P#O#J#M#P#O#N#N#M#I#M#P#O#M#P#3#O#N#P#N#PaS#L#M#P#P#P#PaS#P#O#N#P#L#P#3#P#P#M#O#P#N#M#N#M#O#O#O#O#L#L#N#N#M#N#O#L#K#P#P#N#N#L#L#P#P#P#P#P#N#O#3aS#N#Pa1#3#O#PaS#Pa0#P#M#P#3aSaSa0a1#P#P"
"#3#N#Na1a0a1#3aSa1#3#3#PaSaSaSa1aSaS#3#3a0#3#3a1#P#O#3aba1aS#P#O#Pa0#3#3aS#P#O#Pa1aS#NaSa0#3#Pa1#P#Pa1#N#M#P#3#P#3aS#P#O#O#N#L#OaSbGh6itiyiziA",
"iBdWc5#E#E#E#F#H#G#H#D#C#E#G#E#D#D#C#H#HePbW#RbYf0f0fZghghfZfZghghghfZfOgBbjc5#n#o#o#n#m#m#l#l#l#l#l#l#l#oc5#2#E#Oa0abab#O#Bbqb.#o#l#l#o#o#R#o#l#n#R#o#Rc5#of#eOghghgVfOghfOf0fOhofOghghfFaSf#eOa2#H#F#M#L#I#K#K#G#G#L#I#G#G#G#G#G#K#I#G#I#J#H#G#L#J#G#I#G#G#J#J#J#K#L#G#F#I#L#I#G#J#G#K#K#G#J#L#J#J#J#G#M#L#I#G#K#O#L#I#N#O#G#M#3#N#O#P#L#J#O#N#K#L#M#L#K#O#P#M#M#P#M#L#N#3#M#M#O#L#M#O#M#O#P#O#J#J#N#N#K#O#M#L#P#L#I#M#M#J#M#I#L#O#L#J#K#O#N#L#L#P#K#K#3#P#O#N#N#L#M#P#M#L#O#O#L#O#3#N#M#P#P#M#Ma1#3#N#3#N#M#P#P#PaSa1#N#M#P"
"a1#P#NaS#Na1a1#N#Pa1#3#P#P#Na0a0aS#Pa1a0a0#3aba0#NaSbwbxa0aba0#Pa0bxaS#3a1#3#Pa0a0a1a1aba1aSa0bya1aSa0#3#3a1a0a0aba0#P#Pa0a0#3a1aSbGbaiCiDiEiF",
"iGbgb.#G#G#G#I#I#J#G#E#G#G#G#H#J#H#H#JeObjfP#QeOfOfOfOgVf0ghfOgVgVghghgVeX#Q#nc5#R#R#R#l#l#R#R#o#R#o#o#ob.c6#Afh#H#K#3#O#Ff#c7c7c5b.b.c5c5c5#R#ob.c5c5bq#Ac7c6#Ke9hohphphoh0gVhphogVhohphobUfP#Kfibj#K#N#J#G#O#J#G#J#L#I#I#J#J#L#L#L#K#L#M#I#G#L#P#M#K#M#P#P#N#3#P#P#P#L#M#P#P#Pa1aS#PaS#M#K#Pa0aS#3#P#NaS#O#L#Pa1a0#P#MaS#P#L#3#P#J#M#P#L#L#P#P#O#N#N#P#P#P#N#P#P#P#K#M#3#P#L#M#P#3#P#P#P#P#P#L#K#O#P#N#P#P#O#N#O#G#K#P#N#M#O#L#N#M#G#L#O#P#N#K#L#N#K#L#N#K#G#O#M#K#L#P#O#O#N#N#P#P#P#N#PaS#N#O#3a0aS#Pa0bxaba0a0ababa0aSa1bx"
"abbxbwbwabbwa1#Pa0bwa0aba0a1bwaS#3abbwbwaba1bybxa0bybw#3a0aBa0a0bybyabbxbxbxbxbybyabbybxaSa0bwbwa0a0bwbwbxbxbwbwbwaba0abbxabbybwabb#dKiHiIiJiK",
"iLdWc5#G#G#G#J#G#G#J#H#G#G#H#G#J#G#JbNb##F#K#If.ghfOgVfOghghfOghghghfOgH#3#l#o#o#o#R#l#l#l#l#l#n#n#ob.#n#Rb.b.bqaa#C#F#DfPc7b.b.#R#Rb.b.#Rb.#R#R#Rb.#oc5c5c5b.#oaBfOh0hofOgVhohofOfOgVhoghbG#H#K#OeObw#E#D#F#G#D#D#E#H#D#E#E#G#G#F#G#G#E#H#E#J#O#L#I#K#K#L#L#L#N#O#M#N#O#L#M#K#L#O#M#L#K#G#I#N#P#M#L#O#P#O#L#M#P#N#O#L#L#P#M#K#L#J#G#L#L#G#J#L#L#J#J#K#L#K#L#M#J#J#K#K#P#3#O#L#M#L#M#L#M#O#L#O#O#L#O#L#K#M#O#L#L#G#G#L#N#L#K#K#O#O#L#J#L#L#L#L#J#M#O#I#G#I#H#G#L#I#G#I#K#J#J#J#M#N#L#O#M#J#K#J#OaSaS#N#M#O#P#NiM#3#3#3a1aS#3#P"
"#P#Pa0aS#3#P#M#Na1a0#3#3a1a0a1#3#3a0a0a0aSaSa0a1#P#3#P#Pa1a0#P#P#3#3#P#3aSa0a1aSa0#3#P#P#Pa0bya1aSa1aSaS#3aSa1a1a1a1aS#3#P#NaSa0#3bXfuiNiOiPiQ",
"iRa9c5#G#G#G#G#F#G#G#F#H#G#G#G#H#JbGbY#LaSaS#LfoghghghghhofOghghghfOghhOc5#nb.#ob.b.#n#o#o#R#R#o#o#Rb.#n#o#o#ob.c7#2f##Ac7#R#l#l#o#n#o#o#ob.b.#o#Rc5b.c5b.c5c5#n#Qg1gVfOfOfOghghhoh0ghfOf0bY#Nbx#3a1f.by#F#I#F#D#F#F#G#D#C#E#H#E#C#E#E#E#H#I#J#G#G#E#D#B#E#F#F#F#F#H#G#F#E#G#G#G#G#G#G#E#F#I#J#I#G#G#I#G#I#N#L#I#J#J#J#L#L#G#I#G#H#K#J#H#G#G#I#I#E#D#G#G#E#H#G#F#I#K#M#L#K#J#G#E#F#I#I#G#H#H#I#G#F#G#I#G#J#G#G#G#F#G#J#K#G#G#G#I#G#M#O#I#J#K#J#L#L#K#J#K#G#J#L#K#I#K#J#O#L#G#J#L#L#I#K#L#J#L#N#P#O#O#L#I#G#K#LaR#M#L#O#P#M#M#P"
"#PaS#3#P#P#O#N#3aS#3#PiS#3#P#3aba1#PaS#3aSa1a1#3#3#3#Pa0aS#N#P#P#3a1#N#M#PaS#N#O#N#N#P#3a0aS#P#P#M#J#L#P#N#O#O#M#N#N#J#L#O#N#P#N#NaTePiTiUiViW",
"iXd2#A#L#J#G#G#G#G#G#G#G#I#G#G#Jbzb0aSbwbVaBbVe2ghf0ghhogVghfOhofOfOe3#H#n#R#R#oc6b.b.c5c5c6c5b.c5c5b.b.#Rb.c5#Rc5c5#Rb.b.#o#oc5b.#R#R#R#R#o#Rb.c5c5c5c5c5c6b.#Rc6#PfngVgVfOghgVh0fOghhogVf.aTaBbwbxbyg1ab#G#D#E#G#G#I#E#E#G#F#D#E#E#H#H#G#G#D#B#E#D#B#F#G#H#F#F#E#F#E#E#H#G#H#G#G#I#I#E#G#G#H#G#G#H#D#F#L#J#E#H#L#J#G#H#E#F#G#H#F#K#G#H#K#K#M#L#H#J#J#I#I#G#K#L#K#O#L#G#G#J#H#H#L#L#I#I#I#I#G#G#G#L#K#J#L#K#L#J#G#L#K#J#K#K#G#E#J#O#I#G#L#O#J#J#G#G#I#K#G#K#O#K#L#O#M#P#L#K#N#M#L#L#L#N#O#N#P#L#J#M#M#K#OaS#3#P#P#P#3#P#PaSa1"
"aSa0a0a0a0#P#3a0a1a0a0aS#N#Paba1#N#Pa0a0aS#P#O#M#3#P#Ma0aS#Pa1a0a0a0#PaSa1#3#P#P#3a1#Pa1aS#O#M#P#L#L#3a1#P#P#P#P#O#M#O#P#P#PaS#PaSbUiYiTiZi0i1",
"i2d2c7#H#G#I#G#I#G#H#G#G#H#F#Nf8eQaBbNbZeQeXfvhogVfOh0hofOfOfOgVghfRbV#Ab.#R#R#Rb.#R#R#R#Rc5b.#Rb.b.b.b.#Rb.b.#ob.#R#ob.c5b.c5c5b.c5c5c5c6c5c5c6c5c5c5c6c7c5c5c6c5#QhOgVhpgVhphpgVfOhohohogVfRfafNbZbGbjeXaB#J#L#I#K#M#G#L#M#L#L#L#L#N#L#M#M#K#K#O#M#L#N#M#M#O#M#O#O#M#O#L#K#J#L#O#L#L#L#O#L#M#P#P#N#M#3#P#K#L#O#N#O#L#L#L#M#M#M#M#P#O#O#M#M#P#O#L#P#N#N#P#M#P#N#L#N#L#L#O#P#O#N#P#M#O#N#O#P#M#M#M#L#L#J#O#O#L#L#L#M#L#O#P#P#L#M#P#L#G#L#K#M#L#I#J#K#K#L#L#L#M#L#O#L#L#P#K#O#P#N#N#N#N#P#P#P#P#M#NaS#3#Pa1#3aSa1#3aSa0aSa1aS#P"
"#P#Pa0a1#P#3aSaSa1abbxa0aSbxab#O#N#3aS#3#P#P#N#N#3#3#Pa1aSa1a1aSa0a1#Pa0a1a1a0aSa1a0#3a1#P#P#3a0#3aSa0#3aSaSaSaS#P#P#P#N#O#M#P#3#PbVePi3i4i5i6",
"i7i8c7#G#J#K#I#K#J#J#J#I#LaBe1fGeNe3e9gBh0hphphph0hphpgVhphphoh0hog0#Kaabqc6c7c5c5c6c7b.c6bqc5c5c5c6c6bqc6c6bqbqbqc5c6c7c7c6c7c5c5c7c6c7c7c7bqc6c7#Abq#Ac7c6#2bq#Afha0eYhyi9hyi9hphyhyhphyi9hyj.hyfFe9g0eQe2aT#N#K#P#N#L#O#M#P#3#N#M#PaSaS#P#L#N#P#P#P#M#L#N#3#N#P#P#N#P#L#N#P#P#P#K#O#P#L#Pa1a1aS#P#3aS#P#3a1#M#NaS#3a1a0a0aSaS#N#P#3aS#N#Pa1#P#P#P#3aSaS#P#NaSa1a1#N#P#3#3#3#P#O#O#3#P#P#3#P#P#N#L#P#N#3#M#G#N#L#K#P#P#P#O#L#O#L#J#O#L#G#L#L#K#O#N#O#M#L#I#I#L#L#I#M#O#K#L#M#P#N#P#N#Pa0a0#3#N#PaS#P#3#3#Pa0abaSa0a0a0a0#Pa0"
"a0a0ab#P#3bxa1a0bwbwbwbxabbya0a0bxa1a0bxa0bybwbybybya0a1a1aba1a1bwaba0a0abbybyaba0abbwbya1a1a0aba0a0j#a0bxa0a0aba1a0a1#3a0a0a0aS#Nbjb2i3jajbjc",
"jd.P#R#E#D#D#F#F#D#H#G#F#Le2f7eYgBfOfOghgVgVghghghghghghfOghghfOe9byfPc6b.#R#R#o#Rb.c6b.c5c6#R#R#Rc6c6b.b.b.c6c6b.#Rc6c6c5#Rc5c5c5c5c5c5c5b.c7c5c5c7c5c5#Rc5c7c5c7aag2jef7gVgVfOh0h0fOgVhphogVhogVfOfOgVgHe0fvbx#I#K#I#H#F#G#K#G#F#H#K#L#G#E#G#K#J#G#G#G#J#J#J#J#K#G#G#K#I#L#K#J#G#D#I#J#H#L#L#J#G#H#G#G#I#O#L#H#L#L#J#J#J#G#G#J#I#I#K#L#K#L#O#L#I#J#L#L#J#I#I#O#L#J#G#L#M#K#J#J#L#L#L#K#L#K#G#O#L#M#N#K#J#H#H#L#G#K#O#K#G#H#H#G#G#J#K#H#H#J#J#G#J#I#H#G#J#I#I#L#L#L#O#M#I#G#J#L#J#I#I#O#P#M#I#L#P#3#N#N#P#3#3#P#3#3#N#NaS#Pa1"
"a1#3#P#M#3a1#3aba0aSaS#P#P#P#3a0aS#Na0a0a1aba0aS#Pa0a0a1a1bxaba0bya0aS#Pa0a0#3#3#3abab#3#PaSaba1#3jfj#a0aSaSa1#3#Pa0a1a1aba1#3#N#Nbjfijgjhjijj",
"jkjlc6#E#D#G#H#C#C#D#C#B#EbXfaeZfFfOghf0ghf0fZghghfZfZf0fZfZfZfZeO#Ff#b.#o#ob.b.#R#Rb.c5c5c6b.#Rb.c5c5#Rc5c5c6c5b.c5c6c6b.b.c6c6b.c6c7c6b.c6c7c6c6c6c5b.c6#Abqc6bq#2jm#Pe3gVgVgVhogVghgVhohogVgVfOfOghf0gBe9e1eP#K#J#L#G#G#J#J#G#G#J#K#I#H#F#I#J#I#G#G#L#I#G#L#L#G#F#G#G#E#H#G#E#D#J#L#I#G#K#J#G#J#K#G#H#I#I#H#H#J#I#I#I#G#H#G#K#J#G#J#L#L#K#O#L#G#K#L#K#I#L#M#M#M#I#K#M#M#K#J#M#O#K#L#N#O#J#J#M#J#K#L#J#G#L#P#N#L#L#O#K#K#L#L#J#K#M#L#I#L#O#O#L#L#K#G#K#O#L#L#M#N#O#N#3#O#O#N#3#N#P#3a1a1#P#PaSa0a1aSa1aba0a1bybwa0aSa0a0a0ab"
"aba0a0bwbWbwbxbwbwbxbybwbxabbwbwaba0bybwbybxbxa0a1bwbyabbxbwbwbxbwbxa1a0ababa1a0bxbxaba1a0a0aba0a1a0aba1a1bxabaSaSa1aSaSa1aS#NaSbxb#isjgjnjojp",
"jqi8#A#G#K#M#J#G#G#G#J#J#I#K#K#3bwbzfae1e0fvgBfOgVgVhohofOfOfOfRbU#DfPc6b.c6c6c5b.c6c5c5c5c6c5c5c5b.c5c6c6c6c6c6c6c5c5c6c6c6c6c6c6bqc7c6c6c6c6c7c6c6c6c6#A#Ac7c6c6#A#Q#Ia2fZhohohogVhohoghe2fueQbZbNaTbxaS#P#L#H#H#I#I#G#K#J#G#L#M#N#O#L#L#K#K#J#J#M#M#O#L#L#P#L#I#I#K#K#L#L#O#K#Ma1#P#M#K#M#O#K#O#O#M#P#O#L#M#O#M#P#M#M#N#O#P#3#P#3a1aS#P#M#N#N#P#P#O#O#P#PaS#P#P#N#P#N#N#P#P#3#P#Na1a0#P#N#P#N#P#P#P#P#M#3a1#P#M#M#P#M#L#O#L#O#O#M#K#O#M#M#O#L#O#N#N#P#P#N#3#3#P#N#N#3#Pa1aS#3a1a0a0a0a0a0a0a1aSa0abbxbxa0bxbWbya0abbxbxbyby"
"bwabbyaTbWbwbxbwaBabbwbwbybWaBbxbxbybybwbybybxbyaBaBbybybVaBbyabbybxabbya0a0bwbybyabababa0a0a1a0ababa0a0bwbya0a1a0a0aba0a0aba0bwbWb#fojrjsjtju",
"jvjwf##O#L#L#I#K#L#J#L#K#I#K#I#K#L#G#F#J#L#P#Ob#f0hphphohohphofG#3#G#Q#2#A#Abqbq#A#Ac7bq#A#A#A#Abqc7#A#Abq#2#A#Abq#2#2f#aa#2#2f#f##2#A#A#2#A#2#2f##2#2bqf#f##Af#aafP#B#KaBfnhyhph0hphphofG#K#F#D#C#B#D#B#B#D#B#D#L#J#M#M#M#K#L#P#O#O#P#N#Mjx#P#P#P#P#M#N#3#P#O#L#N#N#M#O#N#L#L#K#L#P#K#L#M#O#P#L#N#P#N#N#L#L#P#M#O#3#P#N#P#N#3aS#N#3aS#N#P#3#P#P#P#P#Na1#3#PaSaS#P#P#P#3#PaS#N#M#P#P#P#L#L#N#M#M#O#M#J#M#J#M#O#I#K#L#M#L#L#M#L#L#K#G#J#M#J#L#O#L#K#L#L#N#L#L#P#M#K#M#L#M#O#N#L#NaS#P#PaS#3#P#3aSa1aba0#3aSa0a0a1#3a0aba1a0bxa1"
"a0a1a0bwa0a0bxbybwabbybybxbwaba0bxababbwbxababa0bxbya0bxbwa0a1a0a1a0a1a1aSbxbxa1a0a0a1aSa0a0abjya1#3a0bxa0aS#3a0a1a1a0a0#3aS#Pa1a0bUfijzjAjBjC",
"jD.Qc6#F#D#D#F#E#D#F#G#D#D#D#C#E#G#C#C#C#B#B#C#CeZf0f0f0f0ghfFbY#H#D#Abqc5c6c5b.c6c5b.c6c6c6c6c7c5c6c7c5c6c7c7c5c7bqc7bq#Abq#A#2c7c6c7c7c7c6#Abqc6c7c6c6#2#2c7bqbqc7aa#H#LeQf0ghghgVhohob0#G#H#L#J#J#K#E#F#G#E#F#G#H#G#G#G#G#J#G#D#H#G#F#F#I#G#G#I#I#G#L#J#E#H#J#I#H#G#K#G#H#G#H#K#P#K#J#O#J#L#M#P#N#K#J#G#J#O#M#M#N#K#N#P#L#N#M#I#L#L#G#L#L#K#L#L#K#M#N#J#J#O#M#I#K#O#L#O#N#O#O#P#K#G#O#N#M#K#P#N#K#M#K#M#PaS#L#N#O#M#M#O#O#M#K#J#I#K#O#M#M#L#K#O#O#M#O#J#J#M#I#J#M#K#L#L#L#L#N#N#L#L#N#L#K#P#N#O#P#P#N#3aS#K#N#3#P#O#Pa0#P#P"
"#3#P#3bya1#3a0aSa0a0a0a0#P#P#O#Na1a1aSa1#PaSa0aSa0aS#OaS#P#L#P#P#P#3#3#P#PaS#N#N#3#P#O#N#P#P#N#P#P#Pa0#P#L#Pa1#P#Oa1aS#O#N#O#Oa1a0bUbkjEjFjGjH",
"jI.Qc5#C#D#E#H#D#F#I#F#C#H#H#H#K#J#D#D#F#E#H#G#Ig0f0fOfOgVhofna1#H#C#Ac5c5c6c7c7c6c5c6c6c6c6c7bqbqc7c5c5c6bqbqc5c5c5c5c6c7c7bqbqc5c6#Ac7c5bqbqc5c6bqbq#Af#bqc5c7c7c5#2#E#HaBfwgVfOh0hpfObx#G#G#F#D#D#F#E#F#D#B#E#E#D#E#G#G#H#D#B#B#E#H#D#B#B#B#C#E#G#F#G#D#B#F#G#D#D#I#E#B#H#H#H#L#K#E#E#I#F#F#G#H#D#D#H#F#I#O#I#E#G#G#G#F#D#F#G#G#H#C#C#F#H#H#G#I#I#G#E#D#F#G#H#C#D#B#D#H#G#G#G#G#D#E#I#G#D#G#K#D#D#J#G#K#N#L#F#G#G#H#G#I#H#D#H#G#G#L#L#G#F#G#I#I#H#G#I#G#I#G#D#H#G#G#G#K#L#K#G#H#H#I#K#G#H#H#G#I#L#O#M#P#L#I#O#3#L#La1#P#K#P"
"a1#3aba0#P#OaS#P#PaS#P#O#K#P#3aSbxa1#O#Pa1a1#P#O#P#3#3#3#O#L#P#P#P#3a1a1#3#N#M#O#P#P#L#L#K#M#N#P#P#P#3#M#O#3#3#L#Pa1#M#LaS#3aSa0a1bWiYjEjJjKjL",
"jMjNjO#H#G#J#I#H#J#I#F#G#K#J#I#K#G#E#F#G#G#E#F#Eb#f0gVfOgVgVfi#K#I#Bc7c6c7c7c7c6c5c5c7#Ac7c7bqbqc6c5c5c7#A#Abqc7c7#A#2#2#2bqc7c7bq#A#2bqbq#2c7c6#2f##A#Af#c7c5bq#2bq#A#C#I#PfGhohohphofZ#L#I#F#E#E#G#G#G#D#C#E#G#I#F#H#K#E#D#D#E#G#J#G#F#H#G#K#K#L#K#I#G#G#J#L#J#G#K#J#E#G#N#O#J#O#L#H#G#L#K#I#I#J#G#I#K#K#L#M#K#I#L#J#G#G#J#K#J#G#E#E#G#L#K#I#L#L#G#H#E#G#L#L#G#H#G#J#L#M#M#L#I#G#G#L#M#I#J#M#G#F#J#O#K#K#O#G#D#I#L#I#G#I#G#G#I#G#G#J#I#H#G#I#H#F#G#I#I#I#F#E#H#J#K#I#K#M#I#G#F#G#K#P#O#J#J#K#N#P#P#P#O#M#M#Na0#3#OaSaS#L#Oab"
"aba1a0ab#N#Na0a1#P#P#P#P#PaS#3a1abaS#PaS#3#P#PaSa1a1#3#O#Na1a0a0#3a0a0#3#P#P#3a0a0aS#P#P#3a0a0a0a1#P#P#3a0a0#3#3a0#3#OaSaba1a1abaSaTfijPjQjRjS",
"jTjNc6#G#G#I#G#I#G#G#G#I#J#G#I#J#H#H#I#J#H#F#G#Gabf7gVh0hoghbZ#J#Gfh#A#Abq#A#Abqbq#2aaf##A#2#Abq#A#A#2f#aaf##Af#aafPfPfP#Qf##A#2f#fPf#f#fPf#aa#QfPfPfPfP#Q#2#2fPfPf#aa#H#L#Mfuhphyhphpfv#O#O#O#P#P#P#P#P#O#Na1a0aS#P#3#P#N#P#PaSa1aS#P#PaSa1a0a0a0a0#P#P#3aSaba1a1aS#3a0a0a0a0a0bxa1#Pa1bxa0#3a0aba0aSa0aba0#3aSa1a1#P#3a1a0a0a0aS#Pa0bwbxa0a0a0aSaSa1a1a0a0a1#PaSa1a0a0a1a0aS#N#P#PaSa1aSaS#P#3aSaS#3#PaSa1#O#M#3#3#O#O#N#P#O#O#P#P#O#O#M#N#O#K#L#P#N#P#N#K#MaSa1#3#P#3#P#N#PaSa1aba0a1a1ababbybxbwbwaba0a0bxbwbwbxbyabbwbwbw"
"bybwbWbwa0bxaBbya0byaBbwbxbybWbwababbxbyababbxbxbxbxa0aSabaBaBbybxbya0a0ababbwbwbxa0bybxbwbwbwbwbxa0a0a0abbybxbya0a0abbwbxabbybwa0bjfajUjVjWjX",
"jYjZf##L#O#O#L#Lj0#O#O#M#M#O#M#K#K#M#N#O#L#M#L#L#Me1hphyh0f7bU#L#G#Daaf#f#aaaaf#f#fPaaf#f##2#2f#aaf#aaaaaaf#f#fPfPaa#Q#QfPf#f#aafP#QfPaa#Q#Q#Q#QfPfP#Qaa#2f##Qfh#Qaaaa#D#J#KbZgVhyh0hyb1#M#N#N#P#P#N#P#P#NaSa1#P#P#3#P#P#P#3aSaS#3#P#PaSa0#P#P#P#P#P#N#P#PaSa0#P#3a0a0a0a0a0a0a0aS#3a0bybwa0abbxa0a0a0bxbya1a1bxa0a0a0bxaba0ababa0abbybya0a0a0a1a1a0a0a1a0a1a1a1bxbxa1a0aSaS#P#P#3aSa0a0#3a0a0a0a0aSaSa0#3#P#Pa1a0#3#P#P#N#P#P#NaS#3#M#P#P#P#P#P#3#P#P#3#3#3a0a0a1aSa1aSa1a0a0a0a0bxaba0abbwbxbxabbxabaSa0abbxbwbybxbwbwbwbyby"
"bwbwbya0bybVaTbwbWaBbwbwaBaTbUbwbwbVaBaBaBbWbWaBbWbwbwaBbVaTbwbwbwbwbwbwaBbwaBaBbwbwbVaBbyaBbwaBbxbybwbybwbwbybwbWaBbWbwbwbwbwa0bxbZfGjUj1j2j3",
"j4j5c6#H#I#G#H#Gj6#G#G#I#J#K#G#G#I#L#L#G#G#G#F#G#IbYgVgVghe2a1#I#Ffhf##2f##A#2#Aaaf##A#2#2#Af#f##2#2#2aaf#aaaaaaaaf#fPfPfPf#aaaaaa#QfPaa#QfPaaaaaafPaa#2f##Q#QfPf#f#aa#B#J#KbXf7hph0hpbx#M#O#N#P#N#M#M#O#P#P#O#K#O#M#L#O#M#M#L#L#O#N#P#P#P#M#N#P#3#N#P#N#N#3aS#PaSa0aSa1a1a1a0#3#P#3aba0#3#3a1#P#3aSa0aba0#Pa1bxa0aSa1a0a0a1a1a1a1byaba1a1a0aSa1a0a0aSaSa0a1a0a0a0a1aSa0a0a0a1a0a1a1a0a0aSa0a0a1a0aSa1a0#P#Pa1a0aS#P#P#P#O#PaSa1aS#P#OaS#3#P#P#3aSaS#3#P#PaSa1#3#Pa1aS#Pa0a0a1a1a1aba0bxaba0a1a0abbwa0a0aba0bwaBbybwaBbybwbwbw"
"aBbwabbybVaTbwbybwbybxaBaTbUaTbwaBbVbwbwbwaBaBaBbwbwbybWbWababbwababbyabababbxbybwbybyaba0bybybya0aba0a0bxbxa0bybya0bxababbya0a0bxbZe3j7j8j9k.",
"k#kafP#L#L#M#M#L#L#K#K#K#M#O#M#L#M#N#L#L#L#L#L#P#Pa0fvhphpe3aS#M#Jkbfh#Q#QfPfhfh#Qf#aafhfPfPfh#Qfh#B#B#B#B#B#Bfh#Qfhfh#Cfh#Qfh#QfP#BfhfhfhfhfhaafPfhfhfhfhfhfhaafPfhfP#D#K#LabeYhpi9eZ#N#M#O#N#O#L#L#L#N#P#L#I#L#N#L#M#P#M#O#N#P#P#O#N#L#L#L#N#3#3#M#M#O#L#M#P#P#3#P#P#P#O#P#3#3#P#PaS#P#O#P#P#OaSaS#P#P#N#3aS#3#P#P#3#3#P#P#O#Pa1a1#M#LaS#3#Pa1aS#3aSaSa0#3a1aS#P#P#3a1a0aS#PaS#3#Pa1a0a1a1#3aS#P#PaSa1#3#3#3aS#O#N#P#M#O#3#P#N#L#Lkc#N#O#M#O#P#N#O#M#O#P#3#O#L#P#3#P#Pa1#PaSaSa1aS#3aS#3#P#3#3a0bx#P#3a1#3a1aba0aba0a0aba1bx"
"bwbxa0abbyaba1a0aba1bxbwabbxa0a0byaba0a0bxaba0a1a1a0abbx#P#Pa0a0aSaba0aSa1a0a0a1a1aS#3aSa1a1bxa0#P#3aS#Pa1a0a0a1aSa1#P#Pa0a0a1a1a0bNfij7kdkekf",
"kgjZ#Q#L#O#3#M#K#J#J#I#J#L#J#I#I#L#M#L#I#L#J#J#M#L#KbYf0hofN#O#K#F#EfPaafPfP#QfhfPf#fP#QfP#B#BfP#QfPfP#QfPfP#Bfhfhfhfh#Qaaaafhfhfh#C#B#QfP#QfPf#fhfhfPfP#Q#B#C#Q#Q#Qaa#D#J#L#Nfihph0bz#P#O#N#3#N#P#P#3a0a1#O#NaS#3aSbxa0#P#3#3#PaS#P#3a1aSa1aSaS#P#Oa1aba1a0bya0a1a1a0#PaSaba1a1a0abbxaba1a0a1aSaba0a0a0a1bxbxbxaba0bybxa0bxabbybwa0#3abbya0bwbWa0a0bxa0bxa0a1bxa0abbxbxabaSaSbxbxa0bwbya0a1a0a0#3a0bxaSaSa1a0a0a1aSaS#P#3aS#P#P#O#PaS#3a1#P#Pa0#3#3a1a1abab#P#Pa0a1a0byabaSa0a1a0aba0abbybxbybxbybxa0bxbwbybwbVbwbwbybwbybyaT"
"bVbybwaBaTbVbwaBbwabbWbybxbya0bwbwbwbxa0bwbwa0bwbxbwbVbyaSabbyabbwaBbxa0a0a1bxa0a1aba0abbxa0ab#3#3abbxabbybwaba0a0abaSabbya1a0abbxbYfaj7khkikj",
"kkjwf##L#L#I#H#G#G#J#G#G#I#G#G#G#F#J#G#E#G#H#H#G#H#F#JeYfFbN#I#F#C#C#2#2f#f#f#f##Af#aa#2aafP#2bqf#fPf#aaf#aafhfPaaf##2f#f#fPfPfhfhfhfPf#f#fPfPaafPfPf#fPfPfP#QfPaaf#f##C#F#I#Lb0fOfR#N#K#G#O#O#G#L#M#L#N#L#L#O#L#M#N#O#I#G#M#L#L#L#L#O#N#L#L#K#G#I#L#N#P#P#N#M#L#K#M#P#O#M#O#L#O#N#L#3#P#M#P#O#M#N#O#M#N#3#P#N#P#L#Oa0#M#L#P#O#3#P#M#PaS#P#3a1#N#L#N#3#P#P#O#NaS#P#N#P#M#L#N#PaSaS#3#P#O#M#M#N#P#M#N#N#L#N#N#N#3#N#O#N#M#O#O#O#O#P#P#N#P#O#L#PaS#L#P#P#NaS#P#PaS#3#3a0a0#N#Ma1aSaSa1a0a0aba1a0aS#PaSa0bybwbwbya0a1a1a0bwababby"
"a0abbwabbwbwabbxaba0bybxababbybwbybya0a0bWaba0bwa0bxbxa0a0bya0abbyab#3a1aba0a0a0a1bxa0a0a0#3#Pa0abbybwbwbya0a0a1abbya0aba0a0bybxa0bYeXklkmknko",
"kp.Rb.#E#D#C#D#D#D#E#D#C#E#F#F#E#B#E#D#C#E#F#E#D#D#C#FeQfwbV#H#Cfhaabq#A#Abq#Ac7c7bqbqbq#A#Ac7c7f#f##A#2f#f##2#Abq#A#2f#aaf#f#aaf##A#2f#f#aaf#f#f#fPfPaa#2f#f##Af#aaf#fh#E#F#Kb#f0eN#I#F#E#L#G#E#I#G#G#G#G#G#H#H#J#J#E#D#G#L#I#G#G#J#J#I#H#H#H#F#J#J#G#J#I#E#E#G#H#I#I#G#F#G#J#I#G#D#G#G#F#I#J#G#J#J#G#M#N#L#L#J#E#K#N#G#L#M#K#M#K#L#K#J#K#P#L#H#G#M#N#O#L#O#N#O#M#I#L#J#L#P#L#M#P#L#G#J#L#K#L#L#J#J#L#L#L#G#G#L#G#I#L#J#J#J#I#J#N#M#K#L#G#G#O#K#G#M#L#L#M#K#L#M#L#N#P#L#I#LaS#3#P#Pa1a1aS#P#P#P#Pa0a0a1ababaS#Pa0a0abbxa0a0ab"
"bxaba0aSa0a0a0bxbxababbwa0bybWbwbxa0#3a0bwa1a0aba0aba0a0a0a0aSbxa0#P#Pa0aba0a1a0aba0a0#3aS#3#3bxa0a1bxa0#PaSa0a0ababa1a1abbxaba0a1bzb2klkqkrks",
"kt.R#R#C#D#E#H#D#D#E#D#E#G#F#D#D#E#E#D#D#D#D#D#D#F#F#GbVe9bw#G#E#BfPf#f##2#2#2#A#2#A#Af#f##A#Af#f##2f#aaaaf#f#aa#Af#aaaafPf#aaaa#A#A#QfPaaaaaaf#aafhfPf#f#aaaaf#f#f#fP#B#F#J#ObUgHa1#J#G#G#J#G#J#K#I#I#G#G#I#G#I#O#K#H#G#L#K#G#J#L#L#I#L#I#G#K#J#O#L#G#K#J#H#L#P#K#L#N#M#L#P#3#M#K#M#L#K#J#L#L#Lku#N#P#3#M#L#M#L#L#N#O#M#P#M#M#O#L#M#L#J#M#P#K#I#M#O#K#K#M#P#L#L#O#J#L#O#N#N#L#L#M#I#I#P#P#L#M#O#M#N#P#P#L#K#L#K#I#J#J#J#I#J#L#N#M#G#K#L#J#L#O#L#O#N#M#M#M#M#O#M#OaS#3#L#MaS#P#N#PaSaS#3#3#3#PaSaSaba0#3a0aS#NaSbwa0a0ababbxbw"
"aBbxa0bxbxa0a0a0a0a0a0bybyaBbya0bxaba0bxbxabbwaba0aba1a0a0a1a0byaS#Na1a0#P#3a1a0a1#3a1#P#3aSkva0aS#3aS#N#Ma0a0#3aSa1#3a1bxa0#3#PaSbGbkkwkxkykz",
"kAjl#R#D#D#F#F#D#D#E#D#F#F#D#C#C#E#D#D#D#D#E#D#D#H#E#D#GeXab#I#E#BfPaaf#f#aaf##2fPaa#2#2f##Af#aaf#f#aafPfPf#fPfPf#f#fPfh#B#QfPfP#2fP#Baa#2aaaaf#aaaaf#f#aaaaf#f#f#aaaa#Q#D#G#Kbxfu#I#G#H#G#G#G#G#H#H#G#G#G#J#G#H#I#G#H#I#H#H#H#G#J#G#F#G#F#D#G#G#K#I#G#G#G#F#K#L#E#G#L#G#K#L#G#G#G#J#J#G#I#J#K#G#G#L#J#I#F#G#J#G#I#K#J#K#J#H#G#I#G#I#K#G#G#K#G#J#K#I#G#G#K#L#G#I#K#G#G#L#O#N#L#K#M#K#L#3#L#I#M#L#L#O#L#K#J#L#L#K#L#K#K#K#I#L#L#L#I#F#L#L#I#L#L#K#L#J#J#L#L#L#P#O#L#M#M#L#O#L#L#L#L#P#O#L#N#M#J#M#Pa1a1#P#3#P#OaSa0#L#PaS#3aSa1"
"#P#P#PaS#3#P#3#PaS#P#Na1aS#P#L#MaS#3#PaS#3#P#P#O#P#3#N#P#3#O#N#P#O#N#P#N#O#M#3#3#N#P#P#M#O#P#3kB#3#P#3#N#Pa0#P#OaSaS#P#3#3#P#P#PaSbUbkkwkCkDkE",
"kF.Q#R#D#D#H#D#C#E#F#F#H#E#D#D#D#E#F#D#E#G#G#F#G#G#E#D#CbNby#J#F#Baaf#f#f##2f#fPaaf##AfP#Qaaf#f#fPfPfPfPfPf#aaaaf#f##Q#Q#QfPfP#Q#Q#Bfh#2f##QfP#QfP#2#2f#f#aaf#f#aafPfP#Q#E#I#Jbyby#G#H#E#F#E#D#H#G#F#H#I#I#J#E#E#L#J#H#F#G#J#G#G#K#G#G#I#G#H#I#L#K#K#L#Kj6#I#M#K#E#K#L#K#L#K#G#G#G#J#L#I#K#M#N#L#M#O#J#G#F#K#O#K#G#I#F#G#L#J#I#J#O#M#K#H#L#P#J#G#J#O#L#I#L#L#I#M#L#I#J#M#P#N#L#L#O#L#M#O#H#G#L#K#L#L#G#G#G#G#J#J#I#K#M#L#J#L#K#G#H#G#O#K#G#G#H#F#I#J#G#G#L#M#M#I#G#P#N#J#J#L#N#L#K#N#K#K#N#L#J#O#3aS#3#P#3#P#Pa1#P#L#3a1aSaS#3"
"#O#P#P#PaS#P#Pa1a0#P#3a0#P#O#L#Pa1#P#N#N#L#M#P#O#M#NaSaS#P#K#Pa0#P#M#M#P#P#M#P#N#M#N#N#M#N#PaSaS#P#P#3#P#PaS#L#O#3#3#P#3#O#M#P#P#3bXfukGkHkIkJ",
"kKkLc5#F#G#G#H#G#G#I#I#G#H#E#F#H#H#F#G#G#J#G#D#G#H#E#E#D#Kby#K#G#Cfhfh#B#Qf#fP#QfPkMfP#BfhfP#Qfh#B#Qfh#B#Qaafhfh#Qfh#B#Qaaaaaaaa#Q#B#QfP#Q#Qfh#Q#Qaaf#fP#QfPaa#QfhfhfP#D#H#J#ObV#I#H#F#G#F#E#F#J#L#H#H#I#G#F#E#G#L#H#F#H#K#I#H#J#J#E#F#I#G#H#G#G#E#D#D#DgN#H#J#F#E#G#G#J#G#H#D#E#G#G#F#G#G#L#I#D#G#G#H#F#H#G#H#G#G#F#F#G#M#I#F#G#K#G#F#G#L#M#G#G#L#M#G#J#L#J#E#K#K#I#J#K#J#F#E#F#H#G#J#G#F#G#G#I#I#G#H#E#G#G#G#H#G#J#L#H#H#G#G#H#H#H#G#F#G#H#E#F#K#L#G#G#K#K#G#H#K#P#L#I#L#P#O#L#N#P#L#K#P#O#N#P#3#O#L#O#L#M#Pa1#N#O#3aSa1#P#P"
"#L#O#P#P#O#P#3a0#3#MaS#3#N#N#N#P#N#N#N#O#M#Pa0#P#M#N#3#O#M#MaSa0#M#L#PaS#N#O#3#P#K#O#P#N#N#P#P#L#K#L#L#M#P#P#L#O#O#P#P#N#M#L#O#P#NaTfukNkOkPkQ",
"kR.Q#n#C#D#D#C#D#D#D#D#D#C#C#C#C#C#B#F#D#D#C#C#D#C#B#B#C#Bab#N#I#C#B#BfPfPaaf#aa#2f#fPaaaaaaaa#QfPf#fPfPf#aafP#QaafP#Qf#f##Q#QaafP#QfP#Q#Q#Q#Qaa#QaafP#QfPf#fP#QfPaa#Q#E#H#Ia0a0#C#E#G#F#C#E#J#I#H#F#D#D#C#C#E#D#C#C#D#D#D#D#D#H#F#B#D#H#D#D#E#E#B#D#D#C#C#D#E#D#E#D#E#E#C#D#C#D#E#D#B#H#F#D#C#D#G#E#D#F#F#E#I#L#H#C#K#N#M#L#I#I#I#G#I#L#I#I#J#L#L#M#I#L#O#K#G#L#L#I#I#L#I#H#K#J#G#J#L#J#K#L#L#L#G#L#I#I#I#I#G#I#K#G#H#H#G#I#H#G#I#H#G#L#J#F#G#M#M#K#J#I#I#G#G#L#K#J#I#J#K#M#L#J#N#O#J#K#N#M#L#N#N#K#L#P#M#N#P#P#O#N#P#3#P#M#P"
"#M#N#O#M#L#P#P#O#K#M#P#O#L#M#O#L#N#3#L#G#Pa0aS#P#O#O#O#L#M#P#M#L#O#N#P#P#N#P#3#N#L#N#P#M#M#P#M#J#M#O#M#O#P#N#O#P#N#P#M#O#L#O#O#N#MbWbkkNkSkTkU",
"kV.Q#n#D#E#F#D#D#D#F#E#E#E#H#E#D#D#D#G#E#C#D#D#D#C#B#C#C#E#Kbx#J#H#E#Bf#f#f##2f#f#aaf#f##QfP#2f#aaf#f#f#f#aaaaaaf##Q#Qf#fP#Qaaf#aa#QfPaaaaaafPfP#QfP#QfPaaaafhfhaafP#C#F#G#OaB#G#E#I#H#D#C#H#G#F#D#E#B#D#F#F#D#D#F#G#D#B#D#F#D#F#C#C#E#F#D#E#G#F#D#G#H#D#D#F#H#D#D#H#I#G#G#G#L#K#I#G#G#M#L#G#G#L#J#G#G#J#L#L#N#K#G#J#O#L#G#K#I#F#I#I#J#G#G#M#M#H#G#K#I#J#L#G#J#K#K#I#O#N#K#L#N#L#J#L#N#L#J#L#M#M#M#N#O#P#L#L#I#O#P#L#I#L#L#L#G#G#K#L#N#O#J#I#M#P#L#K#L#I#J#L#M#M#K#M#P#O#J#L#O#L#O#M#K#N#P#N#PaS#3#NaSa0#P#P#Pa0#P#3aSa1a0a0a0"
"bxaba0a1aSbwabaS#3a0a0a1aSa1a0a0bxa1#P#3bxabaSa1aS#Pa1aSa1aS#3aba0#P#N#3#P#3aS#P#PaSaS#PaSa0#P#Pa0#3#N#Pa0a1#3aSaSaSa1a0a0abaSa1#3bjfokWkXkYkZ",
"k0k1aa#O#P#P#N#L#J#M#P#M#L#L#J#I#L#M#M#I#J#L#I#I#G#G#K#L#K#Hbwby#N#L#I#E#D#D#C#F#F#E#E#F#H#F#D#F#H#E#F#E#E#F#H#H#F#H#F#H#H#F#E#E#H#G#F#F#D#E#F#F#D#E#F#D#D#H#H#E#D#G#K#OaSbUbx#O#P#P#L#M#P#P#N#O#O#P#L#NaS#O#O#PaSaS#N#M#P#P#N#P#O#O#P#P#N#P#P#P#P#P#N#N#Na1a1#3#N#N#3a0aS#Pa1#3#PaSa0a0aSaSa1#3#P#P#P#3a1#3#O#MaSa1a0aS#PaS#P#Na0#3#P#PaSa1#3#N#Pgp#P#3#P#O#P#3aS#3#3a1#PaS#3#P#NaSa0aS#3#P#PaSa1#PaSaS#N#P#Pa1aS#P#P#3#P#N#M#O#3#P#N#L#O#3#P#3#P#P#P#O#Pa0#P#P#Pa1a1#3#3a0a1aSa0#P#3a0a0a0a0aba0a0a0a1a1a0bxbya0a0a1abbwbxa0"
"aba0a1abbwbwababbwbxa0a0a1abbxa0a1#3abbyabbxa0a0a0aSbyab#3a1a0aba0a1a1aba1a1aS#3a1a1a0aSaSa0#3a1a1#P#Pa1bxa0a1#3aSababa1a1ab#3a1a0b#eXkWk2k3k4",
"k5k6#B#P#P#3#P#N#NaS#3#P#P#N#P#P#3#3#P#N#N#P#P#P#N#O#P#N#L#O#PbNbx#3#O#J#I#F#F#H#F#F#G#H#F#F#E#G#G#H#H#H#H#G#H#G#F#E#H#G#F#H#G#H#H#I#H#F#C#E#H#E#C#D#D#C#E#F#F#E#E#G#M#3aTaT#J#P#L#K#O#P#N#O#O#N#P#P#N#P#P#MaSa1#P#P#O#Pa1#P#P#P#P#3aS#3#3#N#O#P#P#NaSaS#3a1a0a1#P#Pa0a1#N#N#P#L#N#3#3#3#O#P#P#N#3#N#L#P#P#L#O#PaS#P#P#3a1a1#3#Pa1#N#Oa0a1#P#N#O#P#3#N#P#P#P#3#P#3#N#L#N#P#N#P#3#P#3a0a1#3#O#Pa1#N#M#N#O#K#N#P#P#O#L#M#M#O#O#K#L#N#L#L#O#P#3#O#P#P#3#3#P#3aS#OaSa0#3#P#N#3a0a1#3aSaSa0aba0a0#3#3a0a0a1ababa0bybwbyaba0bwbwa1a1"
"a0a1a1abbybya1a1a0a0byaba1a0bxaSa0abbxa0a0a0abbxa0a0bxa1#Pbxa0a1#3#Pa0a0#3#P#P#3a1#3a1#P#O#P#P#P#Pa1#3aSa0a0aS#N#Pa0#P#N#P#N#M#P#3bGfikWk7k8k9",
"l.jw#A#G#J#L#H#H#J#J#G#F#H#G#I#G#G#J#J#H#I#J#J#J#G#J#O#J#J#M#Ja1aT#3#O#J#E#C#C#D#D#E#H#E#C#B#D#E#C#C#F#H#E#E#E#F#E#C#D#D#C#F#G#E#E#F#E#C#E#H#E#B#C#D#C#E#E#E#H#F#H#K#ObxaT#J#L#M#I#K#O#L#K#J#L#M#M#J#I#J#J#J#O#N#K#J#J#L#K#J#L#N#N#L#L#L#N#L#L#O#L#L#P#3#O#P#P#L#K#N#3#L#J#L#K#M#N#M#P#P#M#N#P#P#N#L#OaS#P#N#P#3#P#O#O#P#3#P#L#M#P#M#Pa1#P#M#M#M#P#L#L#P#3#N#N#P#P#P#M#P#P#O#3a0#3#N#3#P#K#Oa1#P#K#L#M#M#N#O#O#P#N#M#P#P#P#M#L#P#3#O#P#P#N#L#L#L#N#N#M#L#O#M#M#3#3#N#M#L#N#N#L#O#3#3#N#N#N#P#P#N#P#M#Ma0a0#P#3a1#L#L#3a1#N#K#O"
"#N#P#3#Pa1a0#NaSa0a0#3#O#3a0aS#P#3#3#P#O#N#PaS#P#L#M#O#M#Na1#P#O#L#M#N#L#J#M#P#O#M#M#O#P#L#O#P#L#OaS#P#P#P#P#L#M#3#P#K#L#M#O#P#N#NbXfil#lalblc",
"ldk1#A#J#L#L#I#K#L#K#G#G#G#I#L#L#I#L#G#G#L#I#H#G#J#L#L#L#L#L#K#GaBbXa1#P#J#E#F#H#G#F#E#E#E#F#F#F#D#F#I#I#H#H#G#I#I#F#G#G#G#I#I#H#F#I#F#F#G#I#F#E#H#H#G#I#G#H#I#I#L#3abbXaS#M#P#P#O#P#P#O#N#P#3#P#P#O#N#PaSa1#P#P#P#N#P#P#N#NaSa1#3#N#3a1a0#3#PaS#3#3a0#P#M#3aS#N#Pa1#3#P#P#3#PaSa1#PaS#N#NaS#P#N#M#PaSaS#P#3a0aS#P#PaS#P#P#N#M#N#NaS#P#N#N#L#O#P#N#O#Pa1#3#M#O#P#3#3#M#P#3#PaS#3#M#O#3#O#O#3aS#N#O#P#P#PaS#3#P#3#M#N#3#P#M#O#P#P#P#O#P#N#O#O#N#P#O#N#L#L#M#P#P#M#N#O#K#O#O#M#M#3aS#P#N#Pa0abaS#Pa1a0a0ab#3#NaSa0#P#3aba0#3aSa1"
"a0bxbxa0a0a0#3a0a0#3#PaSa0a0#3#3a0aS#P#PaS#PaS#P#O#P#Pa1#3#O#P#O#O#N#N#M#N#3aS#P#P#PaSaS#P#P#P#P#3aS#N#NaS#P#M#3aS#N#O#N#N#Pa1aS#PbGfulelflglh",
"li.R#n#C#C#C#C#B#B#B#D#F#D#D#F#E#D#D#B#C#D#B#C#E#E#C#C#D#D#D#D#B#Bbyab#L#G#F#E#E#Dfhfhfh#B#C#C#C#C#C#D#Bfh#B#C#C#B#B#F#F#C#B#B#B#B#B#C#D#C#B#C#C#E#D#C#D#D#E#D#F#L#PbW#3#G#G#G#I#G#J#J#G#G#I#J#I#G#I#M#M#P#L#I#L#L#M#L#L#O#L#N#M#I#I#L#L#L#J#L#P#M#I#J#I#J#J#K#K#J#I#I#J#M#O#L#O#P#O#L#K#L#M#L#L#P#P#O#N#P#P#P#P#O#N#P#P#N#L#P#PaSa0#O#N#P#P#3#3aSaSa1a1#P#N#P#3aS#P#Pa0abaS#P#P#P#3#3#3aS#3#PaSa0aba0aSa0a0aS#P#N#P#3#N#Pa0a1#P#3#P#3#3#P#P#P#P#P#P#PaSaSa0a1#PaSaSa0a0a0bxa0ababa1aSa0aba0a1bxbwbwabbyabbxa0bybxa0aba0bybwbw"
"bxbwbwbwbxa1a0aba1a1abbxa0a0aba0bxaba1a0a0a1a0#3a1ababbwa1#3aSa1a1a1aba0a0a0#3#P#PaSa1#P#Pa1a0aS#P#3#P#P#3#P#3#P#P#3aSa1aS#3a0a1aSbXfuljlklllm",
"lnloc7#G#F#G#G#F#E#H#G#G#H#G#G#F#D#D#H#I#F#E#F#E#D#D#H#G#D#E#F#Cfh#GbWby#N#O#G#F#E#C#D#D#E#D#F#G#E#F#F#F#F#F#H#H#H#G#I#F#F#F#H#H#H#F#G#H#E#H#I#G#H#H#H#G#H#H#KaSbxbVab#M#L#K#L#M#K#J#J#I#I#L#L#L#K#M#L#J#K#G#J#M#M#L#K#O#M#J#L#L#K#K#K#L#K#K#M#L#K#J#L#L#M#K#O#O#K#K#M#N#N#O#N#P#O#L#J#L#P#M#L#O#O#L#K#O#N#L#K#L#K#K#O#O#O#M#3#O#O#O#L#P#P#3#P#PaS#N#N#P#N#N#N#P#P#N#P#3#P#P#P#P#P#N#N#P#P#O#N#P#P#P#P#3aS#P#M#O#P#3#N#P#P#P#O#O#P#N#N#N#O#O#3a1aS#3a1aS#3aS#P#Pa1a0a0a1bxbxaSa0a0a0a0a0aba0a0bybxa0a0bxbybxa0bybwa0a0bxbwbwbx"
"bxbwbya0aSa0byaba0ababa0a0a0aba0a0a0a1a1a0a0a0a0a0a1a0a0#3a1a1a1aSaSa0aS#P#3#3#P#PaSaS#P#3a1#3#P#P#3#3#3#PaSaS#N#PaSa1aS#3aSa1#3#PaTf.lplqlrls",
"ltjNc7#E#D#H#H#D#D#F#E#C#B#E#D#D#C#D#G#F#D#D#E#H#H#E#H#G#E#E#E#D#G#C#HaTbW#3#K#G#H#F#F#F#D#D#D#D#C#D#E#H#H#F#F#H#H#E#E#D#F#H#H#F#E#H#H#F#E#F#F#F#D#H#K#K#K#NabaBbXbV#J#K#J#J#I#L#L#J#J#G#K#P#M#M#P#N#L#J#L#K#L#N#O#L#M#K#L#I#L#O#N#O#M#N#P#P#M#J#L#P#P#P#O#M#P#P#L#N#P#P#M#L#P#P#M#M#Oa1#3#O#M#P#3aS#3aSaS#P#3#P#PababaSababa0#P#3#3aSa1a0a1#3#3#P#P#N#P#3#3#N#P#PaS#P#N#O#3a0a0aS#P#Pa0#P#O#P#3#P#L#OaS#N#O#O#3aS#O#L#M#P#P#P#O#P#P#N#P#O#Pa0aSaSa0a1#P#P#P#P#3a0a0a1a1#PaS#P#3a0a0a0aSa0aba0aS#P#3a0bwbya0a1abbxaSa1abab#3#N"
"a0abaSaSaSbxbxaS#Pa0a0a0a0a0bxa0a0aSaSbxbxa0a0bxa0#P#P#P#3#3a0aS#P#P#P#P#N#PaSaS#P#PaS#3#P#P#O#PaS#3#P#P#PaS#P#M#P#P#P#L#N#3#P#O#ObUg0lulvlwlx",
"lyj5b.#F#E#G#H#D#F#G#H#D#E#G#E#G#G#J#I#D#E#G#I#K#I#G#G#G#F#G#F#H#J#J#KbxaBaba0a1a1aSa0#3#P#O#G#E#D#E#F#E#F#D#F#H#F#E#E#E#H#H#E#E#D#E#E#Bfh#F#J#O#Pa0abaSa1aSaS#O#O#3#Pa1bxbx#M#I#F#F#G#G#J#G#D#G#I#F#H#G#G#I#J#K#I#I#J#H#J#K#L#L#L#L#K#M#M#L#J#K#L#N#L#K#L#Jlz#L#H#K#O#O#K#J#N#M#N#P#P#P#J#L#N#P#3#P#O#M#O#L#O#O#O#N#J#J#O#K#K#L#L#M#O#N#N#M#O#L#L#O#P#3#P#3#N#3aS#3#P#N#PaSa1#P#N#O#PaS#L#L#PaS#N#K#PaS#Pa1aSa1#N#L#N#3a1aS#3#P#P#O#OaS#3aS#3#L#PaS#M#N#P#PaSa1a0a1aSa1#Pa1a0bwbybxaba0bwbwbxababbybwbxa0a0a0bwby#3a0bxabaSaS"
"bxbxbxbwbwby#3aSa1bxbybxa0a1a0aSaSa0a0ab#3#Pa0#3#PaS#3aSa1a1a1#3#3#P#PaSaSa0aSa1#3aSaS#3#P#P#PaSaS#N#N#O#NaS#O#M#P#3#P#L#Pa1#PaSa1bjfilulAlBlC",
"lDlEbq#G#I#K#H#G#I#I#G#F#I#I#I#L#J#H#E#F#I#G#H#H#E#D#E#H#F#GaSbxa1#K#H#Baaf#f##Aaafh#C#F#K#Pabbxa0#O#H#E#F#D#D#C#B#D#C#D#H#E#D#D#C#E#D#E#Mbxbw#3#I#DfP#A#Ac5#R#nb.c5c7#Aaa#E#Ka1abj0#I#I#G#E#D#F#F#F#G#G#G#J#J#I#K#I#J#K#K#N#M#L#M#L#J#J#G#I#G#G#J#M#I#J#J#I#O#J#I#L#O#L#G#L#O#O#P#N#K#G#G#M#K#L#K#J#I#J#K#J#K#L#L#K#H#G#I#G#G#K#G#K#K#K#K#K#J#K#K#M#P#L#M#P#L#K#I#G#L#I#J#L#L#K#L#J#M#L#G#J#M#O#J#I#O#M#O#P#L#G#H#J#L#K#K#G#G#I#J#L#I#L#L#L#K#G#I#J#I#L#L#L#N#N#N#P#O#P#N#Na0a1#Pa1a1#P#3#N#P#P#Pa1a0aSa1aS#PabaS#Pa0a0a1#PaS"
"ababbyaba1#P#Na1#3aS#3#N#P#P#3#P#N#P#P#P#M#L#M#M#O#P#N#P#3#P#P#P#O#O#O#PaS#P#P#3#N#O#M#L#M#M#O#P#P#O#O#L#O#N#L#L#N#P#O#M#P#3#PaS#PbWePlulFlGlH",
"lIlJf##L#M#O#L#L#L#K#I#G#L#L#L#O#I#I#K#L#L#G#L#L#K#K#K#NbwaB#3#E#Ac6c6c7c6c6c6c6c6c6bqbqc7#A#B#KbwbGaBa0#J#E#E#E#H#G#H#H#G#G#G#H#F#La1bWbGab#Fbqc6bq#Af##Ac7bq#A#Abqbq#2bqc7c7fP#LlKbVaS#I#G#K#L#O#L#L#M#M#L#M#M#O#K#M#L#L#N#J#K#M#G#G#G#K#L#L#K#L#M#L#M#M#O#P#O#P#P#N#L#J#M#P#P#3#O#L#N#P#P#L#P#P#P#P#N#3#N#M#P#P#L#O#P#3#3#O#N#P#P#P#PaS#P#N#3#Pa1#3#O#3#P#M#L#K#O#P#M#O#N#P#N#N#N#3#N#O#P#N#M#J#J#N#N#N#M#G#K#M#N#K#J#O#L#L#L#M#N#K#L#L#L#J#L#O#P#O#L#O#N#N#P#3aS#P#3a1#3ab#3#3aS#N#O#M#Oa1#3#3aSa1#3#P#3a1abaSa1a0#3#P#M#P"
"a1a1a0#P#N#P#3a1#O#3aS#P#3#PaS#P#N#P#3#O#M#P#3aS#N#P#P#N#P#P#3#P#N#P#P#3#3#M#P#O#L#K#L#M#N#M#N#N#N#O#M#O#P#N#M#N#N#O#L#M#N#P#3#P#LbVg1lLlMlNlO",
"lPlJbq#I#L#L#K#K#K#I#K#K#O#N#J#K#J#L#M#J#K#M#P#N#L#La1aTbw#Iaa#2#Aaa#QfhfPaafPaaaafPfPaaaaf##Abqaa#LaBbUby#O#H#G#J#G#I#H#F#F#F#C#JbwaTaBa1#QbqaafPfh#Q#QfPfP#QfPaafP#Q#B#QfhfPaa#2#EbxbWbx#J#O#N#P#M#L#O#L#L#O#M#L#J#L#J#L#L#I#L#L#L#L#O#P#P#N#N#O#L#M#K#L#N#N#M#L#L#J#L#M#NaS#M#O#M#N#Phj#M#Pa0a1#3#3#P#3#P#P#3#3#M#Pa1a0a0#PaS#3#PaSa0#3#P#O#O#P#3#N#P#3#P#3aSa1a1#3#3#3#P#N#O#M#P#P#P#N#P#M#O#P#Na0aS#P#N#OaS#3#N#Pa0bya1aS#PaSa1#P#Pa0#P#Na0abbya0aSa0a1a0aba0a0aSaSaSa1a0a1a0a0aSa0abbybxa0aba0a1a0#3a1abbxa0a0a1#3a0a1ab"
"bwa0a0aSa0a0aSaSa0bwbwa0a0a1a0aS#Pa1a0#PaSa0bxa0#3a1#3#PaSaS#P#P#P#N#N#P#M#L#P#L#M#P#P#3#P#P#P#O#M#M#L#M#N#O#O#N#M#L#O#M#P#P#O#O#MbUfulLlQlRlS",
"lTlUb.#G#G#F#E#H#H#H#G#E#J#J#H#G#J#G#F#H#K#J#J#G#H#IaSa0#Mf#fP#CfP#QfPfh#QfPfh#QfP#Q#Q#QfhfhfP#C#Qfh#3bybVbU#P#F#E#G#G#G#G#G#H#IbwbVbxa0#N#D#D#C#B#D#Bfh#E#Cfh#Q#B#E#D#C#B#C#B#D#B#E#3abbyaS#L#L#L#J#L#L#L#L#J#L#M#L#G#J#N#K#I#L#L#L#P#M#I#L#M#O#N#L#L#K#K#M#M#L#L#L#L#O#K#O#N#J#M#P#L#K#L#P#P#N#O#L#N#O#N#M#L#N#P#O#O#N#P#N#M#3#N#P#O#M#O#N#L#J#N#P#L#M#P#NaSa1#M#L#O#P#P#P#O#O#O#N#P#M#L#M#L#P#P#Oa0#P#NaS#3#M#L#Pa0aS#P#O#P#PaSaS#O#Pa0a1#PaSa1a0#3aSa0a1a0aSaSa0a0#PlVbxa1#3a0a0a0bwa0#PaSa0a0byabbxa0abbxaba0aba0a0bya1ab"
"bwa1a0bxa0aS#3abbxaba0aSa0a0a0#3#Pa0a0a1aSaSa0a1#Pa0a1a1aS#P#3#3#P#O#P#3#M#O#P#N#3a1#N#O#O#P#P#P#N#N#N#N#N#O#O#N#M#P#P#MaS#P#O#3#3bUePlWlXlYlZ",
"l0l1#A#L#J#I#G#K#K#K#G#G#K#I#K#M#M#I#I#M#L#G#I#G#K#NaSa1#3#K#G#I#E#E#H#G#F#F#F#E#F#F#F#G#I#F#F#I#J#Ma1bxbxbUbV#K#I#L#J#K#K#G#JbxbXaBa0aSa0#3#L#F#H#J#H#I#K#G#E#H#I#I#G#H#H#G#H#G#K#Na1ababbx#3#P#L#J#M#K#K#L#L#N#P#P#L#L#3#O#M#P#P#M#N#L#K#N#O#M#P#M#J#N#N#N#M#L#O#P#N#L#J#O#M#M#P#P#K#J#P#P#K#K#K#K#M#K#M#L#L#P#3#O#L#P#P#L#O#P#K#M#L#L#P#P#L#J#P#P#K#O#3#O#O#M#I#L#P#O#M#N#K#L#3#P#P#O#L#O#P#P#K#O#3#N#3a0#P#M#OaS#P#O#O#M#P#O#M#P#M#NaS#P#L#O#3#N#L#P#N#N#P#P#3a1a1#O#PabaSaSa0a0#3a0#P#NaSa1#3a0a1#Na0aba0a0a1a0a0abaS#Pa0"
"a0a1abbya1#3a0a0#P#P#P#P#3#P#P#3#PaSa1#N#O#3#3#M#O#P#M#N#O#O#P#P#O#K#P#P#L#O#P#M#M#M#J#L#O#L#L#O#L#K#O#O#M#L#L#L#O#N#L#L#N#M#N#P#PbWePl2l3l4l5",
"l6.T#A#G#E#H#D#F#F#D#D#H#J#G#G#G#F#E#E#F#D#D#E#F#G#O#3#3#3#P#M#K#F#H#I#H#H#I#H#E#G#J#G#I#J#G#H#K#M#PaSaS#PabaB#3#L#M#M#N#O#I#KaBbyaS#N#O#O#O#K#J#L#J#G#I#I#G#H#H#F#F#F#G#I#J#J#L#N#N#N#3#N#P#3#J#G#J#J#H#H#L#O#K#L#O#G#J#O#K#O#P#L#I#L#J#L#M#M#N#P#L#I#P#N#K#L#G#J#K#G#E#K#N#M#L#L#K#K#J#K#G#H#G#I#Idkdkl7#M#L#L#L#I#J#O#L#K#O#J#G#K#N#L#K#O#K#G#L#O#L#P#P#L#L#K#K#N#P#N#3aS#L#Oa1#P#P#P#M#N#N#L#La1a0aSa1a0#3#3#3#3#N#N#PaSaSa1#3a0a1aSa1#P#OaSa0#P#3a1#P#3abbxa0a0bx#3#3aba1abbya0#3a0aSa0bxabbxbwa0#PbxbyaSa0#3#3a1#P#Oa1bx"
"a0a0a0a1#P#P#P#O#L#O#N#O#P#P#P#3#P#P#P#K#K#P#O#L#N#L#I#L#P#N#M#M#L#G#L#M#K#O#O#J#K#I#G#L#L#K#O#O#J#I#M#L#J#J#G#I#J#G#G#M#M#M#O#M#LaBeOl2l8l9m.",
"m#l1fP#L#J#K#G#G#G#G#K#L#K#J#G#H#F#H#H#H#G#H#G#I#H#M#O#L#L#K#K#I#G#K#I#F#G#J#H#F#J#J#H#G#K#I#I#M#O#N#3#NmabxbVab#3a0aba0aS#3abbWbwa0#3#N#O#M#M#N#O#K#L#I#G#H#I#G#I#I#J#L#M#O#O#L#M#M#O#O#Pa0bw#M#L#N#M#L#O#P#N#L#L#L#G#J#M#L#O#O#J#K#P#O#L#NaS#P#N#L#L#N#O#L#O#K#L#K#I#M#Phzmb#L#J#G#J#J#J#K#J#L#N#M#N#O#L#M#M#O#L#M#P#P#L#N#N#O#M#3aS#M#L#P#M#K#O#P#P#3#N#L#3aS#P#Pa0aba0a1#Pa1a0aSa0a1aSa1#3#3bxbxa0a0a0#3aSa0a1a1a0a0abbxababa1a0a0a0a0aSa0bxa1a1a0aba0a0bwbx#3a0a0aSa1bxbybybwaSa1aBbya0bybVaTaBabbxaBbwbybwa0aba0a1abaBbx"
"a0a0a1#P#P#3#3#3#3aSa0#3aSaS#3#3#3#P#N#N#P#3#N#P#P#P#N#3a1#N#O#P#L#K#M#N#N#P#O#J#O#N#L#L#P#P#P#O#L#O#N#M#O#M#L#M#L#L#P#P#N#N#N#M#LbVePl2mcmdme",
"mfmg#A#G#J#J#G#K#J#J#L#J#I#K#J#G#I#J#I#G#G#G#K#M#I#M#L#K#K#I#G#G#G#H#F#F#F#F#E#F#G#H#F#F#G#J#J#K#O#O#M#M#3byaTaTbWbWbwbyaBaTbGbXbWbxaS#P#O#M#M#M#J#I#K#I#G#G#G#H#H#H#H#J#I#I#I#G#K#K#L#M#Pa0a1#K#K#K#I#I#L#L#J#G#G#I#L#G#L#N#L#K#G#M#O#I#J#O#M#I#J#G#I#L#I#M#L#I#L#L#L#P#M#J#L#O#L#L#M#J#J#K#I#L#P#L#L#K#K#L#L#L#L#M#N#N#O#N#P#O#NaS#P#O#O#O#P#P#Pa0a0#3#O#Pa0#3#N#3a0aS#O#P#N#3aSa1a0#3aSa0a1bxbyaSa1a0aba0aba0a0a0a1a0bwbya0a0#3a0a1a1a1a1aba1aSa0a0a1aSa0bxa0aS#3aSbxa1a0bwabaS#Pa0bwaSaSabbxaS#3#P#Pa0#3a0abaSa0a0a0bwabaS"
"a0a0a0a0a0a1aSaS#Pa1abaSaS#P#N#P#P#P#O#P#P#N#O#N#N#M#L#P#N#K#K#L#L#M#K#N#N#L#K#L#P#M#J#L#N#L#J#J#I#K#L#L#O#L#L#N#O#N#3#O#O#N#N#N#PbUfumhmimjmk",
"ml.Tb.#E#I#H#D#G#F#E#H#F#G#I#H#H#F#F#H#D#E#I#L#J#G#M#O#M#K#G#H#H#F#D#E#C#C#C#C#E#D#C#D#D#E#G#H#G#M#K#K#O#3a1bxaBbWbwabbyaBbyabaSabbx#N#O#L#I#G#G#E#F#D#C#Cfh#B#Q#Q#B#E#F#D#E#F#F#J#J#K#M#3aS#I#J#G#J#J#K#L#J#G#L#G#L#M#F#M#M#G#H#G#J#H#D#F#G#G#F#J#J#I#J#G#M#L#G#K#J#G#K#I#J#L#J#J#I#J#I#H#H#J#O#L#H#J#G#K#L#I#I#I#K#G#L#J#G#K#J#M#L#K#L#L#J#N#K#J#3#O#I#I#M#L#J#J#K#L#K#K#O#O#O#O#Pa1#P#Pa0#N#N#P#Na1a1#P#P#P#P#N#L#OaSa0#P#P#P#M#3#P#N#N#P#P#P#3#P#P#3a1a0a1aSa0#PaSab#Pa0by#3#N#3a0#3#P#P#P#3#P#3aS#3#3#Pa0a0#Na1#3#P#P#P#P"
"a0#3#P#P#N#P#L#L#NaS#P#M#N#M#N#P#L#L#M#O#M#O#O#K#M#M#N#O#L#L#L#K#M#L#J#O#L#I#G#K#K#G#I#I#J#G#G#J#J#K#K#L#N#L#L#O#K#K#L#K#N#N#M#O#ObVePmmmnmomp",
"mq.Tc7#E#D#E#D#E#C#B#F#E#E#D#D#B#C#D#D#C#F#H#F#E#E#G#M#O#L#G#H#H#F#F#E#QfP#B#B#Bfhfh#B#C#D#F#H#I#I#I#K#NabaS#P#N#M#K#I#G#G#G#J#J#MaSabaS#L#G#G#I#F#Dfh#BfPaa#Qaa#Q#Bfhfh#B#E#F#H#J#I#L#Pa1#K#K#K#F#I#M#L#K#J#I#K#J#M#O#L#M#I#G#K#L#K#I#M#N#N#O#M#K#L#P#P#M#O#M#M#N#L#L#N#P#M#L#J#I#G#K#L#I#M#N#O#L#K#O#L#N#N#K#M#P#P#N#P#M#L#PaS#P#P#P#N#P#Pa0aS#3#3#M#N#PaS#P#Pa0a0aba0a1a1a0bybxa0bxa0bxabaSaSbxa0a0#3#3#P#OaS#3aSa0a1aS#Pa1aS#3ab#3#Pa1a0a0a0a1#Pa1bxbxa0a1a0aba0bxbwabbxa1#3a0aba0a1bxaBbwbwbxbxa0byaBbxbybya0bya0a1abbxa0"
"a0#3aS#NaSa1#Pa0a0a1aS#PaS#P#3aS#O#P#3#P#3#3#P#O#P#P#P#P#O#O#P#N#P#N#N#O#K#K#L#O#K#L#N#N#N#M#L#L#L#O#O#L#O#M#M#O#L#L#N#M#O#L#O#L#JbWePmrmsmtmu",
"mv#a#Q#M#P#P#O#P#P#N#P#P#P#N#P#N#O#P#N#Na1#P#P#P#PaSabaBa0#3#3#P#N#K#J#I#I#J#G#H#I#I#J#L#L#L#M#O#NaSbybyabaSa1a1a0#3#P#O#O#P#P#O#N#3aSbxaBab#N#N#M#L#J#I#I#G#G#H#I#I#G#I#I#M#N#M#Na1aBby#3#3#P#N#Pa0aS#PaS#3#3a1#3aS#3#3#P#PaS#P#3#3a1bxbybxa0a1#3a0aba0#Pa0a0aSa1a1aSa1aS#3#Pa1aS#Pa1#P#Pab#3#3aSaSa0aS#3#3#PaSa1a0a0aS#3abbwa0a0a0a1a0bxbxaba0a0a0a0ababbybybwbWaTbWbwbwbwbWbVbwbwbWbwbwbwaBaBbVbWaBbWaTbVbWaTbwaTaTbwaBbwaTaTbwbwbxbxaBaBbWaBbybwbUaTaBaBaBaBaTaTbUaTaTbVbwbWbVbWbVaTbXbjbjbUbWaBaBaTaBbwbVaTaBbwaBbwaBbwbw"
"bwbwbwbybwbybybWbxbxbybxbwbxaba0a1ababbxaba0a0abbya0a0aba0a1a0a0a0a0a1#3aSaS#3a1#3a1a0a0a1aS#3#P#3a1#3#3a1#3#3aS#3aSa1aS#3aSa1aSa1bjfimrmsmwmx",
"my#.fh#PaS#3#P#P#O#N#P#P#3aSaS#3a1#3#Pa1a1#Pa1#P#P#P#Na0bWbVbwa1#N#M#O#O#L#L#K#K#J#K#O#P#O#M#PabbWbUbyaS#Pgq#N#N#3#N#M#O#3#3#P#P#3aS#N#3aSa1aBaBbxa1aS#P#P#P#O#N#P#P#3aSa1bxbwbWbUbVbyaba1#3a0bwbwbwbybybxabbyaBbwa0a1a0bwbwaBbWaBaBbWbwbVbWaBbwbwbVaBbwbwbWbVbwaBbybybwbwbwbwbwaBaBaBbwbVbWbybWbwbwaBbybybxbxbwbya0a0bwbWbVbVaBaBbwbwaBbVbwababbwbWbWbVbVbVaTaTaTbjaTbVbVbUbjbXbXbjbNbGbGbjaTaTbXbGbjbjbGbGbjbGbjbNbXbjbjbXbGbjaTaTaTbVbjaTbVaTbjbNbjbXbXbXaTbGbNbGaTbwbVbXbjbjbjbXbjbXbUbjbGaTbWaTbGaTaTbVbXaTbWaTaBbwbWaBbW"
"bVbVbVbVbWaBbWbWbwbWbwbwbwbxabababbxbxa0aSa0bxbyabababa0a1a0aba0#P#PaSaSa0a0a1a1a0aSaSa1#3#3#P#3a1aS#3aSa0aSa1a1#P#3aSa1a0a0a1a0a0bjfomrmzmAmB",
"mCmDbq#G#G#F#G#I#E#G#K#I#G#J#I#G#G#H#K#M#I#I#J#I#J#G#H#J#MaSbwbwbwbwbybxa1aSaS#PaSa1bxbwbybyaBbVab#N#M#O#O#N#G#I#J#E#H#L#N#M#L#L#M#O#J#N#K#I#3aSaSabbwaBbwbxbwbWbVbwbWbWbVbVbxa0aS#3#P#3#P#Pa1a0a1#3a0aSaSa0a0aba0aSaSbxbybxa1bxbybyaba1aba1#PaSbybwbxbwbybybxabbwa0bxaBbwbxbybybxa0a0bwaBbybwbwbwbwbxa0bxbxbxbya0a1mEaBbwabbxbyabbybwbwaBbya0bxbWbWbwbwbWbVbVbybwaBbxbxaTbjmFaTbUaTaTbVbjaTbVbjbNbXaTbXbXaTbVaTbjbXbVbUaTaTaTbWbWaTbVaTaTbWaBbUbGaTaBbVbVaBbVaTaTaTbWaBaTbGbXbWaTbUbGaTbwbVbwa0bybUbUbWbVbVbWbWaBbVbybwaTbWbw"
"bwbwbybxa0bwaBbxbxbxaba0a0aSa0a0a0a0a1#Pa1a0a0#3#3aS#P#3aSaSaS#P#O#Pa1a0#3#P#3#3#3#P#P#P#M#M#NaS#3#P#3#3#3#N#3aS#Pa1a0aS#3a1a1aSaSbjfomrmGmAmH",
"mImDbq#H#I#G#G#G#H#J#L#G#H#G#I#G#G#K#L#J#K#K#I#J#I#H#G#K#L#L#M#Pa1abbyaS#M#P#P#Oa0a0aSa1aS#PaSa1#P#M#M#O#P#L#K#N#L#L#P#3#M#J#L#K#L#M#K#L#J#LaS#N#L#K#O#N#O#NaS#P#N#P#O#K#N#M#K#O#N#O#M#P#N#Pa0aS#L#K#O#L#OaS#O#M#P#O#Pa0a0#3#N#Pa0#3#Na1a1#P#3bxbx#3#Pa1#3a0a0aS#3#Na0bxaS#PaSaS#P#Pa1mJaS#3aS#P#3#3#P#PaSaSaSa1a0a0bxbwab#Pa0a0#3bxbxaSa0a1aSa0bwbya0a0bybwa0abaBbya0bwaTbwmKbymLbxaBbybwa0bybUbwbybybwbwbxabaBaBbxbwbwabbwbxa0bybwbwbyaBaBbwaTaTaba0bwbxbwaTbwbybWbwbwbUbXbWbwbWaTaTbwaTaTbWaBbXaTbwbwaBbxbwaBbxbwabbWaTbwbx"
"bwbyababbybyaba0mMa0a0a0aSa1aba0a1a0a1a1a1aba1#N#P#3#NaSaS#N#P#P#N#Pa1#3#P#N#P#3#N#O#P#P#O#N#3#P#M#O#P#O#P#O#N#M#OaS#P#N#P#P#P#N#NbGfimNmOmPmQ",
"mR.9fP#K#O#M#K#I#L#M#K#I#K#M#O#L#J#N#O#L#O#L#K#N#O#L#NaS#P#Na1aS#N#P#N#M#K#P#P#M#P#N#O#P#M#M#P#P#O#K#L#P#N#J#PaS#3#P#3#N#L#NaS#P#P#P#N#L#M#3#P#L#L#P#P#P#P#PaS#P#3#P#O#Pa1#3#Pa0a0#3aSa0#3#P#P#P#M#Pa1#P#PaS#N#PaS#N#Pa1#P#O#O#Na1#N#Na1a0a1a0a1#P#OaSa1#PaSaS#P#O#P#3#N#M#N#P#3#P#Paba1#3a1#3#PaS#3#PaSa0a1#3a1a1#P#P#P#O#L#Pa1#OaS#3#PaS#P#O#3a1#P#M#Oa1a1#Oa1bybybybwa0#Pa0bwaba0bya0#3a1bybxaS#3a0a0a0a1a0bwa1a0a0aSa0bwaba1aBbWbybxaBbxa1a0a0#3aSbwa0a0bya0bxbwa0abaBbwa0a0bxaBa0a1bwaBbwbwaBa1aSbybya0ababa0a1a0abaS#P#P"
"#3a1aS#Pa0a1#P#3#P#NaS#P#O#PaS#3#N#3aS#O#N#P#O#K#M#P#M#P#P#M#P#N#L#N#P#M#K#L#O#N#K#M#N#N#N#P#M#K#L#P#O#L#O#O#M#L#N#P#M#L#O#N#P#P#PbjfimNmSmTmU",
"mV#.fP#L#L#L#K#K#L#K#M#M#L#K#L#J#J#N#G#G#J#K#M#O#L#J#L#L#J#K#L#I#G#L#O#L#L#N#N#I#P#N#L#O#L#J#L#L#K#L#L#O#L#G#L#P#M#L#N#L#L#O#N#L#J#L#L#J#M#M#M#O#O#M#L#M#L#N#N#K#L#O#N#P#N#M#M#Pdc#M#N#N#N#NaSaS#Pa1a0#N#Pab#3#3a1#NaSaS#P#P#PaSa0#P#Pa0a0aSaS#3#N#3a0a1#P#N#P#P#P#P#N#P#3#P#N#P#M#MaS#O#L#N#N#P#3#P#N#P#P#O#O#N#O#M#PaS#3#Pa0a1#Oa0a0#3a1aS#Pa1aS#3#3aSa0a0#3bxbwbwabbwaba0bwbwbya0bybxabbwbybwbwbwbwabbwabbwbwaSa0bxbxbwbwaba0bwbwa0bxbwababbWbWbwaBaTbxbyaTaBbwbWbwaBaBbwbwbwbwbWbyabaBbWbwbwbyabbwaBbwababababa0aba0a0a0a0"
"#3a1#3#Pa0#3#PmW#3#3a1#3#N#P#3#O#N#P#O#L#O#P#P#O#P#P#J#P#P#L#O#M#L#O#L#L#L#L#O#M#J#L#N#O#L#L#L#K#M#M#M#L#L#M#L#O#O#M#P#N#N#O#P#O#PbXePmNmXmYmZ",
"m0cWc5#D#H#G#G#H#H#F#G#G#F#F#G#H#I#L#D#F#J#G#F#E#F#G#I#G#G#G#H#I#I#M#M#L#K#K#G#H#M#H#F#L#I#H#H#F#G#G#F#G#H#E#H#G#H#E#H#E#H#G#G#H#F#G#I#G#G#H#I#J#G#G#I#I#I#L#G#E#J#K#G#H#F#H#H#H#G#G#G#I#K#L#P#P#L#L#L#I#O#P#G#L#O#I#L#J#L#P#L#L#M#K#L#M#O#J#L#K#K#O#L#M#J#L#M#L#K#L#I#L#M#K#J#L#J#M#P#G#K#N#O#J#I#I#I#L#K#K#K#I#M#O#3a0aS#P#P#O#LaS#O#L#3#P#L#O#M#3#3#O#P#P#P#3a1aS#Na1#PaSa0a0a1#3a0ababbxa0a0bya0a1a0a0a1bwa0#Na0bya1#P#P#PaSaSaSaSaS#3a0a0bWaBbxababaSabbwa1a0bwa0a1a1aSbxaS#3a0#3#3a1a0#3#3#3#3a1aSa1#P#3aS#3#3#3#P#3#P#P"
"#O#N#N#P#P#L#L#P#N#L#K#K#K#M#L#K#J#I#K#K#N#P#O#L#L#J#G#M#K#G#L#K#G#G#G#I#I#G#I#I#G#I#I#I#H#I#G#I#J#J#I#G#I#K#J#L#K#K#M#M#L#M#L#L#PaTeQm1mXm2m3",
"m4m5#Q#L#L#K#L#L#L#L#L#L#L#M#N#L#L#K#J#N#M#I#J#L#N#P#PaS#P#O#PaSaS#3#N#L#L#P#P#N#P#Oa1a0#N#L#M#P#P#M#O#3#O#M#N#P#N#L#L#L#P#P#3#P#N#N#M#M#M#L#N#N#M#O#N#O#L#M#J#L#N#L#J#K#L#N#M#M#3#M#M#P#P#3#P#M#M#N#3#P#P#P#Pa0aS#L#L#PaS#P#LaSaS#P#P#3#3#P#P#N#P#P#3a0#3#3#P#P#P#P#3a1aS#Pa1a1#P#P#P#Na1#3#P#M#N#3aS#Pa1a1#N#PaSa0a0aS#N#PaSa1#Pa1aSabbwa1#PaSababa1a0bwaba0abbyaba0a0a0bybyaBbWaBbybxbybybxbwbWbwbwbWbwbybwabbxbWbya1a0a0bybxabbwa0a1abbybwbxa1#PaSaba0a1a1a1bwbx#P#PaSa0aS#PaSa0#P#P#3#3#N#N#O#N#P#3a0aS#P#N#N#N#N#P#P#P#O"
"#P#P#M#M#L#J#M#L#J#H#I#L#M#K#L#L#G#J#L#M#M#K#G#G#J#J#G#I#G#K#M#G#F#H#G#I#G#G#J#J#G#I#J#I#H#G#H#I#J#M#L#L#J#K#L#K#K#M#O#L#M#N#N#M#NbWeOm1m6m7m8",
"m9#c#C#P#P#Pa1#3#3aSa0a0a0a0a0aS#3aSa0ab#3#PaSbxbxababbya0a1bxaba0a0ababa1a0bya0abbxbwbxa1a0abbyababbybxa1a1a0aba1a0a0a1a0a0a0aS#3#Pa0a0a1a1a0aba1a0a1aS#P#3aSa0#3#P#Pa0a0a0#3a1a1#N#3a0aSa1a1a0aS#3a0a1a1a0abbya0a1a0bxbxa0abbya0a1abbwbxa0a0a0byababbxa1aSa1ababa0a0bybxbxbxaba0aSa1a0bxaSaSaSbxbxa0a0a0a1aSaba0a1a1a1a1#3a0a0a1abbxbwaBababbwaBbwbybVaTbwbwaBaTbwbWaBaBbWbWaTaBbxbxaBaTaBbWbVaTbWaTbVbWbwbwbWaTbWbxbyaBbVaBbwaBbwa0bxbwbxbybxbyaba1bxbxa0abbybwaba1a0bybwabbxbwabaSa1bxaba1a0a1a1aSa1a1#N#M#O#P#P#O#N#P#3#N"
"#P#P#L#J#L#M#N#K#I#J#M#O#L#L#L#G#G#L#L#J#I#J#J#G#G#K#G#I#I#K#K#G#H#I#K#I#G#K#L#I#G#J#L#K#K#K#J#L#L#M#L#G#G#L#M#L#L#M#P#O#O#O#N#M#MbVg1m1n.n#na",
"nbnc#A#K#L#L#M#L#M#N#O#L#N#P#O#K#L#3a1#3#L#N#3#3#P#N#P#O#L#M#3#P#M#P#P#M#L#3#P#L#N#P#3#3#L#NaS#P#Pa1a1#N#M#P#3#N#M#P#N#N#P#N#N#O#M#O#P#3#N#3#P#P#Na1aS#N#M#Pa0a0#P#Pa1a0a1#P#P#P#P#NaSa0#3#3a0a1#PaSa0aS#3a1a0bxa1#Pa0abaSa0abaS#O#Pa0a1#P#3aS#3a1aS#P#P#P#P#P#3aSa1a1a1#3a0a0a1#P#3a0bxa0#Pa1bxbxa1aSa1aSaSa1byaba1a0abaS#3bynda0bxbyaBaBbxbxaBaBaBaTaTaBbwbVaTbWbwbVbVbWaTaTbWbwbwaBbVaTaTbUaTbWaBbXbXbwbybWbjbjbVbwbUbGaTbWaTbWbwbwbVbVbwbwbWaBabbybWbwbybwaBaTaBabbwaBbwbwbWbwa0a0bwbya0a0aba1a0a0a1a1#PaS#3aSa1#3aSaS#P#P"
"#3#P#L#L#P#3#P#L#O#P#P#L#L#L#K#J#K#M#L#K#L#L#K#G#L#L#I#J#K#L#M#J#I#K#L#K#M#O#L#J#L#M#K#K#M#L#L#M#L#L#K#Kne#M#O#N#O#P#N#N#3#P#P#M#Nbjfim1n.nfng",
"nhcUc6#F#E#D#D#F#F#G#G#E#E#H#E#D#G#L#J#G#H#K#K#I#G#G#J#I#G#I#M#J#J#N#L#G#I#N#J#G#M#M#O#M#I#K#O#L#M#N#O#J#K#M#L#J#L#L#G#G#I#G#G#L#I#G#G#J#I#J#L#J#I#K#J#G#J#O#P#L#I#L#N#L#M#L#M#O#L#K#M#P#L#P#P#L#K#P#N#K#M#P#P#P#L#I#O#P#N#P#P#L#K#O#3#O#M#P#P#L#M#M#L#P#N#L#L#L#O#M#N#N#O#M#O#L#L#P#3#P#M#M#PaS#P#P#P#P#P#O#N#P#P#Na1#P#O#Na0#P#Oa1a0a0aS#M#Pa0a0a0aba0#3aSbxabaSa0bxa0a0aba0abaBbwbxbxbybybwaBbwbybybwa0bxaTbUbWbxaBaTbVbWaBbVbWbwbybwaBbxbwbVaba0bwaBa0bxbwbwaBbxaSnibybxbybwa0#3a0bxa1#3a0a0#PaSaS#Pa1aS#3#P#P#3#P#3#P#N#O"
"#N#O#L#O#3#P#M#L#O#N#O#L#L#M#L#K#K#L#L#J#M#K#G#J#M#I#H#K#J#K#K#G#G#J#I#L#L#K#G#G#J#L#G#J#M#J#I#L#K#J#Mnenjfx#L#M#M#P#O#O#O#O#M#M#3bjf.m1n.nknl",
"nmnn#Q#K#I#K#L#K#L#O#L#G#I#L#G#G#M#L#L#L#L#L#L#L#K#M#O#P#P#P#O#O#N#P#O#P#P#O#OaSa1aS#3#P#M#P#3#N#P#P#N#L#PaS#P#O#3#3#O#N#P#N#P#P#L#L#L#M#M#O#P#L#L#L#L#G#L#M#L#L#L#M#O#L#L#O#L#O#N#N#O#L#N#3#P#NaS#P#L#Na1#3#P#P#O#L#3#3#PaS#P#O#Na1a0#P#Pa0#P#NaS#3#Pa0#P#M#P#P#P#Pa1#3#N#N#P#N#MaS#P#P#3#PaS#3#P#3#3#PaSa1aS#P#Pa1a0#3a0a0#P#Pa0bwbxaba1#Pa0bwa0a0a0a0aSabbwbya0bwbWbybwaTbwbWaTbxbwbWbVbWaTbUbWaBaBbVabbwaTaBbVbWbWbWbwaBbWbVbWaTaTbVbwbwbVbWbwaTbwabbyaTaTaBaBbxabnobwbybwbwaba0bwbwa0a0bwaba1aba0aSabaS#P#3aSa1aSa1#3#N#O"
"#P#O#L#N#N#O#N#O#O#N#M#O#O#L#N#O#M#L#K#L#N#L#L#O#L#J#L#N#L#L#L#I#J#M#K#L#L#K#I#L#M#M#K#O#N#L#M#P#M#O#P#K#K#M#N#O#N#P#N#O#O#P#M#N#3bXf.npnqnrns",
"ntnc#Q#O#N#N#P#PaS#P#L#L#PaS#N#P#3#Na0#3#M#NaS#N#N#N#Oa0#3#P#N#3a0#3#Pa0a1#Na0ab#3a1a0aS#Pa0a0#3#3aS#P#Pa0aS#3aSa1#P#Pa0a0#3#P#P#P#P#PaSaSa1#P#M#Na1aS#P#3#P#3a0#N#Oa1a1#3a1#O#3a0#3#N#Pa1aS#P#3a0#P#3byaba1a0a0#PaSabaS#PaS#3#P#3a1#3#Pa0aS#N#Pa1aS#O#P#P#P#P#P#3a1a1#L#L#PaS#P#3#3#Ma1#P#L#O#3#N#N#O#LaS#P#O#O#Pa0#3#Pa1#3#OaSbxaSa1bxa0aSbxbwa1a0aba0a0bybyabbwbWbybxbWaTbxbxbwbwbwbwaBbWaTbwa1bxbVaBbyaBbwbwaTbya0bwbwabbwa1bxbWbxaba0bWaBbybxbVa0a0bVaBbxbybwa0a0bwa0a0aba0a1a0aba1aSa0a0#P#Pa0aS#N#P#P#P#N#O#P#P#P#K#I#L"
"#N#L#M#N#J#N#O#G#K#M#K#K#K#G#L#L#J#G#K#O#L#I#L#L#G#L#N#K#K#M#K#G#L#M#I#J#K#J#I#L#K#K#M#M#J#J#M#P#K#K#L#L#L#M#O#O#N#M#I#L#P#P#O#P#NaTfinpnqnrnu",
"nvnwc7#K#G#G#L#L#L#K#G#K#L#K#M#3#M#M#M#G#G#M#N#K#J#I#J#L#F#G#L#N#P#L#J#P#L#I#L#J#F#J#L#H#G#L#L#L#L#L#O#M#M#L#L#L#K#G#L#N#L#J#K#O#O#L#O#P#N#N#M#L#N#L#L#N#P#L#O#L#G#L#P#M#K#L#K#N#K#H#L#O#P#N#J#L#P#K#L#P#J#I#N#L#I#L#P#L#L#M#N#P#N#N#M#M#L#G#I#O#P#L#K#M#P#O#L#P#N#O#L#I#L#M#K#M#P#L#K#L#G#H#L#O#L#J#K#L#O#G#I#M#P#P#K#I#O#M#I#M#L#F#K#N#I#K#P#P#O#O#N#3aSaSa1aSa0aS#NaSbyabaSa0bybwa0bybWbwbwa0a1bybxa0aBbWbxbya0#NaSbwbxa0a0a1bya0#Ma1abbya0#Pa1a0#P#3a0#M#LaS#N#K#M#3#N#P#P#PaS#P#P#N#P#N#J#K#P#3#N#M#N#P#O#L#N#P#O#M#G#J#L"
"#J#L#N#L#L#L#H#F#I#L#J#G#I#I#L#H#H#J#K#L#I#H#J#G#F#I#I#E#H#K#H#H#J#J#G#I#I#K#J#K#K#J#L#J#H#G#L#L#I#J#L#M#L#M#N#N#N#M#K#N#O#L#N#3#NbUfunpnxnynz",
"nAcWb.#H#G#G#J#I#I#K#J#J#J#G#K#L#J#J#G#H#I#M#L#G#G#L#L#I#I#I#I#J#I#G#K#O#G#F#G#F#G#K#G#D#F#G#F#D#D#F#G#E#F#G#D#D#D#H#K#K#G#H#F#F#G#G#G#G#H#I#J#G#G#H#E#G#G#H#H#E#E#I#L#I#F#I#L#J#G#J#J#J#K#K#J#O#N#K#J#J#I#L#O#J#I#K#L#I#G#I#L#L#I#L#K#G#G#I#M#P#P#L#K#J#J#L#L#N#L#L#O#L#L#L#I#K#M#L#M#J#I#L#N#P#M#M#3aS#P#N#N#P#3#P#N#Na1#P#L#O#M#O#3#3#L#O#P#3#N#N#Pa0#3a1bx#3aSa0abbWaTbwbxbxabbwbybwbWbxaBbwbybyaba0bybwabab#3#3abbwbya0a0bwbya0a0abababa0a0bwbwa1a1a0aSa1abaS#P#3a1#P#P#Na0a0#PaS#3#P#O#NaSbxa0aS#3#P#P#P#N#3#3#P#P#O#M#O"
"#L#L#O#M#O#K#I#L#O#N#L#J#L#L#L#K#L#L#M#M#L#L#O#L#K#L#K#J#L#K#J#L#L#K#J#J#K#M#L#L#O#L#K#K#L#N#P#N#M#M#M#M#O#N#P#N#P#3#P#P#N#O#PaS#PbGfunpnBnCnD",
"nEnwc5#J#I#H#H#G#J#J#I#J#L#L#N#O#L#M#I#J#M#O#O#L#L#L#I#LaS#L#K#M#L#L#M#L#G#L#L#G#M#J#H#I#I#L#L#G#G#K#I#H#G#G#G#K#L#L#G#G#G#D#B#F#G#H#F#F#F#G#F#D#G#I#G#L#I#I#G#H#J#L#L#L#K#K#G#G#P#P#J#M#O#O#P#N#M#M#N#L#O#P#O#M#O#NaSnF#L#O#P#O#K#L#L#O#P#3#P#O#O#L#G#G#L#L#L#L#J#L#L#G#G#L#M#N#M#M#O#J#L#O#N#O#M#L#L#K#Na0#P#M#P#P#3aS#3#O#3#3#Oa0a1#PaSa1a0ab#3#3a0a0#3#3a0a1a0bwbwaba0ab#3#NaSaba0aSaSaSa0a1#PaSa0a0bxa0aba0#3a0bxaba0a1a0a1a1aBbWabbxbybxbwbxa0a0aba1a0bya1#3a1a0bxaS#P#3a0#3#N#N#P#P#3a0#3#N#P#O#L#KnG#N#M#M#L#L#L#J#J#M"
"#M#O#M#M#O#K#K#M#L#M#K#L#J#I#L#P#L#J#L#L#L#M#L#J#L#L#K#L#M#J#K#K#O#O#I#J#L#L#K#I#K#J#L#O#P#O#L#M#K#I#K#O#M#L#L#L#N#O#K#L#N#PaS#P#PbUePnHnBnCnI",
".SmD#2#O#L#L#L#L#M#M#M#N#O#M#N#N#N#P#M#P#3#N#P#P#M#L#OaS#M#K#O#P#M#O#K#J#J#L#I#G#M#K#L#O#M#O#L#I#M#M#K#K#K#M#N#L#M#K#I#J#L#I#K#N#O#L#L#L#L#J#L#L#O#O#L#N#N#P#O#M#P#N#P#P#P#M#Ma1a0#O#Oa0a0#3#3#P#N#3aS#NaSa0#Pa1a0a0a0#PaSaba1a1#Pa1aba0a1a0aS#Pa1aS#Na1a0a0a0a1aSaSaSaSa0a0a1a0a1aba0#3a0a1a0a0a0aS#Pa1bya0#3a0bwbxa0aS#PaSaba1aSbybxa0bwbwbWbwabaBaBbwbwbybWbVbwaTbWbxbWaTbwbwbGbXbUaTbVaTbWaTaTbGbUbVaTaTaTbwaBaTbWbWbWbWbxabaTaTabbxbWaTbwbwa0a0bxbxa0bxbya0abbwbybwa0abbybxa0a0a0bxa0a0a0aS#3aS#3#O#3a1#3#3#P#P#P#N#P#P#P"
"#N#N#P#P#P#M#N#P#O#P#N#M#J#L#P#L#I#L#N#O#L#K#I#J#L#K#J#M#M#L#O#N#N#M#L#O#N#M#M#M#N#N#M#P#N#L#M#O#O#O#3#3#P#P#P#P#P#P#PaSaS#3a0a1a0bGfunHnJnKnL",
".ScWc7#F#G#I#G#G#I#I#G#H#H#H#I#K#I#G#I#I#I#J#L#N#K#J#M#K#G#J#I#I#G#G#I#J#J#I#I#J#I#G#J#G#G#L#J#G#K#J#K#J#I#K#J#I#J#G#G#I#J#I#K#J#I#L#K#K#L#K#L#K#I#J#G#L#M#J#K#L#K#L#N#3#P#O#P#3#M#M#P#M#N#O#M#N#P#N#P#N#P#P#P#P#O#P#3#L#N#P#N#P#N#M#N#N#P#P#M#N#3#P#P#3#O#PaS#P#P#3#3#3#N#M#O#PaS#P#P#3#3#Pa1ababa1aSaba1#PaSaSa0a0aSa1a0a0a0aba0bxabbxbxabaBbybxaBaBbWbVbwbWbVaBaTbwbwbVaTbWaTaTbWaTaTbVbUbVaTbwbxbxbxaBaBbxbybwbybwaBaTbVbybVaTaba0bya0bxa0a1a0a0a0a0a0a0a0aSa1#PaSab#3a1a0a0a0a1#3a1#3#3aS#P#PaS#3#P#3#N#P#P#N#P#P#N#O#L#L"
"#K#K#M#L#L#L#L#K#L#O#N#M#L#O#M#G#L#K#L#K#G#J#K#K#K#L#L#L#J#J#L#J#L#L#K#L#L#M#M#K#L#M#M#N#L#L#O#O#O#M#N#O#N#P#N#P#P#P#N#O#O#O#P#3#PbUf.nHnJatnL",
"nMnn#A#J#M#M#L#M#M#M#L#I#L#O#M#K#G#L#M#G#O#P#P#P#N#P#P#L#P#P#K#M#N#O#3aS#3#P#N#L#J#L#M#I#L#O#L#I#I#L#M#K#J#I#L#O#L#I#J#M#L#K#J#J#L#M#L#L#M#K#M#J#L#N#M#O#G#G#M#G#I#O#L#L#L#J#M#J#I#O#K#G#M#L#L#P#3#P#N#L#J#J#M#M#J#N#O#L#K#O#P#P#M#J#MaS#3#L#I#L#M#K#L#K#K#L#O#K#O#M#M#L#K#N#O#N#L#F#K#M#G#L#P#N#N#M#M#M#L#P#P#L#N#3#NaSa0a1#3#3#N#O#Pa1#3#3abaS#3a1a0abbxa0a1bybWaBa0a0bwbybybybxbwbVaBbwbWbwbVbwbybVaBaBa0#Pbya0aSbwbwbwaba0bxa0a1bwa0#Pbxa0a0bybyaba0#3#N#Pa1a1#Pa0a0#P#P#3aS#3#3#N#Pa1aS#N#L#N#N#M#O#M#L#O#N#M#O#M#L#L#K#O"
"#O#O#M#G#L#O#I#L#O#M#M#J#J#J#G#L#M#G#J#M#K#L#M#M#L#L#I#I#J#K#K#K#O#M#L#L#O#N#N#O#M#P#3#P#O#O#N#P#P#N#O#P#3#P#P#3#3a1#3#3a1aSa0aS#NbjfonHnNhjnO",
"cSnP#A#M#K#K#L#L#I#L#O#M#N#M#K#G#G#M#L#L#3#N#L#L#I#J#I#L#N#J#G#M#L#K#L#J#G#G#L#L#M#O#3#P#P#P#M#K#J#L#L#J#K#L#P#M#K#L#P#P#O#M#N#P#P#P#P#P#P#PaS#P#3a1#P#O#M#P#3#O#3aS#P#P#P#P#P#P#3#3#M#Na1#3aSaS#P#M#N#3#3#3a1a0a1a0a0#P#N#Pa1#P#Mj0lVaS#N#L#Na0aS#P#N#P#P#P#PaS#3#O#P#P#PaS#3#P#M#OaS#P#Pa0a1#P#P#N#N#P#PaS#P#Na1a0aSa0aS#P#Pa1a1a1abbybybybwbya0a0bybya0a0abaBbwa0a0bwbWaba0abbybybxbybwaba0bwbxbyaBaba1#Pa1bya1a0bwa0a1#3#3#P#3a0a1#N#Pa0aSaSaS#P#O#N#P#P#PaSa0#3a0aS#P#O#P#3#O#M#O#N#P#O#L#M#P#P#M#M#O#N#O#M#O#O#J#L#O#L#O"
"#M#L#I#I#L#M#K#O#M#L#J#I#J#I#K#M#I#G#L#L#K#K#J#I#I#K#K#L#L#O#O#N#P#M#L#J#L#M#K#L#M#P#N#K#K#O#P#O#M#O#N#O#O#N#3#N#O#3#P#3a0#3#P#O#PbjfinHfO#M.9",
"cSnPaa#G#G#M#L#G#F#G#G#H#G#I#G#G#N#O#L#J#L#L#G#J#J#G#H#I#G#E#H#J#I#I#G#G#G#I#L#J#I#L#L#L#K#L#J#G#J#J#I#I#L#M#L#K#G#K#L#J#K#J#M#L#G#K#O#I#G#I#G#H#G#G#F#E#K#N#L#J#L#L#I#J#L#L#J#L#M#J#G#L#M#M#L#J#I#I#L#O#L#L#O#O#K#M#N#K#J#M#M#L#L#P#N#N#L#L#O#O#M#L#M#N#K#J#P#N#J#I#K#K#J#K#K#G#I#P#P#L#K#N#O#J#O#O#L#L#M#L#I#J#M#O#O#O#M#M#O#P#3#P#Pa1a1#3a0a1#PaSa0#3#3a1aba1a1#P#3a0a1#3#3abbx#Pa1bwa1#P#P#P#P#P#P#N#Ma1bwbxa1a0a0#3#Pa0a1#P#3a1#N#M#N#3#3#3#P#N#O#P#3#P#N#N#P#O#P#P#M#O#N#N#L#L#P#P#N#M#K#L#M#L#K#K#O#J#I#M#O#I#I#I#I#G#I"
"#I#G#G#L#O#J#I#L#K#G#I#L#I#I#J#J#H#G#I#J#I#I#I#I#I#K#J#I#J#L#L#I#L#L#I#K#M#K#J#L#N#M#O#K#K#M#M#L#L#M#O#K#M#3#N#K#L#M#L#L#M#M#J#Na1bGfunHfO#M.9",
"cScXc7#F#I#K#G#H#G#G#I#J#I#J#H#K#P#J#G#H#I#J#F#G#G#G#K#G#F#G#G#G#G#F#G#H#H#I#G#E#H#L#I#F#F#G#H#G#G#E#H#I#G#J#G#G#G#G#F#F#I#I#I#G#I#M#K#G#I#G#G#J#I#I#I#G#N#M#I#I#I#M#K#L#O#K#M#O#K#J#M#L#O#O#L#O#L#O#3#N#O#P#N#L#K#J#L#K#M#J#K#N#O#N#N#L#M#M#L#K#L#N#O#N#M#P#P#L#L#L#K#L#O#O#N#K#Oa0#N#O#O#N#P#L#P#N#N#3#N#L#N#O#N#3#N#P#P#Pa0a0aSa0byaba1aSaSaSabab#3a0bxabbwbybxbxa0a0a0bwbwbwbybybVaBbxbyababaBbwbwbwa0bWbVabbxa0bya0a0bxa0bxbxa1#3a0a1a0a0aSa0a1a0aba0a0a0aba0#3aSaS#PaS#P#N#3aSaS#3#P#P#P#N#O#N#P#P#P#P#P#3#N#O#O#M#M#O#O"
"#O#L#OaS#N#M#L#M#O#L#M#O#L#O#O#L#L#L#M#M#L#M#M#M#O#O#M#M#N#P#M#L#N#O#O#N#M#N#P#P#P#N#P#N#N#O#O#P#P#P#P#Pa1#3#P#P#P#PaS#3#3aS#Na0abbXf.nHfO#M.9",
"cScWbq#L#I#G#G#K#J#J#L#L#G#I#G#K#O#I#L#L#L#M#L#O#M#L#K#G#J#M#L#L#N#M#N#O#L#N#O#K#M#M#J#K#K#I#L#L#G#I#O#J#G#K#K#G#I#L#K#L#L#G#H#K#J#G#F#G#G#H#G#G#H#D#F#F#I#G#F#I#I#K#J#I#L#L#K#G#F#I#L#J#O#O#M#M#M#M#P#O#L#P#L#L#O#L#L#M#L#I#N#P#L#L#O#K#I#J#L#M#N#O#I#L#N#L#K#J#L#M#K#M#M#J#L#J#J#N#K#L#O#N#P#M#N#N#O#M#J#K#O#O#N#P#O#N#N#Ma1aS#M#P#3#L#N#P#O#P#P#M#Oa0a1#Pa1a0#P#3abbxbybya1a1bwbya0a0abbya0abbwaba1a1a1bxbxaSa0a0aba0a0a0a1a1#P#P#Pa1#Pa1a0aS#3#3#3a0#3#Pa0#3#P#3#P#P#P#N#M#PaS#N#N#P#P#O#N#P#P#3#P#M#N#P#O#O#K#M#OaR#O#O#K"
"#L#K#L#O#K#L#L#M#O#K#L#L#K#L#I#J#K#J#J#L#L#K#L#J#M#O#L#M#M#K#L#M#L#M#M#L#K#N#O#L#M#N#M#L#O#N#N#P#O#M#P#P#O#M#O#P#N#P#P#N#O#P#O#P#3aTfunHfO#M.9",
"cScUbq#F#B#E#G#E#C#I#I#D#D#E#E#G#L#H#H#I#E#H#G#I#F#D#D#D#F#I#I#H#G#F#G#I#F#G#H#D#H#D#B#F#D#D#F#F#D#G#G#C#C#E#D#B#C#D#B#D#E#E#H#I#D#C#F#F#C#D#I#E#C#D#D#D#I#I#D#H#H#D#H#G#G#D#C#C#C#H#G#H#H#G#G#J#G#G#I#E#F#G#B#E#H#D#G#G#G#H#G#F#C#F#H#C#D#F#D#E#G#H#F#L#G#B#G#J#H#D#I#J#E#F#G#H#J#N#I#G#J#H#G#G#J#J#E#H#E#H#L#K#I#K#K#L#L#J#M#M#G#M#J#H#L#L#M#P#N#O#P#P#M#M#P#P#L#P#P#N#3aS#3a1ab#O#La1a0#P#PabaS#NaS#PaSbwbwaSa0a0#3a1aba0#P#P#P#PaSa0#3#3#3#PaS#3#P#3#N#P#P#L#M#P#N#P#P#N#P#P#N#L#O#N#L#K#L#L#L#M#M#L#N#M#G#L#O#L#K#L#O#J#J"
"#K#I#L#N#L#L#L#J#L#K#L#L#J#J#I#J#L#L#L#L#K#L#M#L#L#L#I#L#J#H#J#K#K#M#M#L#L#M#K#I#M#O#G#J#L#L#L#M#O#O#P#K#I#N#P#M#L#P#P#L#O#M#OaSaSaTg1nHfO#M.9",
"cSnQ#A#G#G#L#L#G#J#M#G#G#O#O#L#P#P#I#J#N#L#O#N#M#I#G#L#L#N#3#M#J#L#L#M#I#I#L#L#L#J#F#G#K#J#I#L#M#L#J#G#G#I#L#K#H#G#G#I#L#M#L#M#L#I#L#N#L#J#P#O#G#L#P#N#N#3#M#I#L#M#K#L#L#I#G#K#L#L#3#P#K#K#M#M#L#I#J#L#L#L#I#H#I#J#I#I#L#L#K#G#E#H#J#J#F#E#D#E#G#I#G#G#J#H#E#J#K#H#G#L#G#D#K#L#K#N#N#G#H#L#I#I#J#J#H#H#K#K#OaS#L#G#L#N#M#J#I#L#O#L#L#H#G#O#M#L#PaS#P#N#K#J#N#3#O#K#L#J#M#3a1aSa1aS#M#Pa0#3#Na0a0#L#PbxaSa0bwa0#O#3a1#P#3aS#P#L#O#P#Paba0#N#O#P#P#P#M#O#P#P#N#L#G#L#N#M#N#P#P#N#L#I#J#M#M#J#I#G#G#J#L#L#K#M#I#G#L#M#I#K#O#J#G#L"
"#M#L#N#N#J#J#L#K#K#M#K#J#G#J#K#L#P#L#I#L#M#L#K#I#L#M#M#K#J#I#L#L#L#O#N#O#M#L#K#L#N#N#K#L#J#L#O#N#P#P#P#L#O#3#P#M#3a1#M#Oa0aSaSab#3bVg1nHfO#M.9",
"cSnc#A#J#L#N#L#L#O#L#I#OaS#N#Oa1#N#I#L#N#L#J#L#L#J#J#L#L#M#L#J#J#L#J#J#I#L#M#L#J#H#G#L#N#L#I#L#K#G#H#G#L#L#O#J#J#K#O#O#O#N#M#L#K#L#O#N#L#O#O#K#K#P#3#N#P#P#L#I#O#P#L#L#O#O#M#P#P#P#3#P#O#P#P#M#O#P#3#P#N#L#K#Pa0a1#PaSa1#P#M#M#N#3a1#P#O#L#O#3#3#3#P#N#M#M#N#3#P#N#P#N#L#Na1#3#PaSnR#L#NaS#3#N#P#P#P#P#3a1a1a0#P#3a1#P#PaSa0a0a1#3#M#Nabbwaba1byabaS#P#Pabbwbwa0a0abbwbWaBbWbwa0a0a0bwbwbxbybwa0a1bwaBbybyaBa1#Pabbxa1#3a0a0a1a1a1a1a0aS#P#3#3#N#N#PaS#3#P#M#L#NaSa1#O#P#P#M#L#K#L#P#3#O#L#M#O#P#P#P#N#L#K#J#M#N#L#K#O#L#J#L#P"
"#O#L#P#N#I#K#M#L#K#L#L#L#J#L#L#L#M#K#J#L#L#K#L#L#M#L#L#I#J#N#P#O#L#N#N#L#L#L#O#P#P#N#O#N#PaSaSa1#3#N#N#N#3aS#P#PaS#P#O#3a1#3#3a1#NbWg1nHfO#M.9",
"cSnn#A#L#L#O#L#L#L#L#L#O#O#M#M#N#K#J#O#P#M#L#M#M#L#J#L#O#K#G#G#J#I#G#I#J#J#J#J#G#G#L#L#L#K#K#I#H#I#G#G#L#L#K#G#K#L#K#L#L#M#J#G#I#I#L#L#L#L#L#M#P#P#N#PaS#P#L#OaS#3#O#N#3#P#O#Pa1a1#N#P#P#P#P#N#3#P#3#3#P#N#Pa0bxa0#3aSaS#PaSaSa1a0a1#3#Pa1a0a0a1a0aS#N#N#P#P#3#P#P#3#Pa1aS#3#3aSa1#P#L#3a0#3#NaSa1aS#P#3abaS#P#3#3#3#PaSa0a0a0a0aSaSbybVbwbxbybxa0bxbybyaBbWbwabbwbWaBbWbWbVbxa0aba0bxbwbxbwbxbybwbwbwbybwbyaS#3bwbya0a0bxbxa0a1bxbxaSaSaSaSaS#PaSaSaSaS#P#M#Na1a0#P#P#P#N#M#P#P#P#P#P#L#L#P#P#P#P#P#P#L#L#L#L#O#M#L#M#L#O#O#O"
"#M#M#N#L#G#L#O#L#J#L#L#L#K#K#M#K#I#K#K#L#K#L#L#L#L#L#L#G#M#P#N#L#L#M#L#L#M#M#N#P#N#M#N#P#P#P#P#3#O#L#M#O#N#P#O#P#P#P#P#P#P#P#P#P#ObWfunHfO#M.9",
"cSncf##L#N#P#M#O#3#N#P#O#O#N#M#K#K#Pa1#P#PaS#N#O#O#NaSaS#L#O#3#O#O#N#P#P#O#O#M#L#O#P#M#K#L#L#L#M#O#M#L#O#O#O#O#P#O#L#N#O#O#L#J#L#M#P#N#M#3#P#P#3#P#P#3#N#NaSabbxa0a0a0aSaSa0abbwa0#3ababa1a0a0aba0a0a0a0a0bwbya1a1a0aSa0a0a0a0a1a1aSaSa1a0#P#3#P#3#P#O#P#3#PaS#P#Pa1#3aSa1#3aS#P#N#NaSaba1#3aS#3#P#3aSa0bx#3a1bxaSaSa1ababbxbxbxabaBaTaBbybwbybybwbwbwbwaBbwaBbWaTbVbybWaBaBbybwbwbwbWbWbwaTaTbVbVaBbwaBbxabbyaBbVbwbwbwabababbxaBbya1bybya0a0a0bxa0a0a0aSa1a0a0aS#PaS#P#3#3#3#3#P#3#P#N#P#P#O#N#N#P#O#M#N#M#N#P#O#O#P#N#O#N#O"
"#N#O#L#L#O#3#P#O#N#O#L#N#O#N#P#L#L#P#M#L#M#O#N#O#O#N#L#N#3#N#L#M#L#L#O#O#M#M#N#N#N#N#3#P#O#P#O#N#L#L#M#O#P#N#M#P#P#P#P#N#P#P#O#L#ObXfinHfO#M.9",
"cSnwb.#D#F#G#F#G#G#F#G#H#G#J#H#D#F#J#I#E#F#G#D#F#I#G#G#H#D#G#I#F#H#G#G#G#H#D#E#E#G#F#D#E#F#D#F#H#F#H#F#G#G#I#G#G#F#F#I#L#K#G#I#G#I#K#I#G#K#G#G#I#G#J#K#G#G#L#L#J#G#K#K#J#M#M#M#L#I#J#M#L#K#M#Ml7l7#L#L#M#P#P#L#K#N#L#K#N#M#M#M#M#O#M#P#M#L#J#L#O#P#L#J#L#J#J#L#J#K#M#I#J#J#J#O#L#I#J#O#M#I#J#L#J#L#P#P#3#P#M#PaS#N#N#P#3aSaS#3aSaSbya0#Pa1a0#PaSa0a1a1a1a0a0bxaba0#3#Pa0byaba1a0#3#3ababa0bxa0a1a0aSa1a0#P#Pa1a0#P#M#P#P#O#3aS#3aS#O#M#3#P#O#N#P#P#O#L#L#L#N#P#L#J#M#K#J#L#L#K#L#J#K#K#L#K#K#G#I#K#L#J#G#J#G#I#L#J#K#L#J#I#I#I"
"#K#J#G#I#L#L#I#G#K#G#I#M#M#L#L#I#K#M#K#J#L#K#L#L#K#M#L#N#O#J#K#O#K#K#O#L#L#L#O#O#O#N#O#M#L#N#P#3#P#N#N#O#N#N#O#P#N#N#N#O#P#P#O#L#PbXfunHfO#M.9",
"cSmDbq#H#G#L#K#J#G#J#I#G#K#L#J#I#J#K#I#F#I#G#G#J#J#G#H#E#I#I#H#H#H#I#G#F#H#D#G#J#H#B#D#G#H#G#K#I#G#G#G#G#H#E#H#D#F#F#G#J#H#D#H#F#D#G#G#G#H#F#H#D#H#K#G#G#I#K#K#H#G#J#G#K#N#K#K#G#J#O#M#K#K#L#O#L#K#K#L#N#P#K#G#L#N#K#N#P#L#M#M#M#M#M#O#L#L#L#M#P#P#I#K#L#I#K#O#M#M#M#L#K#I#O#N#O#M#M#N#L#K#M#M#L#P#P#P#N#O#Pa1#P#P#PaSaS#P#P#Pa1aba0#M#Na0a1a1byaba1a0a0aba0a0a0#3a1a0a0bwaS#NaSaS#Pa0aba0aS#3aS#M#Pa0aS#P#P#3a1#M#M#P#M#NaS#N#O#L#L#N#P#O#M#M#N#M#L#K#K#O#N#K#H#J#L#J#M#M#L#L#L#J#L#K#J#I#G#I#J#L#L#G#G#I#G#G#L#K#I#G#G#G#F#I"
"#K#I#G#G#K#G#G#J#I#G#L#L#J#I#G#I#L#L#K#J#L#M#K#L#L#M#P#O#I#K#O#O#M#P#P#N#N#N#P#N#O#O#L#O#N#N#3#P#M#N#N#O#P#3#P#P#N#P#M#O#3#P#N#P#PbXg1nHfO#M.9",
"cS.9fh#M#P#N#L#J#I#L#I#I#L#G#G#I#K#L#K#G#J#G#I#J#H#G#F#F#I#I#I#G#F#K#G#F#I#G#J#K#H#E#I#I#I#L#M#G#I#I#G#J#G#H#J#J#J#K#I#G#D#H#K#J#K#M#K#G#H#J#I#E#K#K#F#G#J#L#N#K#J#G#G#K#K#J#K#G#J#L#L#M#I#L#O#I#K#M#L#P#O#G#J#L#L#M#3#M#I#J#I#J#L#I#L#L#L#K#J#K#G#G#K#O#K#M#O#I#I#J#K#I#K#P#K#J#L#M#P#N#K#L#L#L#N#L#N#O#M#P#P#3#N#La1#3#NaS#3a0bwaS#Oa1a1aSbxby#3#P#3#PaS#PaSaba0a0a0a1#3#O#Paba0a0bxa0#P#N#P#3#Ma1a1#M#P#P#Pa1#P#O#O#L#P#N#O#N#L#O#P#N#P#L#L#P#L#M#N#O#3#N#K#L#O#M#O#3#N#J#M#L#L#O#L#L#N#L#M#L#L#J#G#L#M#L#M#N#L#J#K#L#K#J#N"
"#L#K#L#L#O#O#L#M#J#K#O#L#L#L#J#M#O#O#O#L#P#N#L#N#O#N#3#O#L#N#P#N#3aS#N#P#N#O#P#P#P#3#3aSaS#3#3#N#Pa1a1aSa0a1#3#P#3a1#PaSaS#P#P#3aSbNfinHfO#M.9",
"cS.9#Q#O#L#J#I#I#K#L#I#I#J#G#J#K#G#K#G#G#G#G#G#G#G#H#G#J#G#G#G#D#F#K#E#F#I#H#G#G#F#G#G#H#J#J#F#C#H#I#G#H#G#G#J#G#E#F#C#D#H#G#G#J#J#G#H#H#G#J#I#G#G#G#G#L#I#J#L#J#J#J#G#K#K#J#I#M#O#K#L#I#G#P#O#F#J#J#I#L#I#G#L#J#J#M#J#G#H#L#I#G#G#G#K#J#G#G#H#D#G#K#J#K#K#L#I#G#G#J#L#L#K#K#J#L#M#J#O#O#L#M#M#L#M#O#M#OaS#3#P#P#K#Oby#P#Pa1#3a1a0#Pa1a0#3abab#3#Oa1aba0a1a0abbwa0aSa0#P#3a0bxbybybxaba1aSaSbxaba1a0a0a0bxa0a1aba1aSa0#3aSaSaS#PaSa1#3aS#P#OaSaS#M#P#P#P#3#N#N#3#P#N#P#P#M#L#3#N#N#O#O#P#P#O#O#M#J#L#N#N#N#N#N#M#M#L#O#N#M#L#O"
"#L#M#M#L#M#O#L#M#L#M#M#O#O#M#P#P#N#O#L#MaS#M#L#N#M#P#N#M#N#P#N#3#3#P#L#NaS#P#P#3#3aS#3#P#P#P#N#3aSaSaSa1#3#P#P#PaSaS#P#3#3#PaS#3#PbjfinHfO#M.9",
"cSmD#A#I#H#G#J#I#I#I#G#G#L#M#J#G#H#G#G#H#I#G#G#G#G#G#L#L#G#I#G#D#G#I#F#I#I#I#I#G#I#G#G#G#L#G#D#E#J#I#G#G#J#J#I#I#H#G#H#I#L#I#K#L#G#H#K#K#J#K#J#I#K#O#M#J#I#J#L#G#K#M#M#M#O#K#OaS#O#N#O#I#J#N#L#J#M#J#L#L#M#K#K#J#O#N#G#H#L#N#M#L#L#O#M#L#J#J#L#K#N#N#K#N#M#I#K#O#M#M#O#L#L#M#P#O#L#K#N#L#M#N#P#N#N#N#OaSa1#P#P#N#L#PaS#OaSaS#3a0a1a1#3#Pa1bya1#O#Pababa0a1ababababaSa0a0a0bwa0abbya1#Na0aba0a0a0a1a1bxaba0#3aSa0#P#Pa1aS#3#3#P#Pa0aS#3#3#O#L#3#O#M#P#P#P#N#O#N#O#M#P#P#K#I#M#P#O#L#L#O#M#L#L#J#L#L#N#L#L#O#M#J#I#O#M#M#M#M#L#O"
"#N#O#L#L#M#L#K#O#N#N#O#M#M#P#P#N#N#O#J#L#N#L#O#P#O#N#N#O#N#M#O#3#N#J#L#P#P#N#O#P#P#P#P#M#N#N#Pa0#P#PaS#P#M#N#P#P#P#P#N#Pa1aS#P#N#OaTePnHfO#M.9",
"cSnwc7#H#H#J#K#G#G#I#G#G#K#J#G#F#G#H#E#F#F#F#F#H#G#J#I#D#D#F#F#F#H#H#H#G#H#F#H#D#F#H#F#G#J#E#E#G#G#E#H#I#G#H#G#G#H#H#H#G#I#G#G#G#E#F#L#I#G#J#J#I#L#M#K#I#I#K#I#J#K#K#J#I#L#O#N#L#H#K#L#J#L#M#L#L#L#J#L#K#K#K#I#J#O#L#H#J#M#K#J#L#O#L#L#M#L#J#K#K#O#M#K#L#K#G#M#P#K#L#N#M#O#P#P#M#L#P#N#O#N#O#N#N#N#3#3aS#O#L#P#P#PaS#PaSa1#PaSa1#3aSaS#Pa1ab#P#Na1a1#P#3a0a0aS#3a1#P#3#3#3a0aSa1a1#N#Na0aS#PaSa1#3a1aba1#P#PaS#P#P#P#P#P#P#3#3aS#P#M#N#P#P#P#P#O#P#P#N#N#O#M#O#L#M#P#N#I#L#O#M#K#M#O#N#M#O#O#L#M#M#O#L#L#M#J#G#L#N#L#K#O#M#L#O"
"#O#L#L#M#M#K#L#L#L#L#L#M#N#P#M#L#O#O#M#N#N#N#P#N#N#P#N#N#P#O#PaS#N#O#P#P#N#N#P#3#P#P#3#N#P#P#PaS#P#N#P#M#O#P#P#N#N#P#N#P#3#P#M#N#PaTePnHfO#M.9",
"cS.9fP#O#M#P#O#K#O#N#O#N#N#L#L#J#M#L#L#O#O#N#L#M#N#M#K#I#K#M#L#L#M#L#L#M#L#L#M#L#M#O#L#L#L#L#L#L#L#L#L#M#M#J#M#M#J#K#O#P#P#P#N#P#O#NaS#L#M#3#O#O#P#O#M#N#N#P#N#P#P#3#P#P#3aS#3#P#OaS#3#N#P#P#P#3#P#P#P#P#P#3#N#M#P#O#M#O#M#M#L#M#P#L#L#O#L#J#L#N#P#P#M#M#M#L#P#O#I#L#M#J#L#O#L#L#L#O#O#O#O#P#P#P#P#3#P#N#O#3a0#3aSa1aSa1a1#3a1a0ababbya1a0aba0a0a0a0a0a0bybxa1a0a0aSaSa0bybwabababa0a0bwa0aSaba0aSa0a1#P#3#3a1a1aSa1aS#3#P#P#P#P#O#L#P#P#N#P#P#N#N#O#O#O#O#O#P#N#O#N#O#O#N#L#M#M#M#O#N#O#O#L#J#L#M#N#O#M#M#M#L#M#O#J#L#M#L#M#O"
"#L#L#L#M#L#M#M#O#O#M#L#O#O#O#L#L#N#M#M#O#O#O#O#L#O#N#N#P#P#P#N#P#N#P#P#N#N#N#P#3#P#3#P#O#O#N#3a1#P#N#P#P#Pa1#P#M#P#P#N#P#P#M#O#O#PaTePnHfO#M.9",
"cSnSaa#K#L#O#I#G#K#L#K#K#K#I#K#J#L#L#K#L#N#N#L#N#N#M#K#K#O#O#L#L#K#I#K#O#L#I#L#M#M#K#I#O#P#K#G#K#M#L#L#O#M#K#O#M#L#M#P#P#N#N#P#P#P#3aS#M#P#3#3#3#P#P#N#P#N#P#P#PaSa0#3#3a0#3#P#N#NaS#3#P#P#O#O#3a1#P#N#PaSaS#L#Oa0#3#N#O#P#P#O#P#P#O#O#N#O#O#P#P#P#N#N#O#N#O#P#L#J#N#P#N#P#O#L#O#N#P#P#N#Pa1aS#Pa1a1#3#P#Pa1a0aS#3#3#P#Paba0#3a0byaba1#NbxbWa0aSa1aba1#3a0a0#Pa1aS#PaSa0aba0a0a1a1#3aSa0#M#Na1aSaSaS#N#N#N#O#P#P#O#PaS#P#O#P#O#L#I#I#M#K#I#I#G#H#J#L#G#G#L#M#L#H#G#M#K#G#G#I#K#G#I#J#G#G#I#H#H#G#I#J#I#I#J#J#G#K#G#D#G#G#I#I#G"
"#G#G#G#I#J#I#J#K#L#I#J#K#I#G#G#I#L#J#G#G#G#G#L#L#G#J#M#L#K#G#L#P#L#I#K#O#L#K#M#M#K#L#M#J#K#M#O#M#L#L#L#L#L#M#I#G#L#K#L#L#I#I#J#J#KbwfNnHfO#M.9",
"cS.8#o#E#H#G#D#F#H#G#H#E#E#C#D#D#D#C#F#F#H#D#D#F#E#D#D#D#D#D#E#D#C#D#E#G#E#C#E#E#D#C#E#G#H#D#E#GnT#D#H#G#D#C#H#H#F#H#G#H#D#F#E#E#G#I#G#H#G#G#J#G#G#G#H#I#I#G#G#J#L#L#H#I#K#I#I#J#I#I#G#J#G#G#J#L#M#I#I#K#I#G#G#K#M#I#I#J#L#J#IaR#L#G#I#K#J#I#J#K#G#G#G#H#G#I#J#G#I#J#K#L#J#J#I#I#L#M#J#O#N#P#O#L#P#O#L#O#O#L#O#P#P#O#PaSab#3#NaS#3#N#O#NaSaS#O#Na1a1#O#3a0#3#L#P#P#3#P#3#P#L#L#L#L#O#P#O#L#O#O#P#N#N#L#L#O#O#M#L#N#P#P#K#L#O#K#J#L#J#I#J#M#K#J#L#O#N#J#I#L#J#G#G#J#K#G#G#I#L#J#G#K#K#G#G#J#I#G#I#I#G#F#H#F#H#G#K#G#G#J#J#J#I#I"
"#H#H#I#J#G#I#L#L#J#G#K#J#I#G#J#G#G#I#J#G#I#L#N#L#G#K#K#G#G#J#M#L#G#G#L#M#J#L#M#L#G#J#K#J#K#L#J#G#G#G#G#G#L#L#I#J#J#L#K#J#I#G#I#J#JbxeQnHfO#M.9",
"cScV#n#C#D#D#C#C#D#E#D#C#C#D#D#C#B#B#E#C#B#B#B#C#B#B#B#B#B#D#D#B#B#F#F#D#D#B#B#B#B#C#C#B#C#D#C#D#D#C#D#E#C#B#E#H#E#D#F#D#C#E#E#D#D#H#E#H#H#G#G#E#G#F#G#G#G#H#J#LnU#G#G#L#K#I#I#J#I#J#M#J#H#K#P#O#O#L#K#K#J#I#M#K#J#L#L#J#L#L#L#M#L#J#M#P#L#L#M#M#J#L#M#L#L#L#L#L#L#M#O#L#L#M#M#M#M#L#K#N#O#O#M#N#P#P#N#N#P#N#3a1#O#La0a0aSaS#P#PaS#PaSaS#P#P#3#3#3aS#P#3#3#N#N#P#P#O#N#P#M#L#P#N#O#O#P#N#O#O#O#N#L#O#L#M#M#L#J#L#N#L#J#I#M#O#L#K#L#J#L#N#L#G#J#P#O#L#L#L#J#K#I#L#K#J#J#K#J#K#K#J#L#L#I#K#O#L#I#L#L#G#K#L#K#K#L#L#K#L#L#L#L#I#K"
"#J#L#L#J#J#L#L#J#J#J#O#L#K#L#L#J#O#N#J#G#M#P#O#M#L#K#L#K#L#M#K#K#L#M#L#O#M#M#O#O#K#M#N#L#M#N#L#L#N#O#L#L#M#L#M#M#O#O#K#M#L#O#O#M#LbWg1nHfO#M.9",
"cSnQc6#G#J#J#G#G#I#K#K#K#K#M#J#G#G#G#M#I#H#G#G#H#H#H#G#G#G#G#F#E#H#G#H#E#H#E#D#G#G#G#F#H#K#J#D#H#G#H#G#G#H#G#G#G#G#J#L#G#J#L#G#G#I#L#I#I#I#J#K#L#L#L#M#K#L#J#M#O#I#J#J#J#J#G#I#L#J#O#I#H#G#L#L#G#G#J#F#G#J#I#G#H#J#K#H#D#H#G#H#G#H#F#G#I#H#G#L#I#G#J#G#G#G#G#J#G#G#I#J#K#L#K#M#L#J#I#J#P#K#I#J#M#J#J#I#L#M#N#P#L#J#M#3#P#K#O#L#I#O#P#M#L#M#3#N#I#G#K#G#J#K#G#J#K#K#I#M#O#J#K#M#J#G#J#M#L#G#G#K#M#L#L#L#P#L#L#J#M#O#J#J#K#J#G#G#G#J#I#L#J#H#G#J#L#G#G#I#F#H#J#J#G#H#I#L#I#F#G#I#H#G#G#H#G#I#G#G#L#K#G#L#L#I#G#K#L#I#I#I#K#K#L#L"
"#M#L#L#K#J#O#M#J#K#M#J#J#J#L#M#O#N#K#J#L#N#O#K#M#L#G#M#M#M#L#L#P#N#J#I#O#L#L#M#J#L#M#K#K#L#O#J#J#M#K#G#J#L#K#I#J#K#L#M#L#L#M#K#K#KaBg1nHfO#M.9",
"cScV#R#E#G#G#H#E#D#G#I#H#F#F#D#D#H#G#G#D#F#H#H#F#F#E#G#G#F#D#D#G#G#H#H#E#H#H#E#I#H#D#G#I#G#H#H#J#J#G#I#G#G#J#J#J#I#G#G#G#J#I#G#G#L#O#L#L#I#J#O#L#I#K#L#G#K#M#P#L#K#O#M#L#L#J#L#O#L#J#G#L#P#O#O#L#L#O#K#O#P#K#L#O#M#L#J#I#M#M#L#L#J#K#L#L#L#J#K#J#J#J#G#GnV#M#M#K#J#G#K#M#K#G#K#G#G#K#O#O#J#L#M#L#L#J#I#L#M#M#J#J#N#P#O#N#L#O#N#LaS#O#L#N#P#P#N#M#N#P#O#P#N#L#O#O#O#L#K#M#K#M#L#K#K#M#N#L#L#J#I#M#O#I#K#L#G#K#L#O#K#G#K#J#I#I#G#I#M#J#J#G#I#O#M#L#L#J#K#I#L#M#I#J#K#L#K#I#K#L#K#J#J#J#J#K#J#J#J#K#K#L#K#J#I#K#O#O#K#K#I#L#N#L#I"
"#L#K#I#K#M#O#K#K#M#L#M#M#J#L#M#M#K#I#O#O#O#O#L#M#O#L#N#O#K#M#N#N#L#L#O#N#M#M#M#K#M#L#O#M#L#M#L#M#M#L#L#O#N#O#M#K#J#O#P#L#M#M#K#K#LbWePnHfO#M.9",
"cScXc7#H#G#I#G#F#F#K#G#D#H#F#D#E#G#G#G#F#H#G#G#I#H#H#J#I#G#G#J#K#G#G#I#I#J#G#G#J#H#G#J#I#G#F#H#I#G#F#H#H#G#G#G#G#H#E#G#I#F#I#L#K#K#O#L#J#G#L#O#G#I#K#I#J#K#M#N#L#J#L#M#O#M#J#L#L#G#G#L#O#M#K#M#M#O#O#J#L#M#J#M#N#K#I#I#K#M#L#I#J#K#L#O#O#M#K#K#M#L#L#N#N#O#P#3#P#M#L#P#N#L#L#L#L#M#P#P#3#M#P#P#PaS#P#PaSaS#N#3a0aba0a1a0a0aba1a1bxaSa1bwbxa1aS#3a0a0aSa1a0aSa0a1a0a1#PaSa1#P#3a0a1a1a0a0#3#NaSa0#P#N#N#M#M#N#3#3#N#O#N#O#N#N#M#M#P#L#M#O#N#N#M#O#O#N#N#M#O#O#K#O#P#M#L#K#M#N#M#L#L#L#M#O#M#O#K#L#M#L#L#O#N#N#P#P#O#L#L#P#N#L#L"
"#M#K#L#O#N#N#L#M#M#O#P#N#M#N#N#M#M#N#N#O#O#N#N#P#O#L#N#M#L#P#N#M#L#M#P#N#L#M#M#M#N#O#N#M#J#L#M#K#L#O#O#O#N#N#L#J#L#P#K#K#J#K#I#K#LbWePnHfO#M.9",
"cS##fP#O#O#M#I#M#3#P#L#K#M#N#P#P#N#P#N#N#P#P#N#M#O#P#P#P#N#P#O#O#M#O#M#P#O#J#K#L#L#N#N#L#J#I#L#L#J#L#N#N#M#L#M#O#N#L#O#O#L#PaS#N#N#P#M#J#O#P#M#J#L#O#N#P#P#PaS#P#N#P#3#P#M#OaS#3#N#P#P#O#L#L#O#M#M#K#J#K#L#L#N#O#L#J#J#L#K#I#L#N#O#L#L#L#O#L#L#M#L#M#P#P#M#O#P#L#M#3#P#L#L#O#O#P#P#O#3#P#O#PaS#3#P#Pa0aba0aSa0a0aSaSaSa1a0a0#N#3aSaSa0bxa0aS#P#3aS#P#Pa0a0aS#P#3aSa1#P#P#3#Pa1a0#3#Pa1#3#N#Pa1#P#L#N#N#O#P#P#P#P#N#O#P#3#P#M#O#P#P#M#N#O#O#M#L#M#M#M#L#I#K#L#M#N#M#L#I#K#L#L#G#K#O#M#L#L#L#O#L#L#M#L#K#O#N#L#M#N#J#J#L#O#K#G#K"
"#K#M#O#M#N#N#L#O#N#N#M#L#N#P#N#O#N#O#L#L#L#M#O#M#J#L#K#L#L#N#M#L#J#L#M#J#I#M#N#M#L#M#O#N#K#L#M#K#L#P#M#L#O#M#J#L#N#M#J#K#K#L#O#M#LaTePnHfO#M.9",
"cSm5#A#I#L#K#I#L#M#L#J#K#L#L#M#L#L#L#G#J#L#L#I#J#L#L#J#J#K#L#J#I#K#K#I#J#G#H#G#G#J#G#H#H#F#G#G#H#F#G#I#G#F#H#G#K#I#H#G#I#I#J#J#H#I#L#G#G#L#K#I#I#K#J#M#O#L#L#L#G#J#L#J#G#L#L#L#L#J#L#L#I#I#K#L#K#J#G#J#I#M#L#G#I#G#I#I#G#G#I#L#L#I#G#I#L#L#I#I#L#L#K#L#J#G#K#L#I#L#M#L#J#L#L#L#N#P#O#P#M#K#O#O#L#L#N#N#O#N#P#P#N#O#P#P#N#P#O#L#N#NaS#P#O#P#O#N#P#O#L#NaS#P#O#N#PaS#3#N#P#3#3#P#P#M#M#P#O#O#P#N#M#M#O#N#N#P#P#N#N#L#M#N#M#L#M#N#O#O#O#N#N#M#O#N#N#M#O#L#L#L#O#P#M#L#L#L#O#M#L#L#O#N#M#L#O#O#P#O#L#N#P#N#N#O#L#O#N#L#O#N#O#L#M#O"
"#O#P#P#N#P#O#O#N#P#M#M#N#P#N#P#P#P#P#N#P#P#P#P#N#M#P#N#3#P#M#N#O#P#P#O#N#P#3#P#O#N#P#3#3#O#N#P#P#P#P#M#O#P#N#N#P#P#O#O#P#N#NaS#P#PbUg1nHfO#M.9",
"cScV#o#D#D#F#F#E#E#E#E#H#E#E#F#E#D#C#D#D#D#D#D#F#D#C#D#D#D#E#E#C#D#D#D#D#B#D#E#F#F#C#E#E#E#E#F#G#E#H#H#D#D#E#E#F#D#F#G#G#H#E#F#H#H#F#H#G#H#F#G#G#I#G#G#G#G#G#E#F#G#H#F#G#K#I#G#I#G#G#I#G#G#G#I#I#G#H#J#K#M#I#G#I#G#L#J#K#L#J#L#I#H#G#G#K#I#G#L#M#L#I#I#I#K#J#J#L#L#K#L#M#P#N#O#P#O#L#L#L#O#M#M#O#P#N#M#N#P#O#N#N#M#M#O#N#N#M#3aSaSa1#N#P#3#3aSaSa1aS#3#3#N#O#N#P#3#O#NaS#3#N#O#O#M#M#L#O#M#L#L#L#M#O#M#M#N#M#L#K#J#L#L#K#L#M#L#J#L#L#K#L#K#J#K#K#L#K#J#M#M#N#L#K#L#L#L#L#O#N#L#M#L#J#I#L#L#L#K#M#O#M#J#L#K#L#L#L#L#L#K#L#L#M#O"
"#L#M#O#L#L#K#M#M#L#L#O#N#L#M#N#M#O#O#L#L#M#M#M#L#N#N#N#3#L#L#O#M#N#M#P#P#N#N#M#L#L#M#O#L#L#P#P#M#L#L#L#M#M#L#M#L#L#M#O#P#O#M#P#M#LaBeQnHfO#M.9",
"cSnPc7#G#G#J#I#H#G#I#I#G#H#I#J#H#H#D#G#G#H#F#G#G#H#H#G#G#H#H#F#D#H#I#G#G#G#I#G#H#H#H#I#J#J#I#I#J#G#G#I#I#J#I#L#L#J#K#K#J#J#K#L#L#L#L#M#L#K#L#L#L#L#L#L#L#I#G#I#L#L#I#J#L#K#J#K#L#K#J#K#I#I#L#L#L#L#L#K#I#I#G#G#K#K#J#I#K#J#G#G#I#J#G#I#I#I#G#K#G#G#I#L#L#K#J#K#K#G#I#K#L#K#J#K#L#J#G#H#J#M#J#G#K#M#J#J#M#M#K#K#J#G#K#M#L#L#M#N#L#L#K#J#M#M#O#M#O#O#L#K#L#L#L#K#L#L#K#M#L#J#I#L#O#L#J#J#L#J#I#J#K#K#J#I#K#K#G#H#G#K#J#G#G#I#I#G#G#I#G#H#H#F#F#I#I#I#I#K#J#G#G#H#G#I#I#G#G#K#J#H#G#G#G#G#G#I#I#G#I#G#H#H#I#I#G#G#G#I#G#H#G#I#G#G"
"#I#I#G#F#F#G#J#I#H#G#G#G#G#I#L#I#G#G#G#I#K#K#J#L#M#I#I#J#H#J#L#L#J#J#L#I#G#G#I#K#I#I#J#I#J#K#G#G#I#L#K#J#J#L#K#G#I#L#L#J#K#J#K#G#HabfNnHfO#M.9",
"cS.9aa#M#L#N#M#K#M#M#L#J#K#M#L#J#J#L#N#L#I#J#K#L#L#L#L#L#K#J#I#I#M#K#I#M#L#K#J#J#J#L#L#M#K#M#L#J#I#J#L#L#M#L#L#O#M#L#L#K#L#P#O#L#L#O#P#L#L#O#N#M#K#M#P#M#O#M#P#P#L#L#M#N#N#N#O#N#O#L#L#L#O#P#L#O#P#M#K#K#J#J#J#L#K#I#I#G#G#H#G#J#J#I#G#I#J#I#G#F#G#J#L#K#I#G#K#L#H#G#K#L#G#G#L#J#J#K#L#N#L#I#I#O#P#P#M#O#P#O#O#Mmb#P#P#L#3#P#O#M#M#O#N#N#P#O#N#M#L#L#L#O#N#N#M#O#P#P#O#L#L#L#P#N#O#L#L#N#L#K#L#M#L#G#J#M#K#K#K#M#O#J#G#J#L#L#L#L#M#L#I#K#J#L#O#K#K#M#L#J#I#G#J#K#L#J#I#K#G#G#G#J#J#L#J#I#K#L#J#G#G#G#K#K#J#I#G#I#K#G#G#I#I#G#H"
"#J#J#G#G#I#L#J#G#G#J#L#L#L#J#L#K#I#G#I#M#L#J#M#L#J#I#I#J#K#K#L#K#I#I#G#G#G#I#J#L#I#J#L#K#J#G#G#I#L#L#K#I#I#L#J#G#I#J#I#F#G#K#G#G#GbweOnHfO#M.9",
"cSnP#A#K#K#M#L#I#K#L#K#G#I#L#J#L#L#L#J#F#G#I#J#J#I#G#I#I#G#I#J#I#I#E#F#G#F#H#G#G#I#I#J#G#G#G#G#G#G#K#K#J#M#J#L#O#L#K#J#L#O#M#L#L#L#M#P#K#L#N#P#M#L#N#P#OaSjfjf#O#L#N#P#P#N#M#L#M#L#L#O#O#N#L#I#L#L#I#L#L#L#L#L#L#L#L#K#I#J#L#M#L#L#L#K#M#L#L#J#K#L#M#K#K#K#I#M#L#G#L#M#M#K#L#N#M#O#N#P#N#K#L#O#P#P#P#O#N#N#O#N#P#P#3#M#M#P#M#M#P#O#P#P#3#P#O#P#N#O#P#3#P#P#P#O#P#P#N#N#N#O#P#P#M#O#M#O#P#K#K#M#O#L#K#M#N#O#N#N#O#L#J#L#O#O#O#L#K#L#K#K#L#M#M#L#G#K#K#G#K#K#J#L#L#L#L#L#L#J#L#L#O#O#M#M#L#O#L#L#L#L#M#N#L#L#L#L#M#M#K#L#O#L#L#L"
"#O#O#N#P#P#P#L#L#N#P#P#P#P#N#N#M#O#N#N#P#L#K#O#L#L#L#L#M#O#O#M#L#L#L#L#M#O#P#O#N#M#N#N#M#M#L#L#O#O#L#L#L#L#O#K#J#L#L#L#J#L#O#L#M#OaTePnHfO#M.9",
"cSnnf##K#K#M#J#J#L#L#K#G#L#L#L#M#L#I#I#G#L#I#I#G#G#I#G#J#I#G#I#J#G#H#H#G#G#G#G#G#J#J#J#I#I#I#J#J#L#L#J#K#M#I#K#J#I#K#I#L#N#M#M#M#M#N#N#M#P#P#N#L#L#P#PaSa1#P#O#M#3#P#P#N#O#O#O#P#P#N#P#P#O#L#L#M#M#M#N#O#N#P#P#O#P#O#N#P#O#3#P#N#3#P#O#O#M#N#O#O#P#P#O#P#P#N#3#O#N#P#P#P#M#P#P#Pa1#3#O#O#PaS#P#P#P#P#P#3a1aS#3a1a1aS#P#P#P#3aSaS#3aS#3a1aSaS#3aSaSa0ab#3#3aS#3#P#N#N#P#P#PaSaS#P#P#PaS#3#N#PaS#3#N#N#3#P#3aS#P#O#O#P#P#O#O#N#O#M#P#P#N#O#N#N#M#L#L#M#M#O#O#O#N#O#O#N#M#O#N#N#3#P#O#P#P#N#M#L#M#O#O#P#P#N#P#N#P#P#N#N#P#P#P#M#P"
"#P#Pa1aS#P#N#PaS#P#P#P#N#P#P#P#P#P#P#P#P#O#M#N#N#N#P#N#P#P#P#P#P#N#P#P#3aS#P#PaS#P#P#N#O#3#N#N#P#P#P#P#O#P#P#M#N#P#P#O#O#P#P#3a1#PaTePnHfO#M.9",
"cSnQbq#I#L#L#I#K#K#I#G#G#J#K#K#K#G#I#J#K#K#I#L#K#J#K#I#I#I#G#I#J#H#I#J#L#K#I#J#J#J#L#M#O#L#K#L#L#O#L#J#M#J#L#L#L#O#M#L#O#M#O#L#J#L#P#N#O#P#P#N#M#OaS#P#P#P#O#P#3#3#N#P#P#P#P#P#P#P#N#P#P#O#L#N#3#P#P#N#O#O#N#N#N#N#M#N#N#N#P#M#O#O#L#M#M#O#P#N#N#N#N#N#O#N#P#3#P#P#P#N#N#O#PaS#3#3#N#N#3#P#P#Na1aS#3a1#3aSaSaSa1a1#P#PaSa1a0aS#3a1#PaSaSa1aS#P#3#P#3#P#N#P#L#M#N#O#P#P#N#P#N#P#O#O#N#P#P#N#P#O#M#L#L#P#P#N#O#L#O#P#P#M#M#N#N#N#O#L#N#L#L#O#K#I#L#O#O#L#K#L#K#K#K#L#L#K#L#L#L#O#J#K#L#I#J#J#L#L#K#L#L#L#L#K#K#M#O#L#L#O#L#K#J#L"
"#N#O#O#K#L#M#O#L#J#N#P#M#M#L#O#L#L#O#M#J#L#O#N#O#M#M#O#L#M#P#N#O#M#O#O#P#P#M#O#L#L#L#L#O#N#M#O#M#L#L#L#L#P#P#O#N#M#L#L#L#N#O#N#O#LbVg1nHfO#M.9",
"cSnPc6#G#K#K#I#I#G#H#G#G#J#J#G#G#G#I#I#H#H#I#L#K#G#G#I#I#G#H#G#G#E#G#G#J#G#F#G#G#G#G#G#G#G#G#G#G#G#F#H#I#G#I#K#J#K#J#K#K#I#I#I#G#I#I#I#K#K#I#J#L#L#P#O#K#L#L#M#L#J#L#N#P#L#M#K#M#M#I#K#M#K#I#L#L#L#L#K#L#I#J#K#I#I#G#G#G#I#I#G#G#I#I#J#K#L#L#K#L#K#J#J#G#G#L#L#K#K#L#K#L#K#N#P#M#M#M#M#L#K#L#N#3#P#O#P#N#P#O#M#N#N#M#O#N#3#P#M#O#M#L#N#M#L#K#K#I#K#L#K#J#K#L#L#L#M#K#K#L#M#L#K#L#G#J#L#K#K#K#G#G#J#K#O#M#J#L#L#L#K#J#L#M#O#L#L#L#L#L#I#I#M#J#G#L#L#M#K#K#L#J#J#L#J#J#G#I#G#J#J#H#I#J#I#L#L#M#L#L#L#L#K#L#K#K#L#M#L#L#L#I#L#L#M"
"#P#M#L#L#L#M#L#L#M#P#P#M#M#M#O#M#L#M#O#K#M#O#P#N#M#O#O#L#O#O#L#L#K#K#L#L#K#L#L#L#L#L#M#M#L#L#M#L#I#J#I#J#K#K#K#L#I#I#J#J#N#M#J#L#LbWeQnHfO#M.9",
"cSmDc7#G#G#G#H#H#F#H#G#E#H#H#E#H#H#E#D#E#G#H#F#F#D#E#F#F#D#D#F#H#E#E#D#H#D#D#G#F#F#F#E#H#G#E#D#G#G#D#H#H#H#I#J#E#D#H#G#G#I#G#G#G#J#J#G#I#K#K#L#J#J#O#L#L#M#L#G#I#M#O#L#J#G#L#L#K#J#H#J#L#K#J#J#K#L#I#K#L#J#I#I#K#L#L#G#I#M#J#G#K#J#K#O#K#G#J#L#J#L#J#I#K#K#L#L#J#K#L#L#L#I#M#M#L#O#O#L#L#L#P#P#M#M#L#N#N#N#M#M#P#3#N#N#O#3#N#O#P#N#P#O#M#N#N#O#L#P#N#L#L#O#M#N#P#K#J#L#M#O#O#L#M#M#M#O#M#M#M#M#O#L#L#P#L#L#O#O#L#L#O#P#O#M#L#L#O#O#M#J#L#O#O#L#M#L#M#L#L#O#L#M#L#L#O#M#L#L#O#M#L#M#O#M#P#O#L#L#M#O#O#M#O#O#N#N#O#O#M#M#O#P#L#N"
"#N#M#O#P#O#L#M#P#P#N#O#M#N#O#O#M#L#N#P#O#M#O#N#M#L#N#N#M#N#L#O#N#O#L#N#P#L#L#O#M#P#P#L#K#L#M#O#O#M#L#M#M#O#M#M#M#L#O#M#K#N#L#L#O#MbyfNnHfO#M.9",
"cSnQf##M#L#K#I#K#L#L#I#K#M#K#L#L#L#L#L#M#J#G#I#I#I#J#G#G#I#K#M#L#J#G#L#L#I#L#K#I#K#L#L#O#O#L#L#N#O#M#O#N#L#M#M#L#M#N#N#N#P#L#O#3#P#P#P#N#P#3#P#M#P#3#PaSa0#P#N#P#P#M#O#M#N#N#N#P#P#P#P#P#N#K#M#P#O#L#O#K#L#M#M#O#P#P#L#M#P#N#O#P#P#O#P#O#M#P#P#N#P#O#L#P#3#P#P#O#P#P#P#O#O#3#P#Pa0aS#P#PaSaS#N#P#P#P#3#P#3#3#3a0a1#P#PaSaS#PaS#3#P#P#P#3aSa0#3#Pa1a1#P#3a1#3#P#P#O#P#P#N#N#P#M#O#3#P#P#N#N#P#P#P#O#P#P#P#3aS#P#N#P#3#N#M#N#N#N#O#O#N#O#P#3#P#M#N#3#P#N#P#O#M#N#N#P#3#3#N#PaS#P#P#3aS#P#P#N#N#P#3#P#3#P#O#3aS#3#3#P#P#3#P#P#N#3"
"#P#PaS#3#P#PaS#P#N#P#P#P#P#N#P#P#P#3aS#P#N#3aS#N#P#P#O#P#P#P#P#3#P#O#P#P#N#PaS#P#P#O#O#N#3#N#N#N#M#M#3#P#P#N#O#P#P#P#O#N#P#N#P#3#PbVePnHfO#M.9",
"cScXaa#L#K#J#G#I#I#H#G#K#K#J#J#J#I#J#G#G#G#G#G#G#G#I#G#I#I#I#I#G#H#G#J#I#J#K#I#I#J#M#K#L#M#K#J#K#K#L#O#L#J#L#K#K#O#O#N#P#P#L#N#3#O#O#O#M#O#L#I#L#P#P#P#N#P#N#O#O#M#L#L#M#O#P#P#P#3#P#N#N#L#L#N#M#K#M#M#J#L#P#N#K#O#O#I#K#O#L#O#P#M#L#O#M#L#N#N#P#P#N#M#P#P#M#M#K#L#M#K#K#N#P#P#P#N#O#M#M#O#M#K#L#O#O#P#P#P#P#P#N#O#M#M#P#L#M#N#M#L#O#P#N#O#P#L#I#L#O#M#N#P#L#M#L#L#O#O#M#N#P#K#L#N#L#M#L#L#O#L#J#L#O#O#O#N#N#M#M#L#K#J#J#L#L#M#M#M#O#O#O#O#L#J#O#M#L#M#O#L#L#N#P#O#O#N#L#M#P#O#O#P#N#M#O#M#O#N#N#P#3#P#O#3#P#N#P#O#O#N#L#K#N#3"
"#N#N#P#O#O#O#O#M#M#M#O#O#N#P#N#P#P#N#P#L#M#P#O#M#N#L#L#M#P#N#M#N#O#L#M#M#M#O#P#L#L#M#L#M#O#O#N#N#L#K#N#L#L#L#J#L#L#I#J#O#O#O#N#O#LaBeQnHfO#M.9",
"cSmD#A#I#I#G#G#I#G#H#J#J#G#G#G#F#D#H#F#H#G#H#H#G#G#G#H#F#H#H#H#H#G#J#I#G#I#I#I#G#J#J#G#G#G#G#H#G#G#G#I#G#F#J#K#I#J#M#M#L#J#L#O#N#O#P#O#O#N#M#O#3#P#O#N#N#L#M#N#O#N#P#N#P#P#P#P#O#N#N#N#O#O#N#3#O#N#P#O#M#N#P#N#M#O#N#O#O#P#P#P#P#L#O#P#N#N#3a1aS#P#N#N#3#P#P#P#P#P#P#Pa1a0#3#P#P#P#O#P#P#P#3#P#Pa1#PaS#P#N#N#O#O#M#M#P#N#M#O#O#O#M#P#N#L#L#M#L#I#L#O#O#O#J#I#L#O#L#L#O#N#O#L#J#M#O#L#M#L#L#M#M#M#O#O#M#L#K#J#J#J#K#L#M#L#O#M#M#M#K#L#K#L#K#L#M#O#M#M#O#O#L#O#P#O#L#O#O#L#L#N#O#O#N#L#L#P#O#M#O#P#P#M#L#M#N#O#M#P#M#O#O#O#P#P#O"
"#O#O#M#M#O#O#O#N#O#N#P#N#N#N#M#M#O#M#L#O#P#O#L#O#M#M#L#N#N#L#L#L#L#K#M#O#M#O#L#J#M#N#L#M#N#P#O#L#K#M#O#M#O#O#M#M#L#L#P#N#O#O#L#K#KbWeOnHfO#M.9",
"cSnPf##K#N#M#L#O#M#M#N#M#L#O#M#L#L#L#L#J#J#G#L#L#K#K#I#J#K#J#J#K#K#I#K#K#K#L#L#M#O#O#M#M#L#N#O#O#P#P#O#M#PaS#P#P#PaS#3#P#3#P#3#3aSa0#3a0a0a0byaba1a0ababa0ababa0a1#3aSaba0a0a1#3a1aS#3aSaSa1aS#3#P#3#P#P#3aS#3#P#N#PaS#P#Pa1#P#N#Pa1aS#P#PaS#3#P#P#P#Pa1#Pa1aS#Pa0a0a0bya0a0ababa0a0bxa0aba0a0bxnWmKbxa0aba0a0a0a0a0a1a0a0a1a1#3aSa1a1#3#P#PaSaS#3a0a1#3#N#PaS#P#O#N#P#N#M#O#M#N#O#O#P#O#N#P#N#P#P#N#P#P#P#P#P#P#P#P#O#N#3#P#P#N#N#P#P#P#P#P#3#P#3#P#3#3#P#3aS#P#P#P#PaS#P#3a0a1#3#Pa1a1#P#3aSaS#P#P#P#P#3#PaSaS#PaSaS#3a0aS#P"
"aSaSaSaSa1aSaS#P#PaSa0aSaS#3#3#3#P#P#3#3#P#3#3#P#3#N#NaS#P#P#N#N#3nX#N#3#3#P#O#OaS#P#M#N#N#O#M#M#M#M#M#M#N#O#O#P#P#P#P#O#N#P#P#P#PbUfunHfO#M.9",
"cSnQbq#J#M#L#G#L#J#G#I#I#J#K#I#J#J#J#J#G#G#L#L#I#G#K#G#L#L#G#J#K#K#K#M#K#J#M#M#N#O#O#N#O#O#P#N#P#P#N#O#N#P#N#O#P#P#3#P#PaSaSaSaSa1a0aSa0a0aSaSa0a1a0a0a0a0a0a0a0a1a1bxbya0aba0a0bxa0a0a0ababababaSa0abababa0a0a0a1aba0a1a0aba1aSa1a0aSa1a0a0a0a0aba0bxbxbxbyaba0bxaba0abbybxbyababa0ababa0a0bxbwbxa0aba0abbya0a0a0a0a0aba1a1a0a0a0a0aSaSa1a1a0a1aSa0aS#P#3a1#3#P#3#3#3#3#P#3#3#3#3aSaS#P#P#P#N#N#P#N#P#P#N#P#N#N#P#N#P#3aS#P#P#P#PaS#P#P#P#3#3#P#3#N#P#3#3#P#P#P#3#P#3aS#NaSaS#P#P#P#3#N#N#P#N#P#N#P#P#P#P#PaSaS#PaSaS#P#3aSaS"
"a1aSaS#3aSaS#P#Pa1a0a0#3a1#3aSa1#3#3aSaS#3aS#3#PaSaSa1aS#3aS#3#PaS#P#Pa1aS#P#N#3#P#N#P#P#P#P#P#P#P#P#P#P#3#P#P#3#P#P#P#PaS#3#P#P#NbUfunHfO#M.9",
"cSncf##L#J#K#J#L#J#I#L#L#I#G#I#I#H#I#G#G#K#J#I#I#I#K#G#J#J#G#G#J#K#L#L#G#G#L#L#L#K#I#J#K#L#M#L#L#J#I#K#K#M#J#L#P#P#P#N#O#O#NaS#P#P#P#N#P#P#P#Pa0#3aS#P#3#3aSa0a0a0a0a1a0a0a0a0a0a0aSa1a1a0a0a0a1aSa1a0a1aS#3#PaS#3aSa1#3#3#P#N#N#3#P#O#P#3aSaS#P#P#P#3a0#P#3aSaSa1#P#PaSaS#P#P#P#P#L#O#N#M#3#P#N#N#O#P#M#N#N#L#N#P#P#P#N#M#L#N#P#O#N#M#L#O#O#N#N#M#L#L#L#M#O#L#O#P#N#P#M#M#L#L#N#O#L#M#L#L#L#J#J#M#J#K#J#J#J#I#K#J#L#N#L#L#K#L#L#K#O#K#K#L#M#M#M#L#J#L#N#O#L#L#L#O#M#N#N#O#O#L#L#L#M#M#L#O#P#P#P#N#O#O#P#3#P#P#P#N#P#N#O#P#P#N"
"#O#O#O#L#O#N#O#P#P#O#N#O#P#O#N#P#O#O#O#P#P#P#O#O#P#P#O#N#O#O#N#O#P#P#N#M#M#M#O#N#L#L#P#P#P#N#O#M#M#P#N#O#O#M#O#O#L#M#P#O#O#M#M#L#LaTePnHfO#M.9",
"cScXc7#F#G#G#F#G#G#H#G#F#H#G#G#G#G#G#H#H#I#H#G#G#G#J#G#G#H#F#H#G#G#G#F#H#I#J#G#G#I#G#I#K#J#J#G#I#I#K#J#I#K#K#O#O#P#N#M#M#O#P#N#M#M#N#O#M#N#O#N#P#P#P#P#3#P#P#3#Pa0#3#P#P#PaS#3#N#P#O#N#P#P#3#P#P#Pa1#3#P#P#N#P#3#3#P#N#P#O#P#3#P#P#P#3aSa1aS#P#N#O#P#3#N#O#3#P#O#N#N#P#P#P#P#P#P#P#N#3#N#Pa0#P#P#3#PaS#P#O#N#O#N#P#P#N#M#O#P#P#N#M#O#M#O#N#M#M#L#L#K#L#M#K#L#L#O#L#N#M#L#K#L#M#M#K#K#M#L#J#K#J#K#L#K#K#K#L#L#L#M#J#O#M#K#L#K#M#O#L#L#J#K#M#M#M#L#L#O#P#N#M#O#O#M#N#N#O#L#L#M#L#O#M#M#O#N#P#P#P#O#L#M#O#N#M#M#N#P#M#M#O#L#N#N#O"
"#O#O#O#O#N#M#O#P#M#M#M#M#P#O#M#M#L#M#O#O#O#L#L#O#P#M#L#O#M#M#O#O#M#L#L#L#L#O#L#L#M#P#O#P#N#M#M#L#O#O#O#O#N#O#M#O#O#O#O#O#O#N#P#N#PbUg1nHfO#M.9",
"cSnQc6#I#I#G#G#J#G#F#I#J#G#I#I#I#I#G#G#J#G#G#I#I#G#G#H#G#G#I#I#G#H#G#K#K#L#K#J#J#G#I#L#L#I#F#G#K#L#L#K#L#L#M#L#L#O#K#J#L#N#N#O#O#N#N#L#M#O#K#L#N#O#N#N#N#N#O#O#P#3#O#P#P#O#N#M#K#L#M#O#P#L#L#O#3#P#P#P#N#L#L#N#P#N#K#I#M#N#N#N#N#O#N#N#L#N#M#L#K#L#N#M#L#L#N#O#M#P#L#L#O#N#O#O#N#N#N#O#M#3#P#O#P#N#O#O#L#L#M#M#N#M#L#M#N#P#P#O#O#O#M#M#N#P#L#I#J#L#M#M#M#M#L#L#L#K#L#L#I#J#O#O#L#L#M#O#L#L#L#I#K#L#K#K#L#L#L#M#L#N#P#O#N#N#M#O#L#L#M#L#M#M#L#K#L#N#N#P#O#O#M#M#M#P#O#K#I#L#O#N#N#N#O#N#N#M#N#N#K#J#M#P#O#O#O#O#O#M#N#L#L#N#O#O"
"#N#O#N#N#O#O#P#N#M#P#O#M#O#L#L#M#M#O#M#L#L#O#N#P#N#N#M#M#M#O#N#L#I#G#L#O#O#M#O#M#M#L#L#N#L#I#I#L#M#K#L#M#O#L#M#M#J#K#L#M#M#O#M#M#MbWeOnHfO#M.9",
"cSnwbq#G#G#H#G#G#E#G#K#I#H#G#H#H#F#F#G#G#H#H#G#H#G#H#F#G#G#G#G#H#F#J#L#K#G#I#I#G#J#J#K#K#J#G#L#O#N#K#J#M#O#M#L#M#L#J#L#PaS#P#P#3#P#P#N#3#P#Oa0a1#P#N#P#N#M#L#P#3#O#M#N#M#O#O#L#L#O#O#N#M#J#L#P#P#M#L#M#L#L#N#O#M#O#L#L#P#P#N#M#O#N#P#M#M#N#K#I#L#N#N#L#N#M#L#M#L#N#J#M#P#N#L#L#M#L#K#K#O#O#L#L#L#L#L#J#G#K#L#L#L#J#I#L#N#L#G#K#K#G#L#L#K#L#J#G#K#N#M#K#J#L#L#K#I#K#J#G#G#L#O#L#K#L#L#K#I#L#K#J#M#M#J#J#K#J#I#G#K#M#L#L#L#L#L#L#J#J#L#L#L#M#L#L#P#P#M#L#M#L#L#N#M#O#O#L#M#P#P#P#M#O#P#P#M#L#O#L#K#L#P#N#M#N#M#O#M#M#N#L#O#3#N#O"
"#M#M#M#L#L#N#N#L#M#L#L#L#K#J#L#M#O#M#L#K#L#P#O#K#L#M#I#L#M#L#L#L#I#L#N#N#K#K#M#O#M#J#K#L#G#G#L#O#L#L#L#L#L#L#M#L#K#N#N#L#L#L#L#L#KbWePnHfO#M.9",
"cSncaa#J#L#L#K#K#J#O#M#J#I#K#K#I#I#K#L#JnY#J#G#G#G#G#I#K#J#G#J#L#J#L#L#J#H#I#I#G#L#K#I#J#J#J#L#O#L#I#J#L#M#G#K#O#M#L#N#P#L#K#O#L#L#L#K#K#G#K#N#L#I#K#M#L#J#L#PnZku#O#M#L#M#L#Khj#N#M#M#O#M#M#P#N#K#I#L#K#L#O#L#K#M#K#L#N#O#L#I#K#M#L#G#M#M#K#L#N#M#I#J#M#I#L#K#J#I#G#L#M#I#I#K#K#K#J#L#M#J#J#J#H#G#G#H#G#J#J#I#K#K#J#L#M#J#F#I#I#G#K#I#G#G#G#H#J#L#K#G#G#I#J#H#G#J#J#I#L#L#J#G#J#J#I#J#I#J#G#J#L#J#I#J#J#J#J#J#L#L#J#K#J#G#K#I#I#K#L#K#K#M#M#L#N#O#K#G#K#I#K#M#K#J#M#K#L#N#O#L#I#L#M#L#G#L#O#L#L#N#N#J#K#O#K#M#L#K#K#J#N#N#L#L"
"#L#M#L#K#M#O#L#L#L#J#K#K#J#L#O#M#L#M#N#O#M#P#M#I#J#M#K#L#L#J#K#M#K#M#P#On0#J#L#O#K#J#M#L#L#M#N#L#J#L#L#K#M#L#L#J#L#P#O#K#M#M#O#L#MbUg1nHfO#M.9",
"cS#c#Q#G#H#H#D#E#H#G#F#F#F#G#G#F#F#J#G#H#G#H#G#I#I#G#I#K#G#G#K#K#G#I#G#G#G#J#L#G#K#K#J#L#J#J#L#L#G#G#G#L#K#G#J#O#O#M#M#L#G#L#P#L#L#N#L#J#K#O#M#K#L#M#O#N#L#N#P#O#N#N#M#P#P#O#Oa1#3#P#N#3#O#M#N#M#L#M#3#M#O#P#O#P#N#O#M#N#L#J#J#L#M#K#J#O#O#M#M#L#I#I#N#N#L#M#O#J#I#M#M#J#I#K#L#M#K#K#P#L#L#L#L#K#O#L#J#L#N#L#K#M#L#J#I#K#I#I#L#L#G#L#K#J#K#I#G#K#J#G#H#H#J#J#F#I#K#J#I#K#G#H#G#J#I#G#I#I#G#G#J#I#G#G#I#G#J#G#I#L#J#J#J#G#K#M#J#I#L#M#J#K#O#K#I#K#J#I#K#N#L#K#O#L#L#L#K#L#O#L#J#J#L#M#K#J#O#P#N#O#O#K#J#O#N#L#L#L#L#J#K#M#K#I#K"
"#L#M#L#J#O#L#K#L#K#L#O#O#L#M#P#M#K#O#N#L#L#M#L#I#M#O#K#M#M#L#M#L#L#L#M#L#J#K#M#M#J#L#N#O#M#O#L#I#L#P#O#L#M#M#L#L#O#O#L#L#L#M#N#Labbzg1nHfO#M.9",
"bq#K#K#F#F#H#E#F#H#F#G#G#F#F#H#E#H#G#E#E#F#F#H#G#G#H#H#F#F#H#G#H#H#I#K#J#I#J#G#E#K#I#G#I#J#I#I#G#I#I#I#L#I#I#K#N#M#K#L#L#L#O#N#L#L#L#O#L#O#M#O#P#N#M#M#N#M#P#P#L#O#P#N#P#N#M#M#P#M#M#M#O#M#M#PaS#P#3aS#L#OaS#O#N#P#M#O#O#L#M#M#O#O#L#K#O#P#L#L#L#J#L#N#M#J#K#L#K#K#L#K#L#M#L#K#L#K#K#N#K#I#L#L#M#L#K#K#L#L#G#I#J#G#G#I#L#K#J#L#J#F#L#J#G#G#I#G#I#G#I#G#G#J#G#G#G#J#J#H#G#G#G#G#G#G#H#G#G#G#I#G#G#J#I#G#H#I#G#J#J#H#I#K#K#L#L#I#J#L#J#I#K#K#K#J#L#M#L#L#M#I#K#O#I#I#L#G#J#J#G#J#I#J#L#I#G#L#M#J#J#K#G#J#K#L#G#I#I#I#I#J#I#J#L#J"
"#I#J#G#G#L#G#F#K#J#L#K#K#G#I#K#G#G#I#I#H#K#M#L#K#M#L#H#L#L#G#J#J#G#I#G#I#I#G#J#J#H#I#L#L#G#K#J#I#K#L#K#J#J#L#K#L#K#K#M#M#L#K#L#ObUeOfFnHfO#M.9",
"#F#3#O#I#N#O#M#M#M#L#M#L#L#L#L#L#M#O#K#M#O#L#J#J#K#L#L#L#L#K#K#L#L#O#N#L#I#L#L#J#O#J#J#M#L#K#K#K#M#L#L#M#L#K#M#M#L#J#L#L#M#O#N#O#M#N#N#O#N#N#P#P#N#P#P#P#PaS#P#PaSaS#P#M#N#P#P#P#3#3#P#PaSa0aba0aSaSaS#Na1a1#PaSaS#P#P#O#P#3#N#PaS#P#PaSa1#P#P#P#P#3#3a1#3aSa1aS#P#3#Pa1#3#P#3a1#3a1a1#P#PaS#3#N#O#O#P#3#P#O#O#L#O#O#P#P#O#O#O#M#L#N#K#K#M#M#J#K#K#O#L#K#L#L#K#L#L#L#I#L#J#L#L#M#L#M#L#L#L#L#L#L#O#L#L#O#M#M#P#M#L#O#N#M#L#L#M#N#M#O#O#M#M#P#PaS#P#N#N#P#M#N#N#L#O#P#L#O#L#O#N#L#M#N#L#L#O#O#L#L#L#L#M#L#O#L#L#M#M#L#M#L#M#M#L"
"#L#O#L#M#O#K#K#M#M#K#J#J#K#K#K#L#L#K#L#L#N#N#M#L#M#L#J#O#L#K#O#M#K#K#K#L#L#K#L#L#K#L#L#L#K#L#L#M#O#O#O#M#O#O#O#N#M#M#N#O#O#P#NbyeNe1n1n2gh#L.9",
".7#Pa0bx#N#L#K#J#I#J#K#J#J#J#K#I#G#G#G#K#J#G#H#G#J#J#J#K#J#G#I#J#J#J#I#G#H#G#J#G#I#I#L#M#J#G#G#K#L#I#L#M#K#J#L#O#M#K#L#L#M#O#P#P#P#N#O#O#N#N#P#3#N#P#3#P#P#P#N#PaS#3#N#P#3a1a1aSa0#P#PaSaSa0#3#P#N#P#P#P#P#P#Pa0#3#O#N#P#P#P#N#3aS#P#PaSa1aS#3#3aSa1a1a0aS#3#3#3#3#P#3a1#3#P#3#3#P#3#P#O#3#O#M#L#O#P#P#P#P#O#L#O#N#O#M#L#K#K#L#L#J#L#J#M#M#J#G#I#K#K#I#I#L#K#I#K#L#L#J#K#J#L#L#M#L#L#K#K#K#K#L#L#O#M#M#M#O#L#L#L#O#O#L#K#L#O#P#P#P#3#M#M#N#P#P#P#O#O#M#P#N#O#N#PaS#P#M#M#N#P#N#M#P#P#O#O#N#N#M#M#M#O#O#N#P#N#O#L#N#O#M#M#N#N#O"
"#N#P#O#M#L#L#O#M#L#L#M#M#N#O#P#O#L#M#N#P#N#O#M#L#O#O#L#O#O#N#P#M#L#L#M#O#M#O#P#O#M#O#P#N#O#O#O#P#P#3#3#P#N#N#P#P#P#Pa1#P#3aSbwb#ePn3n4n5fv#Hm5",
".7bxfibXbxab#3#L#J#L#L#K#J#L#J#H#G#I#K#L#G#G#J#K#J#I#I#J#G#I#L#J#G#G#I#G#H#G#I#G#I#G#K#L#G#G#K#K#K#K#L#L#G#J#L#L#J#K#J#J#L#L#M#J#G#G#L#M#L#M#M#N#L#O#O#L#J#K#M#P#M#J#L#P#N#L#O#N#L#K#N#P#O#O#M#N#L#K#O#O#M#O#O#P#O#L#O#P#N#N#P#P#O#M#N#P#M#M#N#O#N#O#P#O#J#J#L#O#O#L#L#O#M#L#M#M#K#J#K#L#L#G#I#I#L#L#K#J#J#G#G#K#J#G#G#G#G#F#G#I#H#G#G#J#I#F#G#I#G#G#G#I#I#G#G#I#G#G#I#I#I#J#J#J#G#H#G#J#J#I#I#L#L#K#L#L#K#I#J#L#M#L#I#J#L#M#M#M#M#M#L#O#N#O#M#M#M#L#L#N#O#O#O#O#P#N#M#O#P#N#N#P#P#O#M#N#N#N#O#N#O#N#O#P#O#L#L#L#P#P#N#O#P#P#N"
"#P#P#M#L#N#P#P#M#M#N#P#N#N#N#N#O#M#P#P#O#M#N#P#L#M#N#O#N#O#P#P#M#O#P#P#N#P#P#3#N#N#P#P#P#P#P#N#P#PaS#P#O#O#PaS#3aSa1a0aSbWn6b0ePfvn7n8n9fif#cX",
".7cUb1fvfNb#bXa1#O#L#L#K#M#L#J#G#I#K#N#K#G#L#M#L#I#J#I#I#G#I#L#J#G#J#I#G#G#K#K#G#K#J#L#L#G#I#L#L#L#M#M#K#I#M#O#L#L#O#O#N#P#N#M#L#M#O#P#3#N#3#3#P#Pa1aS#N#O#3a0a1#P#Pa0a0a1#P#P#3#N#N#3a0aSaSa1#3#O#Pa0#P#PaSa0abaS#Pa1a0aSa1a0a1#PaSa1aS#P#3a1#PaSaS#P#3#P#P#P#3#3#P#3#P#O#P#3#P#L#L#N#3#O#L#M#P#N#N#M#O#M#K#K#O#L#L#L#L#I#G#L#K#G#J#K#L#L#I#I#K#L#L#L#L#K#I#L#L#J#J#L#K#K#L#L#L#L#L#M#L#M#O#O#N#L#M#N#N#M#L#O#3#P#O#M#P#3#P#O#O#N#N#O#N#P#N#N#P#N#L#N#P#N#O#N#PaS#N#M#N#P#P#P#P#P#O#O#P#P#M#N#P#N#N#O#O#O#O#N#N#M#O#O#P#N#O#O"
"#N#N#M#L#P#P#P#M#N#P#P#N#M#O#O#M#M#P#O#M#O#P#M#L#P#N#L#O#M#P#P#L#L#P#P#N#P#P#N#O#N#P#N#O#P#N#O#3#P#N#N#P#P#P#3#3aSa0aSbwa2ePfugBo.o#oahobV#icU",
".7cRnSeZobj.bzaTaTbGbGbGbXbXbUbUbGbjbGbUbUbjbGbXbGbGbUbUbUbUbXbUbUbGbUaTbUbGaTaTbGbGbGbGaTbXbjbGbGbjbGbUbGbzbzbGbzb#bjbNbzbGbNa2bzbzbzbYbzbYbYb#bzbYb#bNbYhOf8a2a2bZhObZbZbZbZbZbYbYbZa2bYa2bZbzbzbYbYbjbYa2bZbZbYb#bZbZbZf8bZbYbYbZhObZa2f8hObYbZbZa2f8hObZbZbZhObZbZhObZa2a2bYbYbZbZa2b#b#bYbZbYbYbYbYb#bzbNbzbzbjbzbNbGbjbNbXbXbjbjbjbGbUbGbNbjbNbNbjbXbXbjbGbXbGbjbGbGbGbGbGbNbGbGbGbNbNbNbNbNbjbjbzbjbNbYbYbNbjbNbzbzbzbzbYbYbzbzb#b#bzbYbYb#bzbYbzbjbzbYbYbYbzbjbYb#b#bYbYbzbNb#bYbzbzbYbzbNbzbYbjbYb#bNbzbzb#bzbzb#bzbN"
"bzbNbjb#bYb#bNbNb#ocbzbzb#b#bzbNbzb#bzbzbYbYbNbzbYbzbjb#b#b#b#bjbza2bYbYbYbYbzbzbYbYb#bYbZb#bzbYbzbzbZbYb#bYbYbYa2bZa2eNeOfuodoen4ofogg1#QnccR",
".7#z.8#kghohohgHePg1ePeQeQeOeQeQeOeQePePeOePeOeOeOeOeOePePeOeOeOePeOeQePePfNeOePg1eOeOeOeQePg1eOeOeOeOeOePg1g1eOfug1ePg1f.g1fufug1ePfuf.g1f.f.g1g1f.f.eOg1fufufif.f.fif.g1f.g1f.f.f.fug1fuf.g1fufig1ePfug0fif.f.g1g1g0fufufifug1fufif.fuf.g0f.fug0f.f.g0g1ePfufufuf.f.g1eOePg1eQfNePfNeQeOfNfNeQfNeNfNfNeQeQfNb1b1fNfNb1fNeNb0b1eQfNeNeNb1f8b1eNb1b1eNb0b0b1fNb1b1eNfNb1b1eQb1eNfNb1b1eNfNeNeQfNb1eNeNfNb1fNeOfNeOfNfNfNfNfNeOeQeOePePeOeOeOePg1ePg1ePeOg1fug1g1g1eOeOg1g1eOg1ePeOeOg1fueOePg1ePeOg1g1eOg1eOeQeOePePePg1eOeOeQ"
"eOeQfNePeOePeOeOeOePeOeOePeOePePePeOeOeOePeOePg1eQeQg1g1g1g1eOeQePg1ePePg1ePeOePfug1g1g1g1eOg1f.g1g1fuePePg1fufuf.f.g1g1oio.ojn7okn9eY#N#ecU#z",
".7.7cRnPbqbjoln1omonojooopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopop"
"opopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopopoon4oqoaore2ab#mnw#z.7",
".7.7#zcSm5c5bxfaj.osotouovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovov"
"ovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovovodowoxgVeQ#O#mcX#1.7.7",
".7.7.7#z#1nQ#i#EbGfagBgVhohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohoho"
"hohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohohofOfRf.aBaa#dcW#1#z.7.7",
".7.7.7.7#zcQcVnS#mfP#I#O#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N"
"#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#N#M#G#2#gnncT#z.7.7.7.7",
".7.7.7.7.7.7#z#1cVnQnS#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#."
"#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#..9m5cXcUcQ#z.7.7.7.7.7"};


/*
 *  Constructs a Login_Dlg as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 */
Login_Dlg::Login_Dlg( QWidget* parent, const char* name, WFlags fl )
    : QWidget( parent, name, fl ),
      image0( (const char **) img0_login_dlg ),
      image1( (const char **) img1_login_dlg ),
      image2( (const char **) img2_login_dlg ),
      image3( (const char **) img3_login_dlg ),
      image4( (const char **) img4_login_dlg ),
      image5( (const char **) img5_login_dlg ),
      image6( (const char **) img6_login_dlg ),
      image7( (const char **) img7_login_dlg ),
      image8( (const char **) img8_login_dlg ),
      image9( (const char **) img9_login_dlg ),
      image10( (const char **) img10_login_dlg )
{
    if ( !name )
	setName( "Login_Dlg" );
    setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)1, (QSizePolicy::SizeType)1, 0, 0, sizePolicy().hasHeightForWidth() ) );
    setMinimumSize( QSize( 510, 310 ) );
    setSizeIncrement( QSize( 0, 0 ) );
    setPaletteForegroundColor( QColor( 255, 255, 255 ) );
    setPaletteBackgroundColor( QColor( 239, 239, 239 ) );
    Login_DlgLayout = new QGridLayout( this, 1, 1, 0, 0, "Login_DlgLayout"); 

    frame5 = new QFrame( this, "frame5" );
    frame5->setMinimumSize( QSize( 51, 54 ) );
    frame5->setMaximumSize( QSize( 32767, 54 ) );
    frame5->setPaletteForegroundColor( QColor( 255, 255, 255 ) );
    frame5->setPaletteBackgroundPixmap( image0 );
    frame5->setBackgroundOrigin( QFrame::WidgetOrigin );
    frame5->setFrameShape( QFrame::NoFrame );
    frame5->setFrameShadow( QFrame::Plain );
    frame5->setLineWidth( 0 );
    frame5->setMargin( 0 );
    frame5->setMidLineWidth( 0 );
    frame5Layout = new QGridLayout( frame5, 1, 1, 0, 0, "frame5Layout"); 

    layout8 = new QVBoxLayout( 0, 0, 0, "layout8"); 

    configButtonPlaceHolder = new QLabel( frame5, "configButtonPlaceHolder" );
    configButtonPlaceHolder->setEnabled( TRUE );
    configButtonPlaceHolder->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, configButtonPlaceHolder->sizePolicy().hasHeightForWidth() ) );
    configButtonPlaceHolder->setMinimumSize( QSize( 44, 40 ) );
    configButtonPlaceHolder->setMaximumSize( QSize( 44, 40 ) );
    configButtonPlaceHolder->setBackgroundMode( QLabel::PaletteBackground );
    configButtonPlaceHolder->setBackgroundOrigin( QLabel::WidgetOrigin );
    configButtonPlaceHolder->setFrameShape( QLabel::NoFrame );
    configButtonPlaceHolder->setFrameShadow( QLabel::Plain );
    configButtonPlaceHolder->setLineWidth( 0 );
    configButtonPlaceHolder->setMargin( 0 );
    configButtonPlaceHolder->setMidLineWidth( 0 );
    configButtonPlaceHolder->setTextFormat( QLabel::PlainText );
    configButtonPlaceHolder->setPixmap( image1 );
    configButtonPlaceHolder->setScaledContents( FALSE );
    configButtonPlaceHolder->setAlignment( int( QLabel::AlignTop ) );
    configButtonPlaceHolder->setIndent( 0 );
    layout8->addWidget( configButtonPlaceHolder );
    spacer13 = new QSpacerItem( 20, 13, QSizePolicy::Minimum, QSizePolicy::Fixed );
    layout8->addItem( spacer13 );

    frame5Layout->addMultiCellLayout( layout8, 0, 1, 2, 2 );

    layout9 = new QVBoxLayout( 0, 0, 0, "layout9"); 

    pixmapLabel1 = new QLabel( frame5, "pixmapLabel1" );
    pixmapLabel1->setMinimumSize( QSize( 240, 54 ) );
    pixmapLabel1->setMaximumSize( QSize( 240, 54 ) );
    pixmapLabel1->setPixmap( image2 );
    pixmapLabel1->setScaledContents( FALSE );
    layout9->addWidget( pixmapLabel1 );
    spacer14 = new QSpacerItem( 20, 16, QSizePolicy::Minimum, QSizePolicy::Expanding );
    layout9->addItem( spacer14 );

    frame5Layout->addMultiCellLayout( layout9, 0, 1, 0, 1 );
    spacer5 = new QSpacerItem( 260, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame5Layout->addItem( spacer5, 1, 1 );

    Login_DlgLayout->addWidget( frame5, 1, 0 );

    textLabel1 = new QLabel( this, "textLabel1" );
    textLabel1->setMinimumSize( QSize( 510, 19 ) );
    textLabel1->setMaximumSize( QSize( 32767, 19 ) );
    textLabel1->setPaletteBackgroundPixmap( image3 );

    Login_DlgLayout->addWidget( textLabel1, 0, 0 );

    frame6_2 = new QFrame( this, "frame6_2" );
    frame6_2->setMinimumSize( QSize( 510, 39 ) );
    frame6_2->setMaximumSize( QSize( 32767, 39 ) );
    frame6_2->setPaletteBackgroundPixmap( image4 );
    frame6_2->setFrameShape( QFrame::NoFrame );
    frame6_2->setFrameShadow( QFrame::Plain );
    frame6_2->setLineWidth( 0 );
    frame6_2Layout = new QGridLayout( frame6_2, 1, 1, 0, 0, "frame6_2Layout"); 

    layout4 = new QVBoxLayout( 0, 0, 0, "layout4"); 
    spacer7 = new QSpacerItem( 20, 22, QSizePolicy::Minimum, QSizePolicy::Fixed );
    layout4->addItem( spacer7 );

    exitButtonPlaceHolder = new QLabel( frame6_2, "exitButtonPlaceHolder" );
    exitButtonPlaceHolder->setMinimumSize( QSize( 42, 19 ) );
    exitButtonPlaceHolder->setMaximumSize( QSize( 42, 19 ) );
    exitButtonPlaceHolder->setBackgroundOrigin( QLabel::WidgetOrigin );
    exitButtonPlaceHolder->setLineWidth( 0 );
    exitButtonPlaceHolder->setMargin( 0 );
    exitButtonPlaceHolder->setMidLineWidth( 0 );
    exitButtonPlaceHolder->setPixmap( image5 );
    exitButtonPlaceHolder->setScaledContents( FALSE );
    exitButtonPlaceHolder->setAlignment( int( QLabel::AlignBottom ) );
    exitButtonPlaceHolder->setIndent( -1 );
    layout4->addWidget( exitButtonPlaceHolder );

    frame6_2Layout->addLayout( layout4, 0, 1 );

    layout6 = new QVBoxLayout( 0, 0, 0, "layout6"); 
    spacer8_2 = new QSpacerItem( 20, 0, QSizePolicy::Minimum, QSizePolicy::Fixed );
    layout6->addItem( spacer8_2 );

    aboutButtonPlaceHolder = new QLabel( frame6_2, "aboutButtonPlaceHolder" );
    aboutButtonPlaceHolder->setMinimumSize( QSize( 39, 39 ) );
    aboutButtonPlaceHolder->setMaximumSize( QSize( 39, 39 ) );
    aboutButtonPlaceHolder->setPixmap( image6 );
    aboutButtonPlaceHolder->setScaledContents( FALSE );
    layout6->addWidget( aboutButtonPlaceHolder );

    frame6_2Layout->addLayout( layout6, 0, 2 );
    spacer5_2 = new QSpacerItem( 440, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame6_2Layout->addItem( spacer5_2, 0, 0 );

    Login_DlgLayout->addWidget( frame6_2, 4, 0 );

    textLabel1_2 = new QLabel( this, "textLabel1_2" );
    textLabel1_2->setMinimumSize( QSize( 510, 20 ) );
    textLabel1_2->setMaximumSize( QSize( 32767, 20 ) );
    textLabel1_2->setPaletteBackgroundPixmap( image7 );
    textLabel1_2->setIndent( -1 );

    Login_DlgLayout->addWidget( textLabel1_2, 5, 0 );

    frame20 = new QFrame( this, "frame20" );
    frame20->setMinimumSize( QSize( 0, 1 ) );
    frame20->setPaletteForegroundColor( QColor( 255, 255, 255 ) );
    frame20->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    frame20->setFrameShape( QFrame::NoFrame );
    frame20->setFrameShadow( QFrame::Plain );

    Login_DlgLayout->addWidget( frame20, 3, 0 );

    frame5_2 = new QFrame( this, "frame5_2" );
    frame5_2->setMinimumSize( QSize( 510, 220 ) );
    frame5_2->setMaximumSize( QSize( 32767, 220 ) );
    frame5_2->setPaletteBackgroundPixmap( image8 );
    frame5_2->setFrameShape( QFrame::NoFrame );
    frame5_2->setFrameShadow( QFrame::Plain );
    frame5_2->setLineWidth( 0 );
    frame5_2Layout = new QGridLayout( frame5_2, 1, 1, 0, 0, "frame5_2Layout"); 
    spacer11 = new QSpacerItem( 20, 5, QSizePolicy::Minimum, QSizePolicy::Fixed );
    frame5_2Layout->addItem( spacer11, 0, 2 );

    pixmapLabel3 = new QLabel( frame5_2, "pixmapLabel3" );
    pixmapLabel3->setMinimumSize( QSize( 97, 66 ) );
    pixmapLabel3->setMaximumSize( QSize( 97, 66 ) );
    pixmapLabel3->setBackgroundOrigin( QLabel::AncestorOrigin );
    pixmapLabel3->setPixmap( image9 );
    pixmapLabel3->setScaledContents( FALSE );

    frame5_2Layout->addWidget( pixmapLabel3, 2, 4 );
    spacer39 = new QSpacerItem( 10, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame5_2Layout->addItem( spacer39, 2, 3 );

    pixmapLabel4 = new QLabel( frame5_2, "pixmapLabel4" );
    pixmapLabel4->setMinimumSize( QSize( 82, 60 ) );
    pixmapLabel4->setMaximumSize( QSize( 82, 60 ) );
    pixmapLabel4->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    pixmapLabel4->setScaledContents( TRUE );

    frame5_2Layout->addWidget( pixmapLabel4, 2, 0 );
    spacer40 = new QSpacerItem( 95, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame5_2Layout->addItem( spacer40, 2, 1 );

    loginFrame = new QFrame( frame5_2, "loginFrame" );
    loginFrame->setMinimumSize( QSize( 326, 198 ) );
    loginFrame->setMaximumSize( QSize( 326, 198 ) );
    loginFrame->setPaletteBackgroundPixmap( image10 );
    loginFrame->setBackgroundOrigin( QFrame::WidgetOrigin );
    loginFrame->setFrameShape( QFrame::NoFrame );
    loginFrame->setFrameShadow( QFrame::Plain );
    loginFrame->setLineWidth( 0 );

    passwordLabel = new QLabel( loginFrame, "passwordLabel" );
    passwordLabel->setGeometry( QRect( 104, 64, 68, 16 ) );
    passwordLabel->setPaletteForegroundColor( QColor( 0, 0, 0 ) );
    passwordLabel->setBackgroundOrigin( QLabel::AncestorOrigin );

    userLabel = new QLabel( loginFrame, "userLabel" );
    userLabel->setGeometry( QRect( 104, 36, 65, 18 ) );
    userLabel->setPaletteForegroundColor( QColor( 0, 0, 0 ) );
    userLabel->setBackgroundOrigin( QLabel::AncestorOrigin );

    Password = new QLineEdit( loginFrame, "Password" );
    Password->setGeometry( QRect( 174, 62, 140, 18 ) );
    Password->setPaletteForegroundColor( QColor( 0, 0, 0 ) );
    Password->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    QPalette pal;
    QColorGroup cg;
    cg.setColor( QColorGroup::Foreground, black );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 0, 0, 128) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, black );
    cg.setColor( QColorGroup::LinkVisited, black );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, black );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 0, 0, 128) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 255) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 255, 0, 255) );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, white );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 127, 127, 127) );
    cg.setColor( QColorGroup::Mid, QColor( 170, 170, 170) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, white );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 0, 0, 128) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 255) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 255, 0, 255) );
    pal.setDisabled( cg );
    Password->setPalette( pal );
    Password->setFrameShape( QLineEdit::LineEditPanel );
    Password->setFrameShadow( QLineEdit::Sunken );
    Password->setLineWidth( 2 );
    Password->setMargin( 0 );
    Password->setMidLineWidth( 0 );
    Password->setFrame( TRUE );
    Password->setEchoMode( QLineEdit::Password );
    Password->setDragEnabled( FALSE );

    nickName = new QComboBox( FALSE, loginFrame, "nickName" );
    nickName->setGeometry( QRect( 174, 35, 140, 18 ) );
    nickName->setPaletteBackgroundColor( QColor( 255, 255, 255 ) );
    cg.setColor( QColorGroup::Foreground, black );
    cg.setColor( QColorGroup::Button, QColor( 238, 234, 222) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, QColor( 246, 244, 238) );
    cg.setColor( QColorGroup::Dark, QColor( 119, 117, 111) );
    cg.setColor( QColorGroup::Mid, QColor( 158, 155, 147) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 190, 192, 203) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 0, 0, 128) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, black );
    cg.setColor( QColorGroup::LinkVisited, black );
    pal.setActive( cg );
    cg.setColor( QColorGroup::Foreground, black );
    cg.setColor( QColorGroup::Button, QColor( 238, 234, 222) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 119, 117, 111) );
    cg.setColor( QColorGroup::Mid, QColor( 158, 155, 147) );
    cg.setColor( QColorGroup::Text, black );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, black );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 190, 192, 203) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 0, 0, 128) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 192) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 128, 0, 128) );
    pal.setInactive( cg );
    cg.setColor( QColorGroup::Foreground, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Button, QColor( 238, 234, 222) );
    cg.setColor( QColorGroup::Light, white );
    cg.setColor( QColorGroup::Midlight, white );
    cg.setColor( QColorGroup::Dark, QColor( 119, 117, 111) );
    cg.setColor( QColorGroup::Mid, QColor( 158, 155, 147) );
    cg.setColor( QColorGroup::Text, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::BrightText, white );
    cg.setColor( QColorGroup::ButtonText, QColor( 128, 128, 128) );
    cg.setColor( QColorGroup::Base, white );
    cg.setColor( QColorGroup::Background, QColor( 190, 192, 203) );
    cg.setColor( QColorGroup::Shadow, black );
    cg.setColor( QColorGroup::Highlight, QColor( 0, 0, 128) );
    cg.setColor( QColorGroup::HighlightedText, white );
    cg.setColor( QColorGroup::Link, QColor( 0, 0, 192) );
    cg.setColor( QColorGroup::LinkVisited, QColor( 128, 0, 128) );
    pal.setDisabled( cg );
    nickName->setPalette( pal );
    nickName->setEditable( TRUE );
    nickName->setSizeLimit( 40 );
    nickName->setInsertionPolicy( QComboBox::AtBottom );
    nickName->setAutoCompletion( TRUE );
    nickName->setDuplicatesEnabled( FALSE );

    SavePwdChk = new QCheckBox( loginFrame, "SavePwdChk" );
    SavePwdChk->setGeometry( QRect( 295, 142, 20, 21 ) );
    SavePwdChk->setPaletteForegroundColor( QColor( 255, 255, 255 ) );
    SavePwdChk->setBackgroundOrigin( QCheckBox::AncestorOrigin );
    QFont SavePwdChk_font(  SavePwdChk->font() );
    SavePwdChk->setFont( SavePwdChk_font ); 

    savePasswordLabel = new QLabel( loginFrame, "savePasswordLabel" );
    savePasswordLabel->setGeometry( QRect( 170, 143, 120, 18 ) );
    savePasswordLabel->setPaletteForegroundColor( QColor( 0, 0, 0 ) );
    savePasswordLabel->setBackgroundOrigin( QLabel::ParentOrigin );

    frame5_2Layout->addMultiCellWidget( loginFrame, 1, 2, 2, 2 );
    spacer9_2 = new QSpacerItem( 176, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame5_2Layout->addMultiCell( spacer9_2, 1, 1, 3, 4 );
    spacer9 = new QSpacerItem( 138, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
    frame5_2Layout->addMultiCell( spacer9, 1, 1, 0, 1 );

    Login_DlgLayout->addWidget( frame5_2, 2, 0 );
    languageChange();
    resize( QSize(510, 346).expandedTo(minimumSizeHint()) );
    clearWState( WState_Polished );

    // tab order
    setTabOrder( nickName, Password );
    setTabOrder( Password, SavePwdChk );
}

/*
 *  Destroys the object and frees any allocated resources
 */
Login_Dlg::~Login_Dlg()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void Login_Dlg::languageChange()
{
    setCaption( ( "Openc6 - Login" ) );
    textLabel1->setText( QString::null );
    textLabel1_2->setText( QString::null );
    passwordLabel->setText( ( "Password " ) );
    userLabel->setText( ( "User" ) );
    QToolTip::add( Password, ( "Inserisci la tua password " ) );
    QToolTip::add( nickName, ( "Inserisci la tua chiave unica o il nickname" ) );
    SavePwdChk->setText( QString::null );
    QToolTip::add( SavePwdChk, ( "Salva la password in automatico" ) );
    savePasswordLabel->setText( ( "Salva password" ) );
    QToolTip::add( savePasswordLabel, ( "Salva la password in automatico" ) );
}

#include "login_dlg.moc"
